/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_dphd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (dp|hd) integrals */

void d12hrr_order_dphd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][7][11] = int_stack + 0;
 Libderiv->deriv_classes[3][7][10] = int_stack + 360;
 Libderiv->deriv_classes[3][7][9] = int_stack + 720;
 Libderiv->deriv_classes[3][7][8] = int_stack + 1080;
 Libderiv->deriv_classes[3][7][7] = int_stack + 1440;
 Libderiv->dvrr_classes[3][6] = int_stack + 1800;
 Libderiv->deriv_classes[3][7][6] = int_stack + 2080;
 Libderiv->deriv_classes[3][7][2] = int_stack + 2440;
 Libderiv->deriv_classes[3][7][1] = int_stack + 2800;
 Libderiv->dvrr_classes[2][7] = int_stack + 3160;
 Libderiv->deriv_classes[3][7][0] = int_stack + 3376;
 Libderiv->deriv2_classes[2][5][143] = int_stack + 3736;
 Libderiv->deriv2_classes[2][6][143] = int_stack + 3862;
 Libderiv->deriv2_classes[2][7][143] = int_stack + 4030;
 Libderiv->deriv2_classes[3][5][143] = int_stack + 4246;
 Libderiv->deriv2_classes[3][6][143] = int_stack + 4456;
 Libderiv->deriv2_classes[3][7][143] = int_stack + 4736;
 Libderiv->deriv2_classes[2][5][131] = int_stack + 5096;
 Libderiv->deriv2_classes[2][6][131] = int_stack + 5222;
 Libderiv->deriv2_classes[2][7][131] = int_stack + 5390;
 Libderiv->deriv2_classes[3][5][131] = int_stack + 5606;
 Libderiv->deriv2_classes[3][6][131] = int_stack + 5816;
 Libderiv->deriv2_classes[3][7][131] = int_stack + 6096;
 Libderiv->deriv2_classes[2][5][130] = int_stack + 6456;
 Libderiv->deriv2_classes[2][6][130] = int_stack + 6582;
 Libderiv->deriv2_classes[2][7][130] = int_stack + 6750;
 Libderiv->deriv2_classes[3][5][130] = int_stack + 6966;
 Libderiv->deriv2_classes[3][6][130] = int_stack + 7176;
 Libderiv->deriv2_classes[3][7][130] = int_stack + 7456;
 Libderiv->deriv2_classes[2][5][119] = int_stack + 7816;
 Libderiv->deriv2_classes[2][6][119] = int_stack + 7942;
 Libderiv->deriv2_classes[2][7][119] = int_stack + 8110;
 Libderiv->deriv2_classes[3][5][119] = int_stack + 8326;
 Libderiv->deriv2_classes[3][6][119] = int_stack + 8536;
 Libderiv->deriv2_classes[3][7][119] = int_stack + 8816;
 Libderiv->deriv2_classes[2][5][118] = int_stack + 9176;
 Libderiv->deriv2_classes[2][6][118] = int_stack + 9302;
 Libderiv->deriv2_classes[2][7][118] = int_stack + 9470;
 Libderiv->deriv2_classes[3][5][118] = int_stack + 9686;
 Libderiv->deriv2_classes[3][6][118] = int_stack + 9896;
 Libderiv->deriv2_classes[3][7][118] = int_stack + 10176;
 Libderiv->deriv2_classes[2][5][117] = int_stack + 10536;
 Libderiv->deriv2_classes[2][6][117] = int_stack + 10662;
 Libderiv->deriv2_classes[2][7][117] = int_stack + 10830;
 Libderiv->deriv2_classes[3][5][117] = int_stack + 11046;
 Libderiv->deriv2_classes[3][6][117] = int_stack + 11256;
 Libderiv->deriv2_classes[3][7][117] = int_stack + 11536;
 Libderiv->deriv2_classes[2][5][107] = int_stack + 11896;
 Libderiv->deriv2_classes[2][6][107] = int_stack + 12022;
 Libderiv->deriv2_classes[2][7][107] = int_stack + 12190;
 Libderiv->deriv2_classes[3][5][107] = int_stack + 12406;
 Libderiv->deriv2_classes[3][6][107] = int_stack + 12616;
 Libderiv->deriv2_classes[3][7][107] = int_stack + 12896;
 Libderiv->deriv2_classes[2][5][106] = int_stack + 13256;
 Libderiv->deriv2_classes[2][6][106] = int_stack + 13382;
 Libderiv->deriv2_classes[2][7][106] = int_stack + 13550;
 Libderiv->deriv2_classes[3][5][106] = int_stack + 13766;
 Libderiv->deriv2_classes[3][6][106] = int_stack + 13976;
 Libderiv->deriv2_classes[3][7][106] = int_stack + 14256;
 Libderiv->deriv2_classes[2][5][105] = int_stack + 14616;
 Libderiv->deriv2_classes[2][6][105] = int_stack + 14742;
 Libderiv->deriv2_classes[2][7][105] = int_stack + 14910;
 Libderiv->deriv2_classes[3][5][105] = int_stack + 15126;
 Libderiv->deriv2_classes[3][6][105] = int_stack + 15336;
 Libderiv->deriv2_classes[3][7][105] = int_stack + 15616;
 Libderiv->deriv2_classes[2][5][104] = int_stack + 15976;
 Libderiv->deriv2_classes[2][6][104] = int_stack + 16102;
 Libderiv->deriv2_classes[2][7][104] = int_stack + 16270;
 Libderiv->deriv2_classes[3][5][104] = int_stack + 16486;
 Libderiv->deriv2_classes[3][6][104] = int_stack + 16696;
 Libderiv->deriv2_classes[3][7][104] = int_stack + 16976;
 Libderiv->deriv2_classes[2][5][95] = int_stack + 17336;
 Libderiv->deriv2_classes[2][6][95] = int_stack + 17462;
 Libderiv->deriv2_classes[2][7][95] = int_stack + 17630;
 Libderiv->deriv2_classes[3][5][95] = int_stack + 17846;
 Libderiv->deriv2_classes[3][6][95] = int_stack + 18056;
 Libderiv->deriv2_classes[3][7][95] = int_stack + 18336;
 Libderiv->deriv2_classes[2][5][94] = int_stack + 18696;
 Libderiv->deriv2_classes[2][6][94] = int_stack + 18822;
 Libderiv->deriv2_classes[2][7][94] = int_stack + 18990;
 Libderiv->deriv2_classes[3][5][94] = int_stack + 19206;
 Libderiv->deriv2_classes[3][6][94] = int_stack + 19416;
 Libderiv->deriv2_classes[3][7][94] = int_stack + 19696;
 Libderiv->deriv2_classes[2][5][93] = int_stack + 20056;
 Libderiv->deriv2_classes[2][6][93] = int_stack + 20182;
 Libderiv->deriv2_classes[2][7][93] = int_stack + 20350;
 Libderiv->deriv2_classes[3][5][93] = int_stack + 20566;
 Libderiv->deriv2_classes[3][6][93] = int_stack + 20776;
 Libderiv->deriv2_classes[3][7][93] = int_stack + 21056;
 Libderiv->deriv2_classes[2][5][92] = int_stack + 21416;
 Libderiv->deriv2_classes[2][6][92] = int_stack + 21542;
 Libderiv->deriv2_classes[2][7][92] = int_stack + 21710;
 Libderiv->deriv2_classes[3][5][92] = int_stack + 21926;
 Libderiv->deriv2_classes[3][6][92] = int_stack + 22136;
 Libderiv->deriv2_classes[3][7][92] = int_stack + 22416;
 Libderiv->deriv2_classes[2][5][91] = int_stack + 22776;
 Libderiv->deriv2_classes[2][6][91] = int_stack + 22902;
 Libderiv->deriv2_classes[2][7][91] = int_stack + 23070;
 Libderiv->deriv2_classes[3][5][91] = int_stack + 23286;
 Libderiv->deriv2_classes[3][6][91] = int_stack + 23496;
 Libderiv->deriv2_classes[3][7][91] = int_stack + 23776;
 Libderiv->deriv2_classes[2][5][83] = int_stack + 24136;
 Libderiv->deriv2_classes[2][6][83] = int_stack + 24262;
 Libderiv->deriv2_classes[2][7][83] = int_stack + 24430;
 Libderiv->deriv_classes[3][5][11] = int_stack + 24646;
 Libderiv->deriv2_classes[3][5][83] = int_stack + 24856;
 Libderiv->deriv_classes[3][6][11] = int_stack + 25066;
 Libderiv->deriv2_classes[3][6][83] = int_stack + 25346;
 Libderiv->deriv2_classes[3][7][83] = int_stack + 25626;
 Libderiv->deriv2_classes[2][5][82] = int_stack + 25986;
 Libderiv->deriv2_classes[2][6][82] = int_stack + 26112;
 Libderiv->deriv2_classes[2][7][82] = int_stack + 26280;
 Libderiv->deriv_classes[3][5][10] = int_stack + 26496;
 Libderiv->deriv2_classes[3][5][82] = int_stack + 26706;
 Libderiv->deriv_classes[3][6][10] = int_stack + 26916;
 Libderiv->deriv2_classes[3][6][82] = int_stack + 27196;
 Libderiv->deriv2_classes[3][7][82] = int_stack + 27476;
 Libderiv->deriv2_classes[2][5][81] = int_stack + 27836;
 Libderiv->deriv2_classes[2][6][81] = int_stack + 27962;
 Libderiv->deriv2_classes[2][7][81] = int_stack + 28130;
 Libderiv->deriv_classes[3][5][9] = int_stack + 28346;
 Libderiv->deriv2_classes[3][5][81] = int_stack + 28556;
 Libderiv->deriv_classes[3][6][9] = int_stack + 28766;
 Libderiv->deriv2_classes[3][6][81] = int_stack + 29046;
 Libderiv->deriv2_classes[3][7][81] = int_stack + 29326;
 Libderiv->deriv2_classes[2][5][80] = int_stack + 29686;
 Libderiv->deriv2_classes[2][6][80] = int_stack + 29812;
 Libderiv->deriv2_classes[2][7][80] = int_stack + 29980;
 Libderiv->deriv_classes[3][5][8] = int_stack + 30196;
 Libderiv->deriv2_classes[3][5][80] = int_stack + 30406;
 Libderiv->deriv_classes[3][6][8] = int_stack + 30616;
 Libderiv->deriv2_classes[3][6][80] = int_stack + 30896;
 Libderiv->deriv2_classes[3][7][80] = int_stack + 31176;
 Libderiv->deriv2_classes[2][5][79] = int_stack + 31536;
 Libderiv->deriv2_classes[2][6][79] = int_stack + 31662;
 Libderiv->deriv2_classes[2][7][79] = int_stack + 31830;
 Libderiv->deriv_classes[3][5][7] = int_stack + 32046;
 Libderiv->deriv2_classes[3][5][79] = int_stack + 32256;
 Libderiv->deriv_classes[3][6][7] = int_stack + 32466;
 Libderiv->deriv2_classes[3][6][79] = int_stack + 32746;
 Libderiv->deriv2_classes[3][7][79] = int_stack + 33026;
 Libderiv->deriv2_classes[2][5][78] = int_stack + 33386;
 Libderiv->deriv2_classes[2][6][78] = int_stack + 33512;
 Libderiv->deriv2_classes[2][7][78] = int_stack + 33680;
 Libderiv->dvrr_classes[3][5] = int_stack + 33896;
 Libderiv->deriv_classes[3][5][6] = int_stack + 34106;
 Libderiv->deriv2_classes[3][5][78] = int_stack + 34316;
 Libderiv->deriv_classes[3][6][6] = int_stack + 34526;
 Libderiv->deriv2_classes[3][6][78] = int_stack + 34806;
 Libderiv->deriv2_classes[3][7][78] = int_stack + 35086;
 Libderiv->deriv2_classes[2][5][35] = int_stack + 35446;
 Libderiv->deriv2_classes[2][6][35] = int_stack + 35572;
 Libderiv->deriv2_classes[2][7][35] = int_stack + 35740;
 Libderiv->deriv2_classes[3][5][35] = int_stack + 35956;
 Libderiv->deriv2_classes[3][6][35] = int_stack + 36166;
 Libderiv->deriv2_classes[3][7][35] = int_stack + 36446;
 Libderiv->deriv2_classes[2][5][34] = int_stack + 36806;
 Libderiv->deriv2_classes[2][6][34] = int_stack + 36932;
 Libderiv->deriv2_classes[2][7][34] = int_stack + 37100;
 Libderiv->deriv2_classes[3][5][34] = int_stack + 37316;
 Libderiv->deriv2_classes[3][6][34] = int_stack + 37526;
 Libderiv->deriv2_classes[3][7][34] = int_stack + 37806;
 Libderiv->deriv2_classes[2][5][33] = int_stack + 38166;
 Libderiv->deriv2_classes[2][6][33] = int_stack + 38292;
 Libderiv->deriv2_classes[2][7][33] = int_stack + 38460;
 Libderiv->deriv2_classes[3][5][33] = int_stack + 38676;
 Libderiv->deriv2_classes[3][6][33] = int_stack + 38886;
 Libderiv->deriv2_classes[3][7][33] = int_stack + 39166;
 Libderiv->deriv2_classes[2][5][32] = int_stack + 39526;
 Libderiv->deriv2_classes[2][6][32] = int_stack + 39652;
 Libderiv->deriv2_classes[2][7][32] = int_stack + 39820;
 Libderiv->deriv2_classes[3][5][32] = int_stack + 40036;
 Libderiv->deriv2_classes[3][6][32] = int_stack + 40246;
 Libderiv->deriv2_classes[3][7][32] = int_stack + 40526;
 Libderiv->deriv2_classes[2][5][31] = int_stack + 40886;
 Libderiv->deriv2_classes[2][6][31] = int_stack + 41012;
 Libderiv->deriv2_classes[2][7][31] = int_stack + 41180;
 Libderiv->deriv2_classes[3][5][31] = int_stack + 41396;
 Libderiv->deriv2_classes[3][6][31] = int_stack + 41606;
 Libderiv->deriv2_classes[3][7][31] = int_stack + 41886;
 Libderiv->deriv2_classes[2][5][30] = int_stack + 42246;
 Libderiv->deriv2_classes[2][6][30] = int_stack + 42372;
 Libderiv->deriv2_classes[2][7][30] = int_stack + 42540;
 Libderiv->deriv_classes[3][5][2] = int_stack + 42756;
 Libderiv->deriv2_classes[3][5][30] = int_stack + 42966;
 Libderiv->deriv_classes[3][6][2] = int_stack + 43176;
 Libderiv->deriv2_classes[3][6][30] = int_stack + 43456;
 Libderiv->deriv2_classes[3][7][30] = int_stack + 43736;
 Libderiv->deriv2_classes[2][5][26] = int_stack + 44096;
 Libderiv->deriv2_classes[2][6][26] = int_stack + 44222;
 Libderiv->deriv2_classes[2][7][26] = int_stack + 44390;
 Libderiv->deriv2_classes[3][5][26] = int_stack + 44606;
 Libderiv->deriv2_classes[3][6][26] = int_stack + 44816;
 Libderiv->deriv2_classes[3][7][26] = int_stack + 45096;
 Libderiv->deriv2_classes[2][5][23] = int_stack + 45456;
 Libderiv->deriv2_classes[2][6][23] = int_stack + 45582;
 Libderiv->deriv2_classes[2][7][23] = int_stack + 45750;
 Libderiv->deriv2_classes[3][5][23] = int_stack + 45966;
 Libderiv->deriv2_classes[3][6][23] = int_stack + 46176;
 Libderiv->deriv2_classes[3][7][23] = int_stack + 46456;
 Libderiv->deriv2_classes[2][5][22] = int_stack + 46816;
 Libderiv->deriv2_classes[2][6][22] = int_stack + 46942;
 Libderiv->deriv2_classes[2][7][22] = int_stack + 47110;
 Libderiv->deriv2_classes[3][5][22] = int_stack + 47326;
 Libderiv->deriv2_classes[3][6][22] = int_stack + 47536;
 Libderiv->deriv2_classes[3][7][22] = int_stack + 47816;
 Libderiv->deriv2_classes[2][5][21] = int_stack + 48176;
 Libderiv->deriv2_classes[2][6][21] = int_stack + 48302;
 Libderiv->deriv2_classes[2][7][21] = int_stack + 48470;
 Libderiv->deriv2_classes[3][5][21] = int_stack + 48686;
 Libderiv->deriv2_classes[3][6][21] = int_stack + 48896;
 Libderiv->deriv2_classes[3][7][21] = int_stack + 49176;
 Libderiv->deriv2_classes[2][5][20] = int_stack + 49536;
 Libderiv->deriv2_classes[2][6][20] = int_stack + 49662;
 Libderiv->deriv2_classes[2][7][20] = int_stack + 49830;
 Libderiv->deriv2_classes[3][5][20] = int_stack + 50046;
 Libderiv->deriv2_classes[3][6][20] = int_stack + 50256;
 Libderiv->deriv2_classes[3][7][20] = int_stack + 50536;
 Libderiv->deriv2_classes[2][5][19] = int_stack + 50896;
 Libderiv->deriv2_classes[2][6][19] = int_stack + 51022;
 Libderiv->deriv2_classes[2][7][19] = int_stack + 51190;
 Libderiv->deriv2_classes[3][5][19] = int_stack + 51406;
 Libderiv->deriv2_classes[3][6][19] = int_stack + 51616;
 Libderiv->deriv2_classes[3][7][19] = int_stack + 51896;
 Libderiv->deriv2_classes[2][5][18] = int_stack + 52256;
 Libderiv->deriv2_classes[2][6][18] = int_stack + 52382;
 Libderiv->deriv2_classes[2][7][18] = int_stack + 52550;
 Libderiv->deriv_classes[3][5][1] = int_stack + 52766;
 Libderiv->deriv2_classes[3][5][18] = int_stack + 52976;
 Libderiv->deriv_classes[3][6][1] = int_stack + 53186;
 Libderiv->deriv2_classes[3][6][18] = int_stack + 53466;
 Libderiv->deriv2_classes[3][7][18] = int_stack + 53746;
 Libderiv->deriv2_classes[2][5][14] = int_stack + 54106;
 Libderiv->deriv2_classes[2][6][14] = int_stack + 54232;
 Libderiv->deriv2_classes[2][7][14] = int_stack + 54400;
 Libderiv->deriv2_classes[3][5][14] = int_stack + 54616;
 Libderiv->deriv2_classes[3][6][14] = int_stack + 54826;
 Libderiv->deriv2_classes[3][7][14] = int_stack + 55106;
 Libderiv->deriv2_classes[2][5][13] = int_stack + 55466;
 Libderiv->deriv2_classes[2][6][13] = int_stack + 55592;
 Libderiv->deriv2_classes[2][7][13] = int_stack + 55760;
 Libderiv->deriv2_classes[3][5][13] = int_stack + 55976;
 Libderiv->deriv2_classes[3][6][13] = int_stack + 56186;
 Libderiv->deriv2_classes[3][7][13] = int_stack + 56466;
 Libderiv->deriv_classes[2][5][11] = int_stack + 56826;
 Libderiv->deriv_classes[2][6][11] = int_stack + 56952;
 Libderiv->deriv_classes[2][7][11] = int_stack + 57120;
 Libderiv->deriv2_classes[2][5][11] = int_stack + 57336;
 Libderiv->deriv2_classes[2][6][11] = int_stack + 57462;
 Libderiv->deriv2_classes[2][7][11] = int_stack + 57630;
 Libderiv->deriv2_classes[3][5][11] = int_stack + 57846;
 Libderiv->deriv2_classes[3][6][11] = int_stack + 58056;
 Libderiv->deriv2_classes[3][7][11] = int_stack + 58336;
 Libderiv->deriv_classes[2][5][10] = int_stack + 58696;
 Libderiv->deriv_classes[2][6][10] = int_stack + 58822;
 Libderiv->deriv_classes[2][7][10] = int_stack + 58990;
 Libderiv->deriv2_classes[2][5][10] = int_stack + 59206;
 Libderiv->deriv2_classes[2][6][10] = int_stack + 59332;
 Libderiv->deriv2_classes[2][7][10] = int_stack + 59500;
 Libderiv->deriv2_classes[3][5][10] = int_stack + 59716;
 Libderiv->deriv2_classes[3][6][10] = int_stack + 59926;
 Libderiv->deriv2_classes[3][7][10] = int_stack + 60206;
 Libderiv->deriv_classes[2][5][9] = int_stack + 60566;
 Libderiv->deriv_classes[2][6][9] = int_stack + 60692;
 Libderiv->deriv_classes[2][7][9] = int_stack + 60860;
 Libderiv->deriv2_classes[2][5][9] = int_stack + 61076;
 Libderiv->deriv2_classes[2][6][9] = int_stack + 61202;
 Libderiv->deriv2_classes[2][7][9] = int_stack + 61370;
 Libderiv->deriv2_classes[3][5][9] = int_stack + 61586;
 Libderiv->deriv2_classes[3][6][9] = int_stack + 61796;
 Libderiv->deriv2_classes[3][7][9] = int_stack + 62076;
 Libderiv->deriv_classes[2][5][8] = int_stack + 62436;
 Libderiv->deriv_classes[2][6][8] = int_stack + 62562;
 Libderiv->deriv_classes[2][7][8] = int_stack + 62730;
 Libderiv->deriv2_classes[2][5][8] = int_stack + 62946;
 Libderiv->deriv2_classes[2][6][8] = int_stack + 63072;
 Libderiv->deriv2_classes[2][7][8] = int_stack + 63240;
 Libderiv->deriv2_classes[3][5][8] = int_stack + 63456;
 Libderiv->deriv2_classes[3][6][8] = int_stack + 63666;
 Libderiv->deriv2_classes[3][7][8] = int_stack + 63946;
 Libderiv->deriv_classes[2][5][7] = int_stack + 64306;
 Libderiv->deriv_classes[2][6][7] = int_stack + 64432;
 Libderiv->deriv_classes[2][7][7] = int_stack + 64600;
 Libderiv->deriv2_classes[2][5][7] = int_stack + 64816;
 Libderiv->deriv2_classes[2][6][7] = int_stack + 64942;
 Libderiv->deriv2_classes[2][7][7] = int_stack + 65110;
 Libderiv->deriv2_classes[3][5][7] = int_stack + 65326;
 Libderiv->deriv2_classes[3][6][7] = int_stack + 65536;
 Libderiv->deriv2_classes[3][7][7] = int_stack + 65816;
 Libderiv->dvrr_classes[2][5] = int_stack + 66176;
 Libderiv->deriv_classes[2][5][6] = int_stack + 66302;
 Libderiv->dvrr_classes[2][6] = int_stack + 66428;
 Libderiv->deriv_classes[2][6][6] = int_stack + 66596;
 Libderiv->deriv_classes[2][7][6] = int_stack + 66764;
 Libderiv->deriv2_classes[2][5][6] = int_stack + 66980;
 Libderiv->deriv2_classes[2][6][6] = int_stack + 67106;
 Libderiv->deriv2_classes[2][7][6] = int_stack + 67274;
 Libderiv->deriv_classes[3][5][0] = int_stack + 67490;
 Libderiv->deriv2_classes[3][5][6] = int_stack + 67700;
 Libderiv->deriv_classes[3][6][0] = int_stack + 67910;
 Libderiv->deriv2_classes[3][6][6] = int_stack + 68190;
 Libderiv->deriv2_classes[3][7][6] = int_stack + 68470;
 Libderiv->deriv_classes[2][5][2] = int_stack + 68830;
 Libderiv->deriv_classes[2][6][2] = int_stack + 68956;
 Libderiv->deriv_classes[2][7][2] = int_stack + 69124;
 Libderiv->deriv2_classes[2][5][2] = int_stack + 69340;
 Libderiv->deriv2_classes[2][6][2] = int_stack + 69466;
 Libderiv->deriv2_classes[2][7][2] = int_stack + 69634;
 Libderiv->deriv2_classes[3][5][2] = int_stack + 69850;
 Libderiv->deriv2_classes[3][6][2] = int_stack + 70060;
 Libderiv->deriv2_classes[3][7][2] = int_stack + 70340;
 Libderiv->deriv_classes[2][5][1] = int_stack + 70700;
 Libderiv->deriv_classes[2][6][1] = int_stack + 70826;
 Libderiv->deriv_classes[2][7][1] = int_stack + 70994;
 Libderiv->deriv2_classes[2][5][1] = int_stack + 71210;
 Libderiv->deriv2_classes[2][6][1] = int_stack + 71336;
 Libderiv->deriv2_classes[2][7][1] = int_stack + 71504;
 Libderiv->deriv2_classes[3][5][1] = int_stack + 71720;
 Libderiv->deriv2_classes[3][6][1] = int_stack + 71930;
 Libderiv->deriv2_classes[3][7][1] = int_stack + 72210;
 Libderiv->deriv_classes[2][5][0] = int_stack + 72570;
 Libderiv->deriv_classes[2][6][0] = int_stack + 72696;
 Libderiv->deriv_classes[2][7][0] = int_stack + 72864;
 Libderiv->deriv2_classes[2][5][0] = int_stack + 73080;
 Libderiv->deriv2_classes[2][6][0] = int_stack + 73206;
 Libderiv->deriv2_classes[2][7][0] = int_stack + 73374;
 Libderiv->deriv2_classes[3][5][0] = int_stack + 73590;
 Libderiv->deriv2_classes[3][6][0] = int_stack + 73800;
 Libderiv->deriv2_classes[3][7][0] = int_stack + 74080;
 memset(int_stack,0,595520);

 Libderiv->dvrr_stack = int_stack + 145630;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_dphd(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+66428,int_stack+66176,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74818,int_stack+56952,int_stack+56826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66176,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+57120,int_stack+56952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66428,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+75700,int_stack+75196,int_stack+74818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74440,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+76456,int_stack+1800,int_stack+33896,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+77086,int_stack+25066,int_stack+24646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33896,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77716,int_stack+0,int_stack+25066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+78556,int_stack+77716,int_stack+77086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76456,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+77716,int_stack+58822,int_stack+58696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66176, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+58990,int_stack+58822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66428, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+79816,int_stack+75196,int_stack+77716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74440, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+80572,int_stack+26916,int_stack+26496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33896, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+81202,int_stack+360,int_stack+26916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+82042,int_stack+81202,int_stack+80572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76456, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+81202,int_stack+60692,int_stack+60566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66176, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+60860,int_stack+60692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66428, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+83302,int_stack+75196,int_stack+81202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74440, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+28766,int_stack+28346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33896, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+84058,int_stack+720,int_stack+28766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+84898,int_stack+84058,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76456, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+84058,int_stack+62562,int_stack+62436, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+62730,int_stack+62562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+86158,int_stack+75196,int_stack+84058, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+86914,int_stack+30616,int_stack+30196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+87544,int_stack+1080,int_stack+30616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+88384,int_stack+87544,int_stack+86914, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+87544,int_stack+64432,int_stack+64306, 0.0, zero_stack, 1.0, int_stack+66176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+64600,int_stack+64432, 0.0, zero_stack, 1.0, int_stack+66428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+630,int_stack+75196,int_stack+87544, 0.0, zero_stack, 1.0, int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+89644,int_stack+32466,int_stack+32046, 0.0, zero_stack, 1.0, int_stack+33896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+90274,int_stack+1440,int_stack+32466, 0.0, zero_stack, 1.0, int_stack+1800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+91114,int_stack+90274,int_stack+89644, 0.0, zero_stack, 1.0, int_stack+76456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90274,int_stack+66596,int_stack+66302, 1.0, int_stack+66176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+66764,int_stack+66596, 1.0, int_stack+66428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+92374,int_stack+75196,int_stack+90274, 1.0, int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+34526,int_stack+34106, 1.0, int_stack+33896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93760,int_stack+2080,int_stack+34526, 1.0, int_stack+1800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+94600,int_stack+93760,int_stack+93130, 1.0, int_stack+76456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+3160,int_stack+66428,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+93760,int_stack+75196,int_stack+74440,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+68956,int_stack+68830,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+69124,int_stack+68956,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1386,int_stack+75196,int_stack+74440,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+76456,int_stack+43176,int_stack+42756,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+95860,int_stack+2440,int_stack+43176,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+96700,int_stack+95860,int_stack+76456,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+95860,int_stack+70826,int_stack+70700,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+70994,int_stack+70826,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+97960,int_stack+75196,int_stack+95860,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2142,int_stack+53186,int_stack+52766,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+98716,int_stack+2800,int_stack+53186,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+99556,int_stack+98716,int_stack+2142,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+98716,int_stack+72696,int_stack+72570,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+72864,int_stack+72696,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+100816,int_stack+75196,int_stack+98716,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+101572,int_stack+67910,int_stack+67490,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+102202,int_stack+3376,int_stack+67910,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+103042,int_stack+102202,int_stack+101572,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+3862,int_stack+3736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+56826,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+4030,int_stack+3862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+56952,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2772,int_stack+75196,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+74818,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+4456,int_stack+4246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+24646,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3528,int_stack+4736,int_stack+4456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+25066,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+104302,int_stack+3528,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+77086,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+5222,int_stack+5096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56826, 1.0, int_stack+58696,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+5390,int_stack+5222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56952, 1.0, int_stack+58822,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3528,int_stack+75196,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74818, 1.0, int_stack+77716,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+5816,int_stack+5606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24646, 1.0, int_stack+26496,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4284,int_stack+6096,int_stack+5816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25066, 1.0, int_stack+26916,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5124,int_stack+4284,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77086, 1.0, int_stack+80572,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+6582,int_stack+6456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+58696, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+6750,int_stack+6582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+58822, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4284,int_stack+75196,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+77716, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+7176,int_stack+6966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+26496, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+105562,int_stack+7456,int_stack+7176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+26916, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6384,int_stack+105562,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+80572, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+7942,int_stack+7816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56826, 0.0, zero_stack, 1.0, int_stack+60566,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+8110,int_stack+7942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56952, 0.0, zero_stack, 1.0, int_stack+60692,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+105562,int_stack+75196,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74818, 0.0, zero_stack, 1.0, int_stack+81202,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+8536,int_stack+8326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24646, 0.0, zero_stack, 1.0, int_stack+28346,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7644,int_stack+8816,int_stack+8536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25066, 0.0, zero_stack, 1.0, int_stack+28766,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+106318,int_stack+7644,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77086, 0.0, zero_stack, 1.0, int_stack+0,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+9302,int_stack+9176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58696, 1.0, int_stack+60566, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+9470,int_stack+9302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58822, 1.0, int_stack+60692, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7644,int_stack+75196,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77716, 1.0, int_stack+81202, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+9896,int_stack+9686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26496, 1.0, int_stack+28346, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8400,int_stack+10176,int_stack+9896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26916, 1.0, int_stack+28766, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9240,int_stack+8400,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80572, 1.0, int_stack+0, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+10662,int_stack+10536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+60566, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+10830,int_stack+10662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+60692, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8400,int_stack+75196,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+81202, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+11256,int_stack+11046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+28346, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+107578,int_stack+11536,int_stack+11256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+28766, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10500,int_stack+107578,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+12022,int_stack+11896, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56826, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62436,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+12190,int_stack+12022, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56952, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62562,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+107578,int_stack+75196,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74818, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84058,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+12616,int_stack+12406, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24646, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30196,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11760,int_stack+12896,int_stack+12616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25066, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30616,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+108334,int_stack+11760,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77086, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86914,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+13382,int_stack+13256, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58696, 0.0, zero_stack, 1.0, int_stack+62436, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+13550,int_stack+13382, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58822, 0.0, zero_stack, 1.0, int_stack+62562, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11760,int_stack+75196,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77716, 0.0, zero_stack, 1.0, int_stack+84058, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+13976,int_stack+13766, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26496, 0.0, zero_stack, 1.0, int_stack+30196, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12516,int_stack+14256,int_stack+13976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26916, 0.0, zero_stack, 1.0, int_stack+30616, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13356,int_stack+12516,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80572, 0.0, zero_stack, 1.0, int_stack+86914, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+14742,int_stack+14616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60566, 1.0, int_stack+62436, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+14910,int_stack+14742, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60692, 1.0, int_stack+62562, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12516,int_stack+75196,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81202, 1.0, int_stack+84058, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+15336,int_stack+15126, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28346, 1.0, int_stack+30196, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109594,int_stack+15616,int_stack+15336, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28766, 1.0, int_stack+30616, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+14616,int_stack+109594,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+86914, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+16102,int_stack+15976, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+62436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+16270,int_stack+16102, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+62562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+109594,int_stack+75196,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+84058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+16696,int_stack+16486, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+30196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+110350,int_stack+16976,int_stack+16696, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+30616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15876,int_stack+110350,int_stack+102202, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+86914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+17462,int_stack+17336, 0.0, zero_stack, 1.0, int_stack+56826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64306,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+17630,int_stack+17462, 0.0, zero_stack, 1.0, int_stack+56952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64432,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+110350,int_stack+75196,int_stack+102202, 0.0, zero_stack, 1.0, int_stack+74818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87544,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+18056,int_stack+17846, 0.0, zero_stack, 1.0, int_stack+24646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32046,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+111106,int_stack+18336,int_stack+18056, 0.0, zero_stack, 1.0, int_stack+25066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32466,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17136,int_stack+111106,int_stack+102202, 0.0, zero_stack, 1.0, int_stack+77086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89644,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+18822,int_stack+18696, 0.0, zero_stack, 1.0, int_stack+58696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64306, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+18990,int_stack+18822, 0.0, zero_stack, 1.0, int_stack+58822, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64432, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+111106,int_stack+75196,int_stack+102202, 0.0, zero_stack, 1.0, int_stack+77716, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87544, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+19416,int_stack+19206, 0.0, zero_stack, 1.0, int_stack+26496, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32046, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18396,int_stack+19696,int_stack+19416, 0.0, zero_stack, 1.0, int_stack+26916, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32466, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+111862,int_stack+18396,int_stack+102202, 0.0, zero_stack, 1.0, int_stack+80572, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89644, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+20182,int_stack+20056, 0.0, zero_stack, 1.0, int_stack+60566, 0.0, zero_stack, 1.0, int_stack+64306, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+20350,int_stack+20182, 0.0, zero_stack, 1.0, int_stack+60692, 0.0, zero_stack, 1.0, int_stack+64432, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18396,int_stack+75196,int_stack+102202, 0.0, zero_stack, 1.0, int_stack+81202, 0.0, zero_stack, 1.0, int_stack+87544, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+20776,int_stack+20566, 0.0, zero_stack, 1.0, int_stack+28346, 0.0, zero_stack, 1.0, int_stack+32046, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19152,int_stack+21056,int_stack+20776, 0.0, zero_stack, 1.0, int_stack+28766, 0.0, zero_stack, 1.0, int_stack+32466, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19992,int_stack+19152,int_stack+102202, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+89644, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+21542,int_stack+21416, 0.0, zero_stack, 1.0, int_stack+62436, 1.0, int_stack+64306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+21710,int_stack+21542, 0.0, zero_stack, 1.0, int_stack+62562, 1.0, int_stack+64432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19152,int_stack+75196,int_stack+102202, 0.0, zero_stack, 1.0, int_stack+84058, 1.0, int_stack+87544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+22136,int_stack+21926, 0.0, zero_stack, 1.0, int_stack+30196, 1.0, int_stack+32046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21252,int_stack+22416,int_stack+22136, 0.0, zero_stack, 1.0, int_stack+30616, 1.0, int_stack+32466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+113122,int_stack+21252,int_stack+102202, 0.0, zero_stack, 1.0, int_stack+86914, 1.0, int_stack+89644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+22902,int_stack+22776, 0.0, zero_stack, 2.0, int_stack+64306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+23070,int_stack+22902, 0.0, zero_stack, 2.0, int_stack+64432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21252,int_stack+75196,int_stack+102202, 0.0, zero_stack, 2.0, int_stack+87544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+23496,int_stack+23286, 0.0, zero_stack, 2.0, int_stack+32046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+22008,int_stack+23776,int_stack+23496, 0.0, zero_stack, 2.0, int_stack+32466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22848,int_stack+22008,int_stack+102202, 0.0, zero_stack, 2.0, int_stack+89644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102202,int_stack+24262,int_stack+24136, 1.0, int_stack+56826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66302,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+75196,int_stack+24430,int_stack+24262, 1.0, int_stack+56952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66596,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22008,int_stack+75196,int_stack+102202, 1.0, int_stack+74818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90274,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74818,int_stack+25346,int_stack+24856, 1.0, int_stack+24646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34106,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+102202,int_stack+25626,int_stack+25346, 1.0, int_stack+25066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34526,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+24108,int_stack+102202,int_stack+74818, 1.0, int_stack+77086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93130,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+77086,int_stack+26112,int_stack+25986, 1.0, int_stack+58696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66302, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+74818,int_stack+26280,int_stack+26112, 1.0, int_stack+58822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66596, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+102202,int_stack+74818,int_stack+77086, 1.0, int_stack+77716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90274, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+77086,int_stack+27196,int_stack+26706, 1.0, int_stack+26496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34106, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77716,int_stack+27476,int_stack+27196, 1.0, int_stack+26916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34526, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+25368,int_stack+77716,int_stack+77086, 1.0, int_stack+80572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93130, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+80572,int_stack+27962,int_stack+27836, 1.0, int_stack+60566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66302, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77086,int_stack+28130,int_stack+27962, 1.0, int_stack+60692, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66596, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+77590,int_stack+77086,int_stack+80572, 1.0, int_stack+81202, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90274, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+80572,int_stack+29046,int_stack+28556, 1.0, int_stack+28346, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34106, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+81202,int_stack+29326,int_stack+29046, 1.0, int_stack+28766, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34526, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+26628,int_stack+81202,int_stack+80572, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93130, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+29812,int_stack+29686, 1.0, int_stack+62436, 0.0, zero_stack, 1.0, int_stack+66302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77086,int_stack+29980,int_stack+29812, 1.0, int_stack+62562, 0.0, zero_stack, 1.0, int_stack+66596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+80572,int_stack+77086,int_stack+0, 1.0, int_stack+84058, 0.0, zero_stack, 1.0, int_stack+90274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+30896,int_stack+30406, 1.0, int_stack+30196, 0.0, zero_stack, 1.0, int_stack+34106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+84058,int_stack+31176,int_stack+30896, 1.0, int_stack+30616, 0.0, zero_stack, 1.0, int_stack+34526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+27888,int_stack+84058,int_stack+0, 1.0, int_stack+86914, 0.0, zero_stack, 1.0, int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+86914,int_stack+31662,int_stack+31536, 1.0, int_stack+64306, 1.0, int_stack+66302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77086,int_stack+31830,int_stack+31662, 1.0, int_stack+64432, 1.0, int_stack+66596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+84058,int_stack+77086,int_stack+86914, 1.0, int_stack+87544, 1.0, int_stack+90274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+32746,int_stack+32256, 1.0, int_stack+32046, 1.0, int_stack+34106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+86914,int_stack+33026,int_stack+32746, 1.0, int_stack+32466, 1.0, int_stack+34526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29148,int_stack+86914,int_stack+0, 1.0, int_stack+89644, 1.0, int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+89644,int_stack+33512,int_stack+33386, 2.0, int_stack+66302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77086,int_stack+33680,int_stack+33512, 2.0, int_stack+66596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+86914,int_stack+77086,int_stack+89644, 2.0, int_stack+90274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+34806,int_stack+34316, 2.0, int_stack+34106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+89644,int_stack+35086,int_stack+34806, 2.0, int_stack+34526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30408,int_stack+89644,int_stack+0, 2.0, int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+35572,int_stack+35446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68830,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77086,int_stack+35740,int_stack+35572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68956,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+89644,int_stack+77086,int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74440,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+36166,int_stack+35956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42756,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+74818,int_stack+36446,int_stack+36166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43176,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+31668,int_stack+74818,int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76456,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+36932,int_stack+36806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68830, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77086,int_stack+37100,int_stack+36932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68956, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+74818,int_stack+77086,int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74440, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+37526,int_stack+37316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42756, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+32928,int_stack+37806,int_stack+37526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43176, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+33768,int_stack+32928,int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76456, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+38292,int_stack+38166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68830, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77086,int_stack+38460,int_stack+38292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68956, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32928,int_stack+77086,int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74440, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+38886,int_stack+38676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42756, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+35028,int_stack+39166,int_stack+38886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43176, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35868,int_stack+35028,int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76456, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+39652,int_stack+39526, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77086,int_stack+39820,int_stack+39652, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35028,int_stack+77086,int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+40246,int_stack+40036, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+37128,int_stack+40526,int_stack+40246, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+37968,int_stack+37128,int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+41012,int_stack+40886, 0.0, zero_stack, 1.0, int_stack+68830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77086,int_stack+41180,int_stack+41012, 0.0, zero_stack, 1.0, int_stack+68956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+37128,int_stack+77086,int_stack+93130, 0.0, zero_stack, 1.0, int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+41606,int_stack+41396, 0.0, zero_stack, 1.0, int_stack+42756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+39228,int_stack+41886,int_stack+41606, 0.0, zero_stack, 1.0, int_stack+43176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+40068,int_stack+39228,int_stack+93130, 0.0, zero_stack, 1.0, int_stack+76456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+42372,int_stack+42246, 1.0, int_stack+68830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77086,int_stack+42540,int_stack+42372, 1.0, int_stack+68956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+39228,int_stack+77086,int_stack+93130, 1.0, int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+43456,int_stack+42966, 1.0, int_stack+42756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+41328,int_stack+43736,int_stack+43456, 1.0, int_stack+43176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+42168,int_stack+41328,int_stack+93130, 1.0, int_stack+76456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+44222,int_stack+44096,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+76456,int_stack+44390,int_stack+44222,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+41328,int_stack+76456,int_stack+74440,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+44816,int_stack+44606,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+76456,int_stack+45096,int_stack+44816,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+43428,int_stack+76456,int_stack+93130,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+45582,int_stack+45456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70700,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93130,int_stack+45750,int_stack+45582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70826,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76456,int_stack+93130,int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95860,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+46176,int_stack+45966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52766,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+44688,int_stack+46456,int_stack+46176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53186,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+45528,int_stack+44688,int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2142,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+46942,int_stack+46816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70700, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93130,int_stack+47110,int_stack+46942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70826, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+44688,int_stack+93130,int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95860, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+47536,int_stack+47326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52766, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+114382,int_stack+47816,int_stack+47536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53186, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+46788,int_stack+114382,int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2142, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+48302,int_stack+48176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70700, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93130,int_stack+48470,int_stack+48302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70826, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+114382,int_stack+93130,int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95860, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+48896,int_stack+48686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52766, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+115138,int_stack+49176,int_stack+48896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53186, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48048,int_stack+115138,int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2142, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+49662,int_stack+49536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93130,int_stack+49830,int_stack+49662, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+115138,int_stack+93130,int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+50256,int_stack+50046, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49308,int_stack+50536,int_stack+50256, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+115894,int_stack+49308,int_stack+93130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+51022,int_stack+50896, 0.0, zero_stack, 1.0, int_stack+70700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93130,int_stack+51190,int_stack+51022, 0.0, zero_stack, 1.0, int_stack+70826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+49308,int_stack+93130,int_stack+74440, 0.0, zero_stack, 1.0, int_stack+95860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+51616,int_stack+51406, 0.0, zero_stack, 1.0, int_stack+52766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+50064,int_stack+51896,int_stack+51616, 0.0, zero_stack, 1.0, int_stack+53186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50904,int_stack+50064,int_stack+93130, 0.0, zero_stack, 1.0, int_stack+2142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+52382,int_stack+52256, 1.0, int_stack+70700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93130,int_stack+52550,int_stack+52382, 1.0, int_stack+70826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50064,int_stack+93130,int_stack+74440, 1.0, int_stack+95860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+93130,int_stack+53466,int_stack+52976, 1.0, int_stack+52766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+95860,int_stack+53746,int_stack+53466, 1.0, int_stack+53186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+52164,int_stack+95860,int_stack+93130, 1.0, int_stack+2142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+54232,int_stack+54106,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2142,int_stack+54400,int_stack+54232,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+95860,int_stack+2142,int_stack+74440,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2142,int_stack+54826,int_stack+54616,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+53424,int_stack+55106,int_stack+54826,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+117154,int_stack+53424,int_stack+2142,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+55592,int_stack+55466,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2142,int_stack+55760,int_stack+55592,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+53424,int_stack+2142,int_stack+74440,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2142,int_stack+56186,int_stack+55976,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+54180,int_stack+56466,int_stack+56186,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+55020,int_stack+54180,int_stack+2142,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+57462,int_stack+57336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72570,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2142,int_stack+57630,int_stack+57462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72696,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+54180,int_stack+2142,int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98716,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2142,int_stack+58056,int_stack+57846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67490,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+56280,int_stack+58336,int_stack+58056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67910,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+57120,int_stack+56280,int_stack+2142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101572,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+59332,int_stack+59206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72570, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2142,int_stack+59500,int_stack+59332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72696, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+56280,int_stack+2142,int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98716, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2142,int_stack+59926,int_stack+59716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67490, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58380,int_stack+60206,int_stack+59926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67910, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+59220,int_stack+58380,int_stack+2142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101572, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+61202,int_stack+61076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72570, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2142,int_stack+61370,int_stack+61202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72696, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+58380,int_stack+2142,int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98716, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2142,int_stack+61796,int_stack+61586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67490, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+60480,int_stack+62076,int_stack+61796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67910, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+61320,int_stack+60480,int_stack+2142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101572, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+63072,int_stack+62946, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2142,int_stack+63240,int_stack+63072, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+72696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+60480,int_stack+2142,int_stack+74440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2142,int_stack+63666,int_stack+63456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+62580,int_stack+63946,int_stack+63666, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+63420,int_stack+62580,int_stack+2142, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+64942,int_stack+64816, 0.0, zero_stack, 1.0, int_stack+72570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2142,int_stack+65110,int_stack+64942, 0.0, zero_stack, 1.0, int_stack+72696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+62580,int_stack+2142,int_stack+74440, 0.0, zero_stack, 1.0, int_stack+98716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2142,int_stack+65536,int_stack+65326, 0.0, zero_stack, 1.0, int_stack+67490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+64680,int_stack+65816,int_stack+65536, 0.0, zero_stack, 1.0, int_stack+67910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+65520,int_stack+64680,int_stack+2142, 0.0, zero_stack, 1.0, int_stack+101572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+67106,int_stack+66980, 1.0, int_stack+72570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2142,int_stack+67274,int_stack+67106, 1.0, int_stack+72696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+64680,int_stack+2142,int_stack+74440, 1.0, int_stack+98716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2142,int_stack+68190,int_stack+67700, 1.0, int_stack+67490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+98716,int_stack+68470,int_stack+68190, 1.0, int_stack+67910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+66780,int_stack+98716,int_stack+2142, 1.0, int_stack+101572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+69466,int_stack+69340,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+101572,int_stack+69634,int_stack+69466,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+98716,int_stack+101572,int_stack+74440,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+101572,int_stack+70060,int_stack+69850,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+68040,int_stack+70340,int_stack+70060,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+68880,int_stack+68040,int_stack+101572,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+71336,int_stack+71210,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+101572,int_stack+71504,int_stack+71336,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+68040,int_stack+101572,int_stack+74440,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+101572,int_stack+71930,int_stack+71720,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+70140,int_stack+72210,int_stack+71930,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+70980,int_stack+70140,int_stack+101572,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+74440,int_stack+73206,int_stack+73080,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+101572,int_stack+73374,int_stack+73206,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+70140,int_stack+101572,int_stack+74440,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+101572,int_stack+73800,int_stack+73590,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+72240,int_stack+74080,int_stack+73800,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+73080,int_stack+72240,int_stack+101572,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+118414,int_stack+78556,int_stack+75700,126);
     Libderiv->ABCD[11] = int_stack + 118414;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+120682,int_stack+82042,int_stack+79816,126);
     Libderiv->ABCD[10] = int_stack + 120682;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+122950,int_stack+84898,int_stack+83302,126);
     Libderiv->ABCD[9] = int_stack + 122950;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+125218,int_stack+88384,int_stack+86158,126);
     Libderiv->ABCD[8] = int_stack + 125218;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+127486,int_stack+91114,int_stack+630,126);
     Libderiv->ABCD[7] = int_stack + 127486;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+129754,int_stack+94600,int_stack+92374,126);
     Libderiv->ABCD[6] = int_stack + 129754;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+132022,int_stack+96700,int_stack+1386, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[2] = int_stack + 132022;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+134290,int_stack+99556,int_stack+97960, 0.0, zero_stack, 1.0, int_stack+93760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[1] = int_stack + 134290;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+136558,int_stack+103042,int_stack+100816, 1.0, int_stack+93760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[0] = int_stack + 136558;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+93130,int_stack+104302,int_stack+2772,126);
     Libderiv->ABCD[155] = int_stack + 93130;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+102958,int_stack+5124,int_stack+3528,126);
     Libderiv->ABCD[143] = int_stack + 102958;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+138826,int_stack+6384,int_stack+4284,126);
     Libderiv->ABCD[142] = int_stack + 138826;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+2142,int_stack+106318,int_stack+105562,126);
     Libderiv->ABCD[131] = int_stack + 2142;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+4410,int_stack+9240,int_stack+7644,126);
     Libderiv->ABCD[130] = int_stack + 4410;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+105226,int_stack+10500,int_stack+8400,126);
     Libderiv->ABCD[129] = int_stack + 105226;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+6678,int_stack+108334,int_stack+107578,126);
     Libderiv->ABCD[119] = int_stack + 6678;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+8946,int_stack+13356,int_stack+11760,126);
     Libderiv->ABCD[118] = int_stack + 8946;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+141094,int_stack+14616,int_stack+12516,126);
     Libderiv->ABCD[117] = int_stack + 141094;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+11214,int_stack+15876,int_stack+109594,126);
     Libderiv->ABCD[116] = int_stack + 11214;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+13482,int_stack+17136,int_stack+110350,126);
     Libderiv->ABCD[107] = int_stack + 13482;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+15750,int_stack+111862,int_stack+111106,126);
     Libderiv->ABCD[106] = int_stack + 15750;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+107494,int_stack+19992,int_stack+18396,126);
     Libderiv->ABCD[105] = int_stack + 107494;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+109762,int_stack+113122,int_stack+19152,126);
     Libderiv->ABCD[104] = int_stack + 109762;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+18018,int_stack+22848,int_stack+21252,126);
     Libderiv->ABCD[103] = int_stack + 18018;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+112030,int_stack+24108,int_stack+22008,126);
     Libderiv->ABCD[95] = int_stack + 112030;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+20286,int_stack+25368,int_stack+102202,126);
     Libderiv->ABCD[94] = int_stack + 20286;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+22554,int_stack+26628,int_stack+77590,126);
     Libderiv->ABCD[93] = int_stack + 22554;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+24822,int_stack+27888,int_stack+80572,126);
     Libderiv->ABCD[92] = int_stack + 24822;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+80572,int_stack+29148,int_stack+84058,126);
     Libderiv->ABCD[91] = int_stack + 80572;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+27090,int_stack+30408,int_stack+86914,126);
     Libderiv->ABCD[90] = int_stack + 27090;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+86914,int_stack+31668,int_stack+89644, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[47] = int_stack + 86914;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+89182,int_stack+33768,int_stack+74818, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[46] = int_stack + 89182;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+29358,int_stack+35868,int_stack+32928, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[45] = int_stack + 29358;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+31626,int_stack+37968,int_stack+35028, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[44] = int_stack + 31626;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+33894,int_stack+40068,int_stack+37128, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[43] = int_stack + 33894;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+36162,int_stack+42168,int_stack+39228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[42] = int_stack + 36162;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+38430,int_stack+43428,int_stack+41328, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[38] = int_stack + 38430;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+40698,int_stack+45528,int_stack+76456, 0.0, zero_stack, 1.0, int_stack+75700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[35] = int_stack + 40698;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+76456,int_stack+46788,int_stack+44688, 0.0, zero_stack, 1.0, int_stack+79816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[34] = int_stack + 76456;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+42966,int_stack+48048,int_stack+114382, 0.0, zero_stack, 1.0, int_stack+83302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[33] = int_stack + 42966;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+45234,int_stack+115894,int_stack+115138, 0.0, zero_stack, 1.0, int_stack+86158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[32] = int_stack + 45234;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+114298,int_stack+50904,int_stack+49308, 0.0, zero_stack, 1.0, int_stack+630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[31] = int_stack + 114298;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+47502,int_stack+52164,int_stack+50064, 0.0, zero_stack, 1.0, int_stack+92374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[30] = int_stack + 47502;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+49770,int_stack+117154,int_stack+95860, 0.0, zero_stack, 1.0, int_stack+1386, 1.0, int_stack+97960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[26] = int_stack + 49770;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+95398,int_stack+55020,int_stack+53424, 0.0, zero_stack, 2.0, int_stack+97960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[25] = int_stack + 95398;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+143362,int_stack+57120,int_stack+54180, 1.0, int_stack+75700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[23] = int_stack + 143362;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+52038,int_stack+59220,int_stack+56280, 1.0, int_stack+79816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[22] = int_stack + 52038;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+54306,int_stack+61320,int_stack+58380, 1.0, int_stack+83302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[21] = int_stack + 54306;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+82840,int_stack+63420,int_stack+60480, 1.0, int_stack+86158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[20] = int_stack + 82840;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+56574,int_stack+65520,int_stack+62580, 1.0, int_stack+630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[19] = int_stack + 56574;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+58842,int_stack+66780,int_stack+64680, 1.0, int_stack+92374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[18] = int_stack + 58842;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+61110,int_stack+68880,int_stack+98716, 1.0, int_stack+1386, 0.0, zero_stack, 1.0, int_stack+100816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[14] = int_stack + 61110;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+63378,int_stack+70980,int_stack+68040, 1.0, int_stack+97960, 1.0, int_stack+100816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[13] = int_stack + 63378;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+65646,int_stack+73080,int_stack+70140, 2.0, int_stack+100816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[12] = int_stack + 65646;

}
