/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_g0ff(Libderiv_t *, prim_data *);

  /* Computes derivatives of (g0|ff) integrals */

void d12hrr_order_g0ff(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][6][10] = int_stack + 420;
 Libderiv->deriv_classes[4][6][9] = int_stack + 840;
 Libderiv->deriv_classes[4][6][8] = int_stack + 1260;
 Libderiv->deriv_classes[4][6][7] = int_stack + 1680;
 Libderiv->dvrr_classes[4][5] = int_stack + 2100;
 Libderiv->deriv_classes[4][6][6] = int_stack + 2415;
 Libderiv->deriv_classes[4][6][2] = int_stack + 2835;
 Libderiv->deriv_classes[4][6][1] = int_stack + 3255;
 Libderiv->deriv_classes[4][6][0] = int_stack + 3675;
 Libderiv->deriv2_classes[4][3][143] = int_stack + 4095;
 Libderiv->deriv2_classes[4][4][143] = int_stack + 4245;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 4470;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 4785;
 Libderiv->deriv2_classes[4][3][131] = int_stack + 5205;
 Libderiv->deriv2_classes[4][4][131] = int_stack + 5355;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 5580;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 5895;
 Libderiv->deriv2_classes[4][3][130] = int_stack + 6315;
 Libderiv->deriv2_classes[4][4][130] = int_stack + 6465;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 6690;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 7005;
 Libderiv->deriv2_classes[4][3][119] = int_stack + 7425;
 Libderiv->deriv2_classes[4][4][119] = int_stack + 7575;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 7800;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 8115;
 Libderiv->deriv2_classes[4][3][118] = int_stack + 8535;
 Libderiv->deriv2_classes[4][4][118] = int_stack + 8685;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 8910;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 9225;
 Libderiv->deriv2_classes[4][3][117] = int_stack + 9645;
 Libderiv->deriv2_classes[4][4][117] = int_stack + 9795;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 10020;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 10335;
 Libderiv->deriv2_classes[4][3][107] = int_stack + 10755;
 Libderiv->deriv2_classes[4][4][107] = int_stack + 10905;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 11130;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 11445;
 Libderiv->deriv2_classes[4][3][106] = int_stack + 11865;
 Libderiv->deriv2_classes[4][4][106] = int_stack + 12015;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 12240;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 12555;
 Libderiv->deriv2_classes[4][3][105] = int_stack + 12975;
 Libderiv->deriv2_classes[4][4][105] = int_stack + 13125;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 13350;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 13665;
 Libderiv->deriv2_classes[4][3][104] = int_stack + 14085;
 Libderiv->deriv2_classes[4][4][104] = int_stack + 14235;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 14460;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 14775;
 Libderiv->deriv2_classes[4][3][95] = int_stack + 15195;
 Libderiv->deriv2_classes[4][4][95] = int_stack + 15345;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 15570;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 15885;
 Libderiv->deriv2_classes[4][3][94] = int_stack + 16305;
 Libderiv->deriv2_classes[4][4][94] = int_stack + 16455;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 16680;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 16995;
 Libderiv->deriv2_classes[4][3][93] = int_stack + 17415;
 Libderiv->deriv2_classes[4][4][93] = int_stack + 17565;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 17790;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 18105;
 Libderiv->deriv2_classes[4][3][92] = int_stack + 18525;
 Libderiv->deriv2_classes[4][4][92] = int_stack + 18675;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 18900;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 19215;
 Libderiv->deriv2_classes[4][3][91] = int_stack + 19635;
 Libderiv->deriv2_classes[4][4][91] = int_stack + 19785;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 20010;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 20325;
 Libderiv->deriv_classes[4][3][11] = int_stack + 20745;
 Libderiv->deriv2_classes[4][3][83] = int_stack + 20895;
 Libderiv->deriv_classes[4][4][11] = int_stack + 21045;
 Libderiv->deriv2_classes[4][4][83] = int_stack + 21270;
 Libderiv->deriv_classes[4][5][11] = int_stack + 21495;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 21810;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 22125;
 Libderiv->deriv_classes[4][3][10] = int_stack + 22545;
 Libderiv->deriv2_classes[4][3][82] = int_stack + 22695;
 Libderiv->deriv_classes[4][4][10] = int_stack + 22845;
 Libderiv->deriv2_classes[4][4][82] = int_stack + 23070;
 Libderiv->deriv_classes[4][5][10] = int_stack + 23295;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 23610;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 23925;
 Libderiv->deriv_classes[4][3][9] = int_stack + 24345;
 Libderiv->deriv2_classes[4][3][81] = int_stack + 24495;
 Libderiv->deriv_classes[4][4][9] = int_stack + 24645;
 Libderiv->deriv2_classes[4][4][81] = int_stack + 24870;
 Libderiv->deriv_classes[4][5][9] = int_stack + 25095;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 25410;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 25725;
 Libderiv->deriv_classes[4][3][8] = int_stack + 26145;
 Libderiv->deriv2_classes[4][3][80] = int_stack + 26295;
 Libderiv->deriv_classes[4][4][8] = int_stack + 26445;
 Libderiv->deriv2_classes[4][4][80] = int_stack + 26670;
 Libderiv->deriv_classes[4][5][8] = int_stack + 26895;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 27210;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 27525;
 Libderiv->deriv_classes[4][3][7] = int_stack + 27945;
 Libderiv->deriv2_classes[4][3][79] = int_stack + 28095;
 Libderiv->deriv_classes[4][4][7] = int_stack + 28245;
 Libderiv->deriv2_classes[4][4][79] = int_stack + 28470;
 Libderiv->deriv_classes[4][5][7] = int_stack + 28695;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 29010;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 29325;
 Libderiv->dvrr_classes[4][3] = int_stack + 29745;
 Libderiv->deriv_classes[4][3][6] = int_stack + 29895;
 Libderiv->deriv2_classes[4][3][78] = int_stack + 30045;
 Libderiv->dvrr_classes[4][4] = int_stack + 30195;
 Libderiv->deriv_classes[4][4][6] = int_stack + 30420;
 Libderiv->deriv2_classes[4][4][78] = int_stack + 30645;
 Libderiv->deriv_classes[4][5][6] = int_stack + 30870;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 31185;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 31500;
 Libderiv->deriv2_classes[4][3][35] = int_stack + 31920;
 Libderiv->deriv2_classes[4][4][35] = int_stack + 32070;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 32295;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 32610;
 Libderiv->deriv2_classes[4][3][34] = int_stack + 33030;
 Libderiv->deriv2_classes[4][4][34] = int_stack + 33180;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 33405;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 33720;
 Libderiv->deriv2_classes[4][3][33] = int_stack + 34140;
 Libderiv->deriv2_classes[4][4][33] = int_stack + 34290;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 34515;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 34830;
 Libderiv->deriv2_classes[4][3][32] = int_stack + 35250;
 Libderiv->deriv2_classes[4][4][32] = int_stack + 35400;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 35625;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 35940;
 Libderiv->deriv2_classes[4][3][31] = int_stack + 36360;
 Libderiv->deriv2_classes[4][4][31] = int_stack + 36510;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 36735;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 37050;
 Libderiv->deriv_classes[4][3][2] = int_stack + 37470;
 Libderiv->deriv2_classes[4][3][30] = int_stack + 37620;
 Libderiv->deriv_classes[4][4][2] = int_stack + 37770;
 Libderiv->deriv2_classes[4][4][30] = int_stack + 37995;
 Libderiv->deriv_classes[4][5][2] = int_stack + 38220;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 38535;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 38850;
 Libderiv->deriv2_classes[4][3][26] = int_stack + 39270;
 Libderiv->deriv2_classes[4][4][26] = int_stack + 39420;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 39645;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 39960;
 Libderiv->deriv2_classes[4][3][23] = int_stack + 40380;
 Libderiv->deriv2_classes[4][4][23] = int_stack + 40530;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 40755;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 41070;
 Libderiv->deriv2_classes[4][3][22] = int_stack + 41490;
 Libderiv->deriv2_classes[4][4][22] = int_stack + 41640;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 41865;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 42180;
 Libderiv->deriv2_classes[4][3][21] = int_stack + 42600;
 Libderiv->deriv2_classes[4][4][21] = int_stack + 42750;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 42975;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 43290;
 Libderiv->deriv2_classes[4][3][20] = int_stack + 43710;
 Libderiv->deriv2_classes[4][4][20] = int_stack + 43860;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 44085;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 44400;
 Libderiv->deriv2_classes[4][3][19] = int_stack + 44820;
 Libderiv->deriv2_classes[4][4][19] = int_stack + 44970;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 45195;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 45510;
 Libderiv->deriv_classes[4][3][1] = int_stack + 45930;
 Libderiv->deriv2_classes[4][3][18] = int_stack + 46080;
 Libderiv->deriv_classes[4][4][1] = int_stack + 46230;
 Libderiv->deriv2_classes[4][4][18] = int_stack + 46455;
 Libderiv->deriv_classes[4][5][1] = int_stack + 46680;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 46995;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 47310;
 Libderiv->deriv2_classes[4][3][14] = int_stack + 47730;
 Libderiv->deriv2_classes[4][4][14] = int_stack + 47880;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 48105;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 48420;
 Libderiv->deriv2_classes[4][3][13] = int_stack + 48840;
 Libderiv->deriv2_classes[4][4][13] = int_stack + 48990;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 49215;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 49530;
 Libderiv->deriv2_classes[4][3][11] = int_stack + 49950;
 Libderiv->deriv2_classes[4][4][11] = int_stack + 50100;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 50325;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 50640;
 Libderiv->deriv2_classes[4][3][10] = int_stack + 51060;
 Libderiv->deriv2_classes[4][4][10] = int_stack + 51210;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 51435;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 51750;
 Libderiv->deriv2_classes[4][3][9] = int_stack + 52170;
 Libderiv->deriv2_classes[4][4][9] = int_stack + 52320;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 52545;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 52860;
 Libderiv->deriv2_classes[4][3][8] = int_stack + 53280;
 Libderiv->deriv2_classes[4][4][8] = int_stack + 53430;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 53655;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 53970;
 Libderiv->deriv2_classes[4][3][7] = int_stack + 54390;
 Libderiv->deriv2_classes[4][4][7] = int_stack + 54540;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 54765;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 55080;
 Libderiv->deriv_classes[4][3][0] = int_stack + 55500;
 Libderiv->deriv2_classes[4][3][6] = int_stack + 55650;
 Libderiv->deriv_classes[4][4][0] = int_stack + 55800;
 Libderiv->deriv2_classes[4][4][6] = int_stack + 56025;
 Libderiv->deriv_classes[4][5][0] = int_stack + 56250;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 56565;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 56880;
 Libderiv->deriv2_classes[4][3][2] = int_stack + 57300;
 Libderiv->deriv2_classes[4][4][2] = int_stack + 57450;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 57675;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 57990;
 Libderiv->deriv2_classes[4][3][1] = int_stack + 58410;
 Libderiv->deriv2_classes[4][4][1] = int_stack + 58560;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 58785;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 59100;
 Libderiv->deriv2_classes[4][3][0] = int_stack + 59520;
 Libderiv->deriv2_classes[4][4][0] = int_stack + 59670;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 59895;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 60210;
 memset(int_stack,0,485040);

 Libderiv->dvrr_stack = int_stack + 140205;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_g0ff(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libderiv->CD,int_stack+60630,int_stack+30195,int_stack+29745,15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+61080,int_stack+2100,int_stack+30195,15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libderiv->CD,int_stack+61755,int_stack+61080,int_stack+60630,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+62655,int_stack+21045,int_stack+20745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29745,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+63105,int_stack+21495,int_stack+21045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30195,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+63780,int_stack+63105,int_stack+62655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60630,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+64680,int_stack+0,int_stack+21495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+65625,int_stack+64680,int_stack+63105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61080,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+64680,int_stack+22845,int_stack+22545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29745, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+66975,int_stack+23295,int_stack+22845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30195, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+67650,int_stack+66975,int_stack+64680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60630, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+68550,int_stack+420,int_stack+23295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+69495,int_stack+68550,int_stack+66975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61080, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+68550,int_stack+24645,int_stack+24345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29745, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+25095,int_stack+24645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30195, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+70845,int_stack+0,int_stack+68550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60630, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71745,int_stack+840,int_stack+25095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+72690,int_stack+71745,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61080, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+71745,int_stack+26445,int_stack+26145, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+74040,int_stack+26895,int_stack+26445, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+74715,int_stack+74040,int_stack+71745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+75615,int_stack+1260,int_stack+26895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+76560,int_stack+75615,int_stack+74040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+75615,int_stack+28245,int_stack+27945, 0.0, zero_stack, 1.0, int_stack+29745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+675,int_stack+28695,int_stack+28245, 0.0, zero_stack, 1.0, int_stack+30195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+77910,int_stack+675,int_stack+75615, 0.0, zero_stack, 1.0, int_stack+60630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+78810,int_stack+1680,int_stack+28695, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+79755,int_stack+78810,int_stack+675, 0.0, zero_stack, 1.0, int_stack+61080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+78810,int_stack+30420,int_stack+29895, 1.0, int_stack+29745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+30870,int_stack+30420, 1.0, int_stack+30195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+81105,int_stack+1350,int_stack+78810, 1.0, int_stack+60630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+82005,int_stack+2415,int_stack+30870, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+82950,int_stack+82005,int_stack+1350, 1.0, int_stack+61080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libderiv->CD,int_stack+82005,int_stack+37770,int_stack+37470,15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+60630,int_stack+38220,int_stack+37770,15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libderiv->CD,int_stack+84300,int_stack+60630,int_stack+82005,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+85200,int_stack+2835,int_stack+38220,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+86145,int_stack+85200,int_stack+60630,15);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libderiv->CD,int_stack+61305,int_stack+46230,int_stack+45930,15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+85200,int_stack+46680,int_stack+46230,15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libderiv->CD,int_stack+2025,int_stack+85200,int_stack+61305,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+87495,int_stack+3255,int_stack+46680,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+88440,int_stack+87495,int_stack+85200,15);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libderiv->CD,int_stack+87495,int_stack+55800,int_stack+55500,15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+2925,int_stack+56250,int_stack+55800,15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libderiv->CD,int_stack+89790,int_stack+2925,int_stack+87495,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+90690,int_stack+3675,int_stack+56250,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+91635,int_stack+90690,int_stack+2925,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+90690,int_stack+4245,int_stack+4095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+20745,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+92985,int_stack+4470,int_stack+4245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+21045,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+93660,int_stack+92985,int_stack+90690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+62655,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90690,int_stack+4785,int_stack+4470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+21495,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+3600,int_stack+90690,int_stack+92985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+63105,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+92985,int_stack+5355,int_stack+5205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20745, 1.0, int_stack+22545,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+90690,int_stack+5580,int_stack+5355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21045, 1.0, int_stack+22845,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+94560,int_stack+90690,int_stack+92985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62655, 1.0, int_stack+64680,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+95460,int_stack+5895,int_stack+5580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21495, 1.0, int_stack+23295,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+4950,int_stack+95460,int_stack+90690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63105, 1.0, int_stack+66975,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+90690,int_stack+6465,int_stack+6315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+22545, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+92985,int_stack+6690,int_stack+6465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+22845, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+95460,int_stack+92985,int_stack+90690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+64680, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90690,int_stack+7005,int_stack+6690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+23295, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+96360,int_stack+90690,int_stack+92985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+66975, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+92985,int_stack+7575,int_stack+7425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20745, 0.0, zero_stack, 1.0, int_stack+24345,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+90690,int_stack+7800,int_stack+7575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21045, 0.0, zero_stack, 1.0, int_stack+24645,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+6300,int_stack+90690,int_stack+92985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62655, 0.0, zero_stack, 1.0, int_stack+68550,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97710,int_stack+8115,int_stack+7800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21495, 0.0, zero_stack, 1.0, int_stack+25095,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98655,int_stack+97710,int_stack+90690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63105, 0.0, zero_stack, 1.0, int_stack+0,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+90690,int_stack+8685,int_stack+8535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22545, 1.0, int_stack+24345, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+92985,int_stack+8910,int_stack+8685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22845, 1.0, int_stack+24645, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+97710,int_stack+92985,int_stack+90690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64680, 1.0, int_stack+68550, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90690,int_stack+9225,int_stack+8910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23295, 1.0, int_stack+25095, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+7200,int_stack+90690,int_stack+92985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66975, 1.0, int_stack+0, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+92985,int_stack+9795,int_stack+9645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+24345, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+90690,int_stack+10020,int_stack+9795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+24645, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+100005,int_stack+90690,int_stack+92985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+68550, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8550,int_stack+10335,int_stack+10020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+25095, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+100905,int_stack+8550,int_stack+90690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+90690,int_stack+10905,int_stack+10755, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26145,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+92985,int_stack+11130,int_stack+10905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21045, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26445,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+8550,int_stack+92985,int_stack+90690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71745,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90690,int_stack+11445,int_stack+11130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26895,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+9450,int_stack+90690,int_stack+92985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74040,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+92985,int_stack+12015,int_stack+11865, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22545, 0.0, zero_stack, 1.0, int_stack+26145, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+90690,int_stack+12240,int_stack+12015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22845, 0.0, zero_stack, 1.0, int_stack+26445, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+10800,int_stack+90690,int_stack+92985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64680, 0.0, zero_stack, 1.0, int_stack+71745, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102255,int_stack+12555,int_stack+12240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23295, 0.0, zero_stack, 1.0, int_stack+26895, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+103200,int_stack+102255,int_stack+90690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66975, 0.0, zero_stack, 1.0, int_stack+74040, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+90690,int_stack+13125,int_stack+12975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24345, 1.0, int_stack+26145, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+92985,int_stack+13350,int_stack+13125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24645, 1.0, int_stack+26445, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+102255,int_stack+92985,int_stack+90690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68550, 1.0, int_stack+71745, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90690,int_stack+13665,int_stack+13350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25095, 1.0, int_stack+26895, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+11700,int_stack+90690,int_stack+92985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+74040, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+92985,int_stack+14235,int_stack+14085, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+26145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+90690,int_stack+14460,int_stack+14235, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+26445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+13050,int_stack+90690,int_stack+92985, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+71745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+104550,int_stack+14775,int_stack+14460, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+26895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+105495,int_stack+104550,int_stack+90690, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+74040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+90690,int_stack+15345,int_stack+15195, 0.0, zero_stack, 1.0, int_stack+20745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27945,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+92985,int_stack+15570,int_stack+15345, 0.0, zero_stack, 1.0, int_stack+21045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28245,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+104550,int_stack+92985,int_stack+90690, 0.0, zero_stack, 1.0, int_stack+62655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75615,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90690,int_stack+15885,int_stack+15570, 0.0, zero_stack, 1.0, int_stack+21495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28695,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+13950,int_stack+90690,int_stack+92985, 0.0, zero_stack, 1.0, int_stack+63105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+92985,int_stack+16455,int_stack+16305, 0.0, zero_stack, 1.0, int_stack+22545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27945, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+90690,int_stack+16680,int_stack+16455, 0.0, zero_stack, 1.0, int_stack+22845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28245, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+15300,int_stack+90690,int_stack+92985, 0.0, zero_stack, 1.0, int_stack+64680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75615, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+106845,int_stack+16995,int_stack+16680, 0.0, zero_stack, 1.0, int_stack+23295, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28695, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+107790,int_stack+106845,int_stack+90690, 0.0, zero_stack, 1.0, int_stack+66975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+90690,int_stack+17565,int_stack+17415, 0.0, zero_stack, 1.0, int_stack+24345, 0.0, zero_stack, 1.0, int_stack+27945, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+92985,int_stack+17790,int_stack+17565, 0.0, zero_stack, 1.0, int_stack+24645, 0.0, zero_stack, 1.0, int_stack+28245, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+106845,int_stack+92985,int_stack+90690, 0.0, zero_stack, 1.0, int_stack+68550, 0.0, zero_stack, 1.0, int_stack+75615, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90690,int_stack+18105,int_stack+17790, 0.0, zero_stack, 1.0, int_stack+25095, 0.0, zero_stack, 1.0, int_stack+28695, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+16200,int_stack+90690,int_stack+92985, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+675, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+92985,int_stack+18675,int_stack+18525, 0.0, zero_stack, 1.0, int_stack+26145, 1.0, int_stack+27945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+90690,int_stack+18900,int_stack+18675, 0.0, zero_stack, 1.0, int_stack+26445, 1.0, int_stack+28245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+17550,int_stack+90690,int_stack+92985, 0.0, zero_stack, 1.0, int_stack+71745, 1.0, int_stack+75615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109140,int_stack+19215,int_stack+18900, 0.0, zero_stack, 1.0, int_stack+26895, 1.0, int_stack+28695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+110085,int_stack+109140,int_stack+90690, 0.0, zero_stack, 1.0, int_stack+74040, 1.0, int_stack+675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+90690,int_stack+19785,int_stack+19635, 0.0, zero_stack, 2.0, int_stack+27945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+92985,int_stack+20010,int_stack+19785, 0.0, zero_stack, 2.0, int_stack+28245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+109140,int_stack+92985,int_stack+90690, 0.0, zero_stack, 2.0, int_stack+75615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90690,int_stack+20325,int_stack+20010, 0.0, zero_stack, 2.0, int_stack+28695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+18450,int_stack+90690,int_stack+92985, 0.0, zero_stack, 2.0, int_stack+675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+92985,int_stack+21270,int_stack+20895, 1.0, int_stack+20745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29895,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+90690,int_stack+21810,int_stack+21270, 1.0, int_stack+21045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30420,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+19800,int_stack+90690,int_stack+92985, 1.0, int_stack+62655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78810,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+111435,int_stack+22125,int_stack+21810, 1.0, int_stack+21495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30870,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+20700,int_stack+111435,int_stack+90690, 1.0, int_stack+63105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+90690,int_stack+23070,int_stack+22695, 1.0, int_stack+22545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29895, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+92985,int_stack+23610,int_stack+23070, 1.0, int_stack+22845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30420, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+111435,int_stack+92985,int_stack+90690, 1.0, int_stack+64680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78810, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+64680,int_stack+23925,int_stack+23610, 1.0, int_stack+23295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30870, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+22050,int_stack+64680,int_stack+92985, 1.0, int_stack+66975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+66975,int_stack+24870,int_stack+24495, 1.0, int_stack+24345, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29895, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+92985,int_stack+25410,int_stack+24870, 1.0, int_stack+24645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30420, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+64680,int_stack+92985,int_stack+66975, 1.0, int_stack+68550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78810, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+68550,int_stack+25725,int_stack+25410, 1.0, int_stack+25095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30870, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+23400,int_stack+68550,int_stack+92985, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+0,int_stack+26670,int_stack+26295, 1.0, int_stack+26145, 0.0, zero_stack, 1.0, int_stack+29895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+92985,int_stack+27210,int_stack+26670, 1.0, int_stack+26445, 0.0, zero_stack, 1.0, int_stack+30420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+68550,int_stack+92985,int_stack+0, 1.0, int_stack+71745, 0.0, zero_stack, 1.0, int_stack+78810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71745,int_stack+27525,int_stack+27210, 1.0, int_stack+26895, 0.0, zero_stack, 1.0, int_stack+30870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+24750,int_stack+71745,int_stack+92985, 1.0, int_stack+74040, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+74040,int_stack+28470,int_stack+28095, 1.0, int_stack+27945, 1.0, int_stack+29895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+92985,int_stack+29010,int_stack+28470, 1.0, int_stack+28245, 1.0, int_stack+30420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+71745,int_stack+92985,int_stack+74040, 1.0, int_stack+75615, 1.0, int_stack+78810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+75615,int_stack+29325,int_stack+29010, 1.0, int_stack+28695, 1.0, int_stack+30870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+26100,int_stack+75615,int_stack+92985, 1.0, int_stack+675, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+92985,int_stack+30645,int_stack+30045, 2.0, int_stack+29895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+74040,int_stack+31185,int_stack+30645, 2.0, int_stack+30420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+75615,int_stack+74040,int_stack+92985, 2.0, int_stack+78810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+78810,int_stack+31500,int_stack+31185, 2.0, int_stack+30870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+78810,int_stack+74040, 2.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+1350,int_stack+32070,int_stack+31920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37470,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+74040,int_stack+32295,int_stack+32070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37770,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+78810,int_stack+74040,int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82005,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90690,int_stack+32610,int_stack+32295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38220,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+27450,int_stack+90690,int_stack+74040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60630,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+74040,int_stack+33180,int_stack+33030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37470, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+33405,int_stack+33180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37770, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+90690,int_stack+1350,int_stack+74040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82005, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+62655,int_stack+33720,int_stack+33405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38220, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+28800,int_stack+62655,int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60630, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+1350,int_stack+34290,int_stack+34140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37470, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+74040,int_stack+34515,int_stack+34290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37770, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+62655,int_stack+74040,int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82005, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+30150,int_stack+34830,int_stack+34515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38220, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+31095,int_stack+30150,int_stack+74040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60630, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+74040,int_stack+35400,int_stack+35250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+35625,int_stack+35400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+30150,int_stack+1350,int_stack+74040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+32445,int_stack+35940,int_stack+35625, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+33390,int_stack+32445,int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+1350,int_stack+36510,int_stack+36360, 0.0, zero_stack, 1.0, int_stack+37470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+74040,int_stack+36735,int_stack+36510, 0.0, zero_stack, 1.0, int_stack+37770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+32445,int_stack+74040,int_stack+1350, 0.0, zero_stack, 1.0, int_stack+82005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34740,int_stack+37050,int_stack+36735, 0.0, zero_stack, 1.0, int_stack+38220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+35685,int_stack+34740,int_stack+74040, 0.0, zero_stack, 1.0, int_stack+60630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+74040,int_stack+37995,int_stack+37620, 1.0, int_stack+37470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+38535,int_stack+37995, 1.0, int_stack+37770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+34740,int_stack+1350,int_stack+74040, 1.0, int_stack+82005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+82005,int_stack+38850,int_stack+38535, 1.0, int_stack+38220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+37035,int_stack+82005,int_stack+1350, 1.0, int_stack+60630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libderiv->CD,int_stack+60630,int_stack+39420,int_stack+39270,15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+39645,int_stack+39420,15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libderiv->CD,int_stack+82005,int_stack+1350,int_stack+60630,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+38385,int_stack+39960,int_stack+39645,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+112335,int_stack+38385,int_stack+1350,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+1350,int_stack+40530,int_stack+40380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45930,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+60630,int_stack+40755,int_stack+40530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46230,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+38385,int_stack+60630,int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61305,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39285,int_stack+41070,int_stack+40755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46680,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+113685,int_stack+39285,int_stack+60630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85200,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+60630,int_stack+41640,int_stack+41490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45930, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+41865,int_stack+41640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46230, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+39285,int_stack+1350,int_stack+60630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61305, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+40185,int_stack+42180,int_stack+41865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46680, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+41130,int_stack+40185,int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85200, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+1350,int_stack+42750,int_stack+42600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45930, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+60630,int_stack+42975,int_stack+42750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46230, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+40185,int_stack+60630,int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61305, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+115035,int_stack+43290,int_stack+42975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46680, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+115980,int_stack+115035,int_stack+60630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85200, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+60630,int_stack+43860,int_stack+43710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+44085,int_stack+43860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+115035,int_stack+1350,int_stack+60630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+42480,int_stack+44400,int_stack+44085, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+43425,int_stack+42480,int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+1350,int_stack+44970,int_stack+44820, 0.0, zero_stack, 1.0, int_stack+45930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+60630,int_stack+45195,int_stack+44970, 0.0, zero_stack, 1.0, int_stack+46230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+42480,int_stack+60630,int_stack+1350, 0.0, zero_stack, 1.0, int_stack+61305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+117330,int_stack+45510,int_stack+45195, 0.0, zero_stack, 1.0, int_stack+46680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+118275,int_stack+117330,int_stack+60630, 0.0, zero_stack, 1.0, int_stack+85200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+60630,int_stack+46455,int_stack+46080, 1.0, int_stack+45930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+46995,int_stack+46455, 1.0, int_stack+46230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+117330,int_stack+1350,int_stack+60630, 1.0, int_stack+61305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+60630,int_stack+47310,int_stack+46995, 1.0, int_stack+46680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+44775,int_stack+60630,int_stack+1350, 1.0, int_stack+85200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libderiv->CD,int_stack+85200,int_stack+47880,int_stack+47730,15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+48105,int_stack+47880,15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libderiv->CD,int_stack+60630,int_stack+1350,int_stack+85200,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+85200,int_stack+48420,int_stack+48105,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+46125,int_stack+85200,int_stack+1350,15);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libderiv->CD,int_stack+1350,int_stack+48990,int_stack+48840,15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+74040,int_stack+49215,int_stack+48990,15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libderiv->CD,int_stack+85200,int_stack+74040,int_stack+1350,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+47475,int_stack+49530,int_stack+49215,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+48420,int_stack+47475,int_stack+74040,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+74040,int_stack+50100,int_stack+49950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55500,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+50325,int_stack+50100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55800,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+47475,int_stack+1350,int_stack+74040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87495,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+119625,int_stack+50640,int_stack+50325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56250,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+120570,int_stack+119625,int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2925,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+1350,int_stack+51210,int_stack+51060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55500, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+74040,int_stack+51435,int_stack+51210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55800, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+119625,int_stack+74040,int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87495, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49770,int_stack+51750,int_stack+51435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56250, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+50715,int_stack+49770,int_stack+74040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2925, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+74040,int_stack+52320,int_stack+52170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55500, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+52545,int_stack+52320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55800, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+49770,int_stack+1350,int_stack+74040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87495, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+121920,int_stack+52860,int_stack+52545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56250, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+122865,int_stack+121920,int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2925, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+1350,int_stack+53430,int_stack+53280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+74040,int_stack+53655,int_stack+53430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+121920,int_stack+74040,int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+52065,int_stack+53970,int_stack+53655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53010,int_stack+52065,int_stack+74040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+74040,int_stack+54540,int_stack+54390, 0.0, zero_stack, 1.0, int_stack+55500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+54765,int_stack+54540, 0.0, zero_stack, 1.0, int_stack+55800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+52065,int_stack+1350,int_stack+74040, 0.0, zero_stack, 1.0, int_stack+87495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+124215,int_stack+55080,int_stack+54765, 0.0, zero_stack, 1.0, int_stack+56250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+125160,int_stack+124215,int_stack+1350, 0.0, zero_stack, 1.0, int_stack+2925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   d1hrr3_build_fp(Libderiv->CD,int_stack+1350,int_stack+56025,int_stack+55650, 1.0, int_stack+55500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+74040,int_stack+56565,int_stack+56025, 1.0, int_stack+55800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fd) ---*/
   d1hrr3_build_fd(Libderiv->CD,int_stack+124215,int_stack+74040,int_stack+1350, 1.0, int_stack+87495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+87495,int_stack+56880,int_stack+56565, 1.0, int_stack+56250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+54360,int_stack+87495,int_stack+74040, 1.0, int_stack+2925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libderiv->CD,int_stack+2925,int_stack+57450,int_stack+57300,15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+74040,int_stack+57675,int_stack+57450,15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libderiv->CD,int_stack+87495,int_stack+74040,int_stack+2925,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+55710,int_stack+57990,int_stack+57675,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+56655,int_stack+55710,int_stack+74040,15);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libderiv->CD,int_stack+74040,int_stack+58560,int_stack+58410,15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+2925,int_stack+58785,int_stack+58560,15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libderiv->CD,int_stack+55710,int_stack+2925,int_stack+74040,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+126510,int_stack+59100,int_stack+58785,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+58005,int_stack+126510,int_stack+2925,15);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libderiv->CD,int_stack+2925,int_stack+59670,int_stack+59520,15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+74040,int_stack+59895,int_stack+59670,15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libderiv->CD,int_stack+126510,int_stack+74040,int_stack+2925,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+127410,int_stack+60210,int_stack+59895,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+128355,int_stack+127410,int_stack+74040,15);
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+129705,int_stack+65625,int_stack+63780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61755,15);
     Libderiv->ABCD[11] = int_stack + 129705;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+65580,int_stack+69495,int_stack+67650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61755, 0.0, zero_stack,15);
     Libderiv->ABCD[10] = int_stack + 65580;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+131205,int_stack+72690,int_stack+70845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61755, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[9] = int_stack + 131205;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+72645,int_stack+76560,int_stack+74715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[8] = int_stack + 72645;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+132705,int_stack+79755,int_stack+77910, 0.0, zero_stack, 1.0, int_stack+61755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[7] = int_stack + 132705;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+134205,int_stack+82950,int_stack+81105, 1.0, int_stack+61755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[6] = int_stack + 134205;
 /*--- compute (g0|ff) ---*/
   hrr3_build_ff(Libderiv->CD,int_stack+135705,int_stack+86145,int_stack+84300,15);
     Libderiv->ABCD[2] = int_stack + 135705;
 /*--- compute (g0|ff) ---*/
   hrr3_build_ff(Libderiv->CD,int_stack+137205,int_stack+88440,int_stack+2025,15);
     Libderiv->ABCD[1] = int_stack + 137205;
 /*--- compute (g0|ff) ---*/
   hrr3_build_ff(Libderiv->CD,int_stack+138705,int_stack+91635,int_stack+89790,15);
     Libderiv->ABCD[0] = int_stack + 138705;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+91590,int_stack+3600,int_stack+93660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+63780,15);
     Libderiv->ABCD[155] = int_stack + 91590;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+2925,int_stack+4950,int_stack+94560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63780, 1.0, int_stack+67650,15);
     Libderiv->ABCD[143] = int_stack + 2925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+4425,int_stack+96360,int_stack+95460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+67650, 0.0, zero_stack,15);
     Libderiv->ABCD[142] = int_stack + 4425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+93090,int_stack+98655,int_stack+6300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63780, 0.0, zero_stack, 1.0, int_stack+70845,15);
     Libderiv->ABCD[131] = int_stack + 93090;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+94590,int_stack+7200,int_stack+97710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67650, 1.0, int_stack+70845, 0.0, zero_stack,15);
     Libderiv->ABCD[130] = int_stack + 94590;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+5925,int_stack+100905,int_stack+100005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+70845, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[129] = int_stack + 5925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+96090,int_stack+9450,int_stack+8550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74715,15);
     Libderiv->ABCD[119] = int_stack + 96090;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+7425,int_stack+103200,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67650, 0.0, zero_stack, 1.0, int_stack+74715, 0.0, zero_stack,15);
     Libderiv->ABCD[118] = int_stack + 7425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+8925,int_stack+11700,int_stack+102255, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70845, 1.0, int_stack+74715, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[117] = int_stack + 8925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+10425,int_stack+105495,int_stack+13050, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+74715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[116] = int_stack + 10425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+11925,int_stack+13950,int_stack+104550, 0.0, zero_stack, 1.0, int_stack+63780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77910,15);
     Libderiv->ABCD[107] = int_stack + 11925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+13425,int_stack+107790,int_stack+15300, 0.0, zero_stack, 1.0, int_stack+67650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77910, 0.0, zero_stack,15);
     Libderiv->ABCD[106] = int_stack + 13425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+97590,int_stack+16200,int_stack+106845, 0.0, zero_stack, 1.0, int_stack+70845, 0.0, zero_stack, 1.0, int_stack+77910, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[105] = int_stack + 97590;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+14925,int_stack+110085,int_stack+17550, 0.0, zero_stack, 1.0, int_stack+74715, 1.0, int_stack+77910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[104] = int_stack + 14925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+16425,int_stack+18450,int_stack+109140, 0.0, zero_stack, 2.0, int_stack+77910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[103] = int_stack + 16425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+17925,int_stack+20700,int_stack+19800, 1.0, int_stack+63780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81105,15);
     Libderiv->ABCD[95] = int_stack + 17925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+19425,int_stack+22050,int_stack+111435, 1.0, int_stack+67650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81105, 0.0, zero_stack,15);
     Libderiv->ABCD[94] = int_stack + 19425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+20925,int_stack+23400,int_stack+64680, 1.0, int_stack+70845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81105, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[93] = int_stack + 20925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+22425,int_stack+24750,int_stack+68550, 1.0, int_stack+74715, 0.0, zero_stack, 1.0, int_stack+81105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[92] = int_stack + 22425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+23925,int_stack+26100,int_stack+71745, 1.0, int_stack+77910, 1.0, int_stack+81105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[91] = int_stack + 23925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+25425,int_stack+0,int_stack+75615, 2.0, int_stack+81105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[90] = int_stack + 25425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+0,int_stack+27450,int_stack+78810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84300,15);
     Libderiv->ABCD[47] = int_stack + 0;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+26925,int_stack+28800,int_stack+90690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84300, 0.0, zero_stack,15);
     Libderiv->ABCD[46] = int_stack + 26925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+28425,int_stack+31095,int_stack+62655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84300, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[45] = int_stack + 28425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+61530,int_stack+33390,int_stack+30150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[44] = int_stack + 61530;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+29925,int_stack+35685,int_stack+32445, 0.0, zero_stack, 1.0, int_stack+84300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[43] = int_stack + 29925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+31425,int_stack+37035,int_stack+34740, 1.0, int_stack+84300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[42] = int_stack + 31425;
 /*--- compute (g0|ff) ---*/
   hrr3_build_ff(Libderiv->CD,int_stack+32925,int_stack+112335,int_stack+82005,15);
     Libderiv->ABCD[38] = int_stack + 32925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+34425,int_stack+113685,int_stack+38385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2025,15);
     Libderiv->ABCD[35] = int_stack + 34425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+35925,int_stack+41130,int_stack+39285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2025, 0.0, zero_stack,15);
     Libderiv->ABCD[34] = int_stack + 35925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+37425,int_stack+115980,int_stack+40185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2025, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[33] = int_stack + 37425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+38925,int_stack+43425,int_stack+115035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[32] = int_stack + 38925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+40425,int_stack+118275,int_stack+42480, 0.0, zero_stack, 1.0, int_stack+2025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[31] = int_stack + 40425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+41925,int_stack+44775,int_stack+117330, 1.0, int_stack+2025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[30] = int_stack + 41925;
 /*--- compute (g0|ff) ---*/
   hrr3_build_ff(Libderiv->CD,int_stack+43425,int_stack+46125,int_stack+60630,15);
     Libderiv->ABCD[26] = int_stack + 43425;
 /*--- compute (g0|ff) ---*/
   hrr3_build_ff(Libderiv->CD,int_stack+44925,int_stack+48420,int_stack+85200,15);
     Libderiv->ABCD[25] = int_stack + 44925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+63030,int_stack+120570,int_stack+47475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89790,15);
     Libderiv->ABCD[23] = int_stack + 63030;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+46425,int_stack+50715,int_stack+119625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89790, 0.0, zero_stack,15);
     Libderiv->ABCD[22] = int_stack + 46425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+47925,int_stack+122865,int_stack+49770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89790, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[21] = int_stack + 47925;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+49425,int_stack+53010,int_stack+121920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[20] = int_stack + 49425;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+59355,int_stack+125160,int_stack+52065, 0.0, zero_stack, 1.0, int_stack+89790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[19] = int_stack + 59355;
 /*--- compute (g0|ff) ---*/
   d1hrr3_build_ff(Libderiv->CD,int_stack+50925,int_stack+54360,int_stack+124215, 1.0, int_stack+89790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[18] = int_stack + 50925;
 /*--- compute (g0|ff) ---*/
   hrr3_build_ff(Libderiv->CD,int_stack+52425,int_stack+56655,int_stack+87495,15);
     Libderiv->ABCD[14] = int_stack + 52425;
 /*--- compute (g0|ff) ---*/
   hrr3_build_ff(Libderiv->CD,int_stack+53925,int_stack+58005,int_stack+55710,15);
     Libderiv->ABCD[13] = int_stack + 53925;
 /*--- compute (g0|ff) ---*/
   hrr3_build_ff(Libderiv->CD,int_stack+55425,int_stack+128355,int_stack+126510,15);
     Libderiv->ABCD[12] = int_stack + 55425;

}
