/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_h0hp(Libderiv_t *, prim_data *);

  /* Computes derivatives of (h0|hp) integrals */

void d12hrr_order_h0hp(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][6][11] = int_stack + 0;
 Libderiv->deriv_classes[5][6][10] = int_stack + 588;
 Libderiv->deriv_classes[5][6][9] = int_stack + 1176;
 Libderiv->deriv_classes[5][6][8] = int_stack + 1764;
 Libderiv->deriv_classes[5][6][7] = int_stack + 2352;
 Libderiv->dvrr_classes[5][5] = int_stack + 2940;
 Libderiv->deriv_classes[5][6][6] = int_stack + 3381;
 Libderiv->deriv_classes[5][6][2] = int_stack + 3969;
 Libderiv->deriv_classes[5][6][1] = int_stack + 4557;
 Libderiv->deriv_classes[5][6][0] = int_stack + 5145;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 5733;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 6174;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 6762;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 7203;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 7791;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 8232;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 8820;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 9261;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 9849;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 10290;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 10878;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 11319;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 11907;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 12348;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 12936;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 13377;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 13965;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 14406;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 14994;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 15435;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 16023;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 16464;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 17052;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 17493;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 18081;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 18522;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 19110;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 19551;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 20139;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 20580;
 Libderiv->deriv_classes[5][5][11] = int_stack + 21168;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 21609;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 22050;
 Libderiv->deriv_classes[5][5][10] = int_stack + 22638;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 23079;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 23520;
 Libderiv->deriv_classes[5][5][9] = int_stack + 24108;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 24549;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 24990;
 Libderiv->deriv_classes[5][5][8] = int_stack + 25578;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 26019;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 26460;
 Libderiv->deriv_classes[5][5][7] = int_stack + 27048;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 27489;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 27930;
 Libderiv->deriv_classes[5][5][6] = int_stack + 28518;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 28959;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 29400;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 29988;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 30429;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 31017;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 31458;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 32046;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 32487;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 33075;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 33516;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 34104;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 34545;
 Libderiv->deriv_classes[5][5][2] = int_stack + 35133;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 35574;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 36015;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 36603;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 37044;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 37632;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 38073;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 38661;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 39102;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 39690;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 40131;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 40719;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 41160;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 41748;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 42189;
 Libderiv->deriv_classes[5][5][1] = int_stack + 42777;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 43218;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 43659;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 44247;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 44688;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 45276;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 45717;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 46305;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 46746;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 47334;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 47775;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 48363;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 48804;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 49392;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 49833;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 50421;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 50862;
 Libderiv->deriv_classes[5][5][0] = int_stack + 51450;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 51891;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 52332;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 52920;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 53361;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 53949;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 54390;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 54978;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 55419;
 memset(int_stack,0,448056);

 Libderiv->dvrr_stack = int_stack + 73206;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_h0hp(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+56007,int_stack+0,int_stack+21168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2940,21);
     Libderiv->ABCD[11] = int_stack + 56007;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+57330,int_stack+588,int_stack+22638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2940, 0.0, zero_stack,21);
     Libderiv->ABCD[10] = int_stack + 57330;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58653,int_stack+1176,int_stack+24108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2940, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[9] = int_stack + 58653;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+1764,int_stack+25578, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+59976,int_stack+2352,int_stack+27048, 0.0, zero_stack, 1.0, int_stack+2940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[7] = int_stack + 59976;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1323,int_stack+3381,int_stack+28518, 1.0, int_stack+2940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[6] = int_stack + 1323;
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2646,int_stack+3969,int_stack+35133,21);
     Libderiv->ABCD[2] = int_stack + 2646;
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+61299,int_stack+4557,int_stack+42777,21);
     Libderiv->ABCD[1] = int_stack + 61299;
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+62622,int_stack+5145,int_stack+51450,21);
     Libderiv->ABCD[0] = int_stack + 62622;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3969,int_stack+6174,int_stack+5733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+21168,21);
     Libderiv->ABCD[155] = int_stack + 3969;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5292,int_stack+7203,int_stack+6762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21168, 1.0, int_stack+22638,21);
     Libderiv->ABCD[143] = int_stack + 5292;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+63945,int_stack+8232,int_stack+7791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+22638, 0.0, zero_stack,21);
     Libderiv->ABCD[142] = int_stack + 63945;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6615,int_stack+9261,int_stack+8820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21168, 0.0, zero_stack, 1.0, int_stack+24108,21);
     Libderiv->ABCD[131] = int_stack + 6615;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7938,int_stack+10290,int_stack+9849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22638, 1.0, int_stack+24108, 0.0, zero_stack,21);
     Libderiv->ABCD[130] = int_stack + 7938;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9261,int_stack+11319,int_stack+10878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+24108, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[129] = int_stack + 9261;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10584,int_stack+12348,int_stack+11907, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21168, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25578,21);
     Libderiv->ABCD[119] = int_stack + 10584;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65268,int_stack+13377,int_stack+12936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22638, 0.0, zero_stack, 1.0, int_stack+25578, 0.0, zero_stack,21);
     Libderiv->ABCD[118] = int_stack + 65268;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11907,int_stack+14406,int_stack+13965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24108, 1.0, int_stack+25578, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[117] = int_stack + 11907;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13230,int_stack+15435,int_stack+14994, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+25578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[116] = int_stack + 13230;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+14553,int_stack+16464,int_stack+16023, 0.0, zero_stack, 1.0, int_stack+21168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27048,21);
     Libderiv->ABCD[107] = int_stack + 14553;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+66591,int_stack+17493,int_stack+17052, 0.0, zero_stack, 1.0, int_stack+22638, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27048, 0.0, zero_stack,21);
     Libderiv->ABCD[106] = int_stack + 66591;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15876,int_stack+18522,int_stack+18081, 0.0, zero_stack, 1.0, int_stack+24108, 0.0, zero_stack, 1.0, int_stack+27048, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[105] = int_stack + 15876;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17199,int_stack+19551,int_stack+19110, 0.0, zero_stack, 1.0, int_stack+25578, 1.0, int_stack+27048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[104] = int_stack + 17199;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18522,int_stack+20580,int_stack+20139, 0.0, zero_stack, 2.0, int_stack+27048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[103] = int_stack + 18522;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+19845,int_stack+22050,int_stack+21609, 1.0, int_stack+21168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28518,21);
     Libderiv->ABCD[95] = int_stack + 19845;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+21168,int_stack+23520,int_stack+23079, 1.0, int_stack+22638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28518, 0.0, zero_stack,21);
     Libderiv->ABCD[94] = int_stack + 21168;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+22491,int_stack+24990,int_stack+24549, 1.0, int_stack+24108, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28518, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[93] = int_stack + 22491;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23814,int_stack+26460,int_stack+26019, 1.0, int_stack+25578, 0.0, zero_stack, 1.0, int_stack+28518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[92] = int_stack + 23814;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+25137,int_stack+27930,int_stack+27489, 1.0, int_stack+27048, 1.0, int_stack+28518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[91] = int_stack + 25137;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26460,int_stack+29400,int_stack+28959, 2.0, int_stack+28518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[90] = int_stack + 26460;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+27783,int_stack+30429,int_stack+29988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35133,21);
     Libderiv->ABCD[47] = int_stack + 27783;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29106,int_stack+31458,int_stack+31017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35133, 0.0, zero_stack,21);
     Libderiv->ABCD[46] = int_stack + 29106;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+30429,int_stack+32487,int_stack+32046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35133, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[45] = int_stack + 30429;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+31752,int_stack+33516,int_stack+33075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35133, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[44] = int_stack + 31752;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+67914,int_stack+34545,int_stack+34104, 0.0, zero_stack, 1.0, int_stack+35133, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[43] = int_stack + 67914;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+33075,int_stack+36015,int_stack+35574, 1.0, int_stack+35133, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[42] = int_stack + 33075;
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+34398,int_stack+37044,int_stack+36603,21);
     Libderiv->ABCD[38] = int_stack + 34398;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+35721,int_stack+38073,int_stack+37632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42777,21);
     Libderiv->ABCD[35] = int_stack + 35721;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+37044,int_stack+39102,int_stack+38661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42777, 0.0, zero_stack,21);
     Libderiv->ABCD[34] = int_stack + 37044;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38367,int_stack+40131,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42777, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[33] = int_stack + 38367;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+69237,int_stack+41160,int_stack+40719, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[32] = int_stack + 69237;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39690,int_stack+42189,int_stack+41748, 0.0, zero_stack, 1.0, int_stack+42777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[31] = int_stack + 39690;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+41013,int_stack+43659,int_stack+43218, 1.0, int_stack+42777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[30] = int_stack + 41013;
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+42336,int_stack+44688,int_stack+44247,21);
     Libderiv->ABCD[26] = int_stack + 42336;
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+43659,int_stack+45717,int_stack+45276,21);
     Libderiv->ABCD[25] = int_stack + 43659;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+44982,int_stack+46746,int_stack+46305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51450,21);
     Libderiv->ABCD[23] = int_stack + 44982;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+70560,int_stack+47775,int_stack+47334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51450, 0.0, zero_stack,21);
     Libderiv->ABCD[22] = int_stack + 70560;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46305,int_stack+48804,int_stack+48363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51450, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[21] = int_stack + 46305;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47628,int_stack+49833,int_stack+49392, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[20] = int_stack + 47628;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48951,int_stack+50862,int_stack+50421, 0.0, zero_stack, 1.0, int_stack+51450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[19] = int_stack + 48951;
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71883,int_stack+52332,int_stack+51891, 1.0, int_stack+51450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
     Libderiv->ABCD[18] = int_stack + 71883;
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+50274,int_stack+53361,int_stack+52920,21);
     Libderiv->ABCD[14] = int_stack + 50274;
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+51597,int_stack+54390,int_stack+53949,21);
     Libderiv->ABCD[13] = int_stack + 51597;
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+52920,int_stack+55419,int_stack+54978,21);
     Libderiv->ABCD[12] = int_stack + 52920;

}
