/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_fpig(Libderiv_t *, prim_data *);

  /* Computes derivatives of (fp|ig) integrals */

void d1hrr_order_fpig(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][6][11] = int_stack + 0;
 Libderiv->deriv_classes[3][7][11] = int_stack + 280;
 Libderiv->deriv_classes[3][8][11] = int_stack + 640;
 Libderiv->deriv_classes[3][9][11] = int_stack + 1090;
 Libderiv->deriv_classes[3][10][11] = int_stack + 1640;
 Libderiv->deriv_classes[4][6][11] = int_stack + 2300;
 Libderiv->deriv_classes[4][7][11] = int_stack + 2720;
 Libderiv->deriv_classes[4][8][11] = int_stack + 3260;
 Libderiv->deriv_classes[4][9][11] = int_stack + 3935;
 Libderiv->deriv_classes[4][10][11] = int_stack + 4760;
 Libderiv->deriv_classes[3][6][10] = int_stack + 5750;
 Libderiv->deriv_classes[3][7][10] = int_stack + 6030;
 Libderiv->deriv_classes[3][8][10] = int_stack + 6390;
 Libderiv->deriv_classes[3][9][10] = int_stack + 6840;
 Libderiv->deriv_classes[3][10][10] = int_stack + 7390;
 Libderiv->deriv_classes[4][6][10] = int_stack + 8050;
 Libderiv->deriv_classes[4][7][10] = int_stack + 8470;
 Libderiv->deriv_classes[4][8][10] = int_stack + 9010;
 Libderiv->deriv_classes[4][9][10] = int_stack + 9685;
 Libderiv->deriv_classes[4][10][10] = int_stack + 10510;
 Libderiv->deriv_classes[3][6][9] = int_stack + 11500;
 Libderiv->deriv_classes[3][7][9] = int_stack + 11780;
 Libderiv->deriv_classes[3][8][9] = int_stack + 12140;
 Libderiv->deriv_classes[3][9][9] = int_stack + 12590;
 Libderiv->deriv_classes[3][10][9] = int_stack + 13140;
 Libderiv->deriv_classes[4][6][9] = int_stack + 13800;
 Libderiv->deriv_classes[4][7][9] = int_stack + 14220;
 Libderiv->deriv_classes[4][8][9] = int_stack + 14760;
 Libderiv->deriv_classes[4][9][9] = int_stack + 15435;
 Libderiv->deriv_classes[4][10][9] = int_stack + 16260;
 Libderiv->deriv_classes[3][6][8] = int_stack + 17250;
 Libderiv->deriv_classes[3][7][8] = int_stack + 17530;
 Libderiv->deriv_classes[3][8][8] = int_stack + 17890;
 Libderiv->deriv_classes[3][9][8] = int_stack + 18340;
 Libderiv->deriv_classes[3][10][8] = int_stack + 18890;
 Libderiv->deriv_classes[4][6][8] = int_stack + 19550;
 Libderiv->deriv_classes[4][7][8] = int_stack + 19970;
 Libderiv->deriv_classes[4][8][8] = int_stack + 20510;
 Libderiv->deriv_classes[4][9][8] = int_stack + 21185;
 Libderiv->deriv_classes[4][10][8] = int_stack + 22010;
 Libderiv->deriv_classes[3][6][7] = int_stack + 23000;
 Libderiv->deriv_classes[3][7][7] = int_stack + 23280;
 Libderiv->deriv_classes[3][8][7] = int_stack + 23640;
 Libderiv->deriv_classes[3][9][7] = int_stack + 24090;
 Libderiv->deriv_classes[3][10][7] = int_stack + 24640;
 Libderiv->deriv_classes[4][6][7] = int_stack + 25300;
 Libderiv->deriv_classes[4][7][7] = int_stack + 25720;
 Libderiv->deriv_classes[4][8][7] = int_stack + 26260;
 Libderiv->deriv_classes[4][9][7] = int_stack + 26935;
 Libderiv->deriv_classes[4][10][7] = int_stack + 27760;
 Libderiv->deriv_classes[3][6][6] = int_stack + 28750;
 Libderiv->deriv_classes[3][7][6] = int_stack + 29030;
 Libderiv->deriv_classes[3][8][6] = int_stack + 29390;
 Libderiv->deriv_classes[3][9][6] = int_stack + 29840;
 Libderiv->deriv_classes[3][10][6] = int_stack + 30390;
 Libderiv->dvrr_classes[4][6] = int_stack + 31050;
 Libderiv->deriv_classes[4][6][6] = int_stack + 31470;
 Libderiv->dvrr_classes[4][7] = int_stack + 31890;
 Libderiv->deriv_classes[4][7][6] = int_stack + 32430;
 Libderiv->dvrr_classes[4][8] = int_stack + 32970;
 Libderiv->deriv_classes[4][8][6] = int_stack + 33645;
 Libderiv->dvrr_classes[4][9] = int_stack + 34320;
 Libderiv->deriv_classes[4][9][6] = int_stack + 35145;
 Libderiv->deriv_classes[4][10][6] = int_stack + 35970;
 Libderiv->deriv_classes[3][6][2] = int_stack + 36960;
 Libderiv->deriv_classes[3][7][2] = int_stack + 37240;
 Libderiv->deriv_classes[3][8][2] = int_stack + 37600;
 Libderiv->deriv_classes[3][9][2] = int_stack + 38050;
 Libderiv->deriv_classes[3][10][2] = int_stack + 38600;
 Libderiv->deriv_classes[4][6][2] = int_stack + 39260;
 Libderiv->deriv_classes[4][7][2] = int_stack + 39680;
 Libderiv->deriv_classes[4][8][2] = int_stack + 40220;
 Libderiv->deriv_classes[4][9][2] = int_stack + 40895;
 Libderiv->deriv_classes[4][10][2] = int_stack + 41720;
 Libderiv->deriv_classes[3][6][1] = int_stack + 42710;
 Libderiv->deriv_classes[3][7][1] = int_stack + 42990;
 Libderiv->deriv_classes[3][8][1] = int_stack + 43350;
 Libderiv->deriv_classes[3][9][1] = int_stack + 43800;
 Libderiv->deriv_classes[3][10][1] = int_stack + 44350;
 Libderiv->deriv_classes[4][6][1] = int_stack + 45010;
 Libderiv->deriv_classes[4][7][1] = int_stack + 45430;
 Libderiv->deriv_classes[4][8][1] = int_stack + 45970;
 Libderiv->deriv_classes[4][9][1] = int_stack + 46645;
 Libderiv->deriv_classes[4][10][1] = int_stack + 47470;
 Libderiv->dvrr_classes[3][6] = int_stack + 48460;
 Libderiv->dvrr_classes[3][7] = int_stack + 48740;
 Libderiv->dvrr_classes[3][8] = int_stack + 49100;
 Libderiv->dvrr_classes[3][9] = int_stack + 49550;
 Libderiv->dvrr_classes[3][10] = int_stack + 50100;
 Libderiv->deriv_classes[3][6][0] = int_stack + 50760;
 Libderiv->deriv_classes[3][7][0] = int_stack + 51040;
 Libderiv->deriv_classes[3][8][0] = int_stack + 51400;
 Libderiv->deriv_classes[3][9][0] = int_stack + 51850;
 Libderiv->deriv_classes[3][10][0] = int_stack + 52400;
 Libderiv->deriv_classes[4][6][0] = int_stack + 53060;
 Libderiv->deriv_classes[4][7][0] = int_stack + 53480;
 Libderiv->deriv_classes[4][8][0] = int_stack + 54020;
 Libderiv->deriv_classes[4][9][0] = int_stack + 54695;
 Libderiv->deriv_classes[4][10][0] = int_stack + 55520;
 memset(int_stack,0,452080);

 Libderiv->dvrr_stack = int_stack + 157930;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_fpig(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+56510,int_stack+48740,int_stack+48460,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+57350,int_stack+49100,int_stack+48740,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+58430,int_stack+57350,int_stack+56510,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+60110,int_stack+49550,int_stack+49100,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+61460,int_stack+60110,int_stack+57350,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+63620,int_stack+61460,int_stack+58430,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+66420,int_stack+280,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48460,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+67260,int_stack+640,int_stack+280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48740,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+68340,int_stack+67260,int_stack+66420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56510,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+70020,int_stack+1090,int_stack+640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49100,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+71370,int_stack+70020,int_stack+67260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57350,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+73530,int_stack+71370,int_stack+68340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58430,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+66420,int_stack+1640,int_stack+1090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49550,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+76330,int_stack+66420,int_stack+70020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60110,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+66420,int_stack+76330,int_stack+71370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61460,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+76330,int_stack+66420,int_stack+73530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63620,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+66420,int_stack+31890,int_stack+31050,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+67680,int_stack+32970,int_stack+31890,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+69300,int_stack+67680,int_stack+66420,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+71820,int_stack+34320,int_stack+32970,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+80530,int_stack+71820,int_stack+67680,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+83770,int_stack+80530,int_stack+69300,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+73845,int_stack+2720,int_stack+2300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31050,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+3260,int_stack+2720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31890,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+87970,int_stack+0,int_stack+73845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66420,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+73845,int_stack+3935,int_stack+3260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32970,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+90490,int_stack+73845,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67680,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+93730,int_stack+90490,int_stack+87970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69300,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+87970,int_stack+4760,int_stack+3935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34320,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+87970,int_stack+73845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71820,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+97930,int_stack+0,int_stack+90490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80530,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+103330,int_stack+97930,int_stack+93730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83770,15);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+6030,int_stack+5750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48460, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+840,int_stack+6390,int_stack+6030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48740, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1920,int_stack+840,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56510, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3600,int_stack+6840,int_stack+6390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49100, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+73845,int_stack+3600,int_stack+840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57350, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+87970,int_stack+73845,int_stack+1920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58430, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+7390,int_stack+6840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49550, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4950,int_stack+0,int_stack+3600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60110, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+4950,int_stack+73845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61460, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3600,int_stack+0,int_stack+87970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63620, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+87970,int_stack+8470,int_stack+8050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31050, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+89230,int_stack+9010,int_stack+8470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31890, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+90850,int_stack+89230,int_stack+87970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66420, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+93370,int_stack+9685,int_stack+9010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32970, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+95395,int_stack+93370,int_stack+89230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67680, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+98635,int_stack+95395,int_stack+90850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69300, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+87970,int_stack+10510,int_stack+9685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34320, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+109630,int_stack+87970,int_stack+93370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71820, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+87970,int_stack+109630,int_stack+95395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80530, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+109630,int_stack+87970,int_stack+98635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83770, 0.0, zero_stack,15);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+87970,int_stack+11780,int_stack+11500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48460, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+88810,int_stack+12140,int_stack+11780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48740, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+89890,int_stack+88810,int_stack+87970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56510, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+91570,int_stack+12590,int_stack+12140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49100, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+92920,int_stack+91570,int_stack+88810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57350, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+95080,int_stack+92920,int_stack+89890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58430, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+87970,int_stack+13140,int_stack+12590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49550, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+97880,int_stack+87970,int_stack+91570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60110, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+97880,int_stack+92920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61460, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+97880,int_stack+0,int_stack+95080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63620, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+14220,int_stack+13800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31050, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+14760,int_stack+14220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31890, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+87970,int_stack+1260,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66420, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+90490,int_stack+15435,int_stack+14760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32970, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+92515,int_stack+90490,int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67680, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7800,int_stack+92515,int_stack+87970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69300, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+87970,int_stack+16260,int_stack+15435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34320, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12000,int_stack+87970,int_stack+90490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71820, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+115930,int_stack+12000,int_stack+92515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80530, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+87970,int_stack+115930,int_stack+7800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83770, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7800,int_stack+17530,int_stack+17250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8640,int_stack+17890,int_stack+17530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9720,int_stack+8640,int_stack+7800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11400,int_stack+18340,int_stack+17890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12750,int_stack+11400,int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+14910,int_stack+12750,int_stack+9720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7800,int_stack+18890,int_stack+18340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+115930,int_stack+7800,int_stack+11400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+115930,int_stack+12750, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+115930,int_stack+0,int_stack+14910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+19970,int_stack+19550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+20510,int_stack+19970, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7800,int_stack+1260,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10320,int_stack+21185,int_stack+20510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12345,int_stack+10320,int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+15585,int_stack+12345,int_stack+7800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7800,int_stack+22010,int_stack+21185, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+120130,int_stack+7800,int_stack+10320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+124180,int_stack+120130,int_stack+12345, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7800,int_stack+124180,int_stack+15585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+120130,int_stack+23280,int_stack+23000, 0.0, zero_stack, 1.0, int_stack+48460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+120970,int_stack+23640,int_stack+23280, 0.0, zero_stack, 1.0, int_stack+48740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+122050,int_stack+120970,int_stack+120130, 0.0, zero_stack, 1.0, int_stack+56510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+123730,int_stack+24090,int_stack+23640, 0.0, zero_stack, 1.0, int_stack+49100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+125080,int_stack+123730,int_stack+120970, 0.0, zero_stack, 1.0, int_stack+57350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+14100,int_stack+125080,int_stack+122050, 0.0, zero_stack, 1.0, int_stack+58430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+120130,int_stack+24640,int_stack+24090, 0.0, zero_stack, 1.0, int_stack+49550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+127240,int_stack+120130,int_stack+123730, 0.0, zero_stack, 1.0, int_stack+60110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+127240,int_stack+125080, 0.0, zero_stack, 1.0, int_stack+61460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+120130,int_stack+0,int_stack+14100, 0.0, zero_stack, 1.0, int_stack+63620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14100,int_stack+25720,int_stack+25300, 0.0, zero_stack, 1.0, int_stack+31050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15360,int_stack+26260,int_stack+25720, 0.0, zero_stack, 1.0, int_stack+31890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+16980,int_stack+15360,int_stack+14100, 0.0, zero_stack, 1.0, int_stack+66420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+19500,int_stack+26935,int_stack+26260, 0.0, zero_stack, 1.0, int_stack+32970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+21525,int_stack+19500,int_stack+15360, 0.0, zero_stack, 1.0, int_stack+67680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+124330,int_stack+21525,int_stack+16980, 0.0, zero_stack, 1.0, int_stack+69300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+14100,int_stack+27760,int_stack+26935, 0.0, zero_stack, 1.0, int_stack+34320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+128530,int_stack+14100,int_stack+19500, 0.0, zero_stack, 1.0, int_stack+71820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+14100,int_stack+128530,int_stack+21525, 0.0, zero_stack, 1.0, int_stack+80530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+19500,int_stack+14100,int_stack+124330, 0.0, zero_stack, 1.0, int_stack+83770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+124330,int_stack+29030,int_stack+28750, 1.0, int_stack+48460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+125170,int_stack+29390,int_stack+29030, 1.0, int_stack+48740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+126250,int_stack+125170,int_stack+124330, 1.0, int_stack+56510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+127930,int_stack+29840,int_stack+29390, 1.0, int_stack+49100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+129280,int_stack+127930,int_stack+125170, 1.0, int_stack+57350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+14100,int_stack+129280,int_stack+126250, 1.0, int_stack+58430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+56510,int_stack+30390,int_stack+29840, 1.0, int_stack+49550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+124330,int_stack+56510,int_stack+127930, 1.0, int_stack+60110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+56510,int_stack+124330,int_stack+129280, 1.0, int_stack+61460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+124330,int_stack+56510,int_stack+14100, 1.0, int_stack+63620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14100,int_stack+32430,int_stack+31470, 1.0, int_stack+31050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15360,int_stack+33645,int_stack+32430, 1.0, int_stack+31890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+16980,int_stack+15360,int_stack+14100, 1.0, int_stack+66420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+56510,int_stack+35145,int_stack+33645, 1.0, int_stack+32970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+128530,int_stack+56510,int_stack+15360, 1.0, int_stack+67680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+25800,int_stack+128530,int_stack+16980, 1.0, int_stack+69300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+66420,int_stack+35970,int_stack+35145, 1.0, int_stack+34320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+14100,int_stack+66420,int_stack+56510, 1.0, int_stack+71820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+66420,int_stack+14100,int_stack+128530, 1.0, int_stack+80530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+30000,int_stack+66420,int_stack+25800, 1.0, int_stack+83770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+25800,int_stack+50100,int_stack+49550,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+66420,int_stack+25800,int_stack+60110,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+66420,int_stack+61460,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+25800,int_stack+0,int_stack+63620,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+37240,int_stack+36960,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+840,int_stack+37600,int_stack+37240,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1920,int_stack+840,int_stack+0,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+80530,int_stack+38050,int_stack+37600,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+81880,int_stack+80530,int_stack+840,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+84040,int_stack+81880,int_stack+1920,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+38600,int_stack+38050,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+128530,int_stack+0,int_stack+80530,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+128530,int_stack+81880,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+128530,int_stack+0,int_stack+84040,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+39680,int_stack+39260,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+40220,int_stack+39680,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+80530,int_stack+1260,int_stack+0,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+83050,int_stack+40895,int_stack+40220,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+14100,int_stack+83050,int_stack+1260,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+56510,int_stack+14100,int_stack+80530,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+80530,int_stack+41720,int_stack+40895,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+60710,int_stack+80530,int_stack+83050,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+80530,int_stack+60710,int_stack+14100,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+60710,int_stack+80530,int_stack+56510,15);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+56510,int_stack+42990,int_stack+42710,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+57350,int_stack+43350,int_stack+42990,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+58430,int_stack+57350,int_stack+56510,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+80530,int_stack+43800,int_stack+43350,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+81880,int_stack+80530,int_stack+57350,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+84040,int_stack+81880,int_stack+58430,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+56510,int_stack+44350,int_stack+43800,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+14100,int_stack+56510,int_stack+80530,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+14100,int_stack+81880,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+56510,int_stack+0,int_stack+84040,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+45430,int_stack+45010,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+45970,int_stack+45430,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+14100,int_stack+1260,int_stack+0,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+16620,int_stack+46645,int_stack+45970,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+80530,int_stack+16620,int_stack+1260,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+83770,int_stack+80530,int_stack+14100,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+14100,int_stack+47470,int_stack+46645,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+67010,int_stack+14100,int_stack+16620,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+14100,int_stack+67010,int_stack+80530,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+67010,int_stack+14100,int_stack+83770,15);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+14100,int_stack+51040,int_stack+50760,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+14940,int_stack+51400,int_stack+51040,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+16020,int_stack+14940,int_stack+14100,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+17700,int_stack+51850,int_stack+51400,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+80530,int_stack+17700,int_stack+14940,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+82690,int_stack+80530,int_stack+16020,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+14100,int_stack+52400,int_stack+51850,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+73310,int_stack+14100,int_stack+17700,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+73310,int_stack+80530,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+14100,int_stack+0,int_stack+82690,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+53480,int_stack+53060,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+54020,int_stack+53480,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+80530,int_stack+1260,int_stack+0,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+83050,int_stack+54695,int_stack+54020,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+36300,int_stack+83050,int_stack+1260,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+39540,int_stack+36300,int_stack+80530,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+80530,int_stack+55520,int_stack+54695,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+43740,int_stack+80530,int_stack+83050,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+80530,int_stack+43740,int_stack+36300,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+43740,int_stack+80530,int_stack+39540,15);
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+132730,int_stack+103330,int_stack+76330,420);
     Libderiv->ABCD[11] = int_stack + 132730;
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+73310,int_stack+109630,int_stack+3600,420);
     Libderiv->ABCD[10] = int_stack + 73310;
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+102080,int_stack+87970,int_stack+97880,420);
     Libderiv->ABCD[9] = int_stack + 102080;
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+85910,int_stack+7800,int_stack+115930,420);
     Libderiv->ABCD[8] = int_stack + 85910;
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+0,int_stack+19500,int_stack+120130,420);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+145330,int_stack+30000,int_stack+124330,420);
     Libderiv->ABCD[6] = int_stack + 145330;
 /*--- compute (fp|ig) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+30000,int_stack+60710,int_stack+128530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[2] = int_stack + 30000;
 /*--- compute (fp|ig) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+114680,int_stack+67010,int_stack+56510, 0.0, zero_stack, 1.0, int_stack+25800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[1] = int_stack + 114680;
 /*--- compute (fp|ig) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+50040,int_stack+43740,int_stack+14100, 1.0, int_stack+25800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[0] = int_stack + 50040;

}
