/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gdig(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gd|ig) integrals */

void d1hrr_order_gdig(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[4][8][11] = int_stack + 960;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1635;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2460;
 Libderiv->deriv_classes[5][6][11] = int_stack + 3450;
 Libderiv->deriv_classes[5][7][11] = int_stack + 4038;
 Libderiv->deriv_classes[5][8][11] = int_stack + 4794;
 Libderiv->deriv_classes[5][9][11] = int_stack + 5739;
 Libderiv->deriv_classes[5][10][11] = int_stack + 6894;
 Libderiv->deriv_classes[6][6][11] = int_stack + 8280;
 Libderiv->deriv_classes[6][7][11] = int_stack + 9064;
 Libderiv->deriv_classes[6][8][11] = int_stack + 10072;
 Libderiv->deriv_classes[6][9][11] = int_stack + 11332;
 Libderiv->deriv_classes[6][10][11] = int_stack + 12872;
 Libderiv->deriv_classes[4][6][10] = int_stack + 14720;
 Libderiv->deriv_classes[4][7][10] = int_stack + 15140;
 Libderiv->deriv_classes[4][8][10] = int_stack + 15680;
 Libderiv->deriv_classes[4][9][10] = int_stack + 16355;
 Libderiv->deriv_classes[4][10][10] = int_stack + 17180;
 Libderiv->deriv_classes[5][6][10] = int_stack + 18170;
 Libderiv->deriv_classes[5][7][10] = int_stack + 18758;
 Libderiv->deriv_classes[5][8][10] = int_stack + 19514;
 Libderiv->deriv_classes[5][9][10] = int_stack + 20459;
 Libderiv->deriv_classes[5][10][10] = int_stack + 21614;
 Libderiv->deriv_classes[6][6][10] = int_stack + 23000;
 Libderiv->deriv_classes[6][7][10] = int_stack + 23784;
 Libderiv->deriv_classes[6][8][10] = int_stack + 24792;
 Libderiv->deriv_classes[6][9][10] = int_stack + 26052;
 Libderiv->deriv_classes[6][10][10] = int_stack + 27592;
 Libderiv->deriv_classes[4][6][9] = int_stack + 29440;
 Libderiv->deriv_classes[4][7][9] = int_stack + 29860;
 Libderiv->deriv_classes[4][8][9] = int_stack + 30400;
 Libderiv->deriv_classes[4][9][9] = int_stack + 31075;
 Libderiv->deriv_classes[4][10][9] = int_stack + 31900;
 Libderiv->deriv_classes[5][6][9] = int_stack + 32890;
 Libderiv->deriv_classes[5][7][9] = int_stack + 33478;
 Libderiv->deriv_classes[5][8][9] = int_stack + 34234;
 Libderiv->deriv_classes[5][9][9] = int_stack + 35179;
 Libderiv->deriv_classes[5][10][9] = int_stack + 36334;
 Libderiv->deriv_classes[6][6][9] = int_stack + 37720;
 Libderiv->deriv_classes[6][7][9] = int_stack + 38504;
 Libderiv->deriv_classes[6][8][9] = int_stack + 39512;
 Libderiv->deriv_classes[6][9][9] = int_stack + 40772;
 Libderiv->deriv_classes[6][10][9] = int_stack + 42312;
 Libderiv->deriv_classes[4][6][8] = int_stack + 44160;
 Libderiv->deriv_classes[4][7][8] = int_stack + 44580;
 Libderiv->deriv_classes[4][8][8] = int_stack + 45120;
 Libderiv->deriv_classes[4][9][8] = int_stack + 45795;
 Libderiv->deriv_classes[4][10][8] = int_stack + 46620;
 Libderiv->deriv_classes[5][6][8] = int_stack + 47610;
 Libderiv->deriv_classes[5][7][8] = int_stack + 48198;
 Libderiv->deriv_classes[5][8][8] = int_stack + 48954;
 Libderiv->deriv_classes[5][9][8] = int_stack + 49899;
 Libderiv->deriv_classes[5][10][8] = int_stack + 51054;
 Libderiv->deriv_classes[6][6][8] = int_stack + 52440;
 Libderiv->deriv_classes[6][7][8] = int_stack + 53224;
 Libderiv->deriv_classes[6][8][8] = int_stack + 54232;
 Libderiv->deriv_classes[6][9][8] = int_stack + 55492;
 Libderiv->deriv_classes[6][10][8] = int_stack + 57032;
 Libderiv->deriv_classes[4][6][7] = int_stack + 58880;
 Libderiv->deriv_classes[4][7][7] = int_stack + 59300;
 Libderiv->deriv_classes[4][8][7] = int_stack + 59840;
 Libderiv->deriv_classes[4][9][7] = int_stack + 60515;
 Libderiv->deriv_classes[4][10][7] = int_stack + 61340;
 Libderiv->deriv_classes[5][6][7] = int_stack + 62330;
 Libderiv->deriv_classes[5][7][7] = int_stack + 62918;
 Libderiv->deriv_classes[5][8][7] = int_stack + 63674;
 Libderiv->deriv_classes[5][9][7] = int_stack + 64619;
 Libderiv->deriv_classes[5][10][7] = int_stack + 65774;
 Libderiv->deriv_classes[6][6][7] = int_stack + 67160;
 Libderiv->deriv_classes[6][7][7] = int_stack + 67944;
 Libderiv->deriv_classes[6][8][7] = int_stack + 68952;
 Libderiv->deriv_classes[6][9][7] = int_stack + 70212;
 Libderiv->deriv_classes[6][10][7] = int_stack + 71752;
 Libderiv->deriv_classes[4][6][6] = int_stack + 73600;
 Libderiv->deriv_classes[4][7][6] = int_stack + 74020;
 Libderiv->deriv_classes[4][8][6] = int_stack + 74560;
 Libderiv->deriv_classes[4][9][6] = int_stack + 75235;
 Libderiv->deriv_classes[4][10][6] = int_stack + 76060;
 Libderiv->deriv_classes[5][6][6] = int_stack + 77050;
 Libderiv->deriv_classes[5][7][6] = int_stack + 77638;
 Libderiv->deriv_classes[5][8][6] = int_stack + 78394;
 Libderiv->deriv_classes[5][9][6] = int_stack + 79339;
 Libderiv->deriv_classes[5][10][6] = int_stack + 80494;
 Libderiv->dvrr_classes[6][6] = int_stack + 81880;
 Libderiv->deriv_classes[6][6][6] = int_stack + 82664;
 Libderiv->dvrr_classes[6][7] = int_stack + 83448;
 Libderiv->deriv_classes[6][7][6] = int_stack + 84456;
 Libderiv->dvrr_classes[6][8] = int_stack + 85464;
 Libderiv->deriv_classes[6][8][6] = int_stack + 86724;
 Libderiv->dvrr_classes[6][9] = int_stack + 87984;
 Libderiv->deriv_classes[6][9][6] = int_stack + 89524;
 Libderiv->deriv_classes[6][10][6] = int_stack + 91064;
 Libderiv->deriv_classes[4][6][2] = int_stack + 92912;
 Libderiv->deriv_classes[4][7][2] = int_stack + 93332;
 Libderiv->deriv_classes[4][8][2] = int_stack + 93872;
 Libderiv->deriv_classes[4][9][2] = int_stack + 94547;
 Libderiv->deriv_classes[4][10][2] = int_stack + 95372;
 Libderiv->deriv_classes[5][6][2] = int_stack + 96362;
 Libderiv->deriv_classes[5][7][2] = int_stack + 96950;
 Libderiv->deriv_classes[5][8][2] = int_stack + 97706;
 Libderiv->deriv_classes[5][9][2] = int_stack + 98651;
 Libderiv->deriv_classes[5][10][2] = int_stack + 99806;
 Libderiv->deriv_classes[6][6][2] = int_stack + 101192;
 Libderiv->deriv_classes[6][7][2] = int_stack + 101976;
 Libderiv->deriv_classes[6][8][2] = int_stack + 102984;
 Libderiv->deriv_classes[6][9][2] = int_stack + 104244;
 Libderiv->deriv_classes[6][10][2] = int_stack + 105784;
 Libderiv->deriv_classes[4][6][1] = int_stack + 107632;
 Libderiv->deriv_classes[4][7][1] = int_stack + 108052;
 Libderiv->deriv_classes[4][8][1] = int_stack + 108592;
 Libderiv->deriv_classes[4][9][1] = int_stack + 109267;
 Libderiv->deriv_classes[4][10][1] = int_stack + 110092;
 Libderiv->deriv_classes[5][6][1] = int_stack + 111082;
 Libderiv->deriv_classes[5][7][1] = int_stack + 111670;
 Libderiv->deriv_classes[5][8][1] = int_stack + 112426;
 Libderiv->deriv_classes[5][9][1] = int_stack + 113371;
 Libderiv->deriv_classes[5][10][1] = int_stack + 114526;
 Libderiv->deriv_classes[6][6][1] = int_stack + 115912;
 Libderiv->deriv_classes[6][7][1] = int_stack + 116696;
 Libderiv->deriv_classes[6][8][1] = int_stack + 117704;
 Libderiv->deriv_classes[6][9][1] = int_stack + 118964;
 Libderiv->deriv_classes[6][10][1] = int_stack + 120504;
 Libderiv->dvrr_classes[4][6] = int_stack + 122352;
 Libderiv->dvrr_classes[4][7] = int_stack + 122772;
 Libderiv->dvrr_classes[4][8] = int_stack + 123312;
 Libderiv->dvrr_classes[4][9] = int_stack + 123987;
 Libderiv->dvrr_classes[4][10] = int_stack + 124812;
 Libderiv->deriv_classes[4][6][0] = int_stack + 125802;
 Libderiv->deriv_classes[4][7][0] = int_stack + 126222;
 Libderiv->deriv_classes[4][8][0] = int_stack + 126762;
 Libderiv->deriv_classes[4][9][0] = int_stack + 127437;
 Libderiv->deriv_classes[4][10][0] = int_stack + 128262;
 Libderiv->dvrr_classes[5][6] = int_stack + 129252;
 Libderiv->dvrr_classes[5][7] = int_stack + 129840;
 Libderiv->dvrr_classes[5][8] = int_stack + 130596;
 Libderiv->dvrr_classes[5][9] = int_stack + 131541;
 Libderiv->dvrr_classes[5][10] = int_stack + 132696;
 Libderiv->deriv_classes[5][6][0] = int_stack + 134082;
 Libderiv->deriv_classes[5][7][0] = int_stack + 134670;
 Libderiv->deriv_classes[5][8][0] = int_stack + 135426;
 Libderiv->deriv_classes[5][9][0] = int_stack + 136371;
 Libderiv->deriv_classes[5][10][0] = int_stack + 137526;
 Libderiv->deriv_classes[6][6][0] = int_stack + 138912;
 Libderiv->deriv_classes[6][7][0] = int_stack + 139696;
 Libderiv->deriv_classes[6][8][0] = int_stack + 140704;
 Libderiv->deriv_classes[6][9][0] = int_stack + 141964;
 Libderiv->deriv_classes[6][10][0] = int_stack + 143504;
 memset(int_stack,0,1162816);

 Libderiv->dvrr_stack = int_stack + 573137;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gdig(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+145352,int_stack+122772,int_stack+122352,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+146612,int_stack+123312,int_stack+122772,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+148232,int_stack+146612,int_stack+145352,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+150752,int_stack+123987,int_stack+123312,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+152777,int_stack+150752,int_stack+146612,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+156017,int_stack+152777,int_stack+148232,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+160217,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122352,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+161477,int_stack+960,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122772,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+163097,int_stack+161477,int_stack+160217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145352,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+165617,int_stack+1635,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123312,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+167642,int_stack+165617,int_stack+161477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146612,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+170882,int_stack+167642,int_stack+163097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148232,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+160217,int_stack+2460,int_stack+1635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123987,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+175082,int_stack+160217,int_stack+165617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150752,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+160217,int_stack+175082,int_stack+167642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152777,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+175082,int_stack+160217,int_stack+170882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156017,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+160217,int_stack+129840,int_stack+129252,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+161981,int_stack+130596,int_stack+129840,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+164249,int_stack+161981,int_stack+160217,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+167777,int_stack+131541,int_stack+130596,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+181382,int_stack+167777,int_stack+161981,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+185918,int_stack+181382,int_stack+164249,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+170612,int_stack+4038,int_stack+3450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129252,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+172376,int_stack+4794,int_stack+4038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129840,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+172376,int_stack+170612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+160217,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+191798,int_stack+5739,int_stack+4794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130596,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+194633,int_stack+191798,int_stack+172376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161981,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+199169,int_stack+194633,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164249,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+6894,int_stack+5739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131541,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+205049,int_stack+0,int_stack+191798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167777,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+205049,int_stack+194633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181382,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+205049,int_stack+0,int_stack+199169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185918,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+213869,int_stack+205049,int_stack+175082,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+83448,int_stack+81880,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+85464,int_stack+83448,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+191798,int_stack+2352,int_stack+0,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+196502,int_stack+87984,int_stack+85464,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+170612,int_stack+196502,int_stack+2352,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+232769,int_stack+170612,int_stack+191798,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5376,int_stack+9064,int_stack+8280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81880,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+200282,int_stack+10072,int_stack+9064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83448,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+176660,int_stack+200282,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5376,int_stack+11332,int_stack+10072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85464,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+240609,int_stack+5376,int_stack+200282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+246657,int_stack+240609,int_stack+176660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191798,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+176660,int_stack+12872,int_stack+11332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87984,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+254497,int_stack+176660,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196502,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+262057,int_stack+254497,int_stack+240609, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170612,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+272137,int_stack+262057,int_stack+246657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232769,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+240609,int_stack+272137,int_stack+205049,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+267069,int_stack+15140,int_stack+14720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122352, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+268329,int_stack+15680,int_stack+15140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122772, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+269949,int_stack+268329,int_stack+267069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145352, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+272469,int_stack+16355,int_stack+15680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123312, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+274494,int_stack+272469,int_stack+268329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146612, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+277734,int_stack+274494,int_stack+269949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148232, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+267069,int_stack+17180,int_stack+16355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123987, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5376,int_stack+267069,int_stack+272469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150752, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+267069,int_stack+5376,int_stack+274494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152777, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5376,int_stack+267069,int_stack+277734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156017, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+267069,int_stack+18758,int_stack+18170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129252, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+268833,int_stack+19514,int_stack+18758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129840, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+271101,int_stack+268833,int_stack+267069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+160217, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+274629,int_stack+20459,int_stack+19514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130596, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+277464,int_stack+274629,int_stack+268833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161981, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11676,int_stack+277464,int_stack+271101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164249, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+267069,int_stack+21614,int_stack+20459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131541, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+200282,int_stack+267069,int_stack+274629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167777, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+267069,int_stack+200282,int_stack+277464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181382, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+200282,int_stack+267069,int_stack+11676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185918, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+267069,int_stack+200282,int_stack+5376,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5376,int_stack+23784,int_stack+23000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81880, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7728,int_stack+24792,int_stack+23784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83448, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10752,int_stack+7728,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+15456,int_stack+26052,int_stack+24792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85464, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+19236,int_stack+15456,int_stack+7728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+285969,int_stack+19236,int_stack+10752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191798, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5376,int_stack+27592,int_stack+26052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87984, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+293809,int_stack+5376,int_stack+15456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196502, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5376,int_stack+293809,int_stack+19236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170612, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+15456,int_stack+5376,int_stack+285969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232769, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+285969,int_stack+15456,int_stack+200282,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+200282,int_stack+29860,int_stack+29440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122352, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+201542,int_stack+30400,int_stack+29860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122772, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+203162,int_stack+201542,int_stack+200282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145352, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+205682,int_stack+31075,int_stack+30400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123312, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+207707,int_stack+205682,int_stack+201542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146612, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5376,int_stack+207707,int_stack+203162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148232, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+200282,int_stack+31900,int_stack+31075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123987, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9576,int_stack+200282,int_stack+205682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150752, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+200282,int_stack+9576,int_stack+207707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152777, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+9576,int_stack+200282,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156017, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5376,int_stack+33478,int_stack+32890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129252, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7140,int_stack+34234,int_stack+33478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129840, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+200282,int_stack+7140,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+160217, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+203810,int_stack+35179,int_stack+34234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130596, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+206645,int_stack+203810,int_stack+7140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161981, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+15876,int_stack+206645,int_stack+200282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164249, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+200282,int_stack+36334,int_stack+35179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131541, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+21756,int_stack+200282,int_stack+203810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167777, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+27426,int_stack+21756,int_stack+206645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181382, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+200282,int_stack+27426,int_stack+15876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185918, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+15876,int_stack+200282,int_stack+9576,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34776,int_stack+38504,int_stack+37720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81880, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+209102,int_stack+39512,int_stack+38504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83448, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+209102,int_stack+34776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+34776,int_stack+40772,int_stack+39512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85464, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+312429,int_stack+34776,int_stack+209102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+318477,int_stack+312429,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191798, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5376,int_stack+42312,int_stack+40772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87984, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+326317,int_stack+5376,int_stack+34776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196502, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5376,int_stack+326317,int_stack+312429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170612, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+326317,int_stack+5376,int_stack+318477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232769, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+338077,int_stack+326317,int_stack+200282,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+200282,int_stack+44580,int_stack+44160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+201542,int_stack+45120,int_stack+44580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+203162,int_stack+201542,int_stack+200282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+205682,int_stack+45795,int_stack+45120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+207707,int_stack+205682,int_stack+201542, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5376,int_stack+207707,int_stack+203162, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+200282,int_stack+46620,int_stack+45795, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123987, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9576,int_stack+200282,int_stack+205682, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+200282,int_stack+9576,int_stack+207707, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+9576,int_stack+200282,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5376,int_stack+48198,int_stack+47610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7140,int_stack+48954,int_stack+48198, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+200282,int_stack+7140,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+160217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+203810,int_stack+49899,int_stack+48954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+206645,int_stack+203810,int_stack+7140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+312429,int_stack+206645,int_stack+200282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+200282,int_stack+51054,int_stack+49899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+318309,int_stack+200282,int_stack+203810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+323979,int_stack+318309,int_stack+206645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+200282,int_stack+323979,int_stack+312429, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+312429,int_stack+200282,int_stack+9576,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+331329,int_stack+53224,int_stack+52440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+333681,int_stack+54232,int_stack+53224, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+209102,int_stack+333681,int_stack+331329, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5376,int_stack+55492,int_stack+54232, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9156,int_stack+5376,int_stack+333681, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+34776,int_stack+9156,int_stack+209102, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+209102,int_stack+57032,int_stack+55492, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+42616,int_stack+209102,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+364537,int_stack+42616,int_stack+9156, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+42616,int_stack+364537,int_stack+34776, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+364537,int_stack+42616,int_stack+200282,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+200282,int_stack+59300,int_stack+58880, 0.0, zero_stack, 1.0, int_stack+122352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+201542,int_stack+59840,int_stack+59300, 0.0, zero_stack, 1.0, int_stack+122772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+203162,int_stack+201542,int_stack+200282, 0.0, zero_stack, 1.0, int_stack+145352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+205682,int_stack+60515,int_stack+59840, 0.0, zero_stack, 1.0, int_stack+123312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+207707,int_stack+205682,int_stack+201542, 0.0, zero_stack, 1.0, int_stack+146612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+34776,int_stack+207707,int_stack+203162, 0.0, zero_stack, 1.0, int_stack+148232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+200282,int_stack+61340,int_stack+60515, 0.0, zero_stack, 1.0, int_stack+123987, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+38976,int_stack+200282,int_stack+205682, 0.0, zero_stack, 1.0, int_stack+150752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+200282,int_stack+38976,int_stack+207707, 0.0, zero_stack, 1.0, int_stack+152777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+38976,int_stack+200282,int_stack+34776, 0.0, zero_stack, 1.0, int_stack+156017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34776,int_stack+62918,int_stack+62330, 0.0, zero_stack, 1.0, int_stack+129252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+36540,int_stack+63674,int_stack+62918, 0.0, zero_stack, 1.0, int_stack+129840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+200282,int_stack+36540,int_stack+34776, 0.0, zero_stack, 1.0, int_stack+160217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+203810,int_stack+64619,int_stack+63674, 0.0, zero_stack, 1.0, int_stack+130596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+206645,int_stack+203810,int_stack+36540, 0.0, zero_stack, 1.0, int_stack+161981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+45276,int_stack+206645,int_stack+200282, 0.0, zero_stack, 1.0, int_stack+164249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+200282,int_stack+65774,int_stack+64619, 0.0, zero_stack, 1.0, int_stack+131541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+51156,int_stack+200282,int_stack+203810, 0.0, zero_stack, 1.0, int_stack+167777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+56826,int_stack+51156,int_stack+206645, 0.0, zero_stack, 1.0, int_stack+181382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+200282,int_stack+56826,int_stack+45276, 0.0, zero_stack, 1.0, int_stack+185918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+45276,int_stack+200282,int_stack+38976,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+64176,int_stack+67944,int_stack+67160, 0.0, zero_stack, 1.0, int_stack+81880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+209102,int_stack+68952,int_stack+67944, 0.0, zero_stack, 1.0, int_stack+83448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+34776,int_stack+209102,int_stack+64176, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+64176,int_stack+70212,int_stack+68952, 0.0, zero_stack, 1.0, int_stack+85464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5376,int_stack+64176,int_stack+209102, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+390997,int_stack+5376,int_stack+34776, 0.0, zero_stack, 1.0, int_stack+191798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+34776,int_stack+71752,int_stack+70212, 0.0, zero_stack, 1.0, int_stack+87984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+398837,int_stack+34776,int_stack+64176, 0.0, zero_stack, 1.0, int_stack+196502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+34776,int_stack+398837,int_stack+5376, 0.0, zero_stack, 1.0, int_stack+170612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+398837,int_stack+34776,int_stack+390997, 0.0, zero_stack, 1.0, int_stack+232769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+410597,int_stack+398837,int_stack+200282,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+200282,int_stack+74020,int_stack+73600, 1.0, int_stack+122352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+201542,int_stack+74560,int_stack+74020, 1.0, int_stack+122772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+203162,int_stack+201542,int_stack+200282, 1.0, int_stack+145352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+205682,int_stack+75235,int_stack+74560, 1.0, int_stack+123312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+207707,int_stack+205682,int_stack+201542, 1.0, int_stack+146612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+390997,int_stack+207707,int_stack+203162, 1.0, int_stack+148232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+145352,int_stack+76060,int_stack+75235, 1.0, int_stack+123987, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+200282,int_stack+145352,int_stack+205682, 1.0, int_stack+150752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+145352,int_stack+200282,int_stack+207707, 1.0, int_stack+152777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+200282,int_stack+145352,int_stack+390997, 1.0, int_stack+156017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+390997,int_stack+77638,int_stack+77050, 1.0, int_stack+129252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+392761,int_stack+78394,int_stack+77638, 1.0, int_stack+129840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+395029,int_stack+392761,int_stack+390997, 1.0, int_stack+160217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+398557,int_stack+79339,int_stack+78394, 1.0, int_stack+130596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+401392,int_stack+398557,int_stack+392761, 1.0, int_stack+161981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+206582,int_stack+401392,int_stack+395029, 1.0, int_stack+164249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+160217,int_stack+80494,int_stack+79339, 1.0, int_stack+131541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+390997,int_stack+160217,int_stack+398557, 1.0, int_stack+167777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+160217,int_stack+390997,int_stack+401392, 1.0, int_stack+181382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+390997,int_stack+160217,int_stack+206582, 1.0, int_stack+185918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+437057,int_stack+390997,int_stack+200282,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+200282,int_stack+84456,int_stack+82664, 1.0, int_stack+81880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+202634,int_stack+86724,int_stack+84456, 1.0, int_stack+83448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+205658,int_stack+202634,int_stack+200282, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+160217,int_stack+89524,int_stack+86724, 1.0, int_stack+85464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+399817,int_stack+160217,int_stack+202634, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+399817,int_stack+205658, 1.0, int_stack+191798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+191798,int_stack+91064,int_stack+89524, 1.0, int_stack+87984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7840,int_stack+191798,int_stack+160217, 1.0, int_stack+196502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+191798,int_stack+7840,int_stack+399817, 1.0, int_stack+170612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+201878,int_stack+191798,int_stack+0, 1.0, int_stack+232769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+64176,int_stack+201878,int_stack+390997,420);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+390997,int_stack+124812,int_stack+123987,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+393472,int_stack+390997,int_stack+150752,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+397522,int_stack+393472,int_stack+152777,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+390997,int_stack+397522,int_stack+156017,15);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+397297,int_stack+132696,int_stack+131541,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+400762,int_stack+397297,int_stack+167777,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+232769,int_stack+400762,int_stack+181382,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+397297,int_stack+232769,int_stack+185918,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+145352,int_stack+397297,int_stack+390997,420);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+232769,int_stack+93332,int_stack+92912,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+234029,int_stack+93872,int_stack+93332,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+235649,int_stack+234029,int_stack+232769,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+238169,int_stack+94547,int_stack+93872,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+406117,int_stack+238169,int_stack+234029,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+406117,int_stack+235649,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+232769,int_stack+95372,int_stack+94547,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4200,int_stack+232769,int_stack+238169,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+232769,int_stack+4200,int_stack+406117,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4200,int_stack+232769,int_stack+0,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+96950,int_stack+96362,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+97706,int_stack+96950,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+232769,int_stack+1764,int_stack+0,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+236297,int_stack+98651,int_stack+97706,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+10500,int_stack+236297,int_stack+1764,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+164252,int_stack+10500,int_stack+232769,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+232769,int_stack+99806,int_stack+98651,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+170132,int_stack+232769,int_stack+236297,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+232769,int_stack+170132,int_stack+10500,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+170132,int_stack+232769,int_stack+164252,21);
 /*--- compute (gp|ig) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+178952,int_stack+170132,int_stack+4200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+164252,int_stack+101976,int_stack+101192,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+166604,int_stack+102984,int_stack+101976,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+232769,int_stack+166604,int_stack+164252,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+197852,int_stack+104244,int_stack+102984,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+201632,int_stack+197852,int_stack+166604,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+201632,int_stack+232769,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+232769,int_stack+105784,int_stack+104244,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7840,int_stack+232769,int_stack+197852,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+34776,int_stack+7840,int_stack+201632,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+197852,int_stack+34776,int_stack+0,28);
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+455957,int_stack+197852,int_stack+170132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+197852,int_stack+108052,int_stack+107632,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+199112,int_stack+108592,int_stack+108052,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+200732,int_stack+199112,int_stack+197852,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+203252,int_stack+109267,int_stack+108592,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+205277,int_stack+203252,int_stack+199112,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+208517,int_stack+205277,int_stack+200732,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+197852,int_stack+110092,int_stack+109267,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+197852,int_stack+203252,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+197852,int_stack+0,int_stack+205277,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+197852,int_stack+208517,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+197852,int_stack+111670,int_stack+111082,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+199616,int_stack+112426,int_stack+111670,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+201884,int_stack+199616,int_stack+197852,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+205412,int_stack+113371,int_stack+112426,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+208247,int_stack+205412,int_stack+199616,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6300,int_stack+208247,int_stack+201884,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+197852,int_stack+114526,int_stack+113371,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+34776,int_stack+197852,int_stack+205412,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+197852,int_stack+34776,int_stack+208247,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+34776,int_stack+197852,int_stack+6300,21);
 /*--- compute (gp|ig) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+90636,int_stack+34776,int_stack+0, 0.0, zero_stack, 1.0, int_stack+390997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+116696,int_stack+115912,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+117704,int_stack+116696,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+10080,int_stack+118964,int_stack+117704,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+197852,int_stack+10080,int_stack+2352,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+232769,int_stack+197852,int_stack+5376,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+120504,int_stack+118964,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+203900,int_stack+0,int_stack+10080,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+203900,int_stack+197852,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+197852,int_stack+0,int_stack+232769,28);
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+482417,int_stack+197852,int_stack+34776, 0.0, zero_stack, 1.0, int_stack+397297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+34776,int_stack+126222,int_stack+125802,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+36036,int_stack+126762,int_stack+126222,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+37656,int_stack+36036,int_stack+34776,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+40176,int_stack+127437,int_stack+126762,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+197852,int_stack+40176,int_stack+36036,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+201092,int_stack+197852,int_stack+37656,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+34776,int_stack+128262,int_stack+127437,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+205292,int_stack+34776,int_stack+40176,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+34776,int_stack+205292,int_stack+197852,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+205292,int_stack+34776,int_stack+201092,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+34776,int_stack+134670,int_stack+134082,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+36540,int_stack+135426,int_stack+134670,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+38808,int_stack+36540,int_stack+34776,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+42336,int_stack+136371,int_stack+135426,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+197852,int_stack+42336,int_stack+36540,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+232769,int_stack+197852,int_stack+38808,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+34776,int_stack+137526,int_stack+136371,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+34776,int_stack+42336,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+34776,int_stack+0,int_stack+197852,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+34776,int_stack+232769,21);
 /*--- compute (gp|ig) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+109536,int_stack+0,int_stack+205292, 1.0, int_stack+390997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+390997,int_stack+139696,int_stack+138912,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+393349,int_stack+140704,int_stack+139696,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+232769,int_stack+393349,int_stack+390997,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+34776,int_stack+141964,int_stack+140704,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+38556,int_stack+34776,int_stack+393349,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+197852,int_stack+38556,int_stack+232769,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+232769,int_stack+143504,int_stack+141964,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+205692,int_stack+232769,int_stack+34776,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+164252,int_stack+205692,int_stack+38556,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+128436,int_stack+164252,int_stack+197852,28);
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+508877,int_stack+128436,int_stack+0, 1.0, int_stack+397297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+535337,int_stack+240609,int_stack+213869,420);
     Libderiv->ABCD[11] = int_stack + 535337;
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+197852,int_stack+285969,int_stack+267069,420);
     Libderiv->ABCD[10] = int_stack + 197852;
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+235652,int_stack+338077,int_stack+15876,420);
     Libderiv->ABCD[9] = int_stack + 235652;
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+0,int_stack+364537,int_stack+312429,420);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+273452,int_stack+410597,int_stack+45276,420);
     Libderiv->ABCD[7] = int_stack + 273452;
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+311252,int_stack+64176,int_stack+437057,420);
     Libderiv->ABCD[6] = int_stack + 311252;
 /*--- compute (gd|ig) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+37800,int_stack+455957,int_stack+178952, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[2] = int_stack + 37800;
 /*--- compute (gd|ig) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+349052,int_stack+482417,int_stack+90636, 0.0, zero_stack, 1.0, int_stack+145352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[1] = int_stack + 349052;
 /*--- compute (gd|ig) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+386852,int_stack+508877,int_stack+109536, 1.0, int_stack+145352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[0] = int_stack + 386852;

}
