/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gfig(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gf|ig) integrals */

void d1hrr_order_gfig(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[4][8][11] = int_stack + 960;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1635;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2460;
 Libderiv->deriv_classes[5][6][11] = int_stack + 3450;
 Libderiv->deriv_classes[5][7][11] = int_stack + 4038;
 Libderiv->deriv_classes[5][8][11] = int_stack + 4794;
 Libderiv->deriv_classes[5][9][11] = int_stack + 5739;
 Libderiv->deriv_classes[5][10][11] = int_stack + 6894;
 Libderiv->deriv_classes[6][6][11] = int_stack + 8280;
 Libderiv->deriv_classes[6][7][11] = int_stack + 9064;
 Libderiv->deriv_classes[6][8][11] = int_stack + 10072;
 Libderiv->deriv_classes[6][9][11] = int_stack + 11332;
 Libderiv->deriv_classes[6][10][11] = int_stack + 12872;
 Libderiv->deriv_classes[7][6][11] = int_stack + 14720;
 Libderiv->deriv_classes[7][7][11] = int_stack + 15728;
 Libderiv->deriv_classes[7][8][11] = int_stack + 17024;
 Libderiv->deriv_classes[7][9][11] = int_stack + 18644;
 Libderiv->deriv_classes[7][10][11] = int_stack + 20624;
 Libderiv->deriv_classes[4][6][10] = int_stack + 23000;
 Libderiv->deriv_classes[4][7][10] = int_stack + 23420;
 Libderiv->deriv_classes[4][8][10] = int_stack + 23960;
 Libderiv->deriv_classes[4][9][10] = int_stack + 24635;
 Libderiv->deriv_classes[4][10][10] = int_stack + 25460;
 Libderiv->deriv_classes[5][6][10] = int_stack + 26450;
 Libderiv->deriv_classes[5][7][10] = int_stack + 27038;
 Libderiv->deriv_classes[5][8][10] = int_stack + 27794;
 Libderiv->deriv_classes[5][9][10] = int_stack + 28739;
 Libderiv->deriv_classes[5][10][10] = int_stack + 29894;
 Libderiv->deriv_classes[6][6][10] = int_stack + 31280;
 Libderiv->deriv_classes[6][7][10] = int_stack + 32064;
 Libderiv->deriv_classes[6][8][10] = int_stack + 33072;
 Libderiv->deriv_classes[6][9][10] = int_stack + 34332;
 Libderiv->deriv_classes[6][10][10] = int_stack + 35872;
 Libderiv->deriv_classes[7][6][10] = int_stack + 37720;
 Libderiv->deriv_classes[7][7][10] = int_stack + 38728;
 Libderiv->deriv_classes[7][8][10] = int_stack + 40024;
 Libderiv->deriv_classes[7][9][10] = int_stack + 41644;
 Libderiv->deriv_classes[7][10][10] = int_stack + 43624;
 Libderiv->deriv_classes[4][6][9] = int_stack + 46000;
 Libderiv->deriv_classes[4][7][9] = int_stack + 46420;
 Libderiv->deriv_classes[4][8][9] = int_stack + 46960;
 Libderiv->deriv_classes[4][9][9] = int_stack + 47635;
 Libderiv->deriv_classes[4][10][9] = int_stack + 48460;
 Libderiv->deriv_classes[5][6][9] = int_stack + 49450;
 Libderiv->deriv_classes[5][7][9] = int_stack + 50038;
 Libderiv->deriv_classes[5][8][9] = int_stack + 50794;
 Libderiv->deriv_classes[5][9][9] = int_stack + 51739;
 Libderiv->deriv_classes[5][10][9] = int_stack + 52894;
 Libderiv->deriv_classes[6][6][9] = int_stack + 54280;
 Libderiv->deriv_classes[6][7][9] = int_stack + 55064;
 Libderiv->deriv_classes[6][8][9] = int_stack + 56072;
 Libderiv->deriv_classes[6][9][9] = int_stack + 57332;
 Libderiv->deriv_classes[6][10][9] = int_stack + 58872;
 Libderiv->deriv_classes[7][6][9] = int_stack + 60720;
 Libderiv->deriv_classes[7][7][9] = int_stack + 61728;
 Libderiv->deriv_classes[7][8][9] = int_stack + 63024;
 Libderiv->deriv_classes[7][9][9] = int_stack + 64644;
 Libderiv->deriv_classes[7][10][9] = int_stack + 66624;
 Libderiv->deriv_classes[4][6][8] = int_stack + 69000;
 Libderiv->deriv_classes[4][7][8] = int_stack + 69420;
 Libderiv->deriv_classes[4][8][8] = int_stack + 69960;
 Libderiv->deriv_classes[4][9][8] = int_stack + 70635;
 Libderiv->deriv_classes[4][10][8] = int_stack + 71460;
 Libderiv->deriv_classes[5][6][8] = int_stack + 72450;
 Libderiv->deriv_classes[5][7][8] = int_stack + 73038;
 Libderiv->deriv_classes[5][8][8] = int_stack + 73794;
 Libderiv->deriv_classes[5][9][8] = int_stack + 74739;
 Libderiv->deriv_classes[5][10][8] = int_stack + 75894;
 Libderiv->deriv_classes[6][6][8] = int_stack + 77280;
 Libderiv->deriv_classes[6][7][8] = int_stack + 78064;
 Libderiv->deriv_classes[6][8][8] = int_stack + 79072;
 Libderiv->deriv_classes[6][9][8] = int_stack + 80332;
 Libderiv->deriv_classes[6][10][8] = int_stack + 81872;
 Libderiv->deriv_classes[7][6][8] = int_stack + 83720;
 Libderiv->deriv_classes[7][7][8] = int_stack + 84728;
 Libderiv->deriv_classes[7][8][8] = int_stack + 86024;
 Libderiv->deriv_classes[7][9][8] = int_stack + 87644;
 Libderiv->deriv_classes[7][10][8] = int_stack + 89624;
 Libderiv->deriv_classes[4][6][7] = int_stack + 92000;
 Libderiv->deriv_classes[4][7][7] = int_stack + 92420;
 Libderiv->deriv_classes[4][8][7] = int_stack + 92960;
 Libderiv->deriv_classes[4][9][7] = int_stack + 93635;
 Libderiv->deriv_classes[4][10][7] = int_stack + 94460;
 Libderiv->deriv_classes[5][6][7] = int_stack + 95450;
 Libderiv->deriv_classes[5][7][7] = int_stack + 96038;
 Libderiv->deriv_classes[5][8][7] = int_stack + 96794;
 Libderiv->deriv_classes[5][9][7] = int_stack + 97739;
 Libderiv->deriv_classes[5][10][7] = int_stack + 98894;
 Libderiv->deriv_classes[6][6][7] = int_stack + 100280;
 Libderiv->deriv_classes[6][7][7] = int_stack + 101064;
 Libderiv->deriv_classes[6][8][7] = int_stack + 102072;
 Libderiv->deriv_classes[6][9][7] = int_stack + 103332;
 Libderiv->deriv_classes[6][10][7] = int_stack + 104872;
 Libderiv->deriv_classes[7][6][7] = int_stack + 106720;
 Libderiv->deriv_classes[7][7][7] = int_stack + 107728;
 Libderiv->deriv_classes[7][8][7] = int_stack + 109024;
 Libderiv->deriv_classes[7][9][7] = int_stack + 110644;
 Libderiv->deriv_classes[7][10][7] = int_stack + 112624;
 Libderiv->deriv_classes[4][6][6] = int_stack + 115000;
 Libderiv->deriv_classes[4][7][6] = int_stack + 115420;
 Libderiv->deriv_classes[4][8][6] = int_stack + 115960;
 Libderiv->deriv_classes[4][9][6] = int_stack + 116635;
 Libderiv->deriv_classes[4][10][6] = int_stack + 117460;
 Libderiv->deriv_classes[5][6][6] = int_stack + 118450;
 Libderiv->deriv_classes[5][7][6] = int_stack + 119038;
 Libderiv->deriv_classes[5][8][6] = int_stack + 119794;
 Libderiv->deriv_classes[5][9][6] = int_stack + 120739;
 Libderiv->deriv_classes[5][10][6] = int_stack + 121894;
 Libderiv->deriv_classes[6][6][6] = int_stack + 123280;
 Libderiv->deriv_classes[6][7][6] = int_stack + 124064;
 Libderiv->deriv_classes[6][8][6] = int_stack + 125072;
 Libderiv->deriv_classes[6][9][6] = int_stack + 126332;
 Libderiv->deriv_classes[6][10][6] = int_stack + 127872;
 Libderiv->dvrr_classes[7][6] = int_stack + 129720;
 Libderiv->deriv_classes[7][6][6] = int_stack + 130728;
 Libderiv->dvrr_classes[7][7] = int_stack + 131736;
 Libderiv->deriv_classes[7][7][6] = int_stack + 133032;
 Libderiv->dvrr_classes[7][8] = int_stack + 134328;
 Libderiv->deriv_classes[7][8][6] = int_stack + 135948;
 Libderiv->dvrr_classes[7][9] = int_stack + 137568;
 Libderiv->deriv_classes[7][9][6] = int_stack + 139548;
 Libderiv->deriv_classes[7][10][6] = int_stack + 141528;
 Libderiv->deriv_classes[4][6][2] = int_stack + 143904;
 Libderiv->deriv_classes[4][7][2] = int_stack + 144324;
 Libderiv->deriv_classes[4][8][2] = int_stack + 144864;
 Libderiv->deriv_classes[4][9][2] = int_stack + 145539;
 Libderiv->deriv_classes[4][10][2] = int_stack + 146364;
 Libderiv->deriv_classes[5][6][2] = int_stack + 147354;
 Libderiv->deriv_classes[5][7][2] = int_stack + 147942;
 Libderiv->deriv_classes[5][8][2] = int_stack + 148698;
 Libderiv->deriv_classes[5][9][2] = int_stack + 149643;
 Libderiv->deriv_classes[5][10][2] = int_stack + 150798;
 Libderiv->deriv_classes[6][6][2] = int_stack + 152184;
 Libderiv->deriv_classes[6][7][2] = int_stack + 152968;
 Libderiv->deriv_classes[6][8][2] = int_stack + 153976;
 Libderiv->deriv_classes[6][9][2] = int_stack + 155236;
 Libderiv->deriv_classes[6][10][2] = int_stack + 156776;
 Libderiv->deriv_classes[7][6][2] = int_stack + 158624;
 Libderiv->deriv_classes[7][7][2] = int_stack + 159632;
 Libderiv->deriv_classes[7][8][2] = int_stack + 160928;
 Libderiv->deriv_classes[7][9][2] = int_stack + 162548;
 Libderiv->deriv_classes[7][10][2] = int_stack + 164528;
 Libderiv->deriv_classes[4][6][1] = int_stack + 166904;
 Libderiv->deriv_classes[4][7][1] = int_stack + 167324;
 Libderiv->deriv_classes[4][8][1] = int_stack + 167864;
 Libderiv->deriv_classes[4][9][1] = int_stack + 168539;
 Libderiv->deriv_classes[4][10][1] = int_stack + 169364;
 Libderiv->deriv_classes[5][6][1] = int_stack + 170354;
 Libderiv->deriv_classes[5][7][1] = int_stack + 170942;
 Libderiv->deriv_classes[5][8][1] = int_stack + 171698;
 Libderiv->deriv_classes[5][9][1] = int_stack + 172643;
 Libderiv->deriv_classes[5][10][1] = int_stack + 173798;
 Libderiv->deriv_classes[6][6][1] = int_stack + 175184;
 Libderiv->deriv_classes[6][7][1] = int_stack + 175968;
 Libderiv->deriv_classes[6][8][1] = int_stack + 176976;
 Libderiv->deriv_classes[6][9][1] = int_stack + 178236;
 Libderiv->deriv_classes[6][10][1] = int_stack + 179776;
 Libderiv->deriv_classes[7][6][1] = int_stack + 181624;
 Libderiv->deriv_classes[7][7][1] = int_stack + 182632;
 Libderiv->deriv_classes[7][8][1] = int_stack + 183928;
 Libderiv->deriv_classes[7][9][1] = int_stack + 185548;
 Libderiv->deriv_classes[7][10][1] = int_stack + 187528;
 Libderiv->dvrr_classes[4][6] = int_stack + 189904;
 Libderiv->dvrr_classes[4][7] = int_stack + 190324;
 Libderiv->dvrr_classes[4][8] = int_stack + 190864;
 Libderiv->dvrr_classes[4][9] = int_stack + 191539;
 Libderiv->dvrr_classes[4][10] = int_stack + 192364;
 Libderiv->deriv_classes[4][6][0] = int_stack + 193354;
 Libderiv->deriv_classes[4][7][0] = int_stack + 193774;
 Libderiv->deriv_classes[4][8][0] = int_stack + 194314;
 Libderiv->deriv_classes[4][9][0] = int_stack + 194989;
 Libderiv->deriv_classes[4][10][0] = int_stack + 195814;
 Libderiv->dvrr_classes[5][6] = int_stack + 196804;
 Libderiv->dvrr_classes[5][7] = int_stack + 197392;
 Libderiv->dvrr_classes[5][8] = int_stack + 198148;
 Libderiv->dvrr_classes[5][9] = int_stack + 199093;
 Libderiv->dvrr_classes[5][10] = int_stack + 200248;
 Libderiv->deriv_classes[5][6][0] = int_stack + 201634;
 Libderiv->deriv_classes[5][7][0] = int_stack + 202222;
 Libderiv->deriv_classes[5][8][0] = int_stack + 202978;
 Libderiv->deriv_classes[5][9][0] = int_stack + 203923;
 Libderiv->deriv_classes[5][10][0] = int_stack + 205078;
 Libderiv->dvrr_classes[6][6] = int_stack + 206464;
 Libderiv->dvrr_classes[6][7] = int_stack + 207248;
 Libderiv->dvrr_classes[6][8] = int_stack + 208256;
 Libderiv->dvrr_classes[6][9] = int_stack + 209516;
 Libderiv->dvrr_classes[6][10] = int_stack + 211056;
 Libderiv->deriv_classes[6][6][0] = int_stack + 212904;
 Libderiv->deriv_classes[6][7][0] = int_stack + 213688;
 Libderiv->deriv_classes[6][8][0] = int_stack + 214696;
 Libderiv->deriv_classes[6][9][0] = int_stack + 215956;
 Libderiv->deriv_classes[6][10][0] = int_stack + 217496;
 Libderiv->deriv_classes[7][6][0] = int_stack + 219344;
 Libderiv->deriv_classes[7][7][0] = int_stack + 220352;
 Libderiv->deriv_classes[7][8][0] = int_stack + 221648;
 Libderiv->deriv_classes[7][9][0] = int_stack + 223268;
 Libderiv->deriv_classes[7][10][0] = int_stack + 225248;
 memset(int_stack,0,1820992);

 Libderiv->dvrr_stack = int_stack + 1134769;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gfig(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+227624,int_stack+190324,int_stack+189904,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+228884,int_stack+190864,int_stack+190324,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+230504,int_stack+228884,int_stack+227624,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+233024,int_stack+191539,int_stack+190864,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+235049,int_stack+233024,int_stack+228884,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+238289,int_stack+235049,int_stack+230504,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+242489,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189904,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+243749,int_stack+960,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190324,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+245369,int_stack+243749,int_stack+242489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227624,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+247889,int_stack+1635,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190864,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+249914,int_stack+247889,int_stack+243749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228884,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+253154,int_stack+249914,int_stack+245369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230504,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+242489,int_stack+2460,int_stack+1635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191539,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+257354,int_stack+242489,int_stack+247889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233024,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+242489,int_stack+257354,int_stack+249914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235049,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+257354,int_stack+242489,int_stack+253154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238289,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+242489,int_stack+197392,int_stack+196804,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+244253,int_stack+198148,int_stack+197392,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+246521,int_stack+244253,int_stack+242489,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+250049,int_stack+199093,int_stack+198148,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+263654,int_stack+250049,int_stack+244253,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+268190,int_stack+263654,int_stack+246521,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+252884,int_stack+4038,int_stack+3450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196804,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+254648,int_stack+4794,int_stack+4038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197392,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+254648,int_stack+252884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242489,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+274070,int_stack+5739,int_stack+4794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198148,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+276905,int_stack+274070,int_stack+254648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244253,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+281441,int_stack+276905,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+246521,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+6894,int_stack+5739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199093,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+287321,int_stack+0,int_stack+274070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250049,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+287321,int_stack+276905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263654,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+287321,int_stack+0,int_stack+281441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268190,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+296141,int_stack+287321,int_stack+257354,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+207248,int_stack+206464,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+208256,int_stack+207248,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+274070,int_stack+2352,int_stack+0,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+278774,int_stack+209516,int_stack+208256,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+252884,int_stack+278774,int_stack+2352,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+315041,int_stack+252884,int_stack+274070,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5376,int_stack+9064,int_stack+8280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206464,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+282554,int_stack+10072,int_stack+9064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207248,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+258932,int_stack+282554,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5376,int_stack+11332,int_stack+10072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208256,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+322881,int_stack+5376,int_stack+282554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+328929,int_stack+322881,int_stack+258932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274070,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+258932,int_stack+12872,int_stack+11332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209516,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+336769,int_stack+258932,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278774,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+344329,int_stack+336769,int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252884,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+354409,int_stack+344329,int_stack+328929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315041,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+322881,int_stack+354409,int_stack+287321,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+366169,int_stack+322881,int_stack+296141,420);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+349341,int_stack+131736,int_stack+129720,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5376,int_stack+134328,int_stack+131736,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+282554,int_stack+5376,int_stack+349341,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9264,int_stack+137568,int_stack+134328,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+288602,int_stack+9264,int_stack+5376,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+296378,int_stack+288602,int_stack+282554,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+258932,int_stack+15728,int_stack+14720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129720,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+306458,int_stack+17024,int_stack+15728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131736,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+403969,int_stack+306458,int_stack+258932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349341,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+410017,int_stack+18644,int_stack+17024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134328,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+414877,int_stack+410017,int_stack+306458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5376,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+422653,int_stack+414877,int_stack+403969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282554,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+403969,int_stack+20624,int_stack+18644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137568,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+432733,int_stack+403969,int_stack+410017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9264,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+442453,int_stack+432733,int_stack+414877, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288602,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+403969,int_stack+442453,int_stack+422653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296378,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+419089,int_stack+403969,int_stack+354409,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+454369,int_stack+419089,int_stack+322881,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+322881,int_stack+23420,int_stack+23000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189904, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+324141,int_stack+23960,int_stack+23420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190324, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+325761,int_stack+324141,int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227624, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+328281,int_stack+24635,int_stack+23960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190864, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+330306,int_stack+328281,int_stack+324141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228884, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+333546,int_stack+330306,int_stack+325761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230504, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+25460,int_stack+24635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191539, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+337746,int_stack+322881,int_stack+328281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233024, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+322881,int_stack+337746,int_stack+330306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235049, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+337746,int_stack+322881,int_stack+333546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238289, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+322881,int_stack+27038,int_stack+26450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196804, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+324645,int_stack+27794,int_stack+27038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197392, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+326913,int_stack+324645,int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242489, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+330441,int_stack+28739,int_stack+27794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198148, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+344046,int_stack+330441,int_stack+324645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244253, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+403969,int_stack+344046,int_stack+326913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+246521, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+29894,int_stack+28739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199093, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+409849,int_stack+322881,int_stack+330441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250049, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+322881,int_stack+409849,int_stack+344046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263654, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+409849,int_stack+322881,int_stack+403969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268190, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+418669,int_stack+409849,int_stack+337746,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403969,int_stack+32064,int_stack+31280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206464, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+406321,int_stack+33072,int_stack+32064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207248, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+322881,int_stack+406321,int_stack+403969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+327585,int_stack+34332,int_stack+33072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208256, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+331365,int_stack+327585,int_stack+406321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+337413,int_stack+331365,int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274070, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+35872,int_stack+34332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209516, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+437569,int_stack+322881,int_stack+327585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278774, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+352365,int_stack+437569,int_stack+331365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252884, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+437569,int_stack+352365,int_stack+337413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315041, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+322881,int_stack+437569,int_stack+409849,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+507289,int_stack+322881,int_stack+418669,420);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+352365,int_stack+38728,int_stack+37720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129720, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+355389,int_stack+40024,int_stack+38728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131736, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+359277,int_stack+355389,int_stack+352365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349341, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+449329,int_stack+41644,int_stack+40024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134328, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+403969,int_stack+449329,int_stack+355389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5376, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+411745,int_stack+403969,int_stack+359277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282554, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+352365,int_stack+43624,int_stack+41644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137568, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+421825,int_stack+352365,int_stack+449329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9264, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+352365,int_stack+421825,int_stack+403969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288602, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+421825,int_stack+352365,int_stack+411745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296378, 0.0, zero_stack,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+545089,int_stack+421825,int_stack+437569,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+580369,int_stack+545089,int_stack+322881,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+322881,int_stack+46420,int_stack+46000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189904, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+324141,int_stack+46960,int_stack+46420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190324, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+325761,int_stack+324141,int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227624, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+328281,int_stack+47635,int_stack+46960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190864, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+330306,int_stack+328281,int_stack+324141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228884, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+333546,int_stack+330306,int_stack+325761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230504, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+48460,int_stack+47635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191539, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+337746,int_stack+322881,int_stack+328281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233024, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+322881,int_stack+337746,int_stack+330306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235049, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+337746,int_stack+322881,int_stack+333546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238289, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+322881,int_stack+50038,int_stack+49450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196804, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+324645,int_stack+50794,int_stack+50038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197392, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+326913,int_stack+324645,int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242489, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+330441,int_stack+51739,int_stack+50794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198148, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+344046,int_stack+330441,int_stack+324645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244253, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+545089,int_stack+344046,int_stack+326913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+246521, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+52894,int_stack+51739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199093, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+550969,int_stack+322881,int_stack+330441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250049, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+322881,int_stack+550969,int_stack+344046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263654, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+550969,int_stack+322881,int_stack+545089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268190, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+559789,int_stack+550969,int_stack+337746,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+545089,int_stack+55064,int_stack+54280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206464, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+547441,int_stack+56072,int_stack+55064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207248, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+322881,int_stack+547441,int_stack+545089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+327585,int_stack+57332,int_stack+56072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208256, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+331365,int_stack+327585,int_stack+547441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+337413,int_stack+331365,int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274070, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+58872,int_stack+57332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209516, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+352365,int_stack+322881,int_stack+327585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278774, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+403969,int_stack+352365,int_stack+331365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252884, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+352365,int_stack+403969,int_stack+337413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315041, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+322881,int_stack+352365,int_stack+550969,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+403969,int_stack+322881,int_stack+559789,420);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+441769,int_stack+61728,int_stack+60720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129720, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+444793,int_stack+63024,int_stack+61728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131736, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+545089,int_stack+444793,int_stack+441769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349341, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+448681,int_stack+64644,int_stack+63024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134328, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+551137,int_stack+448681,int_stack+444793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5376, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+558913,int_stack+551137,int_stack+545089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282554, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+545089,int_stack+66624,int_stack+64644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137568, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+568993,int_stack+545089,int_stack+448681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9264, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+14124,int_stack+568993,int_stack+551137, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288602, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+27084,int_stack+14124,int_stack+558913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296378, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+545089,int_stack+27084,int_stack+352365,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+14124,int_stack+545089,int_stack+322881,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+322881,int_stack+69420,int_stack+69000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+324141,int_stack+69960,int_stack+69420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+325761,int_stack+324141,int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+328281,int_stack+70635,int_stack+69960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+330306,int_stack+328281,int_stack+324141, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+333546,int_stack+330306,int_stack+325761, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+71460,int_stack+70635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+337746,int_stack+322881,int_stack+328281, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+322881,int_stack+337746,int_stack+330306, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+337746,int_stack+322881,int_stack+333546, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+322881,int_stack+73038,int_stack+72450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+324645,int_stack+73794,int_stack+73038, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+326913,int_stack+324645,int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+330441,int_stack+74739,int_stack+73794, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+344046,int_stack+330441,int_stack+324645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+545089,int_stack+344046,int_stack+326913, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+246521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+75894,int_stack+74739, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+550969,int_stack+322881,int_stack+330441, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+322881,int_stack+550969,int_stack+344046, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+550969,int_stack+322881,int_stack+545089, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+559789,int_stack+550969,int_stack+337746,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+545089,int_stack+78064,int_stack+77280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+547441,int_stack+79072,int_stack+78064, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+322881,int_stack+547441,int_stack+545089, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+327585,int_stack+80332,int_stack+79072, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+331365,int_stack+327585,int_stack+547441, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+337413,int_stack+331365,int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+81872,int_stack+80332, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+352365,int_stack+322881,int_stack+327585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+67044,int_stack+352365,int_stack+331365, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+352365,int_stack+67044,int_stack+337413, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+322881,int_stack+352365,int_stack+550969,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+633289,int_stack+322881,int_stack+559789,420);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+67044,int_stack+84728,int_stack+83720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+70068,int_stack+86024,int_stack+84728, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+73956,int_stack+70068,int_stack+67044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+80004,int_stack+87644,int_stack+86024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+545089,int_stack+80004,int_stack+70068, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+552865,int_stack+545089,int_stack+73956, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+67044,int_stack+89624,int_stack+87644, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+562945,int_stack+67044,int_stack+80004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+67044,int_stack+562945,int_stack+545089, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+562945,int_stack+67044,int_stack+552865, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+671089,int_stack+562945,int_stack+352365,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+706369,int_stack+671089,int_stack+322881,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+322881,int_stack+92420,int_stack+92000, 0.0, zero_stack, 1.0, int_stack+189904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+324141,int_stack+92960,int_stack+92420, 0.0, zero_stack, 1.0, int_stack+190324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+325761,int_stack+324141,int_stack+322881, 0.0, zero_stack, 1.0, int_stack+227624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+328281,int_stack+93635,int_stack+92960, 0.0, zero_stack, 1.0, int_stack+190864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+330306,int_stack+328281,int_stack+324141, 0.0, zero_stack, 1.0, int_stack+228884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+333546,int_stack+330306,int_stack+325761, 0.0, zero_stack, 1.0, int_stack+230504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+94460,int_stack+93635, 0.0, zero_stack, 1.0, int_stack+191539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+337746,int_stack+322881,int_stack+328281, 0.0, zero_stack, 1.0, int_stack+233024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+322881,int_stack+337746,int_stack+330306, 0.0, zero_stack, 1.0, int_stack+235049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+337746,int_stack+322881,int_stack+333546, 0.0, zero_stack, 1.0, int_stack+238289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+322881,int_stack+96038,int_stack+95450, 0.0, zero_stack, 1.0, int_stack+196804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+324645,int_stack+96794,int_stack+96038, 0.0, zero_stack, 1.0, int_stack+197392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+326913,int_stack+324645,int_stack+322881, 0.0, zero_stack, 1.0, int_stack+242489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+330441,int_stack+97739,int_stack+96794, 0.0, zero_stack, 1.0, int_stack+198148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+344046,int_stack+330441,int_stack+324645, 0.0, zero_stack, 1.0, int_stack+244253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+671089,int_stack+344046,int_stack+326913, 0.0, zero_stack, 1.0, int_stack+246521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+98894,int_stack+97739, 0.0, zero_stack, 1.0, int_stack+199093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+676969,int_stack+322881,int_stack+330441, 0.0, zero_stack, 1.0, int_stack+250049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+322881,int_stack+676969,int_stack+344046, 0.0, zero_stack, 1.0, int_stack+263654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+676969,int_stack+322881,int_stack+671089, 0.0, zero_stack, 1.0, int_stack+268190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+685789,int_stack+676969,int_stack+337746,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+671089,int_stack+101064,int_stack+100280, 0.0, zero_stack, 1.0, int_stack+206464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+673441,int_stack+102072,int_stack+101064, 0.0, zero_stack, 1.0, int_stack+207248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+322881,int_stack+673441,int_stack+671089, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+327585,int_stack+103332,int_stack+102072, 0.0, zero_stack, 1.0, int_stack+208256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+331365,int_stack+327585,int_stack+673441, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+337413,int_stack+331365,int_stack+322881, 0.0, zero_stack, 1.0, int_stack+274070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+104872,int_stack+103332, 0.0, zero_stack, 1.0, int_stack+209516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+352365,int_stack+322881,int_stack+327585, 0.0, zero_stack, 1.0, int_stack+278774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+67044,int_stack+352365,int_stack+331365, 0.0, zero_stack, 1.0, int_stack+252884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+352365,int_stack+67044,int_stack+337413, 0.0, zero_stack, 1.0, int_stack+315041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+322881,int_stack+352365,int_stack+676969,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+67044,int_stack+322881,int_stack+685789,420);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+671089,int_stack+107728,int_stack+106720, 0.0, zero_stack, 1.0, int_stack+129720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+674113,int_stack+109024,int_stack+107728, 0.0, zero_stack, 1.0, int_stack+131736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+678001,int_stack+674113,int_stack+671089, 0.0, zero_stack, 1.0, int_stack+349341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+684049,int_stack+110644,int_stack+109024, 0.0, zero_stack, 1.0, int_stack+134328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+688909,int_stack+684049,int_stack+674113, 0.0, zero_stack, 1.0, int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+545089,int_stack+688909,int_stack+678001, 0.0, zero_stack, 1.0, int_stack+282554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+671089,int_stack+112624,int_stack+110644, 0.0, zero_stack, 1.0, int_stack+137568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+104844,int_stack+671089,int_stack+684049, 0.0, zero_stack, 1.0, int_stack+9264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+671089,int_stack+104844,int_stack+688909, 0.0, zero_stack, 1.0, int_stack+288602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+684049,int_stack+671089,int_stack+545089, 0.0, zero_stack, 1.0, int_stack+296378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+545089,int_stack+684049,int_stack+352365,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+759289,int_stack+545089,int_stack+322881,420);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+322881,int_stack+115420,int_stack+115000, 1.0, int_stack+189904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+324141,int_stack+115960,int_stack+115420, 1.0, int_stack+190324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+325761,int_stack+324141,int_stack+322881, 1.0, int_stack+227624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+328281,int_stack+116635,int_stack+115960, 1.0, int_stack+190864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+330306,int_stack+328281,int_stack+324141, 1.0, int_stack+228884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+333546,int_stack+330306,int_stack+325761, 1.0, int_stack+230504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+227624,int_stack+117460,int_stack+116635, 1.0, int_stack+191539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+322881,int_stack+227624,int_stack+328281, 1.0, int_stack+233024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+227624,int_stack+322881,int_stack+330306, 1.0, int_stack+235049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+322881,int_stack+227624,int_stack+333546, 1.0, int_stack+238289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+227624,int_stack+119038,int_stack+118450, 1.0, int_stack+196804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+229388,int_stack+119794,int_stack+119038, 1.0, int_stack+197392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+329181,int_stack+229388,int_stack+227624, 1.0, int_stack+242489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+332709,int_stack+120739,int_stack+119794, 1.0, int_stack+198148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+335544,int_stack+332709,int_stack+229388, 1.0, int_stack+244253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+340080,int_stack+335544,int_stack+329181, 1.0, int_stack+246521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+329181,int_stack+121894,int_stack+120739, 1.0, int_stack+199093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+242489,int_stack+329181,int_stack+332709, 1.0, int_stack+250049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+545089,int_stack+242489,int_stack+335544, 1.0, int_stack+263654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+329181,int_stack+545089,int_stack+340080, 1.0, int_stack+268190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+545089,int_stack+329181,int_stack+322881,420);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+322881,int_stack+124064,int_stack+123280, 1.0, int_stack+206464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+325233,int_stack+125072,int_stack+124064, 1.0, int_stack+207248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+563989,int_stack+325233,int_stack+322881, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+568693,int_stack+126332,int_stack+125072, 1.0, int_stack+208256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+572473,int_stack+568693,int_stack+325233, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+338001,int_stack+572473,int_stack+563989, 1.0, int_stack+274070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+274070,int_stack+127872,int_stack+126332, 1.0, int_stack+209516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+242489,int_stack+274070,int_stack+568693, 1.0, int_stack+278774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+352365,int_stack+242489,int_stack+572473, 1.0, int_stack+252884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+563989,int_stack+352365,int_stack+338001, 1.0, int_stack+315041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+671089,int_stack+563989,int_stack+329181,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+812209,int_stack+671089,int_stack+545089,420);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+545089,int_stack+133032,int_stack+130728, 1.0, int_stack+129720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+548113,int_stack+135948,int_stack+133032, 1.0, int_stack+131736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+552001,int_stack+548113,int_stack+545089, 1.0, int_stack+349341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+558049,int_stack+139548,int_stack+135948, 1.0, int_stack+134328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+322881,int_stack+558049,int_stack+548113, 1.0, int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+330657,int_stack+322881,int_stack+552001, 1.0, int_stack+282554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+282554,int_stack+141528,int_stack+139548, 1.0, int_stack+137568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+545089,int_stack+282554,int_stack+558049, 1.0, int_stack+9264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+545089,int_stack+322881, 1.0, int_stack+288602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+545089,int_stack+0,int_stack+330657, 1.0, int_stack+296378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ig) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+322881,int_stack+545089,int_stack+563989,420);
 /*--- compute (hd|ig) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+850009,int_stack+322881,int_stack+671089,420);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+671089,int_stack+192364,int_stack+191539,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+673564,int_stack+671089,int_stack+233024,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+677614,int_stack+673564,int_stack+235049,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+671089,int_stack+677614,int_stack+238289,15);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+677389,int_stack+200248,int_stack+199093,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+680854,int_stack+677389,int_stack+250049,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+686524,int_stack+680854,int_stack+263654,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+677389,int_stack+686524,int_stack+268190,21);
 /*--- compute (gp|ig) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+686209,int_stack+677389,int_stack+671089,420);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+322881,int_stack+211056,int_stack+209516,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+327501,int_stack+322881,int_stack+278774,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+335061,int_stack+327501,int_stack+252884,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+322881,int_stack+335061,int_stack+315041,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+334641,int_stack+322881,int_stack+677389,420);
 /*--- compute (gd|ig) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+227624,int_stack+334641,int_stack+686209,420);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+705109,int_stack+144324,int_stack+143904,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+361101,int_stack+144864,int_stack+144324,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+362721,int_stack+361101,int_stack+705109,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+545089,int_stack+145539,int_stack+144864,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+547114,int_stack+545089,int_stack+361101,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+550354,int_stack+547114,int_stack+362721,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+361101,int_stack+146364,int_stack+145539,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+554554,int_stack+361101,int_stack+545089,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+558604,int_stack+554554,int_stack+547114,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+564004,int_stack+558604,int_stack+550354,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+545089,int_stack+147942,int_stack+147354,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+546853,int_stack+148698,int_stack+147942,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+549121,int_stack+546853,int_stack+545089,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+552649,int_stack+149643,int_stack+148698,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+555484,int_stack+552649,int_stack+546853,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+570304,int_stack+555484,int_stack+549121,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+545089,int_stack+150798,int_stack+149643,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+545089,int_stack+552649,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+545089,int_stack+0,int_stack+555484,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+545089,int_stack+570304,21);
 /*--- compute (gp|ig) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+545089,int_stack+0,int_stack+564004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+671089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+563989,int_stack+152968,int_stack+152184,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+566341,int_stack+153976,int_stack+152968,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+569365,int_stack+566341,int_stack+563989,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+574069,int_stack+155236,int_stack+153976,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+206464,int_stack+574069,int_stack+566341,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+265424,int_stack+206464,int_stack+569365,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+563989,int_stack+156776,int_stack+155236,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+273264,int_stack+563989,int_stack+574069,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+563989,int_stack+273264,int_stack+206464,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+273264,int_stack+563989,int_stack+265424,28);
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+285024,int_stack+273264,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gd|ig) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+104844,int_stack+285024,int_stack+545089, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+545089,int_stack+159632,int_stack+158624,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+548113,int_stack+160928,int_stack+159632,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+552001,int_stack+548113,int_stack+545089,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+558049,int_stack+162548,int_stack+160928,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+562909,int_stack+558049,int_stack+548113,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+562909,int_stack+552001,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+545089,int_stack+164528,int_stack+162548,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+311484,int_stack+545089,int_stack+558049,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+545089,int_stack+311484,int_stack+562909,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+558049,int_stack+545089,int_stack+0,36);
 /*--- compute (ip|ig) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+902929,int_stack+558049,int_stack+273264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (hd|ig) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+938209,int_stack+902929,int_stack+285024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+705109,int_stack+167324,int_stack+166904,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+902929,int_stack+167864,int_stack+167324,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+904549,int_stack+902929,int_stack+705109,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+907069,int_stack+168539,int_stack+167864,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+909094,int_stack+907069,int_stack+902929,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+912334,int_stack+909094,int_stack+904549,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+902929,int_stack+169364,int_stack+168539,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+916534,int_stack+902929,int_stack+907069,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+902929,int_stack+916534,int_stack+909094,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+916534,int_stack+902929,int_stack+912334,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+902929,int_stack+170942,int_stack+170354,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+904693,int_stack+171698,int_stack+170942,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+906961,int_stack+904693,int_stack+902929,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+910489,int_stack+172643,int_stack+171698,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+922834,int_stack+910489,int_stack+904693,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+927370,int_stack+922834,int_stack+906961,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+902929,int_stack+173798,int_stack+172643,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+902929,int_stack+910489,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+902929,int_stack+0,int_stack+922834,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+902929,int_stack+927370,21);
 /*--- compute (gp|ig) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+545089,int_stack+0,int_stack+916534, 0.0, zero_stack, 1.0, int_stack+671089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+902929,int_stack+175968,int_stack+175184,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+905281,int_stack+176976,int_stack+175968,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+908305,int_stack+905281,int_stack+902929,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+913009,int_stack+178236,int_stack+176976,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+916789,int_stack+913009,int_stack+905281,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+922837,int_stack+916789,int_stack+908305,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+902929,int_stack+179776,int_stack+178236,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+563989,int_stack+902929,int_stack+913009,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+902929,int_stack+563989,int_stack+916789,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+563989,int_stack+902929,int_stack+922837,28);
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+902929,int_stack+563989,int_stack+0, 0.0, zero_stack, 1.0, int_stack+677389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gd|ig) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+265424,int_stack+902929,int_stack+545089, 0.0, zero_stack, 1.0, int_stack+686209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+545089,int_stack+182632,int_stack+181624,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+548113,int_stack+183928,int_stack+182632,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+552001,int_stack+548113,int_stack+545089,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+558049,int_stack+185548,int_stack+183928,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+558049,int_stack+548113,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+303224,int_stack+0,int_stack+552001,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+545089,int_stack+187528,int_stack+185548,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+142644,int_stack+545089,int_stack+558049,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+545089,int_stack+142644,int_stack+0,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+142644,int_stack+545089,int_stack+303224,36);
 /*--- compute (ip|ig) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+157764,int_stack+142644,int_stack+563989, 0.0, zero_stack, 1.0, int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (hd|ig) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+991129,int_stack+157764,int_stack+902929, 0.0, zero_stack, 1.0, int_stack+334641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+705109,int_stack+193774,int_stack+193354,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+902929,int_stack+194314,int_stack+193774,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+904549,int_stack+902929,int_stack+705109,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+907069,int_stack+194989,int_stack+194314,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+909094,int_stack+907069,int_stack+902929,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+912334,int_stack+909094,int_stack+904549,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+902929,int_stack+195814,int_stack+194989,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+916534,int_stack+902929,int_stack+907069,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+902929,int_stack+916534,int_stack+909094,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+916534,int_stack+902929,int_stack+912334,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+902929,int_stack+202222,int_stack+201634,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+904693,int_stack+202978,int_stack+202222,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+906961,int_stack+904693,int_stack+902929,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+910489,int_stack+203923,int_stack+202978,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+922834,int_stack+910489,int_stack+904693,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+927370,int_stack+922834,int_stack+906961,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+902929,int_stack+205078,int_stack+203923,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+142644,int_stack+902929,int_stack+910489,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+902929,int_stack+142644,int_stack+922834,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+142644,int_stack+902929,int_stack+927370,21);
 /*--- compute (gp|ig) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+151464,int_stack+142644,int_stack+916534, 1.0, int_stack+671089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+671089,int_stack+213688,int_stack+212904,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+673441,int_stack+214696,int_stack+213688,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+902929,int_stack+673441,int_stack+671089,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+907633,int_stack+215956,int_stack+214696,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+911413,int_stack+907633,int_stack+673441,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+917461,int_stack+911413,int_stack+902929,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+902929,int_stack+217496,int_stack+215956,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+925301,int_stack+902929,int_stack+907633,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+170364,int_stack+925301,int_stack+911413,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+925301,int_stack+170364,int_stack+917461,28);
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+170364,int_stack+925301,int_stack+142644, 1.0, int_stack+677389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gd|ig) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1044049,int_stack+170364,int_stack+151464, 1.0, int_stack+686209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+142644,int_stack+220352,int_stack+219344,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+145668,int_stack+221648,int_stack+220352,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+149556,int_stack+145668,int_stack+142644,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+155604,int_stack+223268,int_stack+221648,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+160464,int_stack+155604,int_stack+145668,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+196824,int_stack+160464,int_stack+149556,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+142644,int_stack+225248,int_stack+223268,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+206904,int_stack+142644,int_stack+155604,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+142644,int_stack+206904,int_stack+160464,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+206904,int_stack+142644,int_stack+196824,36);
 /*--- compute (ip|ig) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+671089,int_stack+206904,int_stack+925301, 1.0, int_stack+322881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (hd|ig) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1081849,int_stack+671089,int_stack+170364, 1.0, int_stack+334641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+142644,int_stack+454369,int_stack+366169,420);
     Libderiv->ABCD[11] = int_stack + 142644;
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+303224,int_stack+580369,int_stack+507289,420);
     Libderiv->ABCD[10] = int_stack + 303224;
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+441769,int_stack+14124,int_stack+403969,420);
     Libderiv->ABCD[9] = int_stack + 441769;
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+366224,int_stack+706369,int_stack+633289,420);
     Libderiv->ABCD[8] = int_stack + 366224;
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+0,int_stack+759289,int_stack+67044,420);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (gf|ig) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+504769,int_stack+850009,int_stack+812209,420);
     Libderiv->ABCD[6] = int_stack + 504769;
 /*--- compute (gf|ig) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+567769,int_stack+938209,int_stack+104844, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[2] = int_stack + 567769;
 /*--- compute (gf|ig) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+63000,int_stack+991129,int_stack+265424, 0.0, zero_stack, 1.0, int_stack+227624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[1] = int_stack + 63000;
 /*--- compute (gf|ig) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+630769,int_stack+1081849,int_stack+1044049, 1.0, int_stack+227624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[0] = int_stack + 630769;

}
