/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gghf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gg|hf) integrals */

void d1hrr_order_gghf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][5][11] = int_stack + 0;
 Libderiv->deriv_classes[4][6][11] = int_stack + 315;
 Libderiv->deriv_classes[4][7][11] = int_stack + 735;
 Libderiv->deriv_classes[4][8][11] = int_stack + 1275;
 Libderiv->deriv_classes[5][5][11] = int_stack + 1950;
 Libderiv->deriv_classes[5][6][11] = int_stack + 2391;
 Libderiv->deriv_classes[5][7][11] = int_stack + 2979;
 Libderiv->deriv_classes[5][8][11] = int_stack + 3735;
 Libderiv->deriv_classes[6][5][11] = int_stack + 4680;
 Libderiv->deriv_classes[6][6][11] = int_stack + 5268;
 Libderiv->deriv_classes[6][7][11] = int_stack + 6052;
 Libderiv->deriv_classes[6][8][11] = int_stack + 7060;
 Libderiv->deriv_classes[7][5][11] = int_stack + 8320;
 Libderiv->deriv_classes[7][6][11] = int_stack + 9076;
 Libderiv->deriv_classes[7][7][11] = int_stack + 10084;
 Libderiv->deriv_classes[7][8][11] = int_stack + 11380;
 Libderiv->deriv_classes[8][5][11] = int_stack + 13000;
 Libderiv->deriv_classes[8][6][11] = int_stack + 13945;
 Libderiv->deriv_classes[8][7][11] = int_stack + 15205;
 Libderiv->deriv_classes[8][8][11] = int_stack + 16825;
 Libderiv->deriv_classes[4][5][10] = int_stack + 18850;
 Libderiv->deriv_classes[4][6][10] = int_stack + 19165;
 Libderiv->deriv_classes[4][7][10] = int_stack + 19585;
 Libderiv->deriv_classes[4][8][10] = int_stack + 20125;
 Libderiv->deriv_classes[5][5][10] = int_stack + 20800;
 Libderiv->deriv_classes[5][6][10] = int_stack + 21241;
 Libderiv->deriv_classes[5][7][10] = int_stack + 21829;
 Libderiv->deriv_classes[5][8][10] = int_stack + 22585;
 Libderiv->deriv_classes[6][5][10] = int_stack + 23530;
 Libderiv->deriv_classes[6][6][10] = int_stack + 24118;
 Libderiv->deriv_classes[6][7][10] = int_stack + 24902;
 Libderiv->deriv_classes[6][8][10] = int_stack + 25910;
 Libderiv->deriv_classes[7][5][10] = int_stack + 27170;
 Libderiv->deriv_classes[7][6][10] = int_stack + 27926;
 Libderiv->deriv_classes[7][7][10] = int_stack + 28934;
 Libderiv->deriv_classes[7][8][10] = int_stack + 30230;
 Libderiv->deriv_classes[8][5][10] = int_stack + 31850;
 Libderiv->deriv_classes[8][6][10] = int_stack + 32795;
 Libderiv->deriv_classes[8][7][10] = int_stack + 34055;
 Libderiv->deriv_classes[8][8][10] = int_stack + 35675;
 Libderiv->deriv_classes[4][5][9] = int_stack + 37700;
 Libderiv->deriv_classes[4][6][9] = int_stack + 38015;
 Libderiv->deriv_classes[4][7][9] = int_stack + 38435;
 Libderiv->deriv_classes[4][8][9] = int_stack + 38975;
 Libderiv->deriv_classes[5][5][9] = int_stack + 39650;
 Libderiv->deriv_classes[5][6][9] = int_stack + 40091;
 Libderiv->deriv_classes[5][7][9] = int_stack + 40679;
 Libderiv->deriv_classes[5][8][9] = int_stack + 41435;
 Libderiv->deriv_classes[6][5][9] = int_stack + 42380;
 Libderiv->deriv_classes[6][6][9] = int_stack + 42968;
 Libderiv->deriv_classes[6][7][9] = int_stack + 43752;
 Libderiv->deriv_classes[6][8][9] = int_stack + 44760;
 Libderiv->deriv_classes[7][5][9] = int_stack + 46020;
 Libderiv->deriv_classes[7][6][9] = int_stack + 46776;
 Libderiv->deriv_classes[7][7][9] = int_stack + 47784;
 Libderiv->deriv_classes[7][8][9] = int_stack + 49080;
 Libderiv->deriv_classes[8][5][9] = int_stack + 50700;
 Libderiv->deriv_classes[8][6][9] = int_stack + 51645;
 Libderiv->deriv_classes[8][7][9] = int_stack + 52905;
 Libderiv->deriv_classes[8][8][9] = int_stack + 54525;
 Libderiv->deriv_classes[4][5][8] = int_stack + 56550;
 Libderiv->deriv_classes[4][6][8] = int_stack + 56865;
 Libderiv->deriv_classes[4][7][8] = int_stack + 57285;
 Libderiv->deriv_classes[4][8][8] = int_stack + 57825;
 Libderiv->deriv_classes[5][5][8] = int_stack + 58500;
 Libderiv->deriv_classes[5][6][8] = int_stack + 58941;
 Libderiv->deriv_classes[5][7][8] = int_stack + 59529;
 Libderiv->deriv_classes[5][8][8] = int_stack + 60285;
 Libderiv->deriv_classes[6][5][8] = int_stack + 61230;
 Libderiv->deriv_classes[6][6][8] = int_stack + 61818;
 Libderiv->deriv_classes[6][7][8] = int_stack + 62602;
 Libderiv->deriv_classes[6][8][8] = int_stack + 63610;
 Libderiv->deriv_classes[7][5][8] = int_stack + 64870;
 Libderiv->deriv_classes[7][6][8] = int_stack + 65626;
 Libderiv->deriv_classes[7][7][8] = int_stack + 66634;
 Libderiv->deriv_classes[7][8][8] = int_stack + 67930;
 Libderiv->deriv_classes[8][5][8] = int_stack + 69550;
 Libderiv->deriv_classes[8][6][8] = int_stack + 70495;
 Libderiv->deriv_classes[8][7][8] = int_stack + 71755;
 Libderiv->deriv_classes[8][8][8] = int_stack + 73375;
 Libderiv->deriv_classes[4][5][7] = int_stack + 75400;
 Libderiv->deriv_classes[4][6][7] = int_stack + 75715;
 Libderiv->deriv_classes[4][7][7] = int_stack + 76135;
 Libderiv->deriv_classes[4][8][7] = int_stack + 76675;
 Libderiv->deriv_classes[5][5][7] = int_stack + 77350;
 Libderiv->deriv_classes[5][6][7] = int_stack + 77791;
 Libderiv->deriv_classes[5][7][7] = int_stack + 78379;
 Libderiv->deriv_classes[5][8][7] = int_stack + 79135;
 Libderiv->deriv_classes[6][5][7] = int_stack + 80080;
 Libderiv->deriv_classes[6][6][7] = int_stack + 80668;
 Libderiv->deriv_classes[6][7][7] = int_stack + 81452;
 Libderiv->deriv_classes[6][8][7] = int_stack + 82460;
 Libderiv->deriv_classes[7][5][7] = int_stack + 83720;
 Libderiv->deriv_classes[7][6][7] = int_stack + 84476;
 Libderiv->deriv_classes[7][7][7] = int_stack + 85484;
 Libderiv->deriv_classes[7][8][7] = int_stack + 86780;
 Libderiv->deriv_classes[8][5][7] = int_stack + 88400;
 Libderiv->deriv_classes[8][6][7] = int_stack + 89345;
 Libderiv->deriv_classes[8][7][7] = int_stack + 90605;
 Libderiv->deriv_classes[8][8][7] = int_stack + 92225;
 Libderiv->deriv_classes[4][5][6] = int_stack + 94250;
 Libderiv->deriv_classes[4][6][6] = int_stack + 94565;
 Libderiv->deriv_classes[4][7][6] = int_stack + 94985;
 Libderiv->deriv_classes[4][8][6] = int_stack + 95525;
 Libderiv->deriv_classes[5][5][6] = int_stack + 96200;
 Libderiv->deriv_classes[5][6][6] = int_stack + 96641;
 Libderiv->deriv_classes[5][7][6] = int_stack + 97229;
 Libderiv->deriv_classes[5][8][6] = int_stack + 97985;
 Libderiv->deriv_classes[6][5][6] = int_stack + 98930;
 Libderiv->deriv_classes[6][6][6] = int_stack + 99518;
 Libderiv->deriv_classes[6][7][6] = int_stack + 100302;
 Libderiv->deriv_classes[6][8][6] = int_stack + 101310;
 Libderiv->deriv_classes[7][5][6] = int_stack + 102570;
 Libderiv->deriv_classes[7][6][6] = int_stack + 103326;
 Libderiv->deriv_classes[7][7][6] = int_stack + 104334;
 Libderiv->deriv_classes[7][8][6] = int_stack + 105630;
 Libderiv->dvrr_classes[8][5] = int_stack + 107250;
 Libderiv->deriv_classes[8][5][6] = int_stack + 108195;
 Libderiv->dvrr_classes[8][6] = int_stack + 109140;
 Libderiv->deriv_classes[8][6][6] = int_stack + 110400;
 Libderiv->dvrr_classes[8][7] = int_stack + 111660;
 Libderiv->deriv_classes[8][7][6] = int_stack + 113280;
 Libderiv->deriv_classes[8][8][6] = int_stack + 114900;
 Libderiv->deriv_classes[4][5][2] = int_stack + 116925;
 Libderiv->deriv_classes[4][6][2] = int_stack + 117240;
 Libderiv->deriv_classes[4][7][2] = int_stack + 117660;
 Libderiv->deriv_classes[4][8][2] = int_stack + 118200;
 Libderiv->deriv_classes[5][5][2] = int_stack + 118875;
 Libderiv->deriv_classes[5][6][2] = int_stack + 119316;
 Libderiv->deriv_classes[5][7][2] = int_stack + 119904;
 Libderiv->deriv_classes[5][8][2] = int_stack + 120660;
 Libderiv->deriv_classes[6][5][2] = int_stack + 121605;
 Libderiv->deriv_classes[6][6][2] = int_stack + 122193;
 Libderiv->deriv_classes[6][7][2] = int_stack + 122977;
 Libderiv->deriv_classes[6][8][2] = int_stack + 123985;
 Libderiv->deriv_classes[7][5][2] = int_stack + 125245;
 Libderiv->deriv_classes[7][6][2] = int_stack + 126001;
 Libderiv->deriv_classes[7][7][2] = int_stack + 127009;
 Libderiv->deriv_classes[7][8][2] = int_stack + 128305;
 Libderiv->deriv_classes[8][5][2] = int_stack + 129925;
 Libderiv->deriv_classes[8][6][2] = int_stack + 130870;
 Libderiv->deriv_classes[8][7][2] = int_stack + 132130;
 Libderiv->deriv_classes[8][8][2] = int_stack + 133750;
 Libderiv->deriv_classes[4][5][1] = int_stack + 135775;
 Libderiv->deriv_classes[4][6][1] = int_stack + 136090;
 Libderiv->deriv_classes[4][7][1] = int_stack + 136510;
 Libderiv->deriv_classes[4][8][1] = int_stack + 137050;
 Libderiv->deriv_classes[5][5][1] = int_stack + 137725;
 Libderiv->deriv_classes[5][6][1] = int_stack + 138166;
 Libderiv->deriv_classes[5][7][1] = int_stack + 138754;
 Libderiv->deriv_classes[5][8][1] = int_stack + 139510;
 Libderiv->deriv_classes[6][5][1] = int_stack + 140455;
 Libderiv->deriv_classes[6][6][1] = int_stack + 141043;
 Libderiv->deriv_classes[6][7][1] = int_stack + 141827;
 Libderiv->deriv_classes[6][8][1] = int_stack + 142835;
 Libderiv->deriv_classes[7][5][1] = int_stack + 144095;
 Libderiv->deriv_classes[7][6][1] = int_stack + 144851;
 Libderiv->deriv_classes[7][7][1] = int_stack + 145859;
 Libderiv->deriv_classes[7][8][1] = int_stack + 147155;
 Libderiv->deriv_classes[8][5][1] = int_stack + 148775;
 Libderiv->deriv_classes[8][6][1] = int_stack + 149720;
 Libderiv->deriv_classes[8][7][1] = int_stack + 150980;
 Libderiv->deriv_classes[8][8][1] = int_stack + 152600;
 Libderiv->dvrr_classes[4][5] = int_stack + 154625;
 Libderiv->dvrr_classes[4][6] = int_stack + 154940;
 Libderiv->dvrr_classes[4][7] = int_stack + 155360;
 Libderiv->dvrr_classes[4][8] = int_stack + 155900;
 Libderiv->deriv_classes[4][5][0] = int_stack + 156575;
 Libderiv->deriv_classes[4][6][0] = int_stack + 156890;
 Libderiv->deriv_classes[4][7][0] = int_stack + 157310;
 Libderiv->deriv_classes[4][8][0] = int_stack + 157850;
 Libderiv->dvrr_classes[5][5] = int_stack + 158525;
 Libderiv->dvrr_classes[5][6] = int_stack + 158966;
 Libderiv->dvrr_classes[5][7] = int_stack + 159554;
 Libderiv->dvrr_classes[5][8] = int_stack + 160310;
 Libderiv->deriv_classes[5][5][0] = int_stack + 161255;
 Libderiv->deriv_classes[5][6][0] = int_stack + 161696;
 Libderiv->deriv_classes[5][7][0] = int_stack + 162284;
 Libderiv->deriv_classes[5][8][0] = int_stack + 163040;
 Libderiv->dvrr_classes[6][5] = int_stack + 163985;
 Libderiv->dvrr_classes[6][6] = int_stack + 164573;
 Libderiv->dvrr_classes[6][7] = int_stack + 165357;
 Libderiv->dvrr_classes[6][8] = int_stack + 166365;
 Libderiv->deriv_classes[6][5][0] = int_stack + 167625;
 Libderiv->deriv_classes[6][6][0] = int_stack + 168213;
 Libderiv->deriv_classes[6][7][0] = int_stack + 168997;
 Libderiv->deriv_classes[6][8][0] = int_stack + 170005;
 Libderiv->dvrr_classes[7][5] = int_stack + 171265;
 Libderiv->dvrr_classes[7][6] = int_stack + 172021;
 Libderiv->dvrr_classes[7][7] = int_stack + 173029;
 Libderiv->dvrr_classes[7][8] = int_stack + 174325;
 Libderiv->deriv_classes[7][5][0] = int_stack + 175945;
 Libderiv->deriv_classes[7][6][0] = int_stack + 176701;
 Libderiv->deriv_classes[7][7][0] = int_stack + 177709;
 Libderiv->deriv_classes[7][8][0] = int_stack + 179005;
 Libderiv->deriv_classes[8][5][0] = int_stack + 180625;
 Libderiv->deriv_classes[8][6][0] = int_stack + 181570;
 Libderiv->deriv_classes[8][7][0] = int_stack + 182830;
 Libderiv->deriv_classes[8][8][0] = int_stack + 184450;
 memset(int_stack,0,1491800);

 Libderiv->dvrr_stack = int_stack + 989329;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gghf(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+186475,int_stack+154940,int_stack+154625,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+187420,int_stack+155360,int_stack+154940,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+188680,int_stack+187420,int_stack+186475,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+190570,int_stack+315,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154625,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+191515,int_stack+735,int_stack+315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154940,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+192775,int_stack+191515,int_stack+190570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186475,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+194665,int_stack+1275,int_stack+735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155360,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+196285,int_stack+194665,int_stack+191515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187420,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+198805,int_stack+196285,int_stack+192775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188680,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+190570,int_stack+158966,int_stack+158525,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+191893,int_stack+159554,int_stack+158966,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+193657,int_stack+191893,int_stack+190570,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196303,int_stack+2391,int_stack+1950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158525,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+2979,int_stack+2391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158966,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+201955,int_stack+0,int_stack+196303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190570,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+196303,int_stack+3735,int_stack+2979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159554,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+204601,int_stack+196303,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191893,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+204601,int_stack+201955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193657,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+201955,int_stack+0,int_stack+198805,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+196303,int_stack+164573,int_stack+163985,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+198067,int_stack+165357,int_stack+164573,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+211405,int_stack+198067,int_stack+196303,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+214933,int_stack+5268,int_stack+4680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163985,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+216697,int_stack+6052,int_stack+5268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164573,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+219049,int_stack+216697,int_stack+214933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196303,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+222577,int_stack+7060,int_stack+6052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165357,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+225601,int_stack+222577,int_stack+216697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198067,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+230305,int_stack+225601,int_stack+219049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211405,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+214933,int_stack+230305,int_stack+0,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+236185,int_stack+214933,int_stack+201955,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+172021,int_stack+171265,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+173029,int_stack+172021,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+200419,int_stack+2268,int_stack+0,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5292,int_stack+9076,int_stack+8320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171265,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+204955,int_stack+10084,int_stack+9076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172021,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+255085,int_stack+204955,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5292,int_stack+11380,int_stack+10084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173029,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+259621,int_stack+5292,int_stack+204955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5292,int_stack+259621,int_stack+255085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200419,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+255085,int_stack+5292,int_stack+230305,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+272725,int_stack+255085,int_stack+214933,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+299185,int_stack+272725,int_stack+236185,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+214933,int_stack+109140,int_stack+107250,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+217768,int_stack+111660,int_stack+109140,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+221548,int_stack+217768,int_stack+214933,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+227218,int_stack+13945,int_stack+13000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107250,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+230053,int_stack+15205,int_stack+13945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109140,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+233833,int_stack+230053,int_stack+227218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214933,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+239503,int_stack+16825,int_stack+15205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111660,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+244363,int_stack+239503,int_stack+230053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217768,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+330685,int_stack+244363,int_stack+233833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221548,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+227218,int_stack+330685,int_stack+5292,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+330685,int_stack+227218,int_stack+255085,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+227218,int_stack+330685,int_stack+272725,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+330685,int_stack+19165,int_stack+18850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154625, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+331630,int_stack+19585,int_stack+19165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154940, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+332890,int_stack+331630,int_stack+330685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186475, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+334780,int_stack+20125,int_stack+19585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155360, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+336400,int_stack+334780,int_stack+331630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187420, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+338920,int_stack+336400,int_stack+332890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188680, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+330685,int_stack+21241,int_stack+20800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158525, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+332008,int_stack+21829,int_stack+21241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158966, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+333772,int_stack+332008,int_stack+330685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190570, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+336418,int_stack+22585,int_stack+21829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159554, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+342070,int_stack+336418,int_stack+332008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191893, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+345598,int_stack+342070,int_stack+333772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193657, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+350008,int_stack+345598,int_stack+338920,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+330685,int_stack+24118,int_stack+23530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163985, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+332449,int_stack+24902,int_stack+24118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164573, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+334801,int_stack+332449,int_stack+330685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196303, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+338329,int_stack+25910,int_stack+24902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165357, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+359458,int_stack+338329,int_stack+332449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198067, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+338329,int_stack+359458,int_stack+334801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211405, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+271318,int_stack+338329,int_stack+345598,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+5292,int_stack+271318,int_stack+350008,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+344209,int_stack+27926,int_stack+27170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171265, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+346477,int_stack+28934,int_stack+27926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172021, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349501,int_stack+346477,int_stack+344209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+354037,int_stack+30230,int_stack+28934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173029, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+357925,int_stack+354037,int_stack+346477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+330685,int_stack+357925,int_stack+349501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200419, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+344209,int_stack+330685,int_stack+338329,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+361849,int_stack+344209,int_stack+271318,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+388309,int_stack+361849,int_stack+5292,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5292,int_stack+32795,int_stack+31850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107250, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8127,int_stack+34055,int_stack+32795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109140, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11907,int_stack+8127,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214933, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+17577,int_stack+35675,int_stack+34055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111660, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+22437,int_stack+17577,int_stack+8127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217768, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+271318,int_stack+22437,int_stack+11907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221548, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5292,int_stack+271318,int_stack+330685,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+419809,int_stack+5292,int_stack+344209,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+455089,int_stack+419809,int_stack+361849,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+419809,int_stack+38015,int_stack+37700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154625, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+420754,int_stack+38435,int_stack+38015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154940, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+422014,int_stack+420754,int_stack+419809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186475, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+423904,int_stack+38975,int_stack+38435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155360, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+425524,int_stack+423904,int_stack+420754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187420, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+428044,int_stack+425524,int_stack+422014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188680, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+419809,int_stack+40091,int_stack+39650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158525, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+421132,int_stack+40679,int_stack+40091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158966, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+422896,int_stack+421132,int_stack+419809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190570, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+425542,int_stack+41435,int_stack+40679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159554, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+431194,int_stack+425542,int_stack+421132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191893, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+434722,int_stack+431194,int_stack+422896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193657, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+439132,int_stack+434722,int_stack+428044,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+419809,int_stack+42968,int_stack+42380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163985, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+421573,int_stack+43752,int_stack+42968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164573, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+423925,int_stack+421573,int_stack+419809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196303, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+427453,int_stack+44760,int_stack+43752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165357, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+448582,int_stack+427453,int_stack+421573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198067, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+427453,int_stack+448582,int_stack+423925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211405, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5292,int_stack+427453,int_stack+434722,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+18522,int_stack+5292,int_stack+439132,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+433333,int_stack+46776,int_stack+46020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171265, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435601,int_stack+47784,int_stack+46776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172021, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+438625,int_stack+435601,int_stack+433333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+443161,int_stack+49080,int_stack+47784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173029, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447049,int_stack+443161,int_stack+435601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+419809,int_stack+447049,int_stack+438625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200419, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+433333,int_stack+419809,int_stack+427453,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+330685,int_stack+433333,int_stack+5292,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+499189,int_stack+330685,int_stack+18522,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5292,int_stack+51645,int_stack+50700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107250, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8127,int_stack+52905,int_stack+51645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109140, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11907,int_stack+8127,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214933, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+17577,int_stack+54525,int_stack+52905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111660, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+22437,int_stack+17577,int_stack+8127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217768, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+29997,int_stack+22437,int_stack+11907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221548, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5292,int_stack+29997,int_stack+419809,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+530689,int_stack+5292,int_stack+433333,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+5292,int_stack+530689,int_stack+330685,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+330685,int_stack+56865,int_stack+56550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+331630,int_stack+57285,int_stack+56865, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+332890,int_stack+331630,int_stack+330685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+334780,int_stack+57825,int_stack+57285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+336400,int_stack+334780,int_stack+331630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+338920,int_stack+336400,int_stack+332890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+330685,int_stack+58941,int_stack+58500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+332008,int_stack+59529,int_stack+58941, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+333772,int_stack+332008,int_stack+330685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+336418,int_stack+60285,int_stack+59529, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+342070,int_stack+336418,int_stack+332008, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+345598,int_stack+342070,int_stack+333772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+350008,int_stack+345598,int_stack+338920,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+330685,int_stack+61818,int_stack+61230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+332449,int_stack+62602,int_stack+61818, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+334801,int_stack+332449,int_stack+330685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+338329,int_stack+63610,int_stack+62602, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+359458,int_stack+338329,int_stack+332449, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+338329,int_stack+359458,int_stack+334801, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+359458,int_stack+338329,int_stack+345598,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+530689,int_stack+359458,int_stack+350008,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+372688,int_stack+65626,int_stack+64870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+374956,int_stack+66634,int_stack+65626, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+377980,int_stack+374956,int_stack+372688, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+382516,int_stack+67930,int_stack+66634, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+344209,int_stack+382516,int_stack+374956, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+350257,int_stack+344209,int_stack+377980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+49392,int_stack+350257,int_stack+338329,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+419809,int_stack+49392,int_stack+359458,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+549589,int_stack+419809,int_stack+530689,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+530689,int_stack+70495,int_stack+69550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+533524,int_stack+71755,int_stack+70495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+537304,int_stack+533524,int_stack+530689, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+542974,int_stack+73375,int_stack+71755, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+357817,int_stack+542974,int_stack+533524, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+365377,int_stack+357817,int_stack+537304, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+271318,int_stack+365377,int_stack+350257,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+330685,int_stack+271318,int_stack+49392,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+581089,int_stack+330685,int_stack+419809,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+419809,int_stack+75715,int_stack+75400, 0.0, zero_stack, 1.0, int_stack+154625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+420754,int_stack+76135,int_stack+75715, 0.0, zero_stack, 1.0, int_stack+154940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+422014,int_stack+420754,int_stack+419809, 0.0, zero_stack, 1.0, int_stack+186475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+423904,int_stack+76675,int_stack+76135, 0.0, zero_stack, 1.0, int_stack+155360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+425524,int_stack+423904,int_stack+420754, 0.0, zero_stack, 1.0, int_stack+187420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+428044,int_stack+425524,int_stack+422014, 0.0, zero_stack, 1.0, int_stack+188680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+419809,int_stack+77791,int_stack+77350, 0.0, zero_stack, 1.0, int_stack+158525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+421132,int_stack+78379,int_stack+77791, 0.0, zero_stack, 1.0, int_stack+158966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+422896,int_stack+421132,int_stack+419809, 0.0, zero_stack, 1.0, int_stack+190570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+425542,int_stack+79135,int_stack+78379, 0.0, zero_stack, 1.0, int_stack+159554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+431194,int_stack+425542,int_stack+421132, 0.0, zero_stack, 1.0, int_stack+191893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+434722,int_stack+431194,int_stack+422896, 0.0, zero_stack, 1.0, int_stack+193657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+439132,int_stack+434722,int_stack+428044,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+419809,int_stack+80668,int_stack+80080, 0.0, zero_stack, 1.0, int_stack+163985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+421573,int_stack+81452,int_stack+80668, 0.0, zero_stack, 1.0, int_stack+164573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+423925,int_stack+421573,int_stack+419809, 0.0, zero_stack, 1.0, int_stack+196303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+427453,int_stack+82460,int_stack+81452, 0.0, zero_stack, 1.0, int_stack+165357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+448582,int_stack+427453,int_stack+421573, 0.0, zero_stack, 1.0, int_stack+198067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+427453,int_stack+448582,int_stack+423925, 0.0, zero_stack, 1.0, int_stack+211405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+330685,int_stack+427453,int_stack+434722,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+530689,int_stack+330685,int_stack+439132,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+433333,int_stack+84476,int_stack+83720, 0.0, zero_stack, 1.0, int_stack+171265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435601,int_stack+85484,int_stack+84476, 0.0, zero_stack, 1.0, int_stack+172021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+438625,int_stack+435601,int_stack+433333, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+443161,int_stack+86780,int_stack+85484, 0.0, zero_stack, 1.0, int_stack+173029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447049,int_stack+443161,int_stack+435601, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+419809,int_stack+447049,int_stack+438625, 0.0, zero_stack, 1.0, int_stack+200419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+433333,int_stack+419809,int_stack+427453,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+343915,int_stack+433333,int_stack+330685,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+49392,int_stack+343915,int_stack+530689,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+530689,int_stack+89345,int_stack+88400, 0.0, zero_stack, 1.0, int_stack+107250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+533524,int_stack+90605,int_stack+89345, 0.0, zero_stack, 1.0, int_stack+109140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+537304,int_stack+533524,int_stack+530689, 0.0, zero_stack, 1.0, int_stack+214933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+542974,int_stack+92225,int_stack+90605, 0.0, zero_stack, 1.0, int_stack+111660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+330685,int_stack+542974,int_stack+533524, 0.0, zero_stack, 1.0, int_stack+217768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+370375,int_stack+330685,int_stack+537304, 0.0, zero_stack, 1.0, int_stack+221548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+271318,int_stack+370375,int_stack+419809,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+625189,int_stack+271318,int_stack+433333,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+660469,int_stack+625189,int_stack+343915,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+625189,int_stack+94565,int_stack+94250, 1.0, int_stack+154625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+626134,int_stack+94985,int_stack+94565, 1.0, int_stack+154940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+627394,int_stack+626134,int_stack+625189, 1.0, int_stack+186475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+629284,int_stack+95525,int_stack+94985, 1.0, int_stack+155360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+630904,int_stack+629284,int_stack+626134, 1.0, int_stack+187420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+633424,int_stack+630904,int_stack+627394, 1.0, int_stack+188680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+625189,int_stack+96641,int_stack+96200, 1.0, int_stack+158525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+626512,int_stack+97229,int_stack+96641, 1.0, int_stack+158966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+628276,int_stack+626512,int_stack+625189, 1.0, int_stack+190570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+630922,int_stack+97985,int_stack+97229, 1.0, int_stack+159554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+636574,int_stack+630922,int_stack+626512, 1.0, int_stack+191893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+640102,int_stack+636574,int_stack+628276, 1.0, int_stack+193657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+644512,int_stack+640102,int_stack+633424,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+625189,int_stack+99518,int_stack+98930, 1.0, int_stack+163985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+626953,int_stack+100302,int_stack+99518, 1.0, int_stack+164573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+629305,int_stack+626953,int_stack+625189, 1.0, int_stack+196303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+632833,int_stack+101310,int_stack+100302, 1.0, int_stack+165357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+653962,int_stack+632833,int_stack+626953, 1.0, int_stack+198067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+632833,int_stack+653962,int_stack+629305, 1.0, int_stack+211405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+271318,int_stack+632833,int_stack+640102,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+530689,int_stack+271318,int_stack+644512,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+638713,int_stack+103326,int_stack+102570, 1.0, int_stack+171265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+640981,int_stack+104334,int_stack+103326, 1.0, int_stack+172021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+644005,int_stack+640981,int_stack+638713, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+648541,int_stack+105630,int_stack+104334, 1.0, int_stack+173029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+652429,int_stack+648541,int_stack+640981, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+625189,int_stack+652429,int_stack+644005, 1.0, int_stack+200419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+638713,int_stack+625189,int_stack+632833,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+419809,int_stack+638713,int_stack+271318,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+330685,int_stack+419809,int_stack+530689,210);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+530689,int_stack+110400,int_stack+108195, 1.0, int_stack+107250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+533524,int_stack+113280,int_stack+110400, 1.0, int_stack+109140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+537304,int_stack+533524,int_stack+530689, 1.0, int_stack+214933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+542974,int_stack+114900,int_stack+113280, 1.0, int_stack+111660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+271318,int_stack+542974,int_stack+533524, 1.0, int_stack+217768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+278878,int_stack+271318,int_stack+537304, 1.0, int_stack+221548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+362185,int_stack+278878,int_stack+625189,210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+80892,int_stack+362185,int_stack+638713,210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+704569,int_stack+80892,int_stack+419809,210);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+419809,int_stack+155900,int_stack+155360,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+421429,int_stack+419809,int_stack+187420,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+423949,int_stack+421429,int_stack+188680,15);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+160310,int_stack+159554,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+419809,int_stack+0,int_stack+191893,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+427099,int_stack+419809,int_stack+193657,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+431509,int_stack+427099,int_stack+423949,210);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+419809,int_stack+166365,int_stack+165357,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+440959,int_stack+419809,int_stack+198067,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+445663,int_stack+440959,int_stack+211405,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+80892,int_stack+445663,int_stack+427099,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+530689,int_stack+80892,int_stack+431509,210);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+440959,int_stack+174325,int_stack+173029,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+94122,int_stack+440959,int_stack+2268,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+100170,int_stack+94122,int_stack+200419,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+362185,int_stack+100170,int_stack+445663,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+625189,int_stack+362185,int_stack+80892,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+186475,int_stack+625189,int_stack+530689,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+94122,int_stack+117240,int_stack+116925,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+95067,int_stack+117660,int_stack+117240,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+96327,int_stack+95067,int_stack+94122,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+98217,int_stack+118200,int_stack+117660,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+440959,int_stack+98217,int_stack+95067,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+419809,int_stack+440959,int_stack+96327,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+440959,int_stack+119316,int_stack+118875,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+442282,int_stack+119904,int_stack+119316,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+94122,int_stack+442282,int_stack+440959,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+96768,int_stack+120660,int_stack+119904,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+96768,int_stack+442282,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+440959,int_stack+0,int_stack+94122,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+107730,int_stack+440959,int_stack+419809, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+423949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+419809,int_stack+122193,int_stack+121605,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+421573,int_stack+122977,int_stack+122193,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+94122,int_stack+421573,int_stack+419809,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+123985,int_stack+122977,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+117180,int_stack+0,int_stack+421573,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+379825,int_stack+117180,int_stack+94122,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+271318,int_stack+379825,int_stack+440959, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+427099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+748669,int_stack+271318,int_stack+107730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+107730,int_stack+126001,int_stack+125245,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+109998,int_stack+127009,int_stack+126001,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+113022,int_stack+109998,int_stack+107730,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+117558,int_stack+128305,int_stack+127009,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+94122,int_stack+117558,int_stack+109998,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+117558,int_stack+94122,int_stack+113022,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+767569,int_stack+117558,int_stack+379825, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+785209,int_stack+767569,int_stack+271318, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+811669,int_stack+785209,int_stack+748669, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+748669,int_stack+130870,int_stack+129925,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+751504,int_stack+132130,int_stack+130870,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+755284,int_stack+751504,int_stack+748669,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+760954,int_stack+133750,int_stack+132130,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+271318,int_stack+760954,int_stack+751504,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+278878,int_stack+271318,int_stack+755284,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+843169,int_stack+278878,int_stack+117558, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+865849,int_stack+843169,int_stack+767569, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+901129,int_stack+865849,int_stack+785209, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+843169,int_stack+136090,int_stack+135775,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+844114,int_stack+136510,int_stack+136090,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+845374,int_stack+844114,int_stack+843169,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+847264,int_stack+137050,int_stack+136510,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+848884,int_stack+847264,int_stack+844114,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+851404,int_stack+848884,int_stack+845374,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+843169,int_stack+138166,int_stack+137725,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+844492,int_stack+138754,int_stack+138166,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+846256,int_stack+844492,int_stack+843169,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+848902,int_stack+139510,int_stack+138754,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+854554,int_stack+848902,int_stack+844492,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+858082,int_stack+854554,int_stack+846256,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+862492,int_stack+858082,int_stack+851404, 0.0, zero_stack, 1.0, int_stack+423949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+843169,int_stack+141043,int_stack+140455,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+844933,int_stack+141827,int_stack+141043,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+847285,int_stack+844933,int_stack+843169,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+850813,int_stack+142835,int_stack+141827,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+440959,int_stack+850813,int_stack+844933,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+850813,int_stack+440959,int_stack+847285,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+871942,int_stack+850813,int_stack+858082, 0.0, zero_stack, 1.0, int_stack+427099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+271318,int_stack+871942,int_stack+862492, 0.0, zero_stack, 1.0, int_stack+431509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+440959,int_stack+144851,int_stack+144095,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+856693,int_stack+145859,int_stack+144851,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+859717,int_stack+856693,int_stack+440959,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+440959,int_stack+147155,int_stack+145859,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+94122,int_stack+440959,int_stack+856693,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+864253,int_stack+94122,int_stack+859717,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+748669,int_stack+864253,int_stack+850813, 0.0, zero_stack, 1.0, int_stack+445663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+766309,int_stack+748669,int_stack+871942, 0.0, zero_stack, 1.0, int_stack+80892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+107730,int_stack+766309,int_stack+271318, 0.0, zero_stack, 1.0, int_stack+530689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+271318,int_stack+149720,int_stack+148775,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+274153,int_stack+150980,int_stack+149720,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+277933,int_stack+274153,int_stack+271318,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+283603,int_stack+152600,int_stack+150980,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+288463,int_stack+283603,int_stack+274153,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+871813,int_stack+288463,int_stack+277933,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+271318,int_stack+871813,int_stack+864253, 0.0, zero_stack, 1.0, int_stack+100170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+843169,int_stack+271318,int_stack+748669, 0.0, zero_stack, 1.0, int_stack+362185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+945229,int_stack+843169,int_stack+766309, 0.0, zero_stack, 1.0, int_stack+625189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+843169,int_stack+156890,int_stack+156575,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+844114,int_stack+157310,int_stack+156890,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+845374,int_stack+844114,int_stack+843169,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+847264,int_stack+157850,int_stack+157310,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+848884,int_stack+847264,int_stack+844114,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+851404,int_stack+848884,int_stack+845374,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+843169,int_stack+161696,int_stack+161255,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+844492,int_stack+162284,int_stack+161696,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+846256,int_stack+844492,int_stack+843169,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+848902,int_stack+163040,int_stack+162284,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+854554,int_stack+848902,int_stack+844492,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+858082,int_stack+854554,int_stack+846256,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+862492,int_stack+858082,int_stack+851404, 1.0, int_stack+423949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+843169,int_stack+168213,int_stack+167625,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+844933,int_stack+168997,int_stack+168213,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+847285,int_stack+844933,int_stack+843169,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+850813,int_stack+170005,int_stack+168997,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+440959,int_stack+850813,int_stack+844933,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+850813,int_stack+440959,int_stack+847285,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+871942,int_stack+850813,int_stack+858082, 1.0, int_stack+427099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+748669,int_stack+871942,int_stack+862492, 1.0, int_stack+431509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+856693,int_stack+176701,int_stack+175945,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+858961,int_stack+177709,int_stack+176701,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+861985,int_stack+858961,int_stack+856693,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+866521,int_stack+179005,int_stack+177709,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+94122,int_stack+866521,int_stack+858961,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+843169,int_stack+94122,int_stack+861985,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+767569,int_stack+843169,int_stack+850813, 1.0, int_stack+445663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+785209,int_stack+767569,int_stack+871942, 1.0, int_stack+80892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+850729,int_stack+785209,int_stack+748669, 1.0, int_stack+530689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+530689,int_stack+181570,int_stack+180625,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+533524,int_stack+182830,int_stack+181570,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+537304,int_stack+533524,int_stack+530689,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+542974,int_stack+184450,int_stack+182830,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+748669,int_stack+542974,int_stack+533524,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+756229,int_stack+748669,int_stack+537304,45);
 /*--- compute (kp|hf) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+271318,int_stack+756229,int_stack+843169, 1.0, int_stack+100170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (id|hf) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+419809,int_stack+271318,int_stack+767569, 1.0, int_stack+362185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hf|hf) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+139230,int_stack+419809,int_stack+785209, 1.0, int_stack+625189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+748669,int_stack+227218,int_stack+299185,210);
     Libderiv->ABCD[11] = int_stack + 748669;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+217975,int_stack+455089,int_stack+388309,210);
     Libderiv->ABCD[10] = int_stack + 217975;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+362185,int_stack+5292,int_stack+499189,210);
     Libderiv->ABCD[9] = int_stack + 362185;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+409435,int_stack+581089,int_stack+549589,210);
     Libderiv->ABCD[8] = int_stack + 409435;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+456685,int_stack+660469,int_stack+49392,210);
     Libderiv->ABCD[7] = int_stack + 456685;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+503935,int_stack+704569,int_stack+330685,210);
     Libderiv->ABCD[6] = int_stack + 503935;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+551185,int_stack+901129,int_stack+811669, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[2] = int_stack + 551185;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+598435,int_stack+945229,int_stack+107730, 0.0, zero_stack, 1.0, int_stack+186475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[1] = int_stack + 598435;
 /*--- compute (gg|hf) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+645685,int_stack+139230,int_stack+850729, 1.0, int_stack+186475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[0] = int_stack + 645685;

}
