/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gpih(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gp|ih) integrals */

void d1hrr_order_gpih(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[4][8][11] = int_stack + 960;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1635;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2460;
 Libderiv->deriv_classes[4][11][11] = int_stack + 3450;
 Libderiv->deriv_classes[5][6][11] = int_stack + 4620;
 Libderiv->deriv_classes[5][7][11] = int_stack + 5208;
 Libderiv->deriv_classes[5][8][11] = int_stack + 5964;
 Libderiv->deriv_classes[5][9][11] = int_stack + 6909;
 Libderiv->deriv_classes[5][10][11] = int_stack + 8064;
 Libderiv->deriv_classes[5][11][11] = int_stack + 9450;
 Libderiv->deriv_classes[4][6][10] = int_stack + 11088;
 Libderiv->deriv_classes[4][7][10] = int_stack + 11508;
 Libderiv->deriv_classes[4][8][10] = int_stack + 12048;
 Libderiv->deriv_classes[4][9][10] = int_stack + 12723;
 Libderiv->deriv_classes[4][10][10] = int_stack + 13548;
 Libderiv->deriv_classes[4][11][10] = int_stack + 14538;
 Libderiv->deriv_classes[5][6][10] = int_stack + 15708;
 Libderiv->deriv_classes[5][7][10] = int_stack + 16296;
 Libderiv->deriv_classes[5][8][10] = int_stack + 17052;
 Libderiv->deriv_classes[5][9][10] = int_stack + 17997;
 Libderiv->deriv_classes[5][10][10] = int_stack + 19152;
 Libderiv->deriv_classes[5][11][10] = int_stack + 20538;
 Libderiv->deriv_classes[4][6][9] = int_stack + 22176;
 Libderiv->deriv_classes[4][7][9] = int_stack + 22596;
 Libderiv->deriv_classes[4][8][9] = int_stack + 23136;
 Libderiv->deriv_classes[4][9][9] = int_stack + 23811;
 Libderiv->deriv_classes[4][10][9] = int_stack + 24636;
 Libderiv->deriv_classes[4][11][9] = int_stack + 25626;
 Libderiv->deriv_classes[5][6][9] = int_stack + 26796;
 Libderiv->deriv_classes[5][7][9] = int_stack + 27384;
 Libderiv->deriv_classes[5][8][9] = int_stack + 28140;
 Libderiv->deriv_classes[5][9][9] = int_stack + 29085;
 Libderiv->deriv_classes[5][10][9] = int_stack + 30240;
 Libderiv->deriv_classes[5][11][9] = int_stack + 31626;
 Libderiv->deriv_classes[4][6][8] = int_stack + 33264;
 Libderiv->deriv_classes[4][7][8] = int_stack + 33684;
 Libderiv->deriv_classes[4][8][8] = int_stack + 34224;
 Libderiv->deriv_classes[4][9][8] = int_stack + 34899;
 Libderiv->deriv_classes[4][10][8] = int_stack + 35724;
 Libderiv->deriv_classes[4][11][8] = int_stack + 36714;
 Libderiv->deriv_classes[5][6][8] = int_stack + 37884;
 Libderiv->deriv_classes[5][7][8] = int_stack + 38472;
 Libderiv->deriv_classes[5][8][8] = int_stack + 39228;
 Libderiv->deriv_classes[5][9][8] = int_stack + 40173;
 Libderiv->deriv_classes[5][10][8] = int_stack + 41328;
 Libderiv->deriv_classes[5][11][8] = int_stack + 42714;
 Libderiv->deriv_classes[4][6][7] = int_stack + 44352;
 Libderiv->deriv_classes[4][7][7] = int_stack + 44772;
 Libderiv->deriv_classes[4][8][7] = int_stack + 45312;
 Libderiv->deriv_classes[4][9][7] = int_stack + 45987;
 Libderiv->deriv_classes[4][10][7] = int_stack + 46812;
 Libderiv->deriv_classes[4][11][7] = int_stack + 47802;
 Libderiv->deriv_classes[5][6][7] = int_stack + 48972;
 Libderiv->deriv_classes[5][7][7] = int_stack + 49560;
 Libderiv->deriv_classes[5][8][7] = int_stack + 50316;
 Libderiv->deriv_classes[5][9][7] = int_stack + 51261;
 Libderiv->deriv_classes[5][10][7] = int_stack + 52416;
 Libderiv->deriv_classes[5][11][7] = int_stack + 53802;
 Libderiv->deriv_classes[4][6][6] = int_stack + 55440;
 Libderiv->deriv_classes[4][7][6] = int_stack + 55860;
 Libderiv->deriv_classes[4][8][6] = int_stack + 56400;
 Libderiv->deriv_classes[4][9][6] = int_stack + 57075;
 Libderiv->deriv_classes[4][10][6] = int_stack + 57900;
 Libderiv->deriv_classes[4][11][6] = int_stack + 58890;
 Libderiv->dvrr_classes[5][6] = int_stack + 60060;
 Libderiv->deriv_classes[5][6][6] = int_stack + 60648;
 Libderiv->dvrr_classes[5][7] = int_stack + 61236;
 Libderiv->deriv_classes[5][7][6] = int_stack + 61992;
 Libderiv->dvrr_classes[5][8] = int_stack + 62748;
 Libderiv->deriv_classes[5][8][6] = int_stack + 63693;
 Libderiv->dvrr_classes[5][9] = int_stack + 64638;
 Libderiv->deriv_classes[5][9][6] = int_stack + 65793;
 Libderiv->dvrr_classes[5][10] = int_stack + 66948;
 Libderiv->deriv_classes[5][10][6] = int_stack + 68334;
 Libderiv->deriv_classes[5][11][6] = int_stack + 69720;
 Libderiv->deriv_classes[4][6][2] = int_stack + 71358;
 Libderiv->deriv_classes[4][7][2] = int_stack + 71778;
 Libderiv->deriv_classes[4][8][2] = int_stack + 72318;
 Libderiv->deriv_classes[4][9][2] = int_stack + 72993;
 Libderiv->deriv_classes[4][10][2] = int_stack + 73818;
 Libderiv->deriv_classes[4][11][2] = int_stack + 74808;
 Libderiv->deriv_classes[5][6][2] = int_stack + 75978;
 Libderiv->deriv_classes[5][7][2] = int_stack + 76566;
 Libderiv->deriv_classes[5][8][2] = int_stack + 77322;
 Libderiv->deriv_classes[5][9][2] = int_stack + 78267;
 Libderiv->deriv_classes[5][10][2] = int_stack + 79422;
 Libderiv->deriv_classes[5][11][2] = int_stack + 80808;
 Libderiv->deriv_classes[4][6][1] = int_stack + 82446;
 Libderiv->deriv_classes[4][7][1] = int_stack + 82866;
 Libderiv->deriv_classes[4][8][1] = int_stack + 83406;
 Libderiv->deriv_classes[4][9][1] = int_stack + 84081;
 Libderiv->deriv_classes[4][10][1] = int_stack + 84906;
 Libderiv->deriv_classes[4][11][1] = int_stack + 85896;
 Libderiv->deriv_classes[5][6][1] = int_stack + 87066;
 Libderiv->deriv_classes[5][7][1] = int_stack + 87654;
 Libderiv->deriv_classes[5][8][1] = int_stack + 88410;
 Libderiv->deriv_classes[5][9][1] = int_stack + 89355;
 Libderiv->deriv_classes[5][10][1] = int_stack + 90510;
 Libderiv->deriv_classes[5][11][1] = int_stack + 91896;
 Libderiv->dvrr_classes[4][6] = int_stack + 93534;
 Libderiv->dvrr_classes[4][7] = int_stack + 93954;
 Libderiv->dvrr_classes[4][8] = int_stack + 94494;
 Libderiv->dvrr_classes[4][9] = int_stack + 95169;
 Libderiv->dvrr_classes[4][10] = int_stack + 95994;
 Libderiv->dvrr_classes[4][11] = int_stack + 96984;
 Libderiv->deriv_classes[4][6][0] = int_stack + 98154;
 Libderiv->deriv_classes[4][7][0] = int_stack + 98574;
 Libderiv->deriv_classes[4][8][0] = int_stack + 99114;
 Libderiv->deriv_classes[4][9][0] = int_stack + 99789;
 Libderiv->deriv_classes[4][10][0] = int_stack + 100614;
 Libderiv->deriv_classes[4][11][0] = int_stack + 101604;
 Libderiv->deriv_classes[5][6][0] = int_stack + 102774;
 Libderiv->deriv_classes[5][7][0] = int_stack + 103362;
 Libderiv->deriv_classes[5][8][0] = int_stack + 104118;
 Libderiv->deriv_classes[5][9][0] = int_stack + 105063;
 Libderiv->deriv_classes[5][10][0] = int_stack + 106218;
 Libderiv->deriv_classes[5][11][0] = int_stack + 107604;
 memset(int_stack,0,873936);

 Libderiv->dvrr_stack = int_stack + 357174;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gpih(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+109242,int_stack+93954,int_stack+93534,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+110502,int_stack+94494,int_stack+93954,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+112122,int_stack+110502,int_stack+109242,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+114642,int_stack+95169,int_stack+94494,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+116667,int_stack+114642,int_stack+110502,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+119907,int_stack+116667,int_stack+112122,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+124107,int_stack+95994,int_stack+95169,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+126582,int_stack+124107,int_stack+114642,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+130632,int_stack+126582,int_stack+116667,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+136032,int_stack+130632,int_stack+119907,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+142332,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93534,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+143592,int_stack+960,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93954,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+145212,int_stack+143592,int_stack+142332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109242,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+147732,int_stack+1635,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94494,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+149757,int_stack+147732,int_stack+143592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110502,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+152997,int_stack+149757,int_stack+145212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112122,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+142332,int_stack+2460,int_stack+1635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95169,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+157197,int_stack+142332,int_stack+147732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114642,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+161247,int_stack+157197,int_stack+149757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116667,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+144807,int_stack+161247,int_stack+152997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119907,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+151107,int_stack+3450,int_stack+2460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95994,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+166647,int_stack+151107,int_stack+142332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124107,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+171597,int_stack+166647,int_stack+157197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126582,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+151107,int_stack+171597,int_stack+161247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130632,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+159207,int_stack+151107,int_stack+144807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136032,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+142332,int_stack+61236,int_stack+60060,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+144096,int_stack+62748,int_stack+61236,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+146364,int_stack+144096,int_stack+142332,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+149892,int_stack+64638,int_stack+62748,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+152727,int_stack+149892,int_stack+144096,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+168027,int_stack+152727,int_stack+146364,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+173907,int_stack+66948,int_stack+64638,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+177372,int_stack+173907,int_stack+149892,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+183042,int_stack+177372,int_stack+152727,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+190602,int_stack+183042,int_stack+168027,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+157263,int_stack+5208,int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60060,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+5964,int_stack+5208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61236,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2268,int_stack+0,int_stack+157263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142332,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+199422,int_stack+6909,int_stack+5964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62748,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+202257,int_stack+199422,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144096,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+206793,int_stack+202257,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146364,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+8064,int_stack+6909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64638,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+212673,int_stack+0,int_stack+199422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149892,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+218343,int_stack+212673,int_stack+202257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152727,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+225903,int_stack+218343,int_stack+206793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168027,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+199422,int_stack+9450,int_stack+8064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66948,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+203580,int_stack+199422,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173907,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+203580,int_stack+212673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+177372,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+199422,int_stack+0,int_stack+218343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183042,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+210762,int_stack+199422,int_stack+225903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190602,21);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+199422,int_stack+11508,int_stack+11088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93534, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+200682,int_stack+12048,int_stack+11508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93954, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+202302,int_stack+200682,int_stack+199422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109242, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+204822,int_stack+12723,int_stack+12048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94494, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+206847,int_stack+204822,int_stack+200682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110502, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+206847,int_stack+202302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112122, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+199422,int_stack+13548,int_stack+12723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95169, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4200,int_stack+199422,int_stack+204822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114642, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+223110,int_stack+4200,int_stack+206847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116667, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+201897,int_stack+223110,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119907, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+14538,int_stack+13548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95994, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+8250,int_stack+0,int_stack+199422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124107, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+228510,int_stack+8250,int_stack+4200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126582, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+228510,int_stack+223110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130632, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+223110,int_stack+0,int_stack+201897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136032, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+16296,int_stack+15708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60060, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+17052,int_stack+16296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61236, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4032,int_stack+1764,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142332, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7560,int_stack+17997,int_stack+17052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62748, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10395,int_stack+7560,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144096, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+199422,int_stack+10395,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146364, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+19152,int_stack+17997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64638, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+231930,int_stack+0,int_stack+7560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149892, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+237600,int_stack+231930,int_stack+10395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152727, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3465,int_stack+237600,int_stack+199422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168027, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+199422,int_stack+20538,int_stack+19152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66948, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+203580,int_stack+199422,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173907, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+12285,int_stack+203580,int_stack+231930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+177372, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+199422,int_stack+12285,int_stack+237600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183042, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+231930,int_stack+199422,int_stack+3465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190602, 0.0, zero_stack,21);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+199422,int_stack+22596,int_stack+22176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93534, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+200682,int_stack+23136,int_stack+22596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93954, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+202302,int_stack+200682,int_stack+199422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109242, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+204822,int_stack+23811,int_stack+23136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94494, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+206847,int_stack+204822,int_stack+200682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110502, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+206847,int_stack+202302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112122, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+199422,int_stack+24636,int_stack+23811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95169, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4200,int_stack+199422,int_stack+204822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114642, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8250,int_stack+4200,int_stack+206847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116667, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+201897,int_stack+8250,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119907, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+25626,int_stack+24636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95994, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+13650,int_stack+0,int_stack+199422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124107, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+18600,int_stack+13650,int_stack+4200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126582, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+18600,int_stack+8250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130632, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+8100,int_stack+0,int_stack+201897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136032, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+27384,int_stack+26796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60060, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+28140,int_stack+27384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61236, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4032,int_stack+1764,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142332, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+199422,int_stack+29085,int_stack+28140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62748, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+202257,int_stack+199422,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144096, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+16920,int_stack+202257,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146364, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+30240,int_stack+29085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64638, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+22800,int_stack+0,int_stack+199422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149892, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+244278,int_stack+22800,int_stack+202257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152727, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+199422,int_stack+244278,int_stack+16920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168027, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+16920,int_stack+31626,int_stack+30240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66948, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+251838,int_stack+16920,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173907, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+258768,int_stack+251838,int_stack+22800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+177372, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+16920,int_stack+258768,int_stack+244278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183042, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+244278,int_stack+16920,int_stack+199422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190602, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+199422,int_stack+33684,int_stack+33264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+200682,int_stack+34224,int_stack+33684, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+202302,int_stack+200682,int_stack+199422, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+204822,int_stack+34899,int_stack+34224, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+206847,int_stack+204822,int_stack+200682, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+16920,int_stack+206847,int_stack+202302, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+199422,int_stack+35724,int_stack+34899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+21120,int_stack+199422,int_stack+204822, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+25170,int_stack+21120,int_stack+206847, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+201897,int_stack+25170,int_stack+16920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+16920,int_stack+36714,int_stack+35724, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+30570,int_stack+16920,int_stack+199422, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+256626,int_stack+30570,int_stack+21120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+256626,int_stack+25170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+256626,int_stack+0,int_stack+201897, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+38472,int_stack+37884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+39228,int_stack+38472, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4032,int_stack+1764,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+265446,int_stack+40173,int_stack+39228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+199422,int_stack+265446,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+203958,int_stack+199422,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+41328,int_stack+40173, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+16920,int_stack+0,int_stack+265446, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+22590,int_stack+16920,int_stack+199422, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+30150,int_stack+22590,int_stack+203958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+199422,int_stack+42714,int_stack+41328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+203580,int_stack+199422,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+265446,int_stack+203580,int_stack+16920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+177372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+199422,int_stack+265446,int_stack+22590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+16920,int_stack+199422,int_stack+30150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+199422,int_stack+44772,int_stack+44352, 0.0, zero_stack, 1.0, int_stack+93534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+200682,int_stack+45312,int_stack+44772, 0.0, zero_stack, 1.0, int_stack+93954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+202302,int_stack+200682,int_stack+199422, 0.0, zero_stack, 1.0, int_stack+109242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+204822,int_stack+45987,int_stack+45312, 0.0, zero_stack, 1.0, int_stack+94494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+206847,int_stack+204822,int_stack+200682, 0.0, zero_stack, 1.0, int_stack+110502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+265446,int_stack+206847,int_stack+202302, 0.0, zero_stack, 1.0, int_stack+112122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+199422,int_stack+46812,int_stack+45987, 0.0, zero_stack, 1.0, int_stack+95169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+269646,int_stack+199422,int_stack+204822, 0.0, zero_stack, 1.0, int_stack+114642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+29268,int_stack+269646,int_stack+206847, 0.0, zero_stack, 1.0, int_stack+116667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+201897,int_stack+29268,int_stack+265446, 0.0, zero_stack, 1.0, int_stack+119907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+265446,int_stack+47802,int_stack+46812, 0.0, zero_stack, 1.0, int_stack+95994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+34668,int_stack+265446,int_stack+199422, 0.0, zero_stack, 1.0, int_stack+124107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+39618,int_stack+34668,int_stack+269646, 0.0, zero_stack, 1.0, int_stack+126582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+39618,int_stack+29268, 0.0, zero_stack, 1.0, int_stack+130632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+29268,int_stack+0,int_stack+201897, 0.0, zero_stack, 1.0, int_stack+136032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+49560,int_stack+48972, 0.0, zero_stack, 1.0, int_stack+60060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+50316,int_stack+49560, 0.0, zero_stack, 1.0, int_stack+61236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4032,int_stack+1764,int_stack+0, 0.0, zero_stack, 1.0, int_stack+142332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+38088,int_stack+51261,int_stack+50316, 0.0, zero_stack, 1.0, int_stack+62748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+40923,int_stack+38088,int_stack+1764, 0.0, zero_stack, 1.0, int_stack+144096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+199422,int_stack+40923,int_stack+4032, 0.0, zero_stack, 1.0, int_stack+146364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+52416,int_stack+51261, 0.0, zero_stack, 1.0, int_stack+64638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+45459,int_stack+0,int_stack+38088, 0.0, zero_stack, 1.0, int_stack+149892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+265446,int_stack+45459,int_stack+40923, 0.0, zero_stack, 1.0, int_stack+152727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+273006,int_stack+265446,int_stack+199422, 0.0, zero_stack, 1.0, int_stack+168027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+199422,int_stack+53802,int_stack+52416, 0.0, zero_stack, 1.0, int_stack+66948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+203580,int_stack+199422,int_stack+0, 0.0, zero_stack, 1.0, int_stack+173907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+281826,int_stack+203580,int_stack+45459, 0.0, zero_stack, 1.0, int_stack+177372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+199422,int_stack+281826,int_stack+265446, 0.0, zero_stack, 1.0, int_stack+183042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+38088,int_stack+199422,int_stack+273006, 0.0, zero_stack, 1.0, int_stack+190602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+199422,int_stack+55860,int_stack+55440, 1.0, int_stack+93534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+200682,int_stack+56400,int_stack+55860, 1.0, int_stack+93954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+202302,int_stack+200682,int_stack+199422, 1.0, int_stack+109242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+204822,int_stack+57075,int_stack+56400, 1.0, int_stack+94494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+206847,int_stack+204822,int_stack+200682, 1.0, int_stack+110502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+265446,int_stack+206847,int_stack+202302, 1.0, int_stack+112122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+109242,int_stack+57900,int_stack+57075, 1.0, int_stack+95169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+199422,int_stack+109242,int_stack+204822, 1.0, int_stack+114642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+269646,int_stack+199422,int_stack+206847, 1.0, int_stack+116667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+111717,int_stack+269646,int_stack+265446, 1.0, int_stack+119907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+265446,int_stack+58890,int_stack+57900, 1.0, int_stack+95994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+118017,int_stack+265446,int_stack+109242, 1.0, int_stack+124107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+203472,int_stack+118017,int_stack+199422, 1.0, int_stack+126582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+203472,int_stack+269646, 1.0, int_stack+130632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+199422,int_stack+0,int_stack+111717, 1.0, int_stack+136032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+61992,int_stack+60648, 1.0, int_stack+60060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+63693,int_stack+61992, 1.0, int_stack+61236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4032,int_stack+1764,int_stack+0, 1.0, int_stack+142332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+109242,int_stack+65793,int_stack+63693, 1.0, int_stack+62748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+112077,int_stack+109242,int_stack+1764, 1.0, int_stack+144096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+116613,int_stack+112077,int_stack+4032, 1.0, int_stack+146364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+142332,int_stack+68334,int_stack+65793, 1.0, int_stack+64638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+142332,int_stack+109242, 1.0, int_stack+149892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+265446,int_stack+0,int_stack+112077, 1.0, int_stack+152727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+145797,int_stack+265446,int_stack+116613, 1.0, int_stack+168027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+168027,int_stack+69720,int_stack+68334, 1.0, int_stack+66948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+109242,int_stack+168027,int_stack+142332, 1.0, int_stack+173907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+273006,int_stack+109242,int_stack+0, 1.0, int_stack+177372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+109242,int_stack+273006,int_stack+265446, 1.0, int_stack+183042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+265446,int_stack+109242,int_stack+145797, 1.0, int_stack+190602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+109242,int_stack+96984,int_stack+95994,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+112212,int_stack+109242,int_stack+124107,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+117162,int_stack+112212,int_stack+126582,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+117162,int_stack+130632,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+109242,int_stack+0,int_stack+136032,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+71778,int_stack+71358,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+72318,int_stack+71778,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+208242,int_stack+1260,int_stack+0,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2880,int_stack+72993,int_stack+72318,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+118062,int_stack+2880,int_stack+1260,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+121302,int_stack+118062,int_stack+208242,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+208242,int_stack+73818,int_stack+72993,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+125502,int_stack+208242,int_stack+2880,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+125502,int_stack+118062,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+129552,int_stack+0,int_stack+121302,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+118062,int_stack+74808,int_stack+73818,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+135852,int_stack+118062,int_stack+208242,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+118062,int_stack+135852,int_stack+125502,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+135852,int_stack+118062,int_stack+0,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+118062,int_stack+135852,int_stack+129552,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+76566,int_stack+75978,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+77322,int_stack+76566,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4032,int_stack+1764,int_stack+0,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+126882,int_stack+78267,int_stack+77322,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+129717,int_stack+126882,int_stack+1764,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+134253,int_stack+129717,int_stack+4032,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+79422,int_stack+78267,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+140133,int_stack+0,int_stack+126882,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+145803,int_stack+140133,int_stack+129717,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+277794,int_stack+145803,int_stack+134253,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+126882,int_stack+80808,int_stack+79422,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+131040,int_stack+126882,int_stack+0,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+168027,int_stack+131040,int_stack+140133,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+126882,int_stack+168027,int_stack+145803,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+168027,int_stack+126882,int_stack+277794,21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+277794,int_stack+82866,int_stack+82446,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+279054,int_stack+83406,int_stack+82866,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+208242,int_stack+279054,int_stack+277794,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+280674,int_stack+84081,int_stack+83406,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+282699,int_stack+280674,int_stack+279054,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+285939,int_stack+282699,int_stack+208242,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+208242,int_stack+84906,int_stack+84081,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+126882,int_stack+208242,int_stack+280674,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+130932,int_stack+126882,int_stack+282699,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+277794,int_stack+130932,int_stack+285939,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+284094,int_stack+85896,int_stack+84906,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+136332,int_stack+284094,int_stack+208242,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+284094,int_stack+136332,int_stack+126882,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+284094,int_stack+130932,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+126882,int_stack+0,int_stack+277794,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+277794,int_stack+87654,int_stack+87066,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+279558,int_stack+88410,int_stack+87654,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+281826,int_stack+279558,int_stack+277794,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+285354,int_stack+89355,int_stack+88410,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+285354,int_stack+279558,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+135702,int_stack+0,int_stack+281826,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+277794,int_stack+90510,int_stack+89355,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+141582,int_stack+277794,int_stack+285354,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+281259,int_stack+141582,int_stack+0,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+147252,int_stack+281259,int_stack+135702,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+135702,int_stack+91896,int_stack+90510,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+0,int_stack+135702,int_stack+277794,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+180375,int_stack+0,int_stack+141582,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+135702,int_stack+180375,int_stack+281259,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+180375,int_stack+135702,int_stack+147252,21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+135702,int_stack+98574,int_stack+98154,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+136962,int_stack+99114,int_stack+98574,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+208242,int_stack+136962,int_stack+135702,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+138582,int_stack+99789,int_stack+99114,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+140607,int_stack+138582,int_stack+136962,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+143847,int_stack+140607,int_stack+208242,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+208242,int_stack+100614,int_stack+99789,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+148047,int_stack+208242,int_stack+138582,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+152097,int_stack+148047,int_stack+140607,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+135702,int_stack+152097,int_stack+143847,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+142002,int_stack+101604,int_stack+100614,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+192723,int_stack+142002,int_stack+208242,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+192723,int_stack+148047,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+142002,int_stack+0,int_stack+152097,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+150102,int_stack+142002,int_stack+135702,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+135702,int_stack+103362,int_stack+102774,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+137466,int_stack+104118,int_stack+103362,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+139734,int_stack+137466,int_stack+135702,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+143262,int_stack+105063,int_stack+104118,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+143262,int_stack+137466,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+192723,int_stack+0,int_stack+139734,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+135702,int_stack+106218,int_stack+105063,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+277794,int_stack+135702,int_stack+143262,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+139167,int_stack+277794,int_stack+0,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+50436,int_stack+139167,int_stack+192723,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+192723,int_stack+107604,int_stack+106218,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+0,int_stack+192723,int_stack+135702,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+59256,int_stack+0,int_stack+277794,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+277794,int_stack+59256,int_stack+139167,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+59256,int_stack+277794,int_stack+50436,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+71604,int_stack+210762,int_stack+159207,588);
     Libderiv->ABCD[11] = int_stack + 71604;
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+277794,int_stack+231930,int_stack+223110,588);
     Libderiv->ABCD[10] = int_stack + 277794;
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+208242,int_stack+244278,int_stack+8100,588);
     Libderiv->ABCD[9] = int_stack + 208242;
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+304254,int_stack+16920,int_stack+256626,588);
     Libderiv->ABCD[8] = int_stack + 304254;
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+0,int_stack+38088,int_stack+29268,588);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+26460,int_stack+265446,int_stack+199422,588);
     Libderiv->ABCD[6] = int_stack + 26460;
 /*--- compute (gp|ih) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+234702,int_stack+168027,int_stack+118062, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[2] = int_stack + 234702;
 /*--- compute (gp|ih) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+330714,int_stack+180375,int_stack+126882, 0.0, zero_stack, 1.0, int_stack+109242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[1] = int_stack + 330714;
 /*--- compute (gp|ih) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+118062,int_stack+59256,int_stack+150102, 1.0, int_stack+109242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[0] = int_stack + 118062;

}
