/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gpii(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gp|ii) integrals */

void d1hrr_order_gpii(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[4][8][11] = int_stack + 960;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1635;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2460;
 Libderiv->deriv_classes[4][11][11] = int_stack + 3450;
 Libderiv->deriv_classes[4][12][11] = int_stack + 4620;
 Libderiv->deriv_classes[5][6][11] = int_stack + 5985;
 Libderiv->deriv_classes[5][7][11] = int_stack + 6573;
 Libderiv->deriv_classes[5][8][11] = int_stack + 7329;
 Libderiv->deriv_classes[5][9][11] = int_stack + 8274;
 Libderiv->deriv_classes[5][10][11] = int_stack + 9429;
 Libderiv->deriv_classes[5][11][11] = int_stack + 10815;
 Libderiv->deriv_classes[5][12][11] = int_stack + 12453;
 Libderiv->deriv_classes[4][6][10] = int_stack + 14364;
 Libderiv->deriv_classes[4][7][10] = int_stack + 14784;
 Libderiv->deriv_classes[4][8][10] = int_stack + 15324;
 Libderiv->deriv_classes[4][9][10] = int_stack + 15999;
 Libderiv->deriv_classes[4][10][10] = int_stack + 16824;
 Libderiv->deriv_classes[4][11][10] = int_stack + 17814;
 Libderiv->deriv_classes[4][12][10] = int_stack + 18984;
 Libderiv->deriv_classes[5][6][10] = int_stack + 20349;
 Libderiv->deriv_classes[5][7][10] = int_stack + 20937;
 Libderiv->deriv_classes[5][8][10] = int_stack + 21693;
 Libderiv->deriv_classes[5][9][10] = int_stack + 22638;
 Libderiv->deriv_classes[5][10][10] = int_stack + 23793;
 Libderiv->deriv_classes[5][11][10] = int_stack + 25179;
 Libderiv->deriv_classes[5][12][10] = int_stack + 26817;
 Libderiv->deriv_classes[4][6][9] = int_stack + 28728;
 Libderiv->deriv_classes[4][7][9] = int_stack + 29148;
 Libderiv->deriv_classes[4][8][9] = int_stack + 29688;
 Libderiv->deriv_classes[4][9][9] = int_stack + 30363;
 Libderiv->deriv_classes[4][10][9] = int_stack + 31188;
 Libderiv->deriv_classes[4][11][9] = int_stack + 32178;
 Libderiv->deriv_classes[4][12][9] = int_stack + 33348;
 Libderiv->deriv_classes[5][6][9] = int_stack + 34713;
 Libderiv->deriv_classes[5][7][9] = int_stack + 35301;
 Libderiv->deriv_classes[5][8][9] = int_stack + 36057;
 Libderiv->deriv_classes[5][9][9] = int_stack + 37002;
 Libderiv->deriv_classes[5][10][9] = int_stack + 38157;
 Libderiv->deriv_classes[5][11][9] = int_stack + 39543;
 Libderiv->deriv_classes[5][12][9] = int_stack + 41181;
 Libderiv->deriv_classes[4][6][8] = int_stack + 43092;
 Libderiv->deriv_classes[4][7][8] = int_stack + 43512;
 Libderiv->deriv_classes[4][8][8] = int_stack + 44052;
 Libderiv->deriv_classes[4][9][8] = int_stack + 44727;
 Libderiv->deriv_classes[4][10][8] = int_stack + 45552;
 Libderiv->deriv_classes[4][11][8] = int_stack + 46542;
 Libderiv->deriv_classes[4][12][8] = int_stack + 47712;
 Libderiv->deriv_classes[5][6][8] = int_stack + 49077;
 Libderiv->deriv_classes[5][7][8] = int_stack + 49665;
 Libderiv->deriv_classes[5][8][8] = int_stack + 50421;
 Libderiv->deriv_classes[5][9][8] = int_stack + 51366;
 Libderiv->deriv_classes[5][10][8] = int_stack + 52521;
 Libderiv->deriv_classes[5][11][8] = int_stack + 53907;
 Libderiv->deriv_classes[5][12][8] = int_stack + 55545;
 Libderiv->deriv_classes[4][6][7] = int_stack + 57456;
 Libderiv->deriv_classes[4][7][7] = int_stack + 57876;
 Libderiv->deriv_classes[4][8][7] = int_stack + 58416;
 Libderiv->deriv_classes[4][9][7] = int_stack + 59091;
 Libderiv->deriv_classes[4][10][7] = int_stack + 59916;
 Libderiv->deriv_classes[4][11][7] = int_stack + 60906;
 Libderiv->deriv_classes[4][12][7] = int_stack + 62076;
 Libderiv->deriv_classes[5][6][7] = int_stack + 63441;
 Libderiv->deriv_classes[5][7][7] = int_stack + 64029;
 Libderiv->deriv_classes[5][8][7] = int_stack + 64785;
 Libderiv->deriv_classes[5][9][7] = int_stack + 65730;
 Libderiv->deriv_classes[5][10][7] = int_stack + 66885;
 Libderiv->deriv_classes[5][11][7] = int_stack + 68271;
 Libderiv->deriv_classes[5][12][7] = int_stack + 69909;
 Libderiv->deriv_classes[4][6][6] = int_stack + 71820;
 Libderiv->deriv_classes[4][7][6] = int_stack + 72240;
 Libderiv->deriv_classes[4][8][6] = int_stack + 72780;
 Libderiv->deriv_classes[4][9][6] = int_stack + 73455;
 Libderiv->deriv_classes[4][10][6] = int_stack + 74280;
 Libderiv->deriv_classes[4][11][6] = int_stack + 75270;
 Libderiv->deriv_classes[4][12][6] = int_stack + 76440;
 Libderiv->dvrr_classes[5][6] = int_stack + 77805;
 Libderiv->deriv_classes[5][6][6] = int_stack + 78393;
 Libderiv->dvrr_classes[5][7] = int_stack + 78981;
 Libderiv->deriv_classes[5][7][6] = int_stack + 79737;
 Libderiv->dvrr_classes[5][8] = int_stack + 80493;
 Libderiv->deriv_classes[5][8][6] = int_stack + 81438;
 Libderiv->dvrr_classes[5][9] = int_stack + 82383;
 Libderiv->deriv_classes[5][9][6] = int_stack + 83538;
 Libderiv->dvrr_classes[5][10] = int_stack + 84693;
 Libderiv->deriv_classes[5][10][6] = int_stack + 86079;
 Libderiv->dvrr_classes[5][11] = int_stack + 87465;
 Libderiv->deriv_classes[5][11][6] = int_stack + 89103;
 Libderiv->deriv_classes[5][12][6] = int_stack + 90741;
 Libderiv->deriv_classes[4][6][2] = int_stack + 92652;
 Libderiv->deriv_classes[4][7][2] = int_stack + 93072;
 Libderiv->deriv_classes[4][8][2] = int_stack + 93612;
 Libderiv->deriv_classes[4][9][2] = int_stack + 94287;
 Libderiv->deriv_classes[4][10][2] = int_stack + 95112;
 Libderiv->deriv_classes[4][11][2] = int_stack + 96102;
 Libderiv->deriv_classes[4][12][2] = int_stack + 97272;
 Libderiv->deriv_classes[5][6][2] = int_stack + 98637;
 Libderiv->deriv_classes[5][7][2] = int_stack + 99225;
 Libderiv->deriv_classes[5][8][2] = int_stack + 99981;
 Libderiv->deriv_classes[5][9][2] = int_stack + 100926;
 Libderiv->deriv_classes[5][10][2] = int_stack + 102081;
 Libderiv->deriv_classes[5][11][2] = int_stack + 103467;
 Libderiv->deriv_classes[5][12][2] = int_stack + 105105;
 Libderiv->deriv_classes[4][6][1] = int_stack + 107016;
 Libderiv->deriv_classes[4][7][1] = int_stack + 107436;
 Libderiv->deriv_classes[4][8][1] = int_stack + 107976;
 Libderiv->deriv_classes[4][9][1] = int_stack + 108651;
 Libderiv->deriv_classes[4][10][1] = int_stack + 109476;
 Libderiv->deriv_classes[4][11][1] = int_stack + 110466;
 Libderiv->deriv_classes[4][12][1] = int_stack + 111636;
 Libderiv->deriv_classes[5][6][1] = int_stack + 113001;
 Libderiv->deriv_classes[5][7][1] = int_stack + 113589;
 Libderiv->deriv_classes[5][8][1] = int_stack + 114345;
 Libderiv->deriv_classes[5][9][1] = int_stack + 115290;
 Libderiv->deriv_classes[5][10][1] = int_stack + 116445;
 Libderiv->deriv_classes[5][11][1] = int_stack + 117831;
 Libderiv->deriv_classes[5][12][1] = int_stack + 119469;
 Libderiv->dvrr_classes[4][6] = int_stack + 121380;
 Libderiv->dvrr_classes[4][7] = int_stack + 121800;
 Libderiv->dvrr_classes[4][8] = int_stack + 122340;
 Libderiv->dvrr_classes[4][9] = int_stack + 123015;
 Libderiv->dvrr_classes[4][10] = int_stack + 123840;
 Libderiv->dvrr_classes[4][11] = int_stack + 124830;
 Libderiv->dvrr_classes[4][12] = int_stack + 126000;
 Libderiv->deriv_classes[4][6][0] = int_stack + 127365;
 Libderiv->deriv_classes[4][7][0] = int_stack + 127785;
 Libderiv->deriv_classes[4][8][0] = int_stack + 128325;
 Libderiv->deriv_classes[4][9][0] = int_stack + 129000;
 Libderiv->deriv_classes[4][10][0] = int_stack + 129825;
 Libderiv->deriv_classes[4][11][0] = int_stack + 130815;
 Libderiv->deriv_classes[4][12][0] = int_stack + 131985;
 Libderiv->deriv_classes[5][6][0] = int_stack + 133350;
 Libderiv->deriv_classes[5][7][0] = int_stack + 133938;
 Libderiv->deriv_classes[5][8][0] = int_stack + 134694;
 Libderiv->deriv_classes[5][9][0] = int_stack + 135639;
 Libderiv->deriv_classes[5][10][0] = int_stack + 136794;
 Libderiv->deriv_classes[5][11][0] = int_stack + 138180;
 Libderiv->deriv_classes[5][12][0] = int_stack + 139818;
 memset(int_stack,0,1133832);

 Libderiv->dvrr_stack = int_stack + 489033;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gpii(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+141729,int_stack+121800,int_stack+121380,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+142989,int_stack+122340,int_stack+121800,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+144609,int_stack+142989,int_stack+141729,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+147129,int_stack+123015,int_stack+122340,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+149154,int_stack+147129,int_stack+142989,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+152394,int_stack+149154,int_stack+144609,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+156594,int_stack+123840,int_stack+123015,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+159069,int_stack+156594,int_stack+147129,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+163119,int_stack+159069,int_stack+149154,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+168519,int_stack+163119,int_stack+152394,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+174819,int_stack+124830,int_stack+123840,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+177789,int_stack+174819,int_stack+156594,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+182739,int_stack+177789,int_stack+159069,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+189489,int_stack+182739,int_stack+163119,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+197589,int_stack+189489,int_stack+168519,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+206409,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121380,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+207669,int_stack+960,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121800,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+209289,int_stack+207669,int_stack+206409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141729,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+211809,int_stack+1635,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122340,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+213834,int_stack+211809,int_stack+207669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142989,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+217074,int_stack+213834,int_stack+209289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144609,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+206409,int_stack+2460,int_stack+1635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123015,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+221274,int_stack+206409,int_stack+211809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147129,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+225324,int_stack+221274,int_stack+213834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149154,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+208884,int_stack+225324,int_stack+217074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152394,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+215184,int_stack+3450,int_stack+2460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123840,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+230724,int_stack+215184,int_stack+206409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156594,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+235674,int_stack+230724,int_stack+221274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159069,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+242424,int_stack+235674,int_stack+225324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163119,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+218154,int_stack+242424,int_stack+208884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168519,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+206409,int_stack+4620,int_stack+3450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124830,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+206409,int_stack+215184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174819,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+206409,int_stack+0,int_stack+230724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+177789,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+250524,int_stack+206409,int_stack+235674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182739,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+206409,int_stack+250524,int_stack+242424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189489,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+226974,int_stack+206409,int_stack+218154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197589,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+206409,int_stack+78981,int_stack+77805,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+208173,int_stack+80493,int_stack+78981,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+210441,int_stack+208173,int_stack+206409,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+213969,int_stack+82383,int_stack+80493,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+216804,int_stack+213969,int_stack+208173,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+216804,int_stack+210441,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+221340,int_stack+84693,int_stack+82383,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+238734,int_stack+221340,int_stack+213969,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+244404,int_stack+238734,int_stack+216804,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+251964,int_stack+244404,int_stack+0,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+260784,int_stack+87465,int_stack+84693,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+264942,int_stack+260784,int_stack+221340,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+271872,int_stack+264942,int_stack+238734,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+281322,int_stack+271872,int_stack+244404,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+292662,int_stack+281322,int_stack+251964,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+224805,int_stack+6573,int_stack+5985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77805,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+305010,int_stack+7329,int_stack+6573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78981,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+307278,int_stack+305010,int_stack+224805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206409,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+310806,int_stack+8274,int_stack+7329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80493,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+313641,int_stack+310806,int_stack+305010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208173,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+318177,int_stack+313641,int_stack+307278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210441,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+305010,int_stack+9429,int_stack+8274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82383,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+324057,int_stack+305010,int_stack+310806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213969,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+329727,int_stack+324057,int_stack+313641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216804,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+308475,int_stack+329727,int_stack+318177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+317295,int_stack+10815,int_stack+9429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84693,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+337287,int_stack+317295,int_stack+305010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221340,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+344217,int_stack+337287,int_stack+324057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238734,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+353667,int_stack+344217,int_stack+329727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244404,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+321453,int_stack+353667,int_stack+308475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251964,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+305010,int_stack+12453,int_stack+10815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87465,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+5880,int_stack+305010,int_stack+317295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260784,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+305010,int_stack+5880,int_stack+337287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264942,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+365007,int_stack+305010,int_stack+344217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271872,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+305010,int_stack+365007,int_stack+353667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281322,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+333801,int_stack+305010,int_stack+321453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292662,21);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+305010,int_stack+14784,int_stack+14364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121380, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+306270,int_stack+15324,int_stack+14784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121800, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+307890,int_stack+306270,int_stack+305010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141729, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+310410,int_stack+15999,int_stack+15324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122340, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+312435,int_stack+310410,int_stack+306270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142989, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+315675,int_stack+312435,int_stack+307890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144609, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+305010,int_stack+16824,int_stack+15999, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123015, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+319875,int_stack+305010,int_stack+310410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147129, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+323925,int_stack+319875,int_stack+312435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149154, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+307485,int_stack+323925,int_stack+315675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152394, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+313785,int_stack+17814,int_stack+16824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123840, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+5880,int_stack+313785,int_stack+305010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156594, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+10830,int_stack+5880,int_stack+319875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159069, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+350265,int_stack+10830,int_stack+323925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163119, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+316755,int_stack+350265,int_stack+307485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168519, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+305010,int_stack+18984,int_stack+17814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124830, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+325575,int_stack+305010,int_stack+313785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174819, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+305010,int_stack+325575,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+177789, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+358365,int_stack+305010,int_stack+10830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182739, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+305010,int_stack+358365,int_stack+350265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189489, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+350265,int_stack+305010,int_stack+316755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197589, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+305010,int_stack+20937,int_stack+20349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77805, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+306774,int_stack+21693,int_stack+20937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78981, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+309042,int_stack+306774,int_stack+305010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206409, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+312570,int_stack+22638,int_stack+21693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80493, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+315405,int_stack+312570,int_stack+306774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208173, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+319941,int_stack+315405,int_stack+309042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210441, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+305010,int_stack+23793,int_stack+22638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82383, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+325821,int_stack+305010,int_stack+312570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213969, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+362025,int_stack+325821,int_stack+315405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216804, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+308475,int_stack+362025,int_stack+319941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+317295,int_stack+25179,int_stack+23793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84693, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+369585,int_stack+317295,int_stack+305010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221340, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+5880,int_stack+369585,int_stack+325821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238734, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+321453,int_stack+5880,int_stack+362025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244404, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+376515,int_stack+321453,int_stack+308475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251964, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+362025,int_stack+26817,int_stack+25179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87465, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+305010,int_stack+362025,int_stack+317295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260784, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+15330,int_stack+305010,int_stack+369585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264942, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+305010,int_stack+15330,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271872, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+5880,int_stack+305010,int_stack+321453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281322, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+305010,int_stack+5880,int_stack+376515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292662, 0.0, zero_stack,21);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+29148,int_stack+28728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121380, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7140,int_stack+29688,int_stack+29148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121800, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8760,int_stack+7140,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141729, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11280,int_stack+30363,int_stack+29688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122340, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13305,int_stack+11280,int_stack+7140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142989, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+16545,int_stack+13305,int_stack+8760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144609, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5880,int_stack+31188,int_stack+30363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123015, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+20745,int_stack+5880,int_stack+11280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147129, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+24795,int_stack+20745,int_stack+13305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149154, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8355,int_stack+24795,int_stack+16545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152394, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+14655,int_stack+32178,int_stack+31188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123840, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+321474,int_stack+14655,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156594, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+326424,int_stack+321474,int_stack+20745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159069, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+362025,int_stack+326424,int_stack+24795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163119, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+17625,int_stack+362025,int_stack+8355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168519, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+5880,int_stack+33348,int_stack+32178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124830, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+26445,int_stack+5880,int_stack+14655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174819, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+5880,int_stack+26445,int_stack+321474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+177789, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+370125,int_stack+5880,int_stack+326424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182739, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+5880,int_stack+370125,int_stack+362025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189489, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+362025,int_stack+5880,int_stack+17625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197589, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+35301,int_stack+34713, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77805, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7644,int_stack+36057,int_stack+35301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78981, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9912,int_stack+7644,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206409, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13440,int_stack+37002,int_stack+36057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80493, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+16275,int_stack+13440,int_stack+7644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208173, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+20811,int_stack+16275,int_stack+9912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210441, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5880,int_stack+38157,int_stack+37002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82383, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+26691,int_stack+5880,int_stack+13440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213969, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+373785,int_stack+26691,int_stack+16275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216804, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+9345,int_stack+373785,int_stack+20811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+18165,int_stack+39543,int_stack+38157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84693, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+32361,int_stack+18165,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221340, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+321474,int_stack+32361,int_stack+26691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238734, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+381345,int_stack+321474,int_stack+373785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244404, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+392685,int_stack+381345,int_stack+9345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251964, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+373785,int_stack+41181,int_stack+39543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87465, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+5880,int_stack+373785,int_stack+18165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260784, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+14196,int_stack+5880,int_stack+32361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264942, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+25746,int_stack+14196,int_stack+321474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271872, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+5880,int_stack+25746,int_stack+381345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281322, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+21756,int_stack+5880,int_stack+392685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292662, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+43512,int_stack+43092, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7140,int_stack+44052,int_stack+43512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8760,int_stack+7140,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11280,int_stack+44727,int_stack+44052, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13305,int_stack+11280,int_stack+7140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+16545,int_stack+13305,int_stack+8760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144609, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5880,int_stack+45552,int_stack+44727, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+321474,int_stack+5880,int_stack+11280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+325524,int_stack+321474,int_stack+13305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8355,int_stack+325524,int_stack+16545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+14655,int_stack+46542,int_stack+45552, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+38220,int_stack+14655,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+373785,int_stack+38220,int_stack+321474, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+380535,int_stack+373785,int_stack+325524, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+321474,int_stack+380535,int_stack+8355, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+5880,int_stack+47712,int_stack+46542, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+388635,int_stack+5880,int_stack+14655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+174819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+5880,int_stack+388635,int_stack+38220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+177789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+38220,int_stack+5880,int_stack+373785, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+5880,int_stack+38220,int_stack+380535, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+373785,int_stack+5880,int_stack+321474, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+321474,int_stack+49665,int_stack+49077, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+323238,int_stack+50421,int_stack+49665, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+325506,int_stack+323238,int_stack+321474, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+329034,int_stack+51366,int_stack+50421, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80493, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5880,int_stack+329034,int_stack+323238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10416,int_stack+5880,int_stack+325506, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+321474,int_stack+52521,int_stack+51366, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+38220,int_stack+321474,int_stack+329034, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+324939,int_stack+38220,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+385545,int_stack+324939,int_stack+10416, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+5880,int_stack+53907,int_stack+52521, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+10038,int_stack+5880,int_stack+321474, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+43890,int_stack+10038,int_stack+38220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+394365,int_stack+43890,int_stack+324939, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+405705,int_stack+394365,int_stack+385545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+385545,int_stack+55545,int_stack+53907, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+321474,int_stack+385545,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+418053,int_stack+321474,int_stack+10038, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+5880,int_stack+418053,int_stack+43890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+38220,int_stack+5880,int_stack+394365, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+385545,int_stack+38220,int_stack+405705, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38220,int_stack+57876,int_stack+57456, 0.0, zero_stack, 1.0, int_stack+121380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+39480,int_stack+58416,int_stack+57876, 0.0, zero_stack, 1.0, int_stack+121800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+41100,int_stack+39480,int_stack+38220, 0.0, zero_stack, 1.0, int_stack+141729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+43620,int_stack+59091,int_stack+58416, 0.0, zero_stack, 1.0, int_stack+122340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+45645,int_stack+43620,int_stack+39480, 0.0, zero_stack, 1.0, int_stack+142989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+48885,int_stack+45645,int_stack+41100, 0.0, zero_stack, 1.0, int_stack+144609, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+38220,int_stack+59916,int_stack+59091, 0.0, zero_stack, 1.0, int_stack+123015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+53085,int_stack+38220,int_stack+43620, 0.0, zero_stack, 1.0, int_stack+147129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5880,int_stack+53085,int_stack+45645, 0.0, zero_stack, 1.0, int_stack+149154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+40695,int_stack+5880,int_stack+48885, 0.0, zero_stack, 1.0, int_stack+152394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+46995,int_stack+60906,int_stack+59916, 0.0, zero_stack, 1.0, int_stack+123840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+11280,int_stack+46995,int_stack+38220, 0.0, zero_stack, 1.0, int_stack+156594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+321474,int_stack+11280,int_stack+53085, 0.0, zero_stack, 1.0, int_stack+159069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+49965,int_stack+321474,int_stack+5880, 0.0, zero_stack, 1.0, int_stack+163119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+402009,int_stack+49965,int_stack+40695, 0.0, zero_stack, 1.0, int_stack+168519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+5880,int_stack+62076,int_stack+60906, 0.0, zero_stack, 1.0, int_stack+124830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+38220,int_stack+5880,int_stack+46995, 0.0, zero_stack, 1.0, int_stack+174819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+410829,int_stack+38220,int_stack+11280, 0.0, zero_stack, 1.0, int_stack+177789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+38220,int_stack+410829,int_stack+321474, 0.0, zero_stack, 1.0, int_stack+182739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+321474,int_stack+38220,int_stack+49965, 0.0, zero_stack, 1.0, int_stack+189489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+38220,int_stack+321474,int_stack+402009, 0.0, zero_stack, 1.0, int_stack+197589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+402009,int_stack+64029,int_stack+63441, 0.0, zero_stack, 1.0, int_stack+77805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+403773,int_stack+64785,int_stack+64029, 0.0, zero_stack, 1.0, int_stack+78981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+406041,int_stack+403773,int_stack+402009, 0.0, zero_stack, 1.0, int_stack+206409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+409569,int_stack+65730,int_stack+64785, 0.0, zero_stack, 1.0, int_stack+80493, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+412404,int_stack+409569,int_stack+403773, 0.0, zero_stack, 1.0, int_stack+208173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+416940,int_stack+412404,int_stack+406041, 0.0, zero_stack, 1.0, int_stack+210441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+402009,int_stack+66885,int_stack+65730, 0.0, zero_stack, 1.0, int_stack+82383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+422820,int_stack+402009,int_stack+409569, 0.0, zero_stack, 1.0, int_stack+213969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+321474,int_stack+422820,int_stack+412404, 0.0, zero_stack, 1.0, int_stack+216804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+405474,int_stack+321474,int_stack+416940, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+414294,int_stack+68271,int_stack+66885, 0.0, zero_stack, 1.0, int_stack+84693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+49980,int_stack+414294,int_stack+402009, 0.0, zero_stack, 1.0, int_stack+221340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+56910,int_stack+49980,int_stack+422820, 0.0, zero_stack, 1.0, int_stack+238734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+418452,int_stack+56910,int_stack+321474, 0.0, zero_stack, 1.0, int_stack+244404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+5880,int_stack+418452,int_stack+405474, 0.0, zero_stack, 1.0, int_stack+251964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+321474,int_stack+69909,int_stack+68271, 0.0, zero_stack, 1.0, int_stack+87465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+402009,int_stack+321474,int_stack+414294, 0.0, zero_stack, 1.0, int_stack+260784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+321474,int_stack+402009,int_stack+49980, 0.0, zero_stack, 1.0, int_stack+264942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+402009,int_stack+321474,int_stack+56910, 0.0, zero_stack, 1.0, int_stack+271872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+49980,int_stack+402009,int_stack+418452, 0.0, zero_stack, 1.0, int_stack+281322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+402009,int_stack+49980,int_stack+5880, 0.0, zero_stack, 1.0, int_stack+292662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+72240,int_stack+71820, 1.0, int_stack+121380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7140,int_stack+72780,int_stack+72240, 1.0, int_stack+121800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8760,int_stack+7140,int_stack+5880, 1.0, int_stack+141729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11280,int_stack+73455,int_stack+72780, 1.0, int_stack+122340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13305,int_stack+11280,int_stack+7140, 1.0, int_stack+142989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+16545,int_stack+13305,int_stack+8760, 1.0, int_stack+144609, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+141729,int_stack+74280,int_stack+73455, 1.0, int_stack+123015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5880,int_stack+141729,int_stack+11280, 1.0, int_stack+147129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+49980,int_stack+5880,int_stack+13305, 1.0, int_stack+149154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+144204,int_stack+49980,int_stack+16545, 1.0, int_stack+152394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+150504,int_stack+75270,int_stack+74280, 1.0, int_stack+123840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+9930,int_stack+150504,int_stack+141729, 1.0, int_stack+156594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+14880,int_stack+9930,int_stack+5880, 1.0, int_stack+159069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+153474,int_stack+14880,int_stack+49980, 1.0, int_stack+163119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+49980,int_stack+153474,int_stack+144204, 1.0, int_stack+168519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+58800,int_stack+76440,int_stack+75270, 1.0, int_stack+124830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+62310,int_stack+58800,int_stack+150504, 1.0, int_stack+174819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+68250,int_stack+62310,int_stack+9930, 1.0, int_stack+177789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+141729,int_stack+68250,int_stack+14880, 1.0, int_stack+182739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+58800,int_stack+141729,int_stack+153474, 1.0, int_stack+189489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+141729,int_stack+58800,int_stack+49980, 1.0, int_stack+197589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49980,int_stack+79737,int_stack+78393, 1.0, int_stack+77805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+51744,int_stack+81438,int_stack+79737, 1.0, int_stack+78981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+54012,int_stack+51744,int_stack+49980, 1.0, int_stack+206409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+57540,int_stack+83538,int_stack+81438, 1.0, int_stack+80493, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+60375,int_stack+57540,int_stack+51744, 1.0, int_stack+208173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+64911,int_stack+60375,int_stack+54012, 1.0, int_stack+210441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+206409,int_stack+86079,int_stack+83538, 1.0, int_stack+82383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+49980,int_stack+206409,int_stack+57540, 1.0, int_stack+213969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+70791,int_stack+49980,int_stack+60375, 1.0, int_stack+216804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+209874,int_stack+70791,int_stack+64911, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+89103,int_stack+86079, 1.0, int_stack+84693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+4158,int_stack+0,int_stack+206409, 1.0, int_stack+221340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+11088,int_stack+4158,int_stack+49980, 1.0, int_stack+238734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+49980,int_stack+11088,int_stack+70791, 1.0, int_stack+244404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+238734,int_stack+49980,int_stack+209874, 1.0, int_stack+251964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+251082,int_stack+90741,int_stack+89103, 1.0, int_stack+87465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+61320,int_stack+251082,int_stack+0, 1.0, int_stack+260784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+251082,int_stack+61320,int_stack+4158, 1.0, int_stack+264942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+61320,int_stack+251082,int_stack+11088, 1.0, int_stack+271872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+251082,int_stack+61320,int_stack+49980, 1.0, int_stack+281322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+49980,int_stack+251082,int_stack+238734, 1.0, int_stack+292662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+238734,int_stack+126000,int_stack+124830,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+242244,int_stack+238734,int_stack+174819,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+248184,int_stack+242244,int_stack+177789,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+256434,int_stack+248184,int_stack+182739,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+238734,int_stack+256434,int_stack+189489,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+250074,int_stack+238734,int_stack+197589,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+238734,int_stack+93072,int_stack+92652,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+239994,int_stack+93612,int_stack+93072,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+241614,int_stack+239994,int_stack+238734,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+244134,int_stack+94287,int_stack+93612,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+246159,int_stack+244134,int_stack+239994,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+261834,int_stack+246159,int_stack+241614,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+238734,int_stack+95112,int_stack+94287,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+266034,int_stack+238734,int_stack+244134,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+270084,int_stack+266034,int_stack+246159,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+241209,int_stack+270084,int_stack+261834,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+261834,int_stack+96102,int_stack+95112,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+275484,int_stack+261834,int_stack+238734,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+280434,int_stack+275484,int_stack+266034,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+287184,int_stack+280434,int_stack+270084,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+264804,int_stack+287184,int_stack+241209,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+238734,int_stack+97272,int_stack+96102,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+242244,int_stack+238734,int_stack+261834,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+295284,int_stack+242244,int_stack+275484,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+238734,int_stack+295284,int_stack+280434,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+273624,int_stack+238734,int_stack+287184,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+284964,int_stack+273624,int_stack+264804,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+238734,int_stack+99225,int_stack+98637,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+240498,int_stack+99981,int_stack+99225,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+242766,int_stack+240498,int_stack+238734,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+246294,int_stack+100926,int_stack+99981,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+261834,int_stack+246294,int_stack+240498,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+266370,int_stack+261834,int_stack+242766,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+238734,int_stack+102081,int_stack+100926,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+272250,int_stack+238734,int_stack+246294,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+242199,int_stack+272250,int_stack+261834,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+66444,int_stack+242199,int_stack+266370,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+261834,int_stack+103467,int_stack+102081,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+277920,int_stack+261834,int_stack+238734,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+75264,int_stack+277920,int_stack+272250,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+265992,int_stack+75264,int_stack+242199,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+84714,int_stack+265992,int_stack+66444,21);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+66444,int_stack+105105,int_stack+103467,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+238734,int_stack+66444,int_stack+261834,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+0,int_stack+238734,int_stack+277920,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+153489,int_stack+0,int_stack+75264,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+0,int_stack+153489,int_stack+265992,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+153489,int_stack+0,int_stack+84714,21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+107436,int_stack+107016,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+107976,int_stack+107436,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2880,int_stack+1260,int_stack+0,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5400,int_stack+108651,int_stack+107976,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7425,int_stack+5400,int_stack+1260,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+10665,int_stack+7425,int_stack+2880,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+109476,int_stack+108651,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+14865,int_stack+0,int_stack+5400,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+169953,int_stack+14865,int_stack+7425,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2475,int_stack+169953,int_stack+10665,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+8775,int_stack+110466,int_stack+109476,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+175353,int_stack+8775,int_stack+0,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+180303,int_stack+175353,int_stack+14865,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+11745,int_stack+180303,int_stack+169953,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+187053,int_stack+11745,int_stack+2475,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+169953,int_stack+111636,int_stack+110466,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+169953,int_stack+8775,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+195873,int_stack+0,int_stack+175353,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+0,int_stack+195873,int_stack+180303,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+238734,int_stack+0,int_stack+11745,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+0,int_stack+238734,int_stack+187053,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+238734,int_stack+113589,int_stack+113001,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+240498,int_stack+114345,int_stack+113589,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+242766,int_stack+240498,int_stack+238734,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+246294,int_stack+115290,int_stack+114345,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+11760,int_stack+246294,int_stack+240498,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+169953,int_stack+11760,int_stack+242766,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+238734,int_stack+116445,int_stack+115290,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+175833,int_stack+238734,int_stack+246294,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+242199,int_stack+175833,int_stack+11760,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+11760,int_stack+242199,int_stack+169953,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+169953,int_stack+117831,int_stack+116445,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+181503,int_stack+169953,int_stack+238734,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+188433,int_stack+181503,int_stack+175833,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+197883,int_stack+188433,int_stack+242199,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+209223,int_stack+197883,int_stack+11760,21);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+11760,int_stack+119469,int_stack+117831,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+238734,int_stack+11760,int_stack+169953,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+169953,int_stack+238734,int_stack+181503,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+261834,int_stack+169953,int_stack+188433,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+169953,int_stack+261834,int_stack+197883,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+261834,int_stack+169953,int_stack+209223,21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+169953,int_stack+127785,int_stack+127365,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+171213,int_stack+128325,int_stack+127785,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+172833,int_stack+171213,int_stack+169953,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+175353,int_stack+129000,int_stack+128325,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+177378,int_stack+175353,int_stack+171213,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+180618,int_stack+177378,int_stack+172833,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+169953,int_stack+129825,int_stack+129000,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+184818,int_stack+169953,int_stack+175353,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+188868,int_stack+184818,int_stack+177378,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+172428,int_stack+188868,int_stack+180618,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+178728,int_stack+130815,int_stack+129825,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+194268,int_stack+178728,int_stack+169953,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+199218,int_stack+194268,int_stack+184818,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+205968,int_stack+199218,int_stack+188868,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+181698,int_stack+205968,int_stack+172428,15);
 /*--- compute (g0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+169953,int_stack+131985,int_stack+130815,15);
 /*--- compute (g0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+214068,int_stack+169953,int_stack+178728,15);
 /*--- compute (g0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+169953,int_stack+214068,int_stack+194268,15);
 /*--- compute (g0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+214068,int_stack+169953,int_stack+199218,15);
 /*--- compute (g0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+238734,int_stack+214068,int_stack+205968,15);
 /*--- compute (g0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+190518,int_stack+238734,int_stack+181698,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+238734,int_stack+133938,int_stack+133350,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+240498,int_stack+134694,int_stack+133938,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+242766,int_stack+240498,int_stack+238734,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+246294,int_stack+135639,int_stack+134694,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+169953,int_stack+246294,int_stack+240498,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+174489,int_stack+169953,int_stack+242766,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+238734,int_stack+136794,int_stack+135639,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+180369,int_stack+238734,int_stack+246294,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+242199,int_stack+180369,int_stack+169953,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+202278,int_stack+242199,int_stack+174489,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+169953,int_stack+138180,int_stack+136794,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+211098,int_stack+169953,int_stack+238734,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+11760,int_stack+211098,int_stack+180369,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+174111,int_stack+11760,int_stack+242199,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+66444,int_stack+174111,int_stack+202278,21);
 /*--- compute (h0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+202278,int_stack+139818,int_stack+138180,21);
 /*--- compute (h0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+238734,int_stack+202278,int_stack+169953,21);
 /*--- compute (h0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+78792,int_stack+238734,int_stack+211098,21);
 /*--- compute (h0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+202278,int_stack+78792,int_stack+11760,21);
 /*--- compute (h0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+78792,int_stack+202278,int_stack+174111,21);
 /*--- compute (h0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+202278,int_stack+78792,int_stack+66444,21);
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+66444,int_stack+333801,int_stack+226974,784);
     Libderiv->ABCD[11] = int_stack + 66444;
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+101724,int_stack+305010,int_stack+350265,784);
     Libderiv->ABCD[10] = int_stack + 101724;
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+296724,int_stack+21756,int_stack+362025,784);
     Libderiv->ABCD[9] = int_stack + 296724;
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+332004,int_stack+385545,int_stack+373785,784);
     Libderiv->ABCD[8] = int_stack + 332004;
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+418473,int_stack+402009,int_stack+38220,784);
     Libderiv->ABCD[7] = int_stack + 418473;
 /*--- compute (gp|ii) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+11760,int_stack+49980,int_stack+141729,784);
     Libderiv->ABCD[6] = int_stack + 11760;
 /*--- compute (gp|ii) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+367284,int_stack+153489,int_stack+284964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[2] = int_stack + 367284;
 /*--- compute (gp|ii) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+137004,int_stack+261834,int_stack+0, 0.0, zero_stack, 1.0, int_stack+250074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[1] = int_stack + 137004;
 /*--- compute (gp|ii) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+453753,int_stack+202278,int_stack+190518, 1.0, int_stack+250074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[0] = int_stack + 453753;

}
