/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_idgg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (id|gg) integrals */

void d1hrr_order_idgg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][4][11] = int_stack + 0;
 Libderiv->deriv_classes[6][5][11] = int_stack + 420;
 Libderiv->deriv_classes[6][6][11] = int_stack + 1008;
 Libderiv->deriv_classes[6][7][11] = int_stack + 1792;
 Libderiv->deriv_classes[6][8][11] = int_stack + 2800;
 Libderiv->deriv_classes[7][4][11] = int_stack + 4060;
 Libderiv->deriv_classes[7][5][11] = int_stack + 4600;
 Libderiv->deriv_classes[7][6][11] = int_stack + 5356;
 Libderiv->deriv_classes[7][7][11] = int_stack + 6364;
 Libderiv->deriv_classes[7][8][11] = int_stack + 7660;
 Libderiv->deriv_classes[8][4][11] = int_stack + 9280;
 Libderiv->deriv_classes[8][5][11] = int_stack + 9955;
 Libderiv->deriv_classes[8][6][11] = int_stack + 10900;
 Libderiv->deriv_classes[8][7][11] = int_stack + 12160;
 Libderiv->deriv_classes[8][8][11] = int_stack + 13780;
 Libderiv->deriv_classes[6][4][10] = int_stack + 15805;
 Libderiv->deriv_classes[6][5][10] = int_stack + 16225;
 Libderiv->deriv_classes[6][6][10] = int_stack + 16813;
 Libderiv->deriv_classes[6][7][10] = int_stack + 17597;
 Libderiv->deriv_classes[6][8][10] = int_stack + 18605;
 Libderiv->deriv_classes[7][4][10] = int_stack + 19865;
 Libderiv->deriv_classes[7][5][10] = int_stack + 20405;
 Libderiv->deriv_classes[7][6][10] = int_stack + 21161;
 Libderiv->deriv_classes[7][7][10] = int_stack + 22169;
 Libderiv->deriv_classes[7][8][10] = int_stack + 23465;
 Libderiv->deriv_classes[8][4][10] = int_stack + 25085;
 Libderiv->deriv_classes[8][5][10] = int_stack + 25760;
 Libderiv->deriv_classes[8][6][10] = int_stack + 26705;
 Libderiv->deriv_classes[8][7][10] = int_stack + 27965;
 Libderiv->deriv_classes[8][8][10] = int_stack + 29585;
 Libderiv->deriv_classes[6][4][9] = int_stack + 31610;
 Libderiv->deriv_classes[6][5][9] = int_stack + 32030;
 Libderiv->deriv_classes[6][6][9] = int_stack + 32618;
 Libderiv->deriv_classes[6][7][9] = int_stack + 33402;
 Libderiv->deriv_classes[6][8][9] = int_stack + 34410;
 Libderiv->deriv_classes[7][4][9] = int_stack + 35670;
 Libderiv->deriv_classes[7][5][9] = int_stack + 36210;
 Libderiv->deriv_classes[7][6][9] = int_stack + 36966;
 Libderiv->deriv_classes[7][7][9] = int_stack + 37974;
 Libderiv->deriv_classes[7][8][9] = int_stack + 39270;
 Libderiv->deriv_classes[8][4][9] = int_stack + 40890;
 Libderiv->deriv_classes[8][5][9] = int_stack + 41565;
 Libderiv->deriv_classes[8][6][9] = int_stack + 42510;
 Libderiv->deriv_classes[8][7][9] = int_stack + 43770;
 Libderiv->deriv_classes[8][8][9] = int_stack + 45390;
 Libderiv->deriv_classes[6][4][8] = int_stack + 47415;
 Libderiv->deriv_classes[6][5][8] = int_stack + 47835;
 Libderiv->deriv_classes[6][6][8] = int_stack + 48423;
 Libderiv->deriv_classes[6][7][8] = int_stack + 49207;
 Libderiv->deriv_classes[6][8][8] = int_stack + 50215;
 Libderiv->deriv_classes[7][4][8] = int_stack + 51475;
 Libderiv->deriv_classes[7][5][8] = int_stack + 52015;
 Libderiv->deriv_classes[7][6][8] = int_stack + 52771;
 Libderiv->deriv_classes[7][7][8] = int_stack + 53779;
 Libderiv->deriv_classes[7][8][8] = int_stack + 55075;
 Libderiv->deriv_classes[8][4][8] = int_stack + 56695;
 Libderiv->deriv_classes[8][5][8] = int_stack + 57370;
 Libderiv->deriv_classes[8][6][8] = int_stack + 58315;
 Libderiv->deriv_classes[8][7][8] = int_stack + 59575;
 Libderiv->deriv_classes[8][8][8] = int_stack + 61195;
 Libderiv->deriv_classes[6][4][7] = int_stack + 63220;
 Libderiv->deriv_classes[6][5][7] = int_stack + 63640;
 Libderiv->deriv_classes[6][6][7] = int_stack + 64228;
 Libderiv->deriv_classes[6][7][7] = int_stack + 65012;
 Libderiv->deriv_classes[6][8][7] = int_stack + 66020;
 Libderiv->deriv_classes[7][4][7] = int_stack + 67280;
 Libderiv->deriv_classes[7][5][7] = int_stack + 67820;
 Libderiv->deriv_classes[7][6][7] = int_stack + 68576;
 Libderiv->deriv_classes[7][7][7] = int_stack + 69584;
 Libderiv->deriv_classes[7][8][7] = int_stack + 70880;
 Libderiv->deriv_classes[8][4][7] = int_stack + 72500;
 Libderiv->deriv_classes[8][5][7] = int_stack + 73175;
 Libderiv->deriv_classes[8][6][7] = int_stack + 74120;
 Libderiv->deriv_classes[8][7][7] = int_stack + 75380;
 Libderiv->deriv_classes[8][8][7] = int_stack + 77000;
 Libderiv->deriv_classes[6][4][6] = int_stack + 79025;
 Libderiv->deriv_classes[6][5][6] = int_stack + 79445;
 Libderiv->deriv_classes[6][6][6] = int_stack + 80033;
 Libderiv->deriv_classes[6][7][6] = int_stack + 80817;
 Libderiv->deriv_classes[6][8][6] = int_stack + 81825;
 Libderiv->deriv_classes[7][4][6] = int_stack + 83085;
 Libderiv->deriv_classes[7][5][6] = int_stack + 83625;
 Libderiv->deriv_classes[7][6][6] = int_stack + 84381;
 Libderiv->deriv_classes[7][7][6] = int_stack + 85389;
 Libderiv->deriv_classes[7][8][6] = int_stack + 86685;
 Libderiv->dvrr_classes[8][4] = int_stack + 88305;
 Libderiv->deriv_classes[8][4][6] = int_stack + 88980;
 Libderiv->dvrr_classes[8][5] = int_stack + 89655;
 Libderiv->deriv_classes[8][5][6] = int_stack + 90600;
 Libderiv->dvrr_classes[8][6] = int_stack + 91545;
 Libderiv->deriv_classes[8][6][6] = int_stack + 92805;
 Libderiv->dvrr_classes[8][7] = int_stack + 94065;
 Libderiv->deriv_classes[8][7][6] = int_stack + 95685;
 Libderiv->deriv_classes[8][8][6] = int_stack + 97305;
 Libderiv->deriv_classes[6][4][2] = int_stack + 99330;
 Libderiv->deriv_classes[6][5][2] = int_stack + 99750;
 Libderiv->deriv_classes[6][6][2] = int_stack + 100338;
 Libderiv->deriv_classes[6][7][2] = int_stack + 101122;
 Libderiv->deriv_classes[6][8][2] = int_stack + 102130;
 Libderiv->deriv_classes[7][4][2] = int_stack + 103390;
 Libderiv->deriv_classes[7][5][2] = int_stack + 103930;
 Libderiv->deriv_classes[7][6][2] = int_stack + 104686;
 Libderiv->deriv_classes[7][7][2] = int_stack + 105694;
 Libderiv->deriv_classes[7][8][2] = int_stack + 106990;
 Libderiv->deriv_classes[8][4][2] = int_stack + 108610;
 Libderiv->deriv_classes[8][5][2] = int_stack + 109285;
 Libderiv->deriv_classes[8][6][2] = int_stack + 110230;
 Libderiv->deriv_classes[8][7][2] = int_stack + 111490;
 Libderiv->deriv_classes[8][8][2] = int_stack + 113110;
 Libderiv->deriv_classes[6][4][1] = int_stack + 115135;
 Libderiv->deriv_classes[6][5][1] = int_stack + 115555;
 Libderiv->deriv_classes[6][6][1] = int_stack + 116143;
 Libderiv->deriv_classes[6][7][1] = int_stack + 116927;
 Libderiv->deriv_classes[6][8][1] = int_stack + 117935;
 Libderiv->deriv_classes[7][4][1] = int_stack + 119195;
 Libderiv->deriv_classes[7][5][1] = int_stack + 119735;
 Libderiv->deriv_classes[7][6][1] = int_stack + 120491;
 Libderiv->deriv_classes[7][7][1] = int_stack + 121499;
 Libderiv->deriv_classes[7][8][1] = int_stack + 122795;
 Libderiv->deriv_classes[8][4][1] = int_stack + 124415;
 Libderiv->deriv_classes[8][5][1] = int_stack + 125090;
 Libderiv->deriv_classes[8][6][1] = int_stack + 126035;
 Libderiv->deriv_classes[8][7][1] = int_stack + 127295;
 Libderiv->deriv_classes[8][8][1] = int_stack + 128915;
 Libderiv->dvrr_classes[6][4] = int_stack + 130940;
 Libderiv->dvrr_classes[6][5] = int_stack + 131360;
 Libderiv->dvrr_classes[6][6] = int_stack + 131948;
 Libderiv->dvrr_classes[6][7] = int_stack + 132732;
 Libderiv->dvrr_classes[6][8] = int_stack + 133740;
 Libderiv->deriv_classes[6][4][0] = int_stack + 135000;
 Libderiv->deriv_classes[6][5][0] = int_stack + 135420;
 Libderiv->deriv_classes[6][6][0] = int_stack + 136008;
 Libderiv->deriv_classes[6][7][0] = int_stack + 136792;
 Libderiv->deriv_classes[6][8][0] = int_stack + 137800;
 Libderiv->dvrr_classes[7][4] = int_stack + 139060;
 Libderiv->dvrr_classes[7][5] = int_stack + 139600;
 Libderiv->dvrr_classes[7][6] = int_stack + 140356;
 Libderiv->dvrr_classes[7][7] = int_stack + 141364;
 Libderiv->dvrr_classes[7][8] = int_stack + 142660;
 Libderiv->deriv_classes[7][4][0] = int_stack + 144280;
 Libderiv->deriv_classes[7][5][0] = int_stack + 144820;
 Libderiv->deriv_classes[7][6][0] = int_stack + 145576;
 Libderiv->deriv_classes[7][7][0] = int_stack + 146584;
 Libderiv->deriv_classes[7][8][0] = int_stack + 147880;
 Libderiv->deriv_classes[8][4][0] = int_stack + 149500;
 Libderiv->deriv_classes[8][5][0] = int_stack + 150175;
 Libderiv->deriv_classes[8][6][0] = int_stack + 151120;
 Libderiv->deriv_classes[8][7][0] = int_stack + 152380;
 Libderiv->deriv_classes[8][8][0] = int_stack + 154000;
 memset(int_stack,0,1248200);

 Libderiv->dvrr_stack = int_stack + 536203;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_idgg(Libderiv, Data);
   Data++;
 }

 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+156025,int_stack+131360,int_stack+130940,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+157285,int_stack+131948,int_stack+131360,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+159049,int_stack+157285,int_stack+156025,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+161569,int_stack+132732,int_stack+131948,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+163921,int_stack+161569,int_stack+157285,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+167449,int_stack+163921,int_stack+159049,28);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+171649,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130940,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+172909,int_stack+1008,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131360,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+174673,int_stack+172909,int_stack+171649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156025,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+177193,int_stack+1792,int_stack+1008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131948,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+179545,int_stack+177193,int_stack+172909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157285,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+183073,int_stack+179545,int_stack+174673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159049,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+171649,int_stack+2800,int_stack+1792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132732,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+187273,int_stack+171649,int_stack+177193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161569,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+171649,int_stack+187273,int_stack+179545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163921,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+187273,int_stack+171649,int_stack+183073, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167449,28);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+171649,int_stack+139600,int_stack+139060,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+173269,int_stack+140356,int_stack+139600,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+175537,int_stack+173269,int_stack+171649,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+178777,int_stack+141364,int_stack+140356,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+181801,int_stack+178777,int_stack+173269,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+193573,int_stack+181801,int_stack+175537,36);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+4600,int_stack+4060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139060,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1620,int_stack+5356,int_stack+4600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139600,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+198973,int_stack+1620,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171649,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+202213,int_stack+6364,int_stack+5356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140356,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+205237,int_stack+202213,int_stack+1620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173269,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+0,int_stack+205237,int_stack+198973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175537,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+209773,int_stack+7660,int_stack+6364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141364,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+213661,int_stack+209773,int_stack+202213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178777,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+219709,int_stack+213661,int_stack+205237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181801,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+198973,int_stack+219709,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193573,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+207073,int_stack+198973,int_stack+187273,225);
 /*--- compute (l0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+89655,int_stack+88305,45);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2025,int_stack+91545,int_stack+89655,45);
 /*--- compute (l0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+4860,int_stack+2025,int_stack+0,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+186337,int_stack+94065,int_stack+91545,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+225973,int_stack+186337,int_stack+2025,45);
 /*--- compute (l0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+231643,int_stack+225973,int_stack+4860,45);
 /*--- compute (l0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+190117,int_stack+9955,int_stack+9280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88305,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+238393,int_stack+10900,int_stack+9955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89655,45);
 /*--- compute (l0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+241228,int_stack+238393,int_stack+190117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+245278,int_stack+12160,int_stack+10900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91545,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+249058,int_stack+245278,int_stack+238393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2025,45);
 /*--- compute (l0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+254728,int_stack+249058,int_stack+241228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+238393,int_stack+13780,int_stack+12160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94065,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+261478,int_stack+238393,int_stack+245278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186337,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+238393,int_stack+261478,int_stack+249058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225973,45);
 /*--- compute (l0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+261478,int_stack+238393,int_stack+254728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231643,45);
 /*--- compute (kp|gg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+271603,int_stack+261478,int_stack+198973,225);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+198973,int_stack+16225,int_stack+15805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130940, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+200233,int_stack+16813,int_stack+16225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131360, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+201997,int_stack+200233,int_stack+198973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156025, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+204517,int_stack+17597,int_stack+16813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131948, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+238393,int_stack+204517,int_stack+200233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157285, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+241921,int_stack+238393,int_stack+201997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159049, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+198973,int_stack+18605,int_stack+17597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132732, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+246121,int_stack+198973,int_stack+204517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161569, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+198973,int_stack+246121,int_stack+238393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163921, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+246121,int_stack+198973,int_stack+241921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167449, 0.0, zero_stack,28);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+198973,int_stack+20405,int_stack+19865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139060, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+200593,int_stack+21161,int_stack+20405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139600, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+202861,int_stack+200593,int_stack+198973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171649, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+238393,int_stack+22169,int_stack+21161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140356, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+241417,int_stack+238393,int_stack+200593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173269, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+252421,int_stack+241417,int_stack+202861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175537, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+198973,int_stack+23465,int_stack+22169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141364, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+257821,int_stack+198973,int_stack+238393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178777, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+198973,int_stack+257821,int_stack+241417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181801, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+257821,int_stack+198973,int_stack+252421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193573, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+295903,int_stack+257821,int_stack+246121,225);
 /*--- compute (l0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+198973,int_stack+25760,int_stack+25085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88305, 0.0, zero_stack,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+200998,int_stack+26705,int_stack+25760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89655, 0.0, zero_stack,45);
 /*--- compute (l0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+265921,int_stack+200998,int_stack+198973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+238393,int_stack+27965,int_stack+26705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91545, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+242173,int_stack+238393,int_stack+200998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2025, 0.0, zero_stack,45);
 /*--- compute (l0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+198973,int_stack+242173,int_stack+265921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+265921,int_stack+29585,int_stack+27965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94065, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+247843,int_stack+265921,int_stack+238393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186337, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8910,int_stack+247843,int_stack+242173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225973, 0.0, zero_stack,45);
 /*--- compute (l0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+238393,int_stack+8910,int_stack+198973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231643, 0.0, zero_stack,45);
 /*--- compute (kp|gg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+314803,int_stack+238393,int_stack+257821,225);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+238393,int_stack+32030,int_stack+31610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130940, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+239653,int_stack+32618,int_stack+32030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131360, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+241417,int_stack+239653,int_stack+238393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156025, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+243937,int_stack+33402,int_stack+32618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131948, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+246289,int_stack+243937,int_stack+239653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157285, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+249817,int_stack+246289,int_stack+241417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159049, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+238393,int_stack+34410,int_stack+33402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132732, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+254017,int_stack+238393,int_stack+243937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161569, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+238393,int_stack+254017,int_stack+246289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163921, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+254017,int_stack+238393,int_stack+249817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167449, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+238393,int_stack+36210,int_stack+35670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139060, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+240013,int_stack+36966,int_stack+36210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139600, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+242281,int_stack+240013,int_stack+238393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171649, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+245521,int_stack+37974,int_stack+36966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140356, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+248545,int_stack+245521,int_stack+240013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173269, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+260317,int_stack+248545,int_stack+242281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175537, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+238393,int_stack+39270,int_stack+37974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141364, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+198973,int_stack+238393,int_stack+245521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178777, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+238393,int_stack+198973,int_stack+248545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181801, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+198973,int_stack+238393,int_stack+260317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193573, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+8910,int_stack+198973,int_stack+254017,225);
 /*--- compute (l0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+238393,int_stack+41565,int_stack+40890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88305, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+240418,int_stack+42510,int_stack+41565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89655, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+243253,int_stack+240418,int_stack+238393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+247303,int_stack+43770,int_stack+42510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91545, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+251083,int_stack+247303,int_stack+240418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2025, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+256753,int_stack+251083,int_stack+243253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+238393,int_stack+45390,int_stack+43770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94065, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+263503,int_stack+238393,int_stack+247303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186337, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+238393,int_stack+263503,int_stack+251083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225973, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+27810,int_stack+238393,int_stack+256753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231643, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|gg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+238393,int_stack+27810,int_stack+198973,225);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+198973,int_stack+47835,int_stack+47415, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+200233,int_stack+48423,int_stack+47835, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+201997,int_stack+200233,int_stack+198973, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+204517,int_stack+49207,int_stack+48423, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+27810,int_stack+204517,int_stack+200233, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+31338,int_stack+27810,int_stack+201997, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+198973,int_stack+50215,int_stack+49207, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+35538,int_stack+198973,int_stack+204517, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+198973,int_stack+35538,int_stack+27810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+35538,int_stack+198973,int_stack+31338, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+198973,int_stack+52015,int_stack+51475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+200593,int_stack+52771,int_stack+52015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+202861,int_stack+200593,int_stack+198973, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+27810,int_stack+53779,int_stack+52771, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30834,int_stack+27810,int_stack+200593, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+41838,int_stack+30834,int_stack+202861, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+198973,int_stack+55075,int_stack+53779, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+47238,int_stack+198973,int_stack+27810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+198973,int_stack+47238,int_stack+30834, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+47238,int_stack+198973,int_stack+41838, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+339103,int_stack+47238,int_stack+35538,225);
 /*--- compute (l0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+198973,int_stack+57370,int_stack+56695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+200998,int_stack+58315,int_stack+57370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+27810,int_stack+200998,int_stack+198973, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31860,int_stack+59575,int_stack+58315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35640,int_stack+31860,int_stack+200998, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+198973,int_stack+35640,int_stack+27810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+41310,int_stack+61195,int_stack+59575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+55338,int_stack+41310,int_stack+31860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+358003,int_stack+55338,int_stack+35640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+27810,int_stack+358003,int_stack+198973, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|gg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+358003,int_stack+27810,int_stack+47238,225);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+27810,int_stack+63640,int_stack+63220, 0.0, zero_stack, 1.0, int_stack+130940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29070,int_stack+64228,int_stack+63640, 0.0, zero_stack, 1.0, int_stack+131360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+30834,int_stack+29070,int_stack+27810, 0.0, zero_stack, 1.0, int_stack+156025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+33354,int_stack+65012,int_stack+64228, 0.0, zero_stack, 1.0, int_stack+131948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35706,int_stack+33354,int_stack+29070, 0.0, zero_stack, 1.0, int_stack+157285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+39234,int_stack+35706,int_stack+30834, 0.0, zero_stack, 1.0, int_stack+159049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+27810,int_stack+66020,int_stack+65012, 0.0, zero_stack, 1.0, int_stack+132732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+43434,int_stack+27810,int_stack+33354, 0.0, zero_stack, 1.0, int_stack+161569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+27810,int_stack+43434,int_stack+35706, 0.0, zero_stack, 1.0, int_stack+163921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+43434,int_stack+27810,int_stack+39234, 0.0, zero_stack, 1.0, int_stack+167449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+27810,int_stack+67820,int_stack+67280, 0.0, zero_stack, 1.0, int_stack+139060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29430,int_stack+68576,int_stack+67820, 0.0, zero_stack, 1.0, int_stack+139600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+31698,int_stack+29430,int_stack+27810, 0.0, zero_stack, 1.0, int_stack+171649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34938,int_stack+69584,int_stack+68576, 0.0, zero_stack, 1.0, int_stack+140356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+37962,int_stack+34938,int_stack+29430, 0.0, zero_stack, 1.0, int_stack+173269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+49734,int_stack+37962,int_stack+31698, 0.0, zero_stack, 1.0, int_stack+175537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+27810,int_stack+70880,int_stack+69584, 0.0, zero_stack, 1.0, int_stack+141364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+55134,int_stack+27810,int_stack+34938, 0.0, zero_stack, 1.0, int_stack+178777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+27810,int_stack+55134,int_stack+37962, 0.0, zero_stack, 1.0, int_stack+181801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+198973,int_stack+27810,int_stack+49734, 0.0, zero_stack, 1.0, int_stack+193573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+49734,int_stack+198973,int_stack+43434,225);
 /*--- compute (l0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+68634,int_stack+73175,int_stack+72500, 0.0, zero_stack, 1.0, int_stack+88305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+27810,int_stack+74120,int_stack+73175, 0.0, zero_stack, 1.0, int_stack+89655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+30645,int_stack+27810,int_stack+68634, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+68634,int_stack+75380,int_stack+74120, 0.0, zero_stack, 1.0, int_stack+91545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+34695,int_stack+68634,int_stack+27810, 0.0, zero_stack, 1.0, int_stack+2025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+40365,int_stack+34695,int_stack+30645, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+27810,int_stack+77000,int_stack+75380, 0.0, zero_stack, 1.0, int_stack+94065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+262693,int_stack+27810,int_stack+68634, 0.0, zero_stack, 1.0, int_stack+186337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+68634,int_stack+262693,int_stack+34695, 0.0, zero_stack, 1.0, int_stack+225973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+27810,int_stack+68634,int_stack+40365, 0.0, zero_stack, 1.0, int_stack+231643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|gg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+382303,int_stack+27810,int_stack+198973,225);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+198973,int_stack+79445,int_stack+79025, 1.0, int_stack+130940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+200233,int_stack+80033,int_stack+79445, 1.0, int_stack+131360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+201997,int_stack+200233,int_stack+198973, 1.0, int_stack+156025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+204517,int_stack+80817,int_stack+80033, 1.0, int_stack+131948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+27810,int_stack+204517,int_stack+200233, 1.0, int_stack+157285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+31338,int_stack+27810,int_stack+201997, 1.0, int_stack+159049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+156025,int_stack+81825,int_stack+80817, 1.0, int_stack+132732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+198973,int_stack+156025,int_stack+204517, 1.0, int_stack+161569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+35538,int_stack+198973,int_stack+27810, 1.0, int_stack+163921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+198973,int_stack+35538,int_stack+31338, 1.0, int_stack+167449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+27810,int_stack+83625,int_stack+83085, 1.0, int_stack+139060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29430,int_stack+84381,int_stack+83625, 1.0, int_stack+139600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+31698,int_stack+29430,int_stack+27810, 1.0, int_stack+171649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34938,int_stack+85389,int_stack+84381, 1.0, int_stack+140356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+37962,int_stack+34938,int_stack+29430, 1.0, int_stack+173269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+42498,int_stack+37962,int_stack+31698, 1.0, int_stack+175537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+171649,int_stack+86685,int_stack+85389, 1.0, int_stack+141364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+27810,int_stack+171649,int_stack+34938, 1.0, int_stack+178777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+68634,int_stack+27810,int_stack+37962, 1.0, int_stack+181801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+27810,int_stack+68634,int_stack+42498, 1.0, int_stack+193573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+68634,int_stack+27810,int_stack+198973,225);
 /*--- compute (l0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+198973,int_stack+90600,int_stack+88980, 1.0, int_stack+88305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+200998,int_stack+92805,int_stack+90600, 1.0, int_stack+89655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+35910,int_stack+200998,int_stack+198973, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+87534,int_stack+95685,int_stack+92805, 1.0, int_stack+91545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+39960,int_stack+87534,int_stack+200998, 1.0, int_stack+2025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+198973,int_stack+39960,int_stack+35910, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+97305,int_stack+95685, 1.0, int_stack+94065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+91314,int_stack+0,int_stack+87534, 1.0, int_stack+186337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+406603,int_stack+91314,int_stack+39960, 1.0, int_stack+225973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+87534,int_stack+406603,int_stack+198973, 1.0, int_stack+231643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|gg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+406603,int_stack+87534,int_stack+27810,225);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+27810,int_stack+133740,int_stack+132732,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+30834,int_stack+27810,int_stack+161569,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+35538,int_stack+30834,int_stack+163921,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+27810,int_stack+35538,int_stack+167449,28);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+34110,int_stack+142660,int_stack+141364,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+37998,int_stack+34110,int_stack+178777,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+87534,int_stack+37998,int_stack+181801,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+198973,int_stack+87534,int_stack+193573,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+156025,int_stack+198973,int_stack+27810,225);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+87534,int_stack+99750,int_stack+99330,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+88794,int_stack+100338,int_stack+99750,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+90558,int_stack+88794,int_stack+87534,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+93078,int_stack+101122,int_stack+100338,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+95430,int_stack+93078,int_stack+88794,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+34110,int_stack+95430,int_stack+90558,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+87534,int_stack+102130,int_stack+101122,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+38310,int_stack+87534,int_stack+93078,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+87534,int_stack+38310,int_stack+95430,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+38310,int_stack+87534,int_stack+34110,28);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+34110,int_stack+103930,int_stack+103390,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+35730,int_stack+104686,int_stack+103930,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+87534,int_stack+35730,int_stack+34110,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+90774,int_stack+105694,int_stack+104686,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+93798,int_stack+90774,int_stack+35730,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+98334,int_stack+93798,int_stack+87534,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+34110,int_stack+106990,int_stack+105694,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+225973,int_stack+34110,int_stack+90774,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+225973,int_stack+93798,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+225973,int_stack+0,int_stack+98334,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+87534,int_stack+225973,int_stack+38310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (l0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+109285,int_stack+108610,45);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2025,int_stack+110230,int_stack+109285,45);
 /*--- compute (l0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+4860,int_stack+2025,int_stack+0,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+234073,int_stack+111490,int_stack+110230,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+34110,int_stack+234073,int_stack+2025,45);
 /*--- compute (l0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+39780,int_stack+34110,int_stack+4860,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+113110,int_stack+111490,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+106434,int_stack+0,int_stack+234073,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+174925,int_stack+106434,int_stack+34110,45);
 /*--- compute (l0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+184375,int_stack+174925,int_stack+39780,45);
 /*--- compute (kp|gg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+430903,int_stack+184375,int_stack+225973, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+225973,int_stack+115555,int_stack+115135,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+227233,int_stack+116143,int_stack+115555,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+228997,int_stack+227233,int_stack+225973,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+231517,int_stack+116927,int_stack+116143,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+233869,int_stack+231517,int_stack+227233,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+174925,int_stack+233869,int_stack+228997,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+225973,int_stack+117935,int_stack+116927,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+179125,int_stack+225973,int_stack+231517,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+225973,int_stack+179125,int_stack+233869,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+179125,int_stack+225973,int_stack+174925,28);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+174925,int_stack+119735,int_stack+119195,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+176545,int_stack+120491,int_stack+119735,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+225973,int_stack+176545,int_stack+174925,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+229213,int_stack+121499,int_stack+120491,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+232237,int_stack+229213,int_stack+176545,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+185425,int_stack+232237,int_stack+225973,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+174925,int_stack+122795,int_stack+121499,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+190825,int_stack+174925,int_stack+229213,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+34110,int_stack+190825,int_stack+232237,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+190825,int_stack+34110,int_stack+185425,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+455203,int_stack+190825,int_stack+179125, 0.0, zero_stack, 1.0, int_stack+27810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (l0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+34110,int_stack+125090,int_stack+124415,45);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+36135,int_stack+126035,int_stack+125090,45);
 /*--- compute (l0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+38970,int_stack+36135,int_stack+34110,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+43020,int_stack+127295,int_stack+126035,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+174925,int_stack+43020,int_stack+36135,45);
 /*--- compute (l0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+180595,int_stack+174925,int_stack+38970,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+34110,int_stack+128915,int_stack+127295,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+225973,int_stack+34110,int_stack+43020,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+34110,int_stack+225973,int_stack+174925,45);
 /*--- compute (l0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+225973,int_stack+34110,int_stack+180595,45);
 /*--- compute (kp|gg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+106434,int_stack+225973,int_stack+190825, 0.0, zero_stack, 1.0, int_stack+198973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+225973,int_stack+135420,int_stack+135000,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+227233,int_stack+136008,int_stack+135420,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+228997,int_stack+227233,int_stack+225973,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+231517,int_stack+136792,int_stack+136008,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+233869,int_stack+231517,int_stack+227233,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+34110,int_stack+233869,int_stack+228997,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+225973,int_stack+137800,int_stack+136792,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+38310,int_stack+225973,int_stack+231517,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+225973,int_stack+38310,int_stack+233869,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+38310,int_stack+225973,int_stack+34110,28);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+34110,int_stack+144820,int_stack+144280,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+35730,int_stack+145576,int_stack+144820,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+225973,int_stack+35730,int_stack+34110,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+229213,int_stack+146584,int_stack+145576,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+232237,int_stack+229213,int_stack+35730,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+174925,int_stack+232237,int_stack+225973,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+34110,int_stack+147880,int_stack+146584,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+180325,int_stack+34110,int_stack+229213,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+186373,int_stack+180325,int_stack+232237,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+225973,int_stack+186373,int_stack+174925,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+174925,int_stack+225973,int_stack+38310, 1.0, int_stack+27810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (l0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+27810,int_stack+150175,int_stack+149500,45);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29835,int_stack+151120,int_stack+150175,45);
 /*--- compute (l0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+32670,int_stack+29835,int_stack+27810,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+36720,int_stack+152380,int_stack+151120,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+40500,int_stack+36720,int_stack+29835,45);
 /*--- compute (l0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+130734,int_stack+40500,int_stack+32670,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+27810,int_stack+154000,int_stack+152380,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+137484,int_stack+27810,int_stack+36720,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+27810,int_stack+137484,int_stack+40500,45);
 /*--- compute (l0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+137484,int_stack+27810,int_stack+130734,45);
 /*--- compute (kp|gg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+474103,int_stack+137484,int_stack+225973, 1.0, int_stack+198973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (id|gg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+498403,int_stack+271603,int_stack+207073,225);
     Libderiv->ABCD[11] = int_stack + 498403;
 /*--- compute (id|gg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+193825,int_stack+314803,int_stack+295903,225);
     Libderiv->ABCD[10] = int_stack + 193825;
 /*--- compute (id|gg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+262693,int_stack+238393,int_stack+8910,225);
     Libderiv->ABCD[9] = int_stack + 262693;
 /*--- compute (id|gg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+0,int_stack+358003,int_stack+339103,225);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (id|gg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+300493,int_stack+382303,int_stack+49734,225);
     Libderiv->ABCD[7] = int_stack + 300493;
 /*--- compute (id|gg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+338293,int_stack+406603,int_stack+68634,225);
     Libderiv->ABCD[6] = int_stack + 338293;
 /*--- compute (id|gg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+37800,int_stack+430903,int_stack+87534, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[2] = int_stack + 37800;
 /*--- compute (id|gg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+376093,int_stack+106434,int_stack+455203, 0.0, zero_stack, 1.0, int_stack+156025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[1] = int_stack + 376093;
 /*--- compute (id|gg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+75600,int_stack+474103,int_stack+174925, 1.0, int_stack+156025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[0] = int_stack + 75600;

}
