/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_p0ih(Libderiv_t *, prim_data *);

  /* Computes derivatives of (p0|ih) integrals */

void d1hrr_order_p0ih(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[1][6][11] = int_stack + 0;
 Libderiv->deriv_classes[1][7][11] = int_stack + 84;
 Libderiv->deriv_classes[1][8][11] = int_stack + 192;
 Libderiv->deriv_classes[1][9][11] = int_stack + 327;
 Libderiv->deriv_classes[1][10][11] = int_stack + 492;
 Libderiv->deriv_classes[1][11][11] = int_stack + 690;
 Libderiv->deriv_classes[1][6][10] = int_stack + 924;
 Libderiv->deriv_classes[1][7][10] = int_stack + 1008;
 Libderiv->deriv_classes[1][8][10] = int_stack + 1116;
 Libderiv->deriv_classes[1][9][10] = int_stack + 1251;
 Libderiv->deriv_classes[1][10][10] = int_stack + 1416;
 Libderiv->deriv_classes[1][11][10] = int_stack + 1614;
 Libderiv->deriv_classes[1][6][9] = int_stack + 1848;
 Libderiv->deriv_classes[1][7][9] = int_stack + 1932;
 Libderiv->deriv_classes[1][8][9] = int_stack + 2040;
 Libderiv->deriv_classes[1][9][9] = int_stack + 2175;
 Libderiv->deriv_classes[1][10][9] = int_stack + 2340;
 Libderiv->deriv_classes[1][11][9] = int_stack + 2538;
 Libderiv->deriv_classes[1][6][8] = int_stack + 2772;
 Libderiv->deriv_classes[1][7][8] = int_stack + 2856;
 Libderiv->deriv_classes[1][8][8] = int_stack + 2964;
 Libderiv->deriv_classes[1][9][8] = int_stack + 3099;
 Libderiv->deriv_classes[1][10][8] = int_stack + 3264;
 Libderiv->deriv_classes[1][11][8] = int_stack + 3462;
 Libderiv->deriv_classes[1][6][7] = int_stack + 3696;
 Libderiv->deriv_classes[1][7][7] = int_stack + 3780;
 Libderiv->deriv_classes[1][8][7] = int_stack + 3888;
 Libderiv->deriv_classes[1][9][7] = int_stack + 4023;
 Libderiv->deriv_classes[1][10][7] = int_stack + 4188;
 Libderiv->deriv_classes[1][11][7] = int_stack + 4386;
 Libderiv->dvrr_classes[1][6] = int_stack + 4620;
 Libderiv->deriv_classes[1][6][6] = int_stack + 4704;
 Libderiv->dvrr_classes[1][7] = int_stack + 4788;
 Libderiv->deriv_classes[1][7][6] = int_stack + 4896;
 Libderiv->dvrr_classes[1][8] = int_stack + 5004;
 Libderiv->deriv_classes[1][8][6] = int_stack + 5139;
 Libderiv->dvrr_classes[1][9] = int_stack + 5274;
 Libderiv->deriv_classes[1][9][6] = int_stack + 5439;
 Libderiv->dvrr_classes[1][10] = int_stack + 5604;
 Libderiv->deriv_classes[1][10][6] = int_stack + 5802;
 Libderiv->deriv_classes[1][11][6] = int_stack + 6000;
 Libderiv->deriv_classes[1][6][2] = int_stack + 6234;
 Libderiv->deriv_classes[1][7][2] = int_stack + 6318;
 Libderiv->deriv_classes[1][8][2] = int_stack + 6426;
 Libderiv->deriv_classes[1][9][2] = int_stack + 6561;
 Libderiv->deriv_classes[1][10][2] = int_stack + 6726;
 Libderiv->deriv_classes[1][11][2] = int_stack + 6924;
 Libderiv->deriv_classes[1][6][1] = int_stack + 7158;
 Libderiv->deriv_classes[1][7][1] = int_stack + 7242;
 Libderiv->deriv_classes[1][8][1] = int_stack + 7350;
 Libderiv->deriv_classes[1][9][1] = int_stack + 7485;
 Libderiv->deriv_classes[1][10][1] = int_stack + 7650;
 Libderiv->deriv_classes[1][11][1] = int_stack + 7848;
 Libderiv->deriv_classes[1][6][0] = int_stack + 8082;
 Libderiv->deriv_classes[1][7][0] = int_stack + 8166;
 Libderiv->deriv_classes[1][8][0] = int_stack + 8274;
 Libderiv->deriv_classes[1][9][0] = int_stack + 8409;
 Libderiv->deriv_classes[1][10][0] = int_stack + 8574;
 Libderiv->deriv_classes[1][11][0] = int_stack + 8772;
 memset(int_stack,0,72048);

 Libderiv->dvrr_stack = int_stack + 33843;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_p0ih(Libderiv, Data);
   Data++;
 }

 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9006,int_stack+4788,int_stack+4620,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9258,int_stack+5004,int_stack+4788,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9582,int_stack+9258,int_stack+9006,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+10086,int_stack+5274,int_stack+5004,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+10491,int_stack+10086,int_stack+9258,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+11139,int_stack+10491,int_stack+9582,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+11979,int_stack+5604,int_stack+5274,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+12474,int_stack+11979,int_stack+10086,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+13284,int_stack+12474,int_stack+10491,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+14364,int_stack+13284,int_stack+11139,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15624,int_stack+84,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4620,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15876,int_stack+192,int_stack+84, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4788,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+16200,int_stack+15876,int_stack+15624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9006,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+16704,int_stack+327,int_stack+192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5004,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+17109,int_stack+16704,int_stack+15876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9258,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17757,int_stack+17109,int_stack+16200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9582,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15624,int_stack+492,int_stack+327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5274,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+18597,int_stack+15624,int_stack+16704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10086,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+19407,int_stack+18597,int_stack+17109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10491,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+16119,int_stack+19407,int_stack+17757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11139,3);
 /*--- compute (p0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+17379,int_stack+690,int_stack+492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5604,3);
 /*--- compute (p0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+20487,int_stack+17379,int_stack+15624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11979,3);
 /*--- compute (p0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+21477,int_stack+20487,int_stack+18597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12474,3);
 /*--- compute (p0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+17379,int_stack+21477,int_stack+19407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13284,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15624,int_stack+1008,int_stack+924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4620, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+18999,int_stack+1116,int_stack+1008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4788, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+19323,int_stack+18999,int_stack+15624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9006, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+15624,int_stack+1251,int_stack+1116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5004, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+19827,int_stack+15624,int_stack+18999, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9258, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+20475,int_stack+19827,int_stack+19323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9582, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+18999,int_stack+1416,int_stack+1251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5274, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+21315,int_stack+18999,int_stack+15624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10086, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+21315,int_stack+19827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10491, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+22125,int_stack+0,int_stack+20475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11139, 0.0, zero_stack,3);
 /*--- compute (p0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+19494,int_stack+1614,int_stack+1416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5604, 0.0, zero_stack,3);
 /*--- compute (p0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+20088,int_stack+19494,int_stack+18999, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11979, 0.0, zero_stack,3);
 /*--- compute (p0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+23385,int_stack+20088,int_stack+21315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12474, 0.0, zero_stack,3);
 /*--- compute (p0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+18999,int_stack+23385,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13284, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+1932,int_stack+1848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4620, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+252,int_stack+2040,int_stack+1932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4788, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+576,int_stack+252,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9006, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1080,int_stack+2175,int_stack+2040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5004, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1485,int_stack+1080,int_stack+252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9258, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+23385,int_stack+1485,int_stack+576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9582, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15624,int_stack+2340,int_stack+2175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5274, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+15624,int_stack+1080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10086, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+20619,int_stack+0,int_stack+1485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10491, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+810,int_stack+20619,int_stack+23385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11139, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+23385,int_stack+2538,int_stack+2340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5604, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+23979,int_stack+23385,int_stack+15624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11979, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+24969,int_stack+23979,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12474, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+26319,int_stack+24969,int_stack+20619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13284, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+20619,int_stack+2856,int_stack+2772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+20871,int_stack+2964,int_stack+2856, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+21195,int_stack+20871,int_stack+20619, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+21699,int_stack+3099,int_stack+2964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+21699,int_stack+20871, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+23385,int_stack+0,int_stack+21195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15624,int_stack+3264,int_stack+3099, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+20619,int_stack+15624,int_stack+21699, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+24225,int_stack+20619,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+27939,int_stack+24225,int_stack+23385, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+23385,int_stack+3462,int_stack+3264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+25305,int_stack+23385,int_stack+15624, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2070,int_stack+25305,int_stack+20619, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+29199,int_stack+2070,int_stack+24225, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2070,int_stack+3780,int_stack+3696, 0.0, zero_stack, 1.0, int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2322,int_stack+3888,int_stack+3780, 0.0, zero_stack, 1.0, int_stack+4788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2646,int_stack+2322,int_stack+2070, 0.0, zero_stack, 1.0, int_stack+9006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3150,int_stack+4023,int_stack+3888, 0.0, zero_stack, 1.0, int_stack+5004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+20619,int_stack+3150,int_stack+2322, 0.0, zero_stack, 1.0, int_stack+9258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+21267,int_stack+20619,int_stack+2646, 0.0, zero_stack, 1.0, int_stack+9582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15624,int_stack+4188,int_stack+4023, 0.0, zero_stack, 1.0, int_stack+5274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+15624,int_stack+3150, 0.0, zero_stack, 1.0, int_stack+10086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2070,int_stack+0,int_stack+20619, 0.0, zero_stack, 1.0, int_stack+10491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+23385,int_stack+2070,int_stack+21267, 0.0, zero_stack, 1.0, int_stack+11139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+20619,int_stack+4386,int_stack+4188, 0.0, zero_stack, 1.0, int_stack+5604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+3150,int_stack+20619,int_stack+15624, 0.0, zero_stack, 1.0, int_stack+11979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+20619,int_stack+3150,int_stack+0, 0.0, zero_stack, 1.0, int_stack+12474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+24645,int_stack+20619,int_stack+2070, 0.0, zero_stack, 1.0, int_stack+13284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2070,int_stack+4896,int_stack+4704, 1.0, int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2322,int_stack+5139,int_stack+4896, 1.0, int_stack+4788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2646,int_stack+2322,int_stack+2070, 1.0, int_stack+9006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3150,int_stack+5439,int_stack+5139, 1.0, int_stack+5004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3555,int_stack+3150,int_stack+2322, 1.0, int_stack+9258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4203,int_stack+3555,int_stack+2646, 1.0, int_stack+9582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15624,int_stack+5802,int_stack+5439, 1.0, int_stack+5274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+15624,int_stack+3150, 1.0, int_stack+10086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+9006,int_stack+0,int_stack+3555, 1.0, int_stack+10491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2070,int_stack+9006,int_stack+4203, 1.0, int_stack+11139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+10086,int_stack+6000,int_stack+5802, 1.0, int_stack+5604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+10680,int_stack+10086,int_stack+15624, 1.0, int_stack+11979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+3330,int_stack+10680,int_stack+0, 1.0, int_stack+12474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+10086,int_stack+3330,int_stack+9006, 1.0, int_stack+13284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9006,int_stack+6318,int_stack+6234,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9258,int_stack+6426,int_stack+6318,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9582,int_stack+9258,int_stack+9006,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3330,int_stack+6561,int_stack+6426,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3735,int_stack+3330,int_stack+9258,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4383,int_stack+3735,int_stack+9582,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+15624,int_stack+6726,int_stack+6561,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+15624,int_stack+3330,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+9006,int_stack+0,int_stack+3735,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5223,int_stack+9006,int_stack+4383,3);
 /*--- compute (p0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3330,int_stack+6924,int_stack+6726,3);
 /*--- compute (p0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3924,int_stack+3330,int_stack+15624,3);
 /*--- compute (p0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+11706,int_stack+3924,int_stack+0,3);
 /*--- compute (p0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3330,int_stack+11706,int_stack+9006,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9006,int_stack+7242,int_stack+7158,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9258,int_stack+7350,int_stack+7242,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9582,int_stack+9258,int_stack+9006,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+11706,int_stack+7485,int_stack+7350,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+12111,int_stack+11706,int_stack+9258,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+12759,int_stack+12111,int_stack+9582,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+15624,int_stack+7650,int_stack+7485,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+15624,int_stack+11706,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+9006,int_stack+0,int_stack+12111,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+20619,int_stack+9006,int_stack+12759,3);
 /*--- compute (p0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+11706,int_stack+7848,int_stack+7650,3);
 /*--- compute (p0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+12300,int_stack+11706,int_stack+15624,3);
 /*--- compute (p0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+6483,int_stack+12300,int_stack+0,3);
 /*--- compute (p0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+11706,int_stack+6483,int_stack+9006,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9006,int_stack+8166,int_stack+8082,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9258,int_stack+8274,int_stack+8166,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9582,int_stack+9258,int_stack+9006,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6483,int_stack+8409,int_stack+8274,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6888,int_stack+6483,int_stack+9258,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7536,int_stack+6888,int_stack+9582,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+15624,int_stack+8574,int_stack+8409,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+15624,int_stack+6483,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+9006,int_stack+0,int_stack+6888,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+30819,int_stack+9006,int_stack+7536,3);
 /*--- compute (p0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+6483,int_stack+8772,int_stack+8574,3);
 /*--- compute (p0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+7077,int_stack+6483,int_stack+15624,3);
 /*--- compute (p0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+32079,int_stack+7077,int_stack+0,3);
 /*--- compute (p0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+6483,int_stack+32079,int_stack+9006,3);
 /*--- compute (p0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+32079,int_stack+17379,int_stack+16119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14364,3);
     Libderiv->ABCD[11] = int_stack + 32079;
 /*--- compute (p0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+15624,int_stack+18999,int_stack+22125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14364, 0.0, zero_stack,3);
     Libderiv->ABCD[10] = int_stack + 15624;
 /*--- compute (p0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+17388,int_stack+26319,int_stack+810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14364, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[9] = int_stack + 17388;
 /*--- compute (p0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+0,int_stack+29199,int_stack+27939, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (p0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+8103,int_stack+24645,int_stack+23385, 0.0, zero_stack, 1.0, int_stack+14364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[7] = int_stack + 8103;
 /*--- compute (p0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+21879,int_stack+10086,int_stack+2070, 1.0, int_stack+14364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
     Libderiv->ABCD[6] = int_stack + 21879;
 /*--- compute (p0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+9867,int_stack+3330,int_stack+5223,3);
     Libderiv->ABCD[2] = int_stack + 9867;
 /*--- compute (p0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1764,int_stack+11706,int_stack+20619,3);
     Libderiv->ABCD[1] = int_stack + 1764;
 /*--- compute (p0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3528,int_stack+6483,int_stack+30819,3);
     Libderiv->ABCD[0] = int_stack + 3528;

}
