/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_dpgp(Libr12_t *, prim_data *);

  /* Computes (dp|gp) integrals for linear R12-methods */

void hrr_grt_order_dpgp(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][4] = int_stack + 0;
 Libr12->t2vrr_classes[2][5] = int_stack + 90;
 Libr12->gvrr_classes[4][4] = int_stack + 216;
 Libr12->t2vrr_classes[3][4] = int_stack + 441;
 Libr12->t2vrr_classes[3][5] = int_stack + 591;
 Libr12->gvrr_classes[2][6] = int_stack + 801;
 Libr12->t1vrr_classes[2][4] = int_stack + 969;
 Libr12->t1vrr_classes[2][5] = int_stack + 1059;
 Libr12->t1vrr_classes[3][4] = int_stack + 1185;
 Libr12->t1vrr_classes[3][5] = int_stack + 1335;
 Libr12->rvrr_classes[2][4] = int_stack + 1545;
 Libr12->rvrr_classes[2][5] = int_stack + 1635;
 Libr12->rvrr_classes[3][4] = int_stack + 1761;
 Libr12->rvrr_classes[3][5] = int_stack + 1911;
 Libr12->gvrr_classes[2][4] = int_stack + 2121;
 Libr12->gvrr_classes[2][5] = int_stack + 2211;
 Libr12->gvrr_classes[3][4] = int_stack + 2337;
 Libr12->gvrr_classes[3][5] = int_stack + 2487;
 memset(int_stack,0,2697*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 2697;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_dpgp(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2697, int_stack+90, int_stack+0, int_stack+2211, int_stack+2337, int_stack+2121, 2, 0);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2967, int_stack+591, int_stack+441, int_stack+2487, int_stack+216, int_stack+2337, 3, 0);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+2211, int_stack+2121, 6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+270, int_stack+801, int_stack+2211, 6);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3417, int_stack+2487, int_stack+2337, 10);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+2121, int_stack+1059, int_stack+969, 6);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+648, int_stack+1335, int_stack+1185, 10);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+2391, int_stack+1635, int_stack+1545, 6);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1098, int_stack+1911, int_stack+1761, 10);
 /*--- compute (dp|[r12,T2]|gp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+3867, int_stack+2967, int_stack+2697, 45);
     Libr12->te_ptr[3] = int_stack + 3867;
 /*--- compute (dp|[r12,T1]|gp) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+4677, int_stack+648, int_stack+2121, int_stack+3417, int_stack+270, int_stack+0, 4, 1);
     Libr12->te_ptr[2] = int_stack + 4677;
 /*--- compute (dp||gp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+270, int_stack+1098, int_stack+2391, 45);
     Libr12->te_ptr[1] = int_stack + 270;
 /*--- compute (dp|gp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+1080, int_stack+3417, int_stack+0, 45);
     Libr12->te_ptr[0] = int_stack + 1080;

}
