/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fdhg(Libr12_t *, prim_data *);

  /* Computes (fd|hg) integrals for linear R12-methods */

void hrr_grt_order_fdhg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][5] = int_stack + 0;
 Libr12->t2vrr_classes[3][6] = int_stack + 210;
 Libr12->t2vrr_classes[3][7] = int_stack + 490;
 Libr12->t2vrr_classes[3][8] = int_stack + 850;
 Libr12->t2vrr_classes[3][9] = int_stack + 1300;
 Libr12->t2vrr_classes[4][5] = int_stack + 1850;
 Libr12->t2vrr_classes[4][6] = int_stack + 2165;
 Libr12->t2vrr_classes[4][7] = int_stack + 2585;
 Libr12->t2vrr_classes[4][8] = int_stack + 3125;
 Libr12->t2vrr_classes[4][9] = int_stack + 3800;
 Libr12->gvrr_classes[6][5] = int_stack + 4625;
 Libr12->t2vrr_classes[5][5] = int_stack + 5213;
 Libr12->gvrr_classes[6][6] = int_stack + 5654;
 Libr12->t2vrr_classes[5][6] = int_stack + 6438;
 Libr12->gvrr_classes[6][7] = int_stack + 7026;
 Libr12->t2vrr_classes[5][7] = int_stack + 8034;
 Libr12->gvrr_classes[6][8] = int_stack + 8790;
 Libr12->t2vrr_classes[5][8] = int_stack + 10050;
 Libr12->t2vrr_classes[5][9] = int_stack + 10995;
 Libr12->gvrr_classes[3][10] = int_stack + 12150;
 Libr12->t1vrr_classes[3][5] = int_stack + 12810;
 Libr12->t1vrr_classes[3][6] = int_stack + 13020;
 Libr12->t1vrr_classes[3][7] = int_stack + 13300;
 Libr12->t1vrr_classes[3][8] = int_stack + 13660;
 Libr12->t1vrr_classes[3][9] = int_stack + 14110;
 Libr12->gvrr_classes[4][10] = int_stack + 14660;
 Libr12->t1vrr_classes[4][5] = int_stack + 15650;
 Libr12->t1vrr_classes[4][6] = int_stack + 15965;
 Libr12->t1vrr_classes[4][7] = int_stack + 16385;
 Libr12->t1vrr_classes[4][8] = int_stack + 16925;
 Libr12->t1vrr_classes[4][9] = int_stack + 17600;
 Libr12->t1vrr_classes[5][5] = int_stack + 18425;
 Libr12->t1vrr_classes[5][6] = int_stack + 18866;
 Libr12->t1vrr_classes[5][7] = int_stack + 19454;
 Libr12->t1vrr_classes[5][8] = int_stack + 20210;
 Libr12->t1vrr_classes[5][9] = int_stack + 21155;
 Libr12->rvrr_classes[3][5] = int_stack + 22310;
 Libr12->rvrr_classes[3][6] = int_stack + 22520;
 Libr12->rvrr_classes[3][7] = int_stack + 22800;
 Libr12->rvrr_classes[3][8] = int_stack + 23160;
 Libr12->rvrr_classes[3][9] = int_stack + 23610;
 Libr12->rvrr_classes[4][5] = int_stack + 24160;
 Libr12->rvrr_classes[4][6] = int_stack + 24475;
 Libr12->rvrr_classes[4][7] = int_stack + 24895;
 Libr12->rvrr_classes[4][8] = int_stack + 25435;
 Libr12->rvrr_classes[4][9] = int_stack + 26110;
 Libr12->rvrr_classes[5][5] = int_stack + 26935;
 Libr12->rvrr_classes[5][6] = int_stack + 27376;
 Libr12->rvrr_classes[5][7] = int_stack + 27964;
 Libr12->rvrr_classes[5][8] = int_stack + 28720;
 Libr12->rvrr_classes[5][9] = int_stack + 29665;
 Libr12->gvrr_classes[3][5] = int_stack + 30820;
 Libr12->gvrr_classes[3][6] = int_stack + 31030;
 Libr12->gvrr_classes[3][7] = int_stack + 31310;
 Libr12->gvrr_classes[3][8] = int_stack + 31670;
 Libr12->gvrr_classes[3][9] = int_stack + 32120;
 Libr12->gvrr_classes[4][5] = int_stack + 32670;
 Libr12->gvrr_classes[4][6] = int_stack + 32985;
 Libr12->gvrr_classes[4][7] = int_stack + 33405;
 Libr12->gvrr_classes[4][8] = int_stack + 33945;
 Libr12->gvrr_classes[4][9] = int_stack + 34620;
 Libr12->gvrr_classes[5][5] = int_stack + 35445;
 Libr12->gvrr_classes[5][6] = int_stack + 35886;
 Libr12->gvrr_classes[5][7] = int_stack + 36474;
 Libr12->gvrr_classes[5][8] = int_stack + 37230;
 Libr12->gvrr_classes[5][9] = int_stack + 38175;
 memset(int_stack,0,39330*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 39330;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fdhg(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+39330, int_stack+31030, int_stack+30820, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+39960, int_stack+31310, int_stack+31030, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+40800, int_stack+39960, int_stack+39330, 10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+42060, int_stack+31670, int_stack+31310, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+43140, int_stack+42060, int_stack+39960, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+44820, int_stack+43140, int_stack+40800, 10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+46920, int_stack+32985, int_stack+32670, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+47865, int_stack+33405, int_stack+32985, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+49125, int_stack+47865, int_stack+46920, 15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+51015, int_stack+33945, int_stack+33405, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+52635, int_stack+51015, int_stack+47865, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+55155, int_stack+52635, int_stack+49125, 15);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+58305, int_stack+32120, int_stack+31670, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+59655, int_stack+58305, int_stack+42060, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+61815, int_stack+59655, int_stack+43140, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+64615, int_stack+210, int_stack+0, int_stack+31030, int_stack+32670, int_stack+30820, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+65245, int_stack+490, int_stack+210, int_stack+31310, int_stack+32985, int_stack+31030, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+66085, int_stack+65245, int_stack+64615, int_stack+39960, int_stack+46920, int_stack+39330, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+67345, int_stack+850, int_stack+490, int_stack+31670, int_stack+33405, int_stack+31310, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+68425, int_stack+67345, int_stack+65245, int_stack+42060, int_stack+47865, int_stack+39960, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+70105, int_stack+68425, int_stack+66085, int_stack+43140, int_stack+49125, int_stack+40800, 3, 0);
 /*--- compute (f0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+39330, int_stack+1300, int_stack+850, int_stack+32120, int_stack+33945, int_stack+31670, 3, 0);
 /*--- compute (f0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+64615, int_stack+39330, int_stack+67345, int_stack+58305, int_stack+51015, int_stack+42060, 3, 0);
 /*--- compute (f0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+39330, int_stack+64615, int_stack+68425, int_stack+59655, int_stack+52635, int_stack+43140, 3, 0);
 /*--- compute (f0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+64615, int_stack+39330, int_stack+70105, int_stack+61815, int_stack+55155, int_stack+44820, 3, 0);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+39330, int_stack+35886, int_stack+35445, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+40653, int_stack+36474, int_stack+35886, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+67765, int_stack+40653, int_stack+39330, 21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+42417, int_stack+37230, int_stack+36474, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+70411, int_stack+42417, int_stack+40653, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+73939, int_stack+70411, int_stack+67765, 21);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+78349, int_stack+34620, int_stack+33945, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+80374, int_stack+78349, int_stack+51015, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+83614, int_stack+80374, int_stack+52635, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30820, int_stack+2165, int_stack+1850, int_stack+32985, int_stack+35445, int_stack+32670, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2585, int_stack+2165, int_stack+33405, int_stack+35886, int_stack+32985, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+87814, int_stack+0, int_stack+30820, int_stack+47865, int_stack+39330, int_stack+46920, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+89704, int_stack+3125, int_stack+2585, int_stack+33945, int_stack+36474, int_stack+33405, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+91324, int_stack+89704, int_stack+0, int_stack+51015, int_stack+40653, int_stack+47865, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+93844, int_stack+91324, int_stack+87814, int_stack+52635, int_stack+67765, int_stack+49125, 4, 0);
 /*--- compute (g0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+3800, int_stack+3125, int_stack+34620, int_stack+37230, int_stack+33945, 4, 0);
 /*--- compute (g0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+46920, int_stack+0, int_stack+89704, int_stack+78349, int_stack+42417, int_stack+51015, 4, 0);
 /*--- compute (g0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+46920, int_stack+91324, int_stack+80374, int_stack+70411, int_stack+52635, 4, 0);
 /*--- compute (g0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+46920, int_stack+0, int_stack+93844, int_stack+83614, int_stack+73939, int_stack+55155, 4, 0);
 /*--- compute (fp|[r12,T2]|hg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+87814, int_stack+46920, int_stack+64615, 315);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+64615, int_stack+5654, int_stack+4625, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+7026, int_stack+5654, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+97264, int_stack+0, int_stack+64615, 28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+51645, int_stack+8790, int_stack+7026, 28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+100792, int_stack+51645, int_stack+0, 28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+105496, int_stack+100792, int_stack+97264, 28);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+111376, int_stack+38175, int_stack+37230, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+114211, int_stack+111376, int_stack+42417, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+118747, int_stack+114211, int_stack+70411, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+66379, int_stack+6438, int_stack+5213, int_stack+35886, int_stack+4625, int_stack+35445, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2352, int_stack+8034, int_stack+6438, int_stack+36474, int_stack+5654, int_stack+35886, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4116, int_stack+2352, int_stack+66379, int_stack+40653, int_stack+64615, int_stack+39330, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+64615, int_stack+10050, int_stack+8034, int_stack+37230, int_stack+7026, int_stack+36474, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+124627, int_stack+64615, int_stack+2352, int_stack+42417, int_stack+0, int_stack+40653, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+128155, int_stack+124627, int_stack+4116, int_stack+70411, int_stack+97264, int_stack+67765, 5, 0);
 /*--- compute (h0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+97264, int_stack+10995, int_stack+10050, int_stack+38175, int_stack+8790, int_stack+37230, 5, 0);
 /*--- compute (h0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+97264, int_stack+64615, int_stack+111376, int_stack+51645, int_stack+42417, 5, 0);
 /*--- compute (h0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4536, int_stack+0, int_stack+124627, int_stack+114211, int_stack+100792, int_stack+70411, 5, 0);
 /*--- compute (h0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+111376, int_stack+4536, int_stack+128155, int_stack+118747, int_stack+105496, int_stack+73939, 5, 0);
 /*--- compute (gp|[r12,T2]|hg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+124627, int_stack+111376, int_stack+46920, 315);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+46920, int_stack+61815, int_stack+44820, 10);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+50070, int_stack+83614, int_stack+55155, 15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+50070, int_stack+46920, 315);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+54795, int_stack+12150, int_stack+32120, 10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+9450, int_stack+54795, int_stack+58305, 10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+54795, int_stack+9450, int_stack+59655, 10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+64615, int_stack+54795, int_stack+61815, 10);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+54795, int_stack+14660, int_stack+34620, 15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+57270, int_stack+54795, int_stack+78349, 15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+97264, int_stack+57270, int_stack+80374, 15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+54795, int_stack+97264, int_stack+83614, 15);
 /*--- compute (fp|ig) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+97264, int_stack+54795, int_stack+64615, 420);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+109864, int_stack+118747, int_stack+73939, 21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+68815, int_stack+109864, int_stack+50070, 315);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+116479, int_stack+13020, int_stack+12810, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+117109, int_stack+13300, int_stack+13020, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+117949, int_stack+117109, int_stack+116479, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+119209, int_stack+13660, int_stack+13300, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+120289, int_stack+119209, int_stack+117109, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+121969, int_stack+120289, int_stack+117949, 10);
 /*--- compute (f0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+116479, int_stack+14110, int_stack+13660, 10);
 /*--- compute (f0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+61095, int_stack+116479, int_stack+119209, 10);
 /*--- compute (f0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+116479, int_stack+61095, int_stack+120289, 10);
 /*--- compute (f0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+61095, int_stack+116479, int_stack+121969, 10);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+116479, int_stack+15965, int_stack+15650, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+117424, int_stack+16385, int_stack+15965, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+118684, int_stack+117424, int_stack+116479, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+120574, int_stack+16925, int_stack+16385, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+9450, int_stack+120574, int_stack+117424, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+11970, int_stack+9450, int_stack+118684, 15);
 /*--- compute (g0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+116479, int_stack+17600, int_stack+16925, 15);
 /*--- compute (g0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+15120, int_stack+116479, int_stack+120574, 15);
 /*--- compute (g0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+116479, int_stack+15120, int_stack+9450, 15);
 /*--- compute (g0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+82990, int_stack+116479, int_stack+11970, 15);
 /*--- compute (fp|[r12,T1]|hg) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+30820, int_stack+82990, int_stack+61095, int_stack+50070, int_stack+64615, int_stack+46920, 5, 4);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+61095, int_stack+18866, int_stack+18425, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+62418, int_stack+19454, int_stack+18866, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+64182, int_stack+62418, int_stack+61095, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+116479, int_stack+20210, int_stack+19454, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+118747, int_stack+116479, int_stack+62418, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+9450, int_stack+118747, int_stack+64182, 21);
 /*--- compute (h0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+61095, int_stack+21155, int_stack+20210, 21);
 /*--- compute (h0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+63930, int_stack+61095, int_stack+116479, 21);
 /*--- compute (h0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+13860, int_stack+63930, int_stack+118747, 21);
 /*--- compute (h0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+116479, int_stack+13860, int_stack+9450, 21);
 /*--- compute (gp|[r12,T1]|hg) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+138802, int_stack+116479, int_stack+82990, int_stack+109864, int_stack+54795, int_stack+50070, 5, 4);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+109864, int_stack+22520, int_stack+22310, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+110494, int_stack+22800, int_stack+22520, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+111334, int_stack+110494, int_stack+109864, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+112594, int_stack+23160, int_stack+22800, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+113674, int_stack+112594, int_stack+110494, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+115354, int_stack+113674, int_stack+111334, 10);
 /*--- compute (f0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+109864, int_stack+23610, int_stack+23160, 10);
 /*--- compute (f0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+117454, int_stack+109864, int_stack+112594, 10);
 /*--- compute (f0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+109864, int_stack+117454, int_stack+113674, 10);
 /*--- compute (f0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+117454, int_stack+109864, int_stack+115354, 10);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+109864, int_stack+24475, int_stack+24160, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+110809, int_stack+24895, int_stack+24475, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+112069, int_stack+110809, int_stack+109864, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+113959, int_stack+25435, int_stack+24895, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+120604, int_stack+113959, int_stack+110809, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+82990, int_stack+120604, int_stack+112069, 15);
 /*--- compute (g0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+109864, int_stack+26110, int_stack+25435, 15);
 /*--- compute (g0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+9450, int_stack+109864, int_stack+113959, 15);
 /*--- compute (g0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+109864, int_stack+9450, int_stack+120604, 15);
 /*--- compute (g0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+9450, int_stack+109864, int_stack+82990, 15);
 /*--- compute (fp||hg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+14175, int_stack+9450, int_stack+117454, 315);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+82990, int_stack+27376, int_stack+26935, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+84313, int_stack+27964, int_stack+27376, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+109864, int_stack+84313, int_stack+82990, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+112510, int_stack+28720, int_stack+27964, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+114778, int_stack+112510, int_stack+84313, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+82990, int_stack+114778, int_stack+109864, 21);
 /*--- compute (h0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+118306, int_stack+29665, int_stack+28720, 21);
 /*--- compute (h0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+23625, int_stack+118306, int_stack+112510, 21);
 /*--- compute (h0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+118306, int_stack+23625, int_stack+114778, 21);
 /*--- compute (h0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+23625, int_stack+118306, int_stack+82990, 21);
 /*--- compute (gp||hg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+109864, int_stack+23625, int_stack+9450, 315);
 /*--- compute (fd|[r12,T2]|hg) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+40270, int_stack+124627, int_stack+87814, 315);
     Libr12->te_ptr[3] = int_stack + 40270;
 /*--- compute (fd|[r12,T1]|hg) ---*/
   t1hrr1_build_fd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+152977, int_stack+138802, int_stack+30820, int_stack+68815, int_stack+97264, int_stack+0, 5, 4);
     Libr12->te_ptr[2] = int_stack + 152977;
 /*--- compute (fd||hg) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+82990, int_stack+109864, int_stack+14175, 315);
     Libr12->te_ptr[1] = int_stack + 82990;
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+9450, int_stack+68815, int_stack+0, 315);
     Libr12->te_ptr[0] = int_stack + 9450;

}
