/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ppdp(Libr12_t *, prim_data *);

  /* Computes (pp|dp) integrals for linear R12-methods */

void hrr_grt_order_ppdp(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[1][2] = int_stack + 0;
 Libr12->t2vrr_classes[1][3] = int_stack + 18;
 Libr12->gvrr_classes[3][2] = int_stack + 48;
 Libr12->t2vrr_classes[2][2] = int_stack + 108;
 Libr12->t2vrr_classes[2][3] = int_stack + 144;
 Libr12->gvrr_classes[1][4] = int_stack + 204;
 Libr12->t1vrr_classes[1][2] = int_stack + 249;
 Libr12->t1vrr_classes[1][3] = int_stack + 267;
 Libr12->t1vrr_classes[2][2] = int_stack + 297;
 Libr12->t1vrr_classes[2][3] = int_stack + 333;
 Libr12->rvrr_classes[1][2] = int_stack + 393;
 Libr12->rvrr_classes[1][3] = int_stack + 411;
 Libr12->rvrr_classes[2][2] = int_stack + 441;
 Libr12->rvrr_classes[2][3] = int_stack + 477;
 Libr12->gvrr_classes[1][2] = int_stack + 537;
 Libr12->gvrr_classes[1][3] = int_stack + 555;
 Libr12->gvrr_classes[2][2] = int_stack + 585;
 Libr12->gvrr_classes[2][3] = int_stack + 621;
 memset(int_stack,0,681*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 681;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ppdp(Libr12, Data);
   Data++;
 }

 /*--- compute (p0|[r12,T2]|dp) ---*/
   t2hrr3_build_dp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+681, int_stack+18, int_stack+0, int_stack+555, int_stack+585, int_stack+537, 1, 0);
 /*--- compute (d0|[r12,T2]|dp) ---*/
   t2hrr3_build_dp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+735, int_stack+144, int_stack+108, int_stack+621, int_stack+48, int_stack+585, 2, 0);
 /*--- compute (p0|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+555, int_stack+537, 3);
 /*--- compute (p0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+54, int_stack+204, int_stack+555, 3);
 /*--- compute (d0|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+843, int_stack+621, int_stack+585, 6);
 /*--- compute (p0|[r12,T1]|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+537, int_stack+267, int_stack+249, 3);
 /*--- compute (d0|[r12,T1]|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+144, int_stack+333, int_stack+297, 6);
 /*--- compute (p0||dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+591, int_stack+411, int_stack+393, 3);
 /*--- compute (d0||dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+252, int_stack+477, int_stack+441, 6);
 /*--- compute (pp|[r12,T2]|dp) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+360, int_stack+735, int_stack+681, 18);
     Libr12->te_ptr[3] = int_stack + 360;
 /*--- compute (pp|[r12,T1]|dp) ---*/
   t1hrr1_build_pp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+645, int_stack+144, int_stack+537, int_stack+843, int_stack+54, int_stack+0, 2, 1);
     Libr12->te_ptr[2] = int_stack + 645;
 /*--- compute (pp||dp) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+54, int_stack+252, int_stack+591, 18);
     Libr12->te_ptr[1] = int_stack + 54;
 /*--- compute (pp|dp) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+951, int_stack+843, int_stack+0, 18);
     Libr12->te_ptr[0] = int_stack + 951;

}
