/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ppgd(Libr12_t *, prim_data *);

  /* Computes (pp|gd) integrals for linear R12-methods */

void hrr_grt_order_ppgd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[1][4] = int_stack + 0;
 Libr12->t2vrr_classes[1][5] = int_stack + 45;
 Libr12->t2vrr_classes[1][6] = int_stack + 108;
 Libr12->gvrr_classes[3][4] = int_stack + 192;
 Libr12->t2vrr_classes[2][4] = int_stack + 342;
 Libr12->gvrr_classes[3][5] = int_stack + 432;
 Libr12->t2vrr_classes[2][5] = int_stack + 642;
 Libr12->t2vrr_classes[2][6] = int_stack + 768;
 Libr12->gvrr_classes[1][7] = int_stack + 936;
 Libr12->t1vrr_classes[1][4] = int_stack + 1044;
 Libr12->t1vrr_classes[1][5] = int_stack + 1089;
 Libr12->t1vrr_classes[1][6] = int_stack + 1152;
 Libr12->t1vrr_classes[2][4] = int_stack + 1236;
 Libr12->t1vrr_classes[2][5] = int_stack + 1326;
 Libr12->t1vrr_classes[2][6] = int_stack + 1452;
 Libr12->rvrr_classes[1][4] = int_stack + 1620;
 Libr12->rvrr_classes[1][5] = int_stack + 1665;
 Libr12->rvrr_classes[1][6] = int_stack + 1728;
 Libr12->rvrr_classes[2][4] = int_stack + 1812;
 Libr12->rvrr_classes[2][5] = int_stack + 1902;
 Libr12->rvrr_classes[2][6] = int_stack + 2028;
 Libr12->gvrr_classes[1][4] = int_stack + 2196;
 Libr12->gvrr_classes[1][5] = int_stack + 2241;
 Libr12->gvrr_classes[1][6] = int_stack + 2304;
 Libr12->gvrr_classes[2][4] = int_stack + 2388;
 Libr12->gvrr_classes[2][5] = int_stack + 2478;
 Libr12->gvrr_classes[2][6] = int_stack + 2604;
 memset(int_stack,0,2772*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 2772;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ppgd(Libr12, Data);
   Data++;
 }

 /*--- compute (p0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+2772, int_stack+2241, int_stack+2196, 3);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+2907, int_stack+2478, int_stack+2388, 6);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+3177, int_stack+2304, int_stack+2241, 3);
 /*--- compute (p0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3366, int_stack+45, int_stack+0, int_stack+2241, int_stack+2388, int_stack+2196, 1, 0);
 /*--- compute (p0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3501, int_stack+108, int_stack+45, int_stack+2304, int_stack+2478, int_stack+2241, 1, 0);
 /*--- compute (p0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3690, int_stack+3501, int_stack+3366, int_stack+3177, int_stack+2907, int_stack+2772, 1, 0);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3960, int_stack+432, int_stack+192, 10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+4410, int_stack+2604, int_stack+2478, 6);
 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3366, int_stack+642, int_stack+342, int_stack+2478, int_stack+192, int_stack+2388, 2, 0);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+768, int_stack+642, int_stack+2604, int_stack+432, int_stack+2478, 2, 0);
 /*--- compute (d0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+378, int_stack+0, int_stack+3366, int_stack+4410, int_stack+3960, int_stack+2907, 2, 0);
 /*--- compute (p0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+3960, int_stack+3177, int_stack+2772, 3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+3366, int_stack+936, int_stack+2304, 3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+3366, int_stack+3177, 3);
 /*--- compute (d0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2196, int_stack+4410, int_stack+2907, 6);
 /*--- compute (p0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4230, int_stack+1089, int_stack+1044, 3);
 /*--- compute (p0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+4365, int_stack+1152, int_stack+1089, 3);
 /*--- compute (p0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+4554, int_stack+4365, int_stack+4230, 3);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4230, int_stack+1326, int_stack+1236, 6);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2736, int_stack+1452, int_stack+1326, 6);
 /*--- compute (d0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+3114, int_stack+2736, int_stack+4230, 6);
 /*--- compute (p0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4230, int_stack+1665, int_stack+1620, 3);
 /*--- compute (p0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+4365, int_stack+1728, int_stack+1665, 3);
 /*--- compute (p0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2736, int_stack+4365, int_stack+4230, 3);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4230, int_stack+1902, int_stack+1812, 6);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+918, int_stack+2028, int_stack+1902, 6);
 /*--- compute (d0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1296, int_stack+918, int_stack+4230, 6);
 /*--- compute (pp|[r12,T2]|gd) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+4824, int_stack+378, int_stack+3690, 90);
     Libr12->te_ptr[3] = int_stack + 4824;
 /*--- compute (pp|[r12,T1]|gd) ---*/
   t1hrr1_build_pp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+378, int_stack+3114, int_stack+4554, int_stack+2196, int_stack+0, int_stack+3960, 4, 2);
     Libr12->te_ptr[2] = int_stack + 378;
 /*--- compute (pp||gd) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+3006, int_stack+1296, int_stack+2736, 90);
     Libr12->te_ptr[1] = int_stack + 3006;
 /*--- compute (pp|gd) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+1188, int_stack+2196, int_stack+3960, 90);
     Libr12->te_ptr[0] = int_stack + 1188;

}
