/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ppgf(Libr12_t *, prim_data *);

  /* Computes (pp|gf) integrals for linear R12-methods */

void hrr_grt_order_ppgf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[1][4] = int_stack + 0;
 Libr12->t2vrr_classes[1][5] = int_stack + 45;
 Libr12->t2vrr_classes[1][6] = int_stack + 108;
 Libr12->t2vrr_classes[1][7] = int_stack + 192;
 Libr12->gvrr_classes[3][4] = int_stack + 300;
 Libr12->t2vrr_classes[2][4] = int_stack + 450;
 Libr12->gvrr_classes[3][5] = int_stack + 540;
 Libr12->t2vrr_classes[2][5] = int_stack + 750;
 Libr12->gvrr_classes[3][6] = int_stack + 876;
 Libr12->t2vrr_classes[2][6] = int_stack + 1156;
 Libr12->t2vrr_classes[2][7] = int_stack + 1324;
 Libr12->gvrr_classes[1][8] = int_stack + 1540;
 Libr12->t1vrr_classes[1][4] = int_stack + 1675;
 Libr12->t1vrr_classes[1][5] = int_stack + 1720;
 Libr12->t1vrr_classes[1][6] = int_stack + 1783;
 Libr12->t1vrr_classes[1][7] = int_stack + 1867;
 Libr12->t1vrr_classes[2][4] = int_stack + 1975;
 Libr12->t1vrr_classes[2][5] = int_stack + 2065;
 Libr12->t1vrr_classes[2][6] = int_stack + 2191;
 Libr12->t1vrr_classes[2][7] = int_stack + 2359;
 Libr12->rvrr_classes[1][4] = int_stack + 2575;
 Libr12->rvrr_classes[1][5] = int_stack + 2620;
 Libr12->rvrr_classes[1][6] = int_stack + 2683;
 Libr12->rvrr_classes[1][7] = int_stack + 2767;
 Libr12->rvrr_classes[2][4] = int_stack + 2875;
 Libr12->rvrr_classes[2][5] = int_stack + 2965;
 Libr12->rvrr_classes[2][6] = int_stack + 3091;
 Libr12->rvrr_classes[2][7] = int_stack + 3259;
 Libr12->gvrr_classes[1][4] = int_stack + 3475;
 Libr12->gvrr_classes[1][5] = int_stack + 3520;
 Libr12->gvrr_classes[1][6] = int_stack + 3583;
 Libr12->gvrr_classes[1][7] = int_stack + 3667;
 Libr12->gvrr_classes[2][4] = int_stack + 3775;
 Libr12->gvrr_classes[2][5] = int_stack + 3865;
 Libr12->gvrr_classes[2][6] = int_stack + 3991;
 Libr12->gvrr_classes[2][7] = int_stack + 4159;
 memset(int_stack,0,4375*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 4375;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ppgf(Libr12, Data);
   Data++;
 }

 /*--- compute (p0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4375, int_stack+3520, int_stack+3475, 3);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+4510, int_stack+3583, int_stack+3520, 3);
 /*--- compute (p0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+4699, int_stack+4510, int_stack+4375, 3);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4969, int_stack+3865, int_stack+3775, 6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+5239, int_stack+3991, int_stack+3865, 6);
 /*--- compute (d0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+5617, int_stack+5239, int_stack+4969, 6);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+6157, int_stack+3667, int_stack+3583, 3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+6409, int_stack+6157, int_stack+4510, 3);
 /*--- compute (p0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6787, int_stack+45, int_stack+0, int_stack+3520, int_stack+3775, int_stack+3475, 1, 0);
 /*--- compute (p0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6922, int_stack+108, int_stack+45, int_stack+3583, int_stack+3865, int_stack+3520, 1, 0);
 /*--- compute (p0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+7111, int_stack+6922, int_stack+6787, int_stack+4510, int_stack+4969, int_stack+4375, 1, 0);
 /*--- compute (p0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+7381, int_stack+192, int_stack+108, int_stack+3667, int_stack+3991, int_stack+3583, 1, 0);
 /*--- compute (p0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+7633, int_stack+7381, int_stack+6922, int_stack+6157, int_stack+5239, int_stack+4510, 1, 0);
 /*--- compute (p0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8011, int_stack+7633, int_stack+7111, int_stack+6409, int_stack+5617, int_stack+4699, 1, 0);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6787, int_stack+540, int_stack+300, 10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7237, int_stack+876, int_stack+540, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+8461, int_stack+7237, int_stack+6787, 10);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9361, int_stack+4159, int_stack+3991, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+9865, int_stack+9361, int_stack+5239, 6);
 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4375, int_stack+750, int_stack+450, int_stack+3865, int_stack+300, int_stack+3775, 2, 0);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1156, int_stack+750, int_stack+3991, int_stack+540, int_stack+3865, 2, 0);
 /*--- compute (d0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10621, int_stack+0, int_stack+4375, int_stack+5239, int_stack+6787, int_stack+4969, 2, 0);
 /*--- compute (d0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+11161, int_stack+1324, int_stack+1156, int_stack+4159, int_stack+876, int_stack+3991, 2, 0);
 /*--- compute (d0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3775, int_stack+11161, int_stack+0, int_stack+9361, int_stack+7237, int_stack+5239, 2, 0);
 /*--- compute (d0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+3775, int_stack+10621, int_stack+9865, int_stack+8461, int_stack+5617, 2, 0);
 /*--- compute (p0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+8461, int_stack+6409, int_stack+4699, 3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+8911, int_stack+1540, int_stack+3667, 3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+9235, int_stack+8911, int_stack+6157, 3);
 /*--- compute (p0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+10621, int_stack+9235, int_stack+6409, 3);
 /*--- compute (d0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+6157, int_stack+9865, int_stack+5617, 6);
 /*--- compute (p0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7057, int_stack+1720, int_stack+1675, 3);
 /*--- compute (p0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7192, int_stack+1783, int_stack+1720, 3);
 /*--- compute (p0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+7381, int_stack+7192, int_stack+7057, 3);
 /*--- compute (p0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+7651, int_stack+1867, int_stack+1783, 3);
 /*--- compute (p0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+8911, int_stack+7651, int_stack+7192, 3);
 /*--- compute (p0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+9289, int_stack+8911, int_stack+7381, 3);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+8911, int_stack+2065, int_stack+1975, 6);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7057, int_stack+2191, int_stack+2065, 6);
 /*--- compute (d0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+7435, int_stack+7057, int_stack+8911, 6);
 /*--- compute (d0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9739, int_stack+2359, int_stack+2191, 6);
 /*--- compute (d0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+900, int_stack+9739, int_stack+7057, 6);
 /*--- compute (d0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+1656, int_stack+900, int_stack+7435, 6);
 /*--- compute (p0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+900, int_stack+2620, int_stack+2575, 3);
 /*--- compute (p0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1035, int_stack+2683, int_stack+2620, 3);
 /*--- compute (p0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1224, int_stack+1035, int_stack+900, 3);
 /*--- compute (p0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+7057, int_stack+2767, int_stack+2683, 3);
 /*--- compute (p0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+8911, int_stack+7057, int_stack+1035, 3);
 /*--- compute (p0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+7057, int_stack+8911, int_stack+1224, 3);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+8911, int_stack+2965, int_stack+2875, 6);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7507, int_stack+3091, int_stack+2965, 6);
 /*--- compute (d0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+900, int_stack+7507, int_stack+8911, 6);
 /*--- compute (d0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9739, int_stack+3259, int_stack+3091, 6);
 /*--- compute (d0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+2556, int_stack+9739, int_stack+7507, 6);
 /*--- compute (d0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+3312, int_stack+2556, int_stack+900, 6);
 /*--- compute (pp|[r12,T2]|gf) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+4212, int_stack+0, int_stack+8011, 150);
     Libr12->te_ptr[3] = int_stack + 4212;
 /*--- compute (pp|[r12,T1]|gf) ---*/
   t1hrr1_build_pp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1656, int_stack+9289, int_stack+6157, int_stack+10621, int_stack+8461, 4, 3);
     Libr12->te_ptr[2] = int_stack + 0;
 /*--- compute (pp||gf) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+1350, int_stack+3312, int_stack+7057, 150);
     Libr12->te_ptr[1] = int_stack + 1350;
 /*--- compute (pp|gf) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+7057, int_stack+6157, int_stack+8461, 150);
     Libr12->te_ptr[0] = int_stack + 7057;

}
