/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_pphp(Libr12_t *, prim_data *);

  /* Computes (pp|hp) integrals for linear R12-methods */

void hrr_grt_order_pphp(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[1][5] = int_stack + 0;
 Libr12->t2vrr_classes[1][6] = int_stack + 63;
 Libr12->gvrr_classes[3][5] = int_stack + 147;
 Libr12->t2vrr_classes[2][5] = int_stack + 357;
 Libr12->t2vrr_classes[2][6] = int_stack + 483;
 Libr12->gvrr_classes[1][7] = int_stack + 651;
 Libr12->t1vrr_classes[1][5] = int_stack + 759;
 Libr12->t1vrr_classes[1][6] = int_stack + 822;
 Libr12->t1vrr_classes[2][5] = int_stack + 906;
 Libr12->t1vrr_classes[2][6] = int_stack + 1032;
 Libr12->rvrr_classes[1][5] = int_stack + 1200;
 Libr12->rvrr_classes[1][6] = int_stack + 1263;
 Libr12->rvrr_classes[2][5] = int_stack + 1347;
 Libr12->rvrr_classes[2][6] = int_stack + 1473;
 Libr12->gvrr_classes[1][5] = int_stack + 1641;
 Libr12->gvrr_classes[1][6] = int_stack + 1704;
 Libr12->gvrr_classes[2][5] = int_stack + 1788;
 Libr12->gvrr_classes[2][6] = int_stack + 1914;
 memset(int_stack,0,2082*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 2082;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_pphp(Libr12, Data);
   Data++;
 }

 /*--- compute (p0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2082, int_stack+63, int_stack+0, int_stack+1704, int_stack+1788, int_stack+1641, 1, 0);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2271, int_stack+483, int_stack+357, int_stack+1914, int_stack+147, int_stack+1788, 2, 0);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+1704, int_stack+1641, 3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+189, int_stack+651, int_stack+1704, 3);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2649, int_stack+1914, int_stack+1788, 6);
 /*--- compute (p0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1641, int_stack+822, int_stack+759, 3);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+441, int_stack+1032, int_stack+906, 6);
 /*--- compute (p0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1830, int_stack+1263, int_stack+1200, 3);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+819, int_stack+1473, int_stack+1347, 6);
 /*--- compute (pp|[r12,T2]|hp) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+3027, int_stack+2271, int_stack+2082, 63);
     Libr12->te_ptr[3] = int_stack + 3027;
 /*--- compute (pp|[r12,T1]|hp) ---*/
   t1hrr1_build_pp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+2019, int_stack+441, int_stack+1641, int_stack+2649, int_stack+189, int_stack+0, 5, 1);
     Libr12->te_ptr[2] = int_stack + 2019;
 /*--- compute (pp||hp) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+189, int_stack+819, int_stack+1830, 63);
     Libr12->te_ptr[1] = int_stack + 189;
 /*--- compute (pp|hp) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+756, int_stack+2649, int_stack+0, 63);
     Libr12->te_ptr[0] = int_stack + 756;

}
