/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_00dp(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (p0|p0)^0 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+0, r12vrr_stack+3, NULL, NULL, Data->F+1);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+15, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+18, r12vrr_stack+3, r12vrr_stack+15, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+0, r12vrr_stack+3, Data->F+0, Data->F+1, NULL);
 tmp = r12vrr_stack + 24;
 target_ptr = Libr12->gvrr_classes[0][2];
 for(i=0;i<6;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|d0)^0 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+30, r12vrr_stack+24, r12vrr_stack+18, NULL, NULL, r12vrr_stack+3);
 tmp = r12vrr_stack + 30;
 target_ptr = Libr12->gvrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+48, r12vrr_stack+24, r12vrr_stack+18, r12vrr_stack+0, r12vrr_stack+3, NULL);
 tmp = r12vrr_stack + 48;
 target_ptr = Libr12->gvrr_classes[0][3];
 for(i=0;i<10;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+58, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+61, r12vrr_stack+15, r12vrr_stack+58, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+67, r12vrr_stack+18, r12vrr_stack+61, r12vrr_stack+3, r12vrr_stack+15, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+77, r12vrr_stack+48, r12vrr_stack+67, NULL, NULL, r12vrr_stack+18);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+107, r12vrr_stack+48, r12vrr_stack+67, r12vrr_stack+24, r12vrr_stack+18, NULL);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+3, &(Data->ss_r12_ss), NULL, r12vrr_stack+0, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+3, &(Data->ss_r12_ss), r12vrr_stack+24, r12vrr_stack+0, Data->F+0, NULL);
 tmp = r12vrr_stack + 15;
 target_ptr = Libr12->rvrr_classes[0][2];
 for(i=0;i<6;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T2]|d0)^0 ---*/
 _T2_BUILD_00d0(Data,&(Libr12->ShellQuartet),r12vrr_stack+58, r12vrr_stack+24, r12vrr_stack+48, r12vrr_stack+30, r12vrr_stack+6, r12vrr_stack+0);
 tmp = r12vrr_stack + 58;
 target_ptr = Libr12->t2vrr_classes[0][2];
 for(i=0;i<6;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T2]|f0)^0 ---*/
 _T2_BUILD_00f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+64, r12vrr_stack+48, r12vrr_stack+107, r12vrr_stack+77, r12vrr_stack+30, r12vrr_stack+24);
 tmp = r12vrr_stack + 64;
 target_ptr = Libr12->t2vrr_classes[0][3];
 for(i=0;i<10;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T1]|d0)^0 ---*/
 _T1_BUILD_00d0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6, r12vrr_stack+24, r12vrr_stack+30, r12vrr_stack+48, NULL, NULL);
 tmp = r12vrr_stack + 6;
 target_ptr = Libr12->t1vrr_classes[0][2];
 for(i=0;i<6;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T1]|f0)^0 ---*/
 _T1_BUILD_00f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+30, r12vrr_stack+48, r12vrr_stack+77, r12vrr_stack+107, NULL, NULL);
 tmp = r12vrr_stack + 30;
 target_ptr = Libr12->t1vrr_classes[0][3];
 for(i=0;i<10;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+74, r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+48, r12vrr_stack+24, r12vrr_stack+0, NULL);
 tmp = r12vrr_stack + 74;
 target_ptr = Libr12->rvrr_classes[0][3];
 for(i=0;i<10;i++)
   target_ptr[i] += tmp[i];


}

