/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_f0ff(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (p0|00)^2 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+9, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (p0|p0)^2 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+12, r12vrr_stack+3, r12vrr_stack+9, NULL, NULL, Data->F+3);

 /*--- compute (p0|p0)^1 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+3, NULL, NULL, Data->F+2);

 /*--- compute (d0|p0)^1 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+30, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+9, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+54, r12vrr_stack+6, r12vrr_stack+3, Data->F+1, Data->F+2, NULL);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+60, r12vrr_stack+54, r12vrr_stack+48, NULL, NULL, r12vrr_stack+3);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+78, r12vrr_stack+6, Data->F+0, Data->F+1, NULL);

 /*--- compute (p0|d0)^0 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+87, r12vrr_stack+81, r12vrr_stack+54, NULL, NULL, r12vrr_stack+6);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+105, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+108, r12vrr_stack+9, r12vrr_stack+105, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+114, r12vrr_stack+48, r12vrr_stack+108, NULL, NULL, r12vrr_stack+9);

 /*--- compute (d0|d0)^1 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+132, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+12);

 /*--- compute (d0|d0)^0 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+168, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+21);

 /*--- compute (f0|d0)^0 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+204, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+30);

 /*--- compute (p0|00)^3 ---*/
 _BUILD_p000(Data,r12vrr_stack+264, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (d0|00)^2 ---*/
 _BUILD_d000(Data,r12vrr_stack+267, r12vrr_stack+0, r12vrr_stack+264, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+273, r12vrr_stack+9, r12vrr_stack+105, NULL, NULL, Data->F+4);

 /*--- compute (d0|p0)^2 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+282, r12vrr_stack+12, r12vrr_stack+273, r12vrr_stack+3, r12vrr_stack+9, r12vrr_stack+264);

 /*--- compute (f0|p0)^1 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+300, r12vrr_stack+30, r12vrr_stack+282, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+267);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+12, r12vrr_stack+105, r12vrr_stack+0, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+18, r12vrr_stack+108, r12vrr_stack+12, NULL, NULL, r12vrr_stack+105);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+330, r12vrr_stack+114, r12vrr_stack+18, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+273);

 /*--- compute (f0|d0)^1 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+366, r12vrr_stack+132, r12vrr_stack+330, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+282);

 /*--- compute (g0|d0)^0 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+426, r12vrr_stack+204, r12vrr_stack+366, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+300);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+36, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+3, r12vrr_stack+9, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+264, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+6, r12vrr_stack+3, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+274, r12vrr_stack+108, r12vrr_stack+12, r12vrr_stack+9, r12vrr_stack+105, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+284, r12vrr_stack+36, r12vrr_stack+274, NULL, NULL, r12vrr_stack+108);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+516, r12vrr_stack+264, r12vrr_stack+36, NULL, NULL, r12vrr_stack+48);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+546, r12vrr_stack+516, r12vrr_stack+284, r12vrr_stack+264, r12vrr_stack+36, r12vrr_stack+114);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+114, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+78, r12vrr_stack+6, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+606, r12vrr_stack+114, r12vrr_stack+264, NULL, NULL, r12vrr_stack+54);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+636, r12vrr_stack+606, r12vrr_stack+516, r12vrr_stack+114, r12vrr_stack+264, r12vrr_stack+60);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+60, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+63, r12vrr_stack+0, r12vrr_stack+60, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+314, r12vrr_stack+12, r12vrr_stack+63, r12vrr_stack+105, r12vrr_stack+0, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+696, r12vrr_stack+274, r12vrr_stack+314, NULL, NULL, r12vrr_stack+12);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+726, r12vrr_stack+284, r12vrr_stack+696, r12vrr_stack+36, r12vrr_stack+274, r12vrr_stack+18);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+786, r12vrr_stack+546, r12vrr_stack+726, r12vrr_stack+516, r12vrr_stack+284, r12vrr_stack+330);

 /*--- compute (f0|f0)^0 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+886, r12vrr_stack+636, r12vrr_stack+546, r12vrr_stack+606, r12vrr_stack+516, r12vrr_stack+132);
 tmp = r12vrr_stack + 886;
 target_ptr = Libr12->gvrr_classes[3][3];
 for(i=0;i<100;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|f0)^0 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+986, r12vrr_stack+886, r12vrr_stack+786, r12vrr_stack+636, r12vrr_stack+546, r12vrr_stack+366);
 tmp = r12vrr_stack + 986;
 target_ptr = Libr12->gvrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+18, r12vrr_stack+36, r12vrr_stack+274, r12vrr_stack+48, r12vrr_stack+108, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+124, r12vrr_stack+264, r12vrr_stack+36, r12vrr_stack+54, r12vrr_stack+48, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+324, r12vrr_stack+124, r12vrr_stack+18, NULL, NULL, r12vrr_stack+36);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+139, r12vrr_stack+114, r12vrr_stack+264, r12vrr_stack+81, r12vrr_stack+54, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+369, r12vrr_stack+139, r12vrr_stack+124, NULL, NULL, r12vrr_stack+264);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1136, r12vrr_stack+274, r12vrr_stack+314, r12vrr_stack+108, r12vrr_stack+12, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1151, r12vrr_stack+18, r12vrr_stack+1136, NULL, NULL, r12vrr_stack+274);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1196, r12vrr_stack+324, r12vrr_stack+1151, r12vrr_stack+124, r12vrr_stack+18, r12vrr_stack+284);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1286, r12vrr_stack+369, r12vrr_stack+324, r12vrr_stack+139, r12vrr_stack+124, r12vrr_stack+516);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1376, r12vrr_stack+1286, r12vrr_stack+1196, r12vrr_stack+369, r12vrr_stack+324, r12vrr_stack+546);
 tmp = r12vrr_stack + 1376;
 target_ptr = Libr12->gvrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+33, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+516, r12vrr_stack+60, r12vrr_stack+33, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+522, r12vrr_stack+63, r12vrr_stack+516, r12vrr_stack+0, r12vrr_stack+60, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+532, r12vrr_stack+314, r12vrr_stack+522, r12vrr_stack+12, r12vrr_stack+63, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+547, r12vrr_stack+1136, r12vrr_stack+532, NULL, NULL, r12vrr_stack+314);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1526, r12vrr_stack+1151, r12vrr_stack+547, r12vrr_stack+18, r12vrr_stack+1136, r12vrr_stack+696);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1616, r12vrr_stack+1196, r12vrr_stack+1526, r12vrr_stack+324, r12vrr_stack+1151, r12vrr_stack+726);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1766, r12vrr_stack+1376, r12vrr_stack+1616, r12vrr_stack+1286, r12vrr_stack+1196, r12vrr_stack+786);
 tmp = r12vrr_stack + 1766;
 target_ptr = Libr12->gvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+696, r12vrr_stack+18, r12vrr_stack+1136, r12vrr_stack+36, r12vrr_stack+274, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+717, r12vrr_stack+124, r12vrr_stack+18, r12vrr_stack+264, r12vrr_stack+36, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+738, r12vrr_stack+717, r12vrr_stack+696, NULL, NULL, r12vrr_stack+18);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+36, r12vrr_stack+139, r12vrr_stack+124, r12vrr_stack+114, r12vrr_stack+264, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+801, r12vrr_stack+36, r12vrr_stack+717, NULL, NULL, r12vrr_stack+124);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+864, r12vrr_stack+1136, r12vrr_stack+532, r12vrr_stack+274, r12vrr_stack+314, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1991, r12vrr_stack+696, r12vrr_stack+864, NULL, NULL, r12vrr_stack+1136);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2054, r12vrr_stack+738, r12vrr_stack+1991, r12vrr_stack+717, r12vrr_stack+696, r12vrr_stack+1151);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2180, r12vrr_stack+801, r12vrr_stack+738, r12vrr_stack+36, r12vrr_stack+717, r12vrr_stack+324);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2306, r12vrr_stack+2180, r12vrr_stack+2054, r12vrr_stack+801, r12vrr_stack+738, r12vrr_stack+1196);
 tmp = r12vrr_stack + 2306;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+57, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+324, r12vrr_stack+33, r12vrr_stack+57, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+330, r12vrr_stack+516, r12vrr_stack+324, r12vrr_stack+60, r12vrr_stack+33, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+340, r12vrr_stack+522, r12vrr_stack+330, r12vrr_stack+63, r12vrr_stack+516, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1151, r12vrr_stack+532, r12vrr_stack+340, r12vrr_stack+314, r12vrr_stack+522, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1172, r12vrr_stack+864, r12vrr_stack+1151, NULL, NULL, r12vrr_stack+532);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2516, r12vrr_stack+1991, r12vrr_stack+1172, r12vrr_stack+696, r12vrr_stack+864, r12vrr_stack+547);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2642, r12vrr_stack+2054, r12vrr_stack+2516, r12vrr_stack+738, r12vrr_stack+1991, r12vrr_stack+1526);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+2852, r12vrr_stack+2306, r12vrr_stack+2642, r12vrr_stack+2180, r12vrr_stack+2054, r12vrr_stack+1616);
 tmp = r12vrr_stack + 2852;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1526, r12vrr_stack+696, r12vrr_stack+864, r12vrr_stack+18, r12vrr_stack+1136, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1554, r12vrr_stack+717, r12vrr_stack+696, r12vrr_stack+124, r12vrr_stack+18, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1582, r12vrr_stack+1554, r12vrr_stack+1526, NULL, NULL, r12vrr_stack+696);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1666, r12vrr_stack+36, r12vrr_stack+717, r12vrr_stack+139, r12vrr_stack+124, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3167, r12vrr_stack+1666, r12vrr_stack+1554, NULL, NULL, r12vrr_stack+717);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1694, r12vrr_stack+864, r12vrr_stack+1151, r12vrr_stack+1136, r12vrr_stack+532, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3251, r12vrr_stack+1526, r12vrr_stack+1694, NULL, NULL, r12vrr_stack+864);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3335, r12vrr_stack+1582, r12vrr_stack+3251, r12vrr_stack+1554, r12vrr_stack+1526, r12vrr_stack+1991);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3503, r12vrr_stack+3167, r12vrr_stack+1582, r12vrr_stack+1666, r12vrr_stack+1554, r12vrr_stack+738);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+3671, r12vrr_stack+3503, r12vrr_stack+3335, r12vrr_stack+3167, r12vrr_stack+1582, r12vrr_stack+2054);
 tmp = r12vrr_stack + 3671;
 target_ptr = Libr12->gvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+738, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+741, r12vrr_stack+57, r12vrr_stack+738, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+747, r12vrr_stack+324, r12vrr_stack+741, r12vrr_stack+33, r12vrr_stack+57, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1136, r12vrr_stack+330, r12vrr_stack+747, r12vrr_stack+516, r12vrr_stack+324, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+57, r12vrr_stack+340, r12vrr_stack+1136, r12vrr_stack+522, r12vrr_stack+330, NULL);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+738, r12vrr_stack+1151, r12vrr_stack+57, r12vrr_stack+532, r12vrr_stack+340, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+516, r12vrr_stack+1694, r12vrr_stack+738, NULL, NULL, r12vrr_stack+1151);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+1991, r12vrr_stack+3251, r12vrr_stack+516, r12vrr_stack+1526, r12vrr_stack+1694, r12vrr_stack+1172);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+3951, r12vrr_stack+3335, r12vrr_stack+1991, r12vrr_stack+1582, r12vrr_stack+3251, r12vrr_stack+2516);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+4231, r12vrr_stack+3671, r12vrr_stack+3951, r12vrr_stack+3503, r12vrr_stack+3335, r12vrr_stack+2642);

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+0, r12vrr_stack+1526, r12vrr_stack+1694, r12vrr_stack+696, r12vrr_stack+864, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3951, r12vrr_stack+1554, r12vrr_stack+1526, r12vrr_stack+717, r12vrr_stack+696, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3987, r12vrr_stack+3951, r12vrr_stack+0, NULL, NULL, r12vrr_stack+1526);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4095, r12vrr_stack+1666, r12vrr_stack+1554, r12vrr_stack+36, r12vrr_stack+717, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2516, r12vrr_stack+4095, r12vrr_stack+3951, NULL, NULL, r12vrr_stack+1554);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1526, r12vrr_stack+1694, r12vrr_stack+738, r12vrr_stack+864, r12vrr_stack+1151, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2624, r12vrr_stack+0, r12vrr_stack+1526, NULL, NULL, r12vrr_stack+1694);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4651, r12vrr_stack+3987, r12vrr_stack+2624, r12vrr_stack+3951, r12vrr_stack+0, r12vrr_stack+3251);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2624, r12vrr_stack+2516, r12vrr_stack+3987, r12vrr_stack+4095, r12vrr_stack+3951, r12vrr_stack+1582);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4867, r12vrr_stack+2624, r12vrr_stack+4651, r12vrr_stack+2516, r12vrr_stack+3987, r12vrr_stack+3335);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+2516, &(Data->ss_r12_ss), NULL, r12vrr_stack+78, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+2519, r12vrr_stack+2516, &(Data->ss_r12_ss), r12vrr_stack+81, r12vrr_stack+78, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+2525, r12vrr_stack+2519, r12vrr_stack+2516, r12vrr_stack+114, r12vrr_stack+81, r12vrr_stack+78, NULL);

 /*--- compute (p0||f0)^0 ---*/
 _R_BUILD_p0f0(Data,r12vrr_stack+2535, r12vrr_stack+2525, NULL, r12vrr_stack+606, r12vrr_stack+114, NULL, r12vrr_stack+81);

 /*--- compute (d0||f0)^0 ---*/
 _R_BUILD_d0f0(Data,r12vrr_stack+4651, r12vrr_stack+2535, r12vrr_stack+2525, r12vrr_stack+636, r12vrr_stack+606, r12vrr_stack+114, r12vrr_stack+87);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+124, r12vrr_stack+2525, r12vrr_stack+2519, r12vrr_stack+139, r12vrr_stack+114, r12vrr_stack+81, NULL);

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+2565, r12vrr_stack+124, NULL, r12vrr_stack+369, r12vrr_stack+139, NULL, r12vrr_stack+114);

 /*--- compute (d0||g0)^0 ---*/
 _R_BUILD_d0g0(Data,r12vrr_stack+516, r12vrr_stack+2565, r12vrr_stack+124, r12vrr_stack+1286, r12vrr_stack+369, r12vrr_stack+139, r12vrr_stack+606);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+4711, r12vrr_stack+124, r12vrr_stack+2525, r12vrr_stack+36, r12vrr_stack+139, r12vrr_stack+114, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+4732, r12vrr_stack+4711, NULL, r12vrr_stack+801, r12vrr_stack+36, NULL, r12vrr_stack+139);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+3951, r12vrr_stack+4732, r12vrr_stack+4711, r12vrr_stack+2180, r12vrr_stack+801, r12vrr_stack+36, r12vrr_stack+369);

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+4795, r12vrr_stack+4711, r12vrr_stack+124, r12vrr_stack+1666, r12vrr_stack+36, r12vrr_stack+139, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+4077, r12vrr_stack+4795, NULL, r12vrr_stack+3167, r12vrr_stack+1666, NULL, r12vrr_stack+36);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+0, r12vrr_stack+4077, r12vrr_stack+4795, r12vrr_stack+3503, r12vrr_stack+3167, r12vrr_stack+1666, r12vrr_stack+801);

 /*--- compute (f0|[r12,T2]|f0)^0 ---*/
 _T2_BUILD_f0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3251, r12vrr_stack+886, r12vrr_stack+1376, r12vrr_stack+986, r12vrr_stack+426, r12vrr_stack+204);
 tmp = r12vrr_stack + 3251;
 target_ptr = Libr12->t2vrr_classes[3][3];
 for(i=0;i<100;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_f0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1136, r12vrr_stack+1376, r12vrr_stack+2306, r12vrr_stack+1766, r12vrr_stack+986, r12vrr_stack+886);
 tmp = r12vrr_stack + 1136;
 target_ptr = Libr12->t2vrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1526, r12vrr_stack+2306, r12vrr_stack+3671, r12vrr_stack+2852, r12vrr_stack+1766, r12vrr_stack+1376);
 tmp = r12vrr_stack + 1526;
 target_ptr = Libr12->t2vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5227, r12vrr_stack+3671, r12vrr_stack+4867, r12vrr_stack+4231, r12vrr_stack+2852, r12vrr_stack+2306);
 tmp = r12vrr_stack + 5227;
 target_ptr = Libr12->t2vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|f0)^0 ---*/
 _T1_BUILD_f0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+204, r12vrr_stack+886, r12vrr_stack+986, r12vrr_stack+1376, r12vrr_stack+1286, r12vrr_stack+636);
 tmp = r12vrr_stack + 204;
 target_ptr = Libr12->t1vrr_classes[3][3];
 for(i=0;i<100;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_f0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+986, r12vrr_stack+1376, r12vrr_stack+1766, r12vrr_stack+2306, r12vrr_stack+2180, r12vrr_stack+1286);
 tmp = r12vrr_stack + 986;
 target_ptr = Libr12->t1vrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1736, r12vrr_stack+2306, r12vrr_stack+2852, r12vrr_stack+3671, r12vrr_stack+3503, r12vrr_stack+2180);
 tmp = r12vrr_stack + 1736;
 target_ptr = Libr12->t1vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2840, r12vrr_stack+3671, r12vrr_stack+4231, r12vrr_stack+4867, r12vrr_stack+2624, r12vrr_stack+3503);
 tmp = r12vrr_stack + 2840;
 target_ptr = Libr12->t1vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||f0)^0 ---*/
 _R_BUILD_f0f0(Data,r12vrr_stack+4795, r12vrr_stack+4651, r12vrr_stack+2535, r12vrr_stack+886, r12vrr_stack+636, r12vrr_stack+606, r12vrr_stack+168);
 tmp = r12vrr_stack + 4795;
 target_ptr = Libr12->rvrr_classes[3][3];
 for(i=0;i<100;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||g0)^0 ---*/
 _R_BUILD_f0g0(Data,r12vrr_stack+4895, r12vrr_stack+516, r12vrr_stack+2565, r12vrr_stack+1376, r12vrr_stack+1286, r12vrr_stack+369, r12vrr_stack+636);
 tmp = r12vrr_stack + 4895;
 target_ptr = Libr12->rvrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+304, r12vrr_stack+3951, r12vrr_stack+4732, r12vrr_stack+2306, r12vrr_stack+2180, r12vrr_stack+801, r12vrr_stack+1286);
 tmp = r12vrr_stack + 304;
 target_ptr = Libr12->rvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+2306, r12vrr_stack+0, r12vrr_stack+4077, r12vrr_stack+3671, r12vrr_stack+3503, r12vrr_stack+3167, r12vrr_stack+2180);
 tmp = r12vrr_stack + 2306;
 target_ptr = Libr12->rvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];


}

