/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_f0gd(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (p0|p0)^2 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, NULL, NULL, Data->F+3);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+21, r12vrr_stack+3, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+30, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+33, r12vrr_stack+0, r12vrr_stack+30, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+33, NULL, NULL, r12vrr_stack+0);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+57, r12vrr_stack+24, r12vrr_stack+15, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^1 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+75, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+6);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+111, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+121, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+131, r12vrr_stack+121, r12vrr_stack+111, NULL, NULL, r12vrr_stack+15);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+161, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+164, r12vrr_stack+161, r12vrr_stack+21, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+170, r12vrr_stack+164, r12vrr_stack+24, r12vrr_stack+161, r12vrr_stack+21, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+180, r12vrr_stack+170, r12vrr_stack+121, NULL, NULL, r12vrr_stack+24);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+210, r12vrr_stack+30, r12vrr_stack+21, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+216, r12vrr_stack+33, r12vrr_stack+210, r12vrr_stack+0, r12vrr_stack+30, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+226, r12vrr_stack+111, r12vrr_stack+216, NULL, NULL, r12vrr_stack+33);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+256, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+39);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+316, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+57);

 /*--- compute (f0|f0)^0 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+376, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+75);

 /*--- compute (p0|00)^3 ---*/
 _BUILD_p000(Data,r12vrr_stack+476, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+479, r12vrr_stack+0, r12vrr_stack+30, NULL, NULL, Data->F+4);

 /*--- compute (d0|p0)^2 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+488, r12vrr_stack+6, r12vrr_stack+479, r12vrr_stack+3, r12vrr_stack+0, r12vrr_stack+476);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+506, r12vrr_stack+33, r12vrr_stack+210, NULL, NULL, r12vrr_stack+30);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+524, r12vrr_stack+39, r12vrr_stack+506, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+479);

 /*--- compute (f0|d0)^1 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+560, r12vrr_stack+75, r12vrr_stack+524, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+488);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+39, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+42, r12vrr_stack+21, r12vrr_stack+39, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+48, r12vrr_stack+210, r12vrr_stack+42, r12vrr_stack+30, r12vrr_stack+21, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+476, r12vrr_stack+216, r12vrr_stack+48, NULL, NULL, r12vrr_stack+210);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+620, r12vrr_stack+226, r12vrr_stack+476, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+506);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+680, r12vrr_stack+256, r12vrr_stack+620, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+524);

 /*--- compute (g0|f0)^0 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+780, r12vrr_stack+376, r12vrr_stack+680, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+560);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+15, r12vrr_stack+33, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+506, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+24, r12vrr_stack+15, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+521, r12vrr_stack+216, r12vrr_stack+48, r12vrr_stack+33, r12vrr_stack+210, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+536, r12vrr_stack+0, r12vrr_stack+521, NULL, NULL, r12vrr_stack+216);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+58, r12vrr_stack+506, r12vrr_stack+0, NULL, NULL, r12vrr_stack+111);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+930, r12vrr_stack+58, r12vrr_stack+536, r12vrr_stack+506, r12vrr_stack+0, r12vrr_stack+226);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+226, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+164, r12vrr_stack+24, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1020, r12vrr_stack+226, r12vrr_stack+506, NULL, NULL, r12vrr_stack+121);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1065, r12vrr_stack+1020, r12vrr_stack+58, r12vrr_stack+226, r12vrr_stack+506, r12vrr_stack+131);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+131, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+39, r12vrr_stack+131, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+134, r12vrr_stack+42, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+39, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+241, r12vrr_stack+48, r12vrr_stack+134, r12vrr_stack+210, r12vrr_stack+42, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1155, r12vrr_stack+521, r12vrr_stack+241, NULL, NULL, r12vrr_stack+48);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1200, r12vrr_stack+536, r12vrr_stack+1155, r12vrr_stack+0, r12vrr_stack+521, r12vrr_stack+476);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1290, r12vrr_stack+930, r12vrr_stack+1200, r12vrr_stack+58, r12vrr_stack+536, r12vrr_stack+620);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1440, r12vrr_stack+1065, r12vrr_stack+930, r12vrr_stack+1020, r12vrr_stack+58, r12vrr_stack+256);
 tmp = r12vrr_stack + 1440;
 target_ptr = Libr12->gvrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1590, r12vrr_stack+1440, r12vrr_stack+1290, r12vrr_stack+1065, r12vrr_stack+930, r12vrr_stack+680);
 tmp = r12vrr_stack + 1590;
 target_ptr = Libr12->gvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+256, r12vrr_stack+0, r12vrr_stack+521, r12vrr_stack+111, r12vrr_stack+216, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+277, r12vrr_stack+506, r12vrr_stack+0, r12vrr_stack+121, r12vrr_stack+111, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+581, r12vrr_stack+277, r12vrr_stack+256, NULL, NULL, r12vrr_stack+0);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+476, r12vrr_stack+226, r12vrr_stack+506, r12vrr_stack+170, r12vrr_stack+121, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+644, r12vrr_stack+476, r12vrr_stack+277, NULL, NULL, r12vrr_stack+506);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+707, r12vrr_stack+521, r12vrr_stack+241, r12vrr_stack+216, r12vrr_stack+48, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1815, r12vrr_stack+256, r12vrr_stack+707, NULL, NULL, r12vrr_stack+521);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1878, r12vrr_stack+581, r12vrr_stack+1815, r12vrr_stack+277, r12vrr_stack+256, r12vrr_stack+536);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2004, r12vrr_stack+644, r12vrr_stack+581, r12vrr_stack+476, r12vrr_stack+277, r12vrr_stack+58);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2130, r12vrr_stack+2004, r12vrr_stack+1878, r12vrr_stack+644, r12vrr_stack+581, r12vrr_stack+930);
 tmp = r12vrr_stack + 2130;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+930, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+933, r12vrr_stack+131, r12vrr_stack+930, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+939, r12vrr_stack+15, r12vrr_stack+933, r12vrr_stack+39, r12vrr_stack+131, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+949, r12vrr_stack+134, r12vrr_stack+939, r12vrr_stack+42, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+964, r12vrr_stack+241, r12vrr_stack+949, r12vrr_stack+48, r12vrr_stack+134, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+21, r12vrr_stack+707, r12vrr_stack+964, NULL, NULL, r12vrr_stack+241);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2340, r12vrr_stack+1815, r12vrr_stack+21, r12vrr_stack+256, r12vrr_stack+707, r12vrr_stack+1155);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2466, r12vrr_stack+1878, r12vrr_stack+2340, r12vrr_stack+581, r12vrr_stack+1815, r12vrr_stack+1200);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+2676, r12vrr_stack+2130, r12vrr_stack+2466, r12vrr_stack+2004, r12vrr_stack+1878, r12vrr_stack+1290);
 tmp = r12vrr_stack + 2676;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1155, r12vrr_stack+256, r12vrr_stack+707, r12vrr_stack+0, r12vrr_stack+521, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1183, r12vrr_stack+277, r12vrr_stack+256, r12vrr_stack+506, r12vrr_stack+0, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1211, r12vrr_stack+1183, r12vrr_stack+1155, NULL, NULL, r12vrr_stack+256);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1295, r12vrr_stack+476, r12vrr_stack+277, r12vrr_stack+226, r12vrr_stack+506, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1323, r12vrr_stack+1295, r12vrr_stack+1183, NULL, NULL, r12vrr_stack+277);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1407, r12vrr_stack+707, r12vrr_stack+964, r12vrr_stack+521, r12vrr_stack+241, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+497, r12vrr_stack+1155, r12vrr_stack+1407, NULL, NULL, r12vrr_stack+707);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+2991, r12vrr_stack+1211, r12vrr_stack+497, r12vrr_stack+1183, r12vrr_stack+1155, r12vrr_stack+1815);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3159, r12vrr_stack+1323, r12vrr_stack+1211, r12vrr_stack+1295, r12vrr_stack+1183, r12vrr_stack+581);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+3327, r12vrr_stack+3159, r12vrr_stack+2991, r12vrr_stack+1323, r12vrr_stack+1211, r12vrr_stack+1878);
 tmp = r12vrr_stack + 3327;
 target_ptr = Libr12->gvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+581, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+584, r12vrr_stack+930, r12vrr_stack+581, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+590, r12vrr_stack+933, r12vrr_stack+584, r12vrr_stack+131, r12vrr_stack+930, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+939, r12vrr_stack+590, r12vrr_stack+15, r12vrr_stack+933, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+581, r12vrr_stack+949, r12vrr_stack+0, r12vrr_stack+134, r12vrr_stack+939, NULL);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+602, r12vrr_stack+964, r12vrr_stack+581, r12vrr_stack+241, r12vrr_stack+949, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1815, r12vrr_stack+1407, r12vrr_stack+602, NULL, NULL, r12vrr_stack+964);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3607, r12vrr_stack+497, r12vrr_stack+1815, r12vrr_stack+1155, r12vrr_stack+1407, r12vrr_stack+21);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+3775, r12vrr_stack+2991, r12vrr_stack+3607, r12vrr_stack+1211, r12vrr_stack+497, r12vrr_stack+2340);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+4055, r12vrr_stack+3327, r12vrr_stack+3775, r12vrr_stack+3159, r12vrr_stack+2991, r12vrr_stack+2466);

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2340, r12vrr_stack+1155, r12vrr_stack+1407, r12vrr_stack+256, r12vrr_stack+707, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2376, r12vrr_stack+1183, r12vrr_stack+1155, r12vrr_stack+277, r12vrr_stack+256, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2412, r12vrr_stack+2376, r12vrr_stack+2340, NULL, NULL, r12vrr_stack+1155);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+241, r12vrr_stack+1295, r12vrr_stack+1183, r12vrr_stack+476, r12vrr_stack+277, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2520, r12vrr_stack+241, r12vrr_stack+2376, NULL, NULL, r12vrr_stack+1183);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+277, r12vrr_stack+1407, r12vrr_stack+602, r12vrr_stack+707, r12vrr_stack+964, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3607, r12vrr_stack+2340, r12vrr_stack+277, NULL, NULL, r12vrr_stack+1407);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3715, r12vrr_stack+2412, r12vrr_stack+3607, r12vrr_stack+2376, r12vrr_stack+2340, r12vrr_stack+497);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4475, r12vrr_stack+2520, r12vrr_stack+2412, r12vrr_stack+241, r12vrr_stack+2376, r12vrr_stack+1211);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4691, r12vrr_stack+4475, r12vrr_stack+3715, r12vrr_stack+2520, r12vrr_stack+2412, r12vrr_stack+2991);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+2991, &(Data->ss_r12_ss), NULL, r12vrr_stack+161, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+2994, r12vrr_stack+2991, &(Data->ss_r12_ss), r12vrr_stack+164, r12vrr_stack+161, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+3000, r12vrr_stack+2994, r12vrr_stack+2991, r12vrr_stack+170, r12vrr_stack+164, r12vrr_stack+161, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+3010, r12vrr_stack+3000, r12vrr_stack+2994, r12vrr_stack+226, r12vrr_stack+170, r12vrr_stack+164, NULL);

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+3025, r12vrr_stack+3010, NULL, r12vrr_stack+1020, r12vrr_stack+226, NULL, r12vrr_stack+170);

 /*--- compute (d0||g0)^0 ---*/
 _R_BUILD_d0g0(Data,r12vrr_stack+930, r12vrr_stack+3025, r12vrr_stack+3010, r12vrr_stack+1065, r12vrr_stack+1020, r12vrr_stack+226, r12vrr_stack+180);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+180, r12vrr_stack+3010, r12vrr_stack+3000, r12vrr_stack+476, r12vrr_stack+226, r12vrr_stack+170, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+3070, r12vrr_stack+180, NULL, r12vrr_stack+644, r12vrr_stack+476, NULL, r12vrr_stack+226);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+497, r12vrr_stack+3070, r12vrr_stack+180, r12vrr_stack+2004, r12vrr_stack+644, r12vrr_stack+476, r12vrr_stack+1020);

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+241, r12vrr_stack+180, r12vrr_stack+3010, r12vrr_stack+1295, r12vrr_stack+476, r12vrr_stack+226, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+2340, r12vrr_stack+241, NULL, r12vrr_stack+1323, r12vrr_stack+1295, NULL, r12vrr_stack+476);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+2424, r12vrr_stack+2340, r12vrr_stack+241, r12vrr_stack+3159, r12vrr_stack+1323, r12vrr_stack+1295, r12vrr_stack+644);

 /*--- compute (f0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_f0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3607, r12vrr_stack+1440, r12vrr_stack+2130, r12vrr_stack+1590, r12vrr_stack+780, r12vrr_stack+376);
 tmp = r12vrr_stack + 3607;
 target_ptr = Libr12->t2vrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3757, r12vrr_stack+2130, r12vrr_stack+3327, r12vrr_stack+2676, r12vrr_stack+1590, r12vrr_stack+1440);
 tmp = r12vrr_stack + 3757;
 target_ptr = Libr12->t2vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+3327, r12vrr_stack+4691, r12vrr_stack+4055, r12vrr_stack+2676, r12vrr_stack+2130);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t2vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_f0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+707, r12vrr_stack+1440, r12vrr_stack+1590, r12vrr_stack+2130, r12vrr_stack+2004, r12vrr_stack+1065);
 tmp = r12vrr_stack + 707;
 target_ptr = Libr12->t1vrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1590, r12vrr_stack+2130, r12vrr_stack+2676, r12vrr_stack+3327, r12vrr_stack+3159, r12vrr_stack+2004);
 tmp = r12vrr_stack + 1590;
 target_ptr = Libr12->t1vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2592, r12vrr_stack+3327, r12vrr_stack+4055, r12vrr_stack+4691, r12vrr_stack+4475, r12vrr_stack+3159);
 tmp = r12vrr_stack + 2592;
 target_ptr = Libr12->t1vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||g0)^0 ---*/
 _R_BUILD_f0g0(Data,r12vrr_stack+1800, r12vrr_stack+930, r12vrr_stack+3025, r12vrr_stack+1440, r12vrr_stack+1065, r12vrr_stack+1020, r12vrr_stack+316);
 tmp = r12vrr_stack + 1800;
 target_ptr = Libr12->rvrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+3967, r12vrr_stack+497, r12vrr_stack+3070, r12vrr_stack+2130, r12vrr_stack+2004, r12vrr_stack+644, r12vrr_stack+1065);
 tmp = r12vrr_stack + 3967;
 target_ptr = Libr12->rvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+2872, r12vrr_stack+2424, r12vrr_stack+2340, r12vrr_stack+3327, r12vrr_stack+3159, r12vrr_stack+1323, r12vrr_stack+2004);
 tmp = r12vrr_stack + 2872;
 target_ptr = Libr12->rvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];


}

