/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_g0g0(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (p0|00)^3 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+9, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+12, r12vrr_stack+3, r12vrr_stack+9, NULL, NULL, Data->F+4);

 /*--- compute (p0|p0)^2 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+3, NULL, NULL, Data->F+3);

 /*--- compute (d0|p0)^2 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+30, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+9, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+54, r12vrr_stack+6, r12vrr_stack+3, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+60, r12vrr_stack+54, r12vrr_stack+48, NULL, NULL, r12vrr_stack+3);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+78, r12vrr_stack+6, Data->F+1, Data->F+2, NULL);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+87, r12vrr_stack+81, r12vrr_stack+54, NULL, NULL, r12vrr_stack+6);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+105, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+108, r12vrr_stack+9, r12vrr_stack+105, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+114, r12vrr_stack+48, r12vrr_stack+108, NULL, NULL, r12vrr_stack+9);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+132, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+12);

 /*--- compute (d0|d0)^1 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+168, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+21);

 /*--- compute (f0|d0)^1 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+204, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+30);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+264, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+6, r12vrr_stack+3, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+274, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+78, r12vrr_stack+6, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+284, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+3, r12vrr_stack+9, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+294, r12vrr_stack+264, r12vrr_stack+284, NULL, NULL, r12vrr_stack+48);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+324, r12vrr_stack+274, r12vrr_stack+264, NULL, NULL, r12vrr_stack+54);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+354, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+60);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+414, r12vrr_stack+6, r12vrr_stack+78, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+81, r12vrr_stack+6, r12vrr_stack+78, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+430, r12vrr_stack+420, r12vrr_stack+274, NULL, NULL, r12vrr_stack+81);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+460, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+87);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+87, r12vrr_stack+105, r12vrr_stack+78, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+93, r12vrr_stack+108, r12vrr_stack+87, r12vrr_stack+9, r12vrr_stack+105, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+520, r12vrr_stack+284, r12vrr_stack+93, NULL, NULL, r12vrr_stack+108);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+550, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+114);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+610, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+132);

 /*--- compute (f0|f0)^0 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+710, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+168);

 /*--- compute (g0|f0)^0 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+810, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+204);

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+960, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (d0|00)^3 ---*/
 _BUILD_d000(Data,r12vrr_stack+963, r12vrr_stack+0, r12vrr_stack+960, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+969, r12vrr_stack+9, r12vrr_stack+105, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+978, r12vrr_stack+12, r12vrr_stack+969, r12vrr_stack+3, r12vrr_stack+9, r12vrr_stack+960);

 /*--- compute (f0|p0)^2 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+996, r12vrr_stack+30, r12vrr_stack+978, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+963);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+9, r12vrr_stack+108, r12vrr_stack+87, NULL, NULL, r12vrr_stack+105);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1026, r12vrr_stack+114, r12vrr_stack+9, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+969);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+1062, r12vrr_stack+132, r12vrr_stack+1026, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+978);

 /*--- compute (g0|d0)^1 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+1122, r12vrr_stack+204, r12vrr_stack+1062, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+996);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+114, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+0, r12vrr_stack+78, r12vrr_stack+114, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+117, r12vrr_stack+87, r12vrr_stack+0, r12vrr_stack+105, r12vrr_stack+78, NULL);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+127, r12vrr_stack+93, r12vrr_stack+117, NULL, NULL, r12vrr_stack+87);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+157, r12vrr_stack+520, r12vrr_stack+127, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+9);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1212, r12vrr_stack+550, r12vrr_stack+157, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+1026);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1312, r12vrr_stack+610, r12vrr_stack+1212, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+1062);

 /*--- compute (h0|f0)^0 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+1462, r12vrr_stack+810, r12vrr_stack+1312, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+1122);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+9, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+48, r12vrr_stack+108, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+24, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+54, r12vrr_stack+48, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+217, r12vrr_stack+24, r12vrr_stack+9, NULL, NULL, r12vrr_stack+284);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+39, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+81, r12vrr_stack+54, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+960, r12vrr_stack+39, r12vrr_stack+24, NULL, NULL, r12vrr_stack+264);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+54, r12vrr_stack+93, r12vrr_stack+117, r12vrr_stack+108, r12vrr_stack+87, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1005, r12vrr_stack+9, r12vrr_stack+54, NULL, NULL, r12vrr_stack+93);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1050, r12vrr_stack+217, r12vrr_stack+1005, r12vrr_stack+24, r12vrr_stack+9, r12vrr_stack+520);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1672, r12vrr_stack+960, r12vrr_stack+217, r12vrr_stack+39, r12vrr_stack+24, r12vrr_stack+294);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1762, r12vrr_stack+1672, r12vrr_stack+1050, r12vrr_stack+960, r12vrr_stack+217, r12vrr_stack+550);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+294, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+414, r12vrr_stack+81, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+520, r12vrr_stack+294, r12vrr_stack+39, NULL, NULL, r12vrr_stack+274);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1912, r12vrr_stack+520, r12vrr_stack+960, r12vrr_stack+294, r12vrr_stack+39, r12vrr_stack+324);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2002, r12vrr_stack+1912, r12vrr_stack+1672, r12vrr_stack+520, r12vrr_stack+960, r12vrr_stack+354);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+81, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+309, r12vrr_stack+114, r12vrr_stack+81, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+315, r12vrr_stack+0, r12vrr_stack+309, r12vrr_stack+78, r12vrr_stack+114, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+325, r12vrr_stack+117, r12vrr_stack+315, r12vrr_stack+87, r12vrr_stack+0, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+565, r12vrr_stack+54, r12vrr_stack+325, NULL, NULL, r12vrr_stack+117);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2152, r12vrr_stack+1005, r12vrr_stack+565, r12vrr_stack+9, r12vrr_stack+54, r12vrr_stack+127);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2242, r12vrr_stack+1050, r12vrr_stack+2152, r12vrr_stack+217, r12vrr_stack+1005, r12vrr_stack+157);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2392, r12vrr_stack+1762, r12vrr_stack+2242, r12vrr_stack+1672, r12vrr_stack+1050, r12vrr_stack+1212);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2152, r12vrr_stack+2002, r12vrr_stack+1762, r12vrr_stack+1912, r12vrr_stack+1672, r12vrr_stack+610);
 tmp = r12vrr_stack + 2152;
 target_ptr = Libr12->gvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+2617, r12vrr_stack+2152, r12vrr_stack+2392, r12vrr_stack+2002, r12vrr_stack+1762, r12vrr_stack+1312);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2377, r12vrr_stack+24, r12vrr_stack+9, r12vrr_stack+264, r12vrr_stack+284, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2398, r12vrr_stack+39, r12vrr_stack+24, r12vrr_stack+274, r12vrr_stack+264, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2419, r12vrr_stack+9, r12vrr_stack+54, r12vrr_stack+284, r12vrr_stack+93, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2440, r12vrr_stack+2377, r12vrr_stack+2419, NULL, NULL, r12vrr_stack+9);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2503, r12vrr_stack+2398, r12vrr_stack+2377, NULL, NULL, r12vrr_stack+24);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+565, r12vrr_stack+2503, r12vrr_stack+2440, r12vrr_stack+2398, r12vrr_stack+2377, r12vrr_stack+217);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+9, r12vrr_stack+294, r12vrr_stack+39, r12vrr_stack+420, r12vrr_stack+274, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+127, r12vrr_stack+9, r12vrr_stack+2398, NULL, NULL, r12vrr_stack+39);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1140, r12vrr_stack+127, r12vrr_stack+2503, r12vrr_stack+9, r12vrr_stack+2398, r12vrr_stack+960);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2398, r12vrr_stack+54, r12vrr_stack+325, r12vrr_stack+93, r12vrr_stack+117, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+190, r12vrr_stack+2419, r12vrr_stack+2398, NULL, NULL, r12vrr_stack+54);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1266, r12vrr_stack+2440, r12vrr_stack+190, r12vrr_stack+2377, r12vrr_stack+2419, r12vrr_stack+1005);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2932, r12vrr_stack+565, r12vrr_stack+1266, r12vrr_stack+2503, r12vrr_stack+2440, r12vrr_stack+1050);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3142, r12vrr_stack+1140, r12vrr_stack+565, r12vrr_stack+127, r12vrr_stack+2503, r12vrr_stack+1672);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+3352, r12vrr_stack+3142, r12vrr_stack+2932, r12vrr_stack+1140, r12vrr_stack+565, r12vrr_stack+1762);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+565, &(Data->ss_r12_ss), NULL, r12vrr_stack+6, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+0, r12vrr_stack+565, &(Data->ss_r12_ss), r12vrr_stack+414, r12vrr_stack+6, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+568, r12vrr_stack+0, r12vrr_stack+565, r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+6, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+6, r12vrr_stack+568, r12vrr_stack+0, r12vrr_stack+294, r12vrr_stack+420, r12vrr_stack+414, NULL);

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+21, r12vrr_stack+6, NULL, r12vrr_stack+520, r12vrr_stack+294, NULL, r12vrr_stack+420);

 /*--- compute (d0||g0)^0 ---*/
 _R_BUILD_d0g0(Data,r12vrr_stack+66, r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+1912, r12vrr_stack+520, r12vrr_stack+294, r12vrr_stack+430);

 /*--- compute (f0||g0)^0 ---*/
 _R_BUILD_f0g0(Data,r12vrr_stack+156, r12vrr_stack+66, r12vrr_stack+21, r12vrr_stack+2002, r12vrr_stack+1912, r12vrr_stack+520, r12vrr_stack+460);

 /*--- compute (g0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+306, r12vrr_stack+2152, r12vrr_stack+3352, r12vrr_stack+2617, r12vrr_stack+1462, r12vrr_stack+810);
 tmp = r12vrr_stack + 306;
 target_ptr = Libr12->t2vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+810, r12vrr_stack+2152, r12vrr_stack+2617, r12vrr_stack+3352, r12vrr_stack+3142, r12vrr_stack+2002);
 tmp = r12vrr_stack + 810;
 target_ptr = Libr12->t1vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||g0)^0 ---*/
 _R_BUILD_g0g0(Data,r12vrr_stack+1035, r12vrr_stack+156, r12vrr_stack+66, r12vrr_stack+2152, r12vrr_stack+2002, r12vrr_stack+1912, r12vrr_stack+710);
 tmp = r12vrr_stack + 1035;
 target_ptr = Libr12->rvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];


}

