/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_g0hp(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, NULL, NULL, Data->F+4);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+21, r12vrr_stack+3, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+30, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+33, r12vrr_stack+0, r12vrr_stack+30, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+33, NULL, NULL, r12vrr_stack+0);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+57, r12vrr_stack+24, r12vrr_stack+15, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+75, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+6);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+111, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+121, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+131, r12vrr_stack+121, r12vrr_stack+111, NULL, NULL, r12vrr_stack+15);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+161, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+164, r12vrr_stack+161, r12vrr_stack+21, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+170, r12vrr_stack+164, r12vrr_stack+24, r12vrr_stack+161, r12vrr_stack+21, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+180, r12vrr_stack+170, r12vrr_stack+121, NULL, NULL, r12vrr_stack+24);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+210, r12vrr_stack+30, r12vrr_stack+21, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+216, r12vrr_stack+33, r12vrr_stack+210, r12vrr_stack+0, r12vrr_stack+30, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+226, r12vrr_stack+111, r12vrr_stack+216, NULL, NULL, r12vrr_stack+33);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+256, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+39);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+316, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+57);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+376, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+75);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+476, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+24, r12vrr_stack+15, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+491, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+164, r12vrr_stack+24, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+506, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+15, r12vrr_stack+33, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+521, r12vrr_stack+476, r12vrr_stack+506, NULL, NULL, r12vrr_stack+111);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+566, r12vrr_stack+491, r12vrr_stack+476, NULL, NULL, r12vrr_stack+121);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+611, r12vrr_stack+566, r12vrr_stack+521, r12vrr_stack+491, r12vrr_stack+476, r12vrr_stack+131);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+24, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+701, r12vrr_stack+24, r12vrr_stack+161, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+707, r12vrr_stack+701, r12vrr_stack+164, r12vrr_stack+24, r12vrr_stack+161, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+717, r12vrr_stack+707, r12vrr_stack+170, r12vrr_stack+701, r12vrr_stack+164, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+732, r12vrr_stack+717, r12vrr_stack+491, NULL, NULL, r12vrr_stack+170);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+777, r12vrr_stack+732, r12vrr_stack+566, r12vrr_stack+717, r12vrr_stack+491, r12vrr_stack+180);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+27, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+180, r12vrr_stack+21, r12vrr_stack+27, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+186, r12vrr_stack+210, r12vrr_stack+180, r12vrr_stack+30, r12vrr_stack+21, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+867, r12vrr_stack+216, r12vrr_stack+186, r12vrr_stack+33, r12vrr_stack+210, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+882, r12vrr_stack+506, r12vrr_stack+867, NULL, NULL, r12vrr_stack+216);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+927, r12vrr_stack+521, r12vrr_stack+882, r12vrr_stack+476, r12vrr_stack+506, r12vrr_stack+226);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1017, r12vrr_stack+611, r12vrr_stack+927, r12vrr_stack+566, r12vrr_stack+521, r12vrr_stack+256);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1167, r12vrr_stack+777, r12vrr_stack+611, r12vrr_stack+732, r12vrr_stack+566, r12vrr_stack+316);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1317, r12vrr_stack+1167, r12vrr_stack+1017, r12vrr_stack+777, r12vrr_stack+611, r12vrr_stack+376);

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+196, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+161, r12vrr_stack+0, r12vrr_stack+30, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+1542, r12vrr_stack+6, r12vrr_stack+161, r12vrr_stack+3, r12vrr_stack+0, r12vrr_stack+196);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1560, r12vrr_stack+33, r12vrr_stack+210, NULL, NULL, r12vrr_stack+30);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1578, r12vrr_stack+39, r12vrr_stack+1560, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+161);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+1614, r12vrr_stack+75, r12vrr_stack+1578, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+1542);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+30, r12vrr_stack+216, r12vrr_stack+186, NULL, NULL, r12vrr_stack+210);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1674, r12vrr_stack+226, r12vrr_stack+30, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+1560);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1734, r12vrr_stack+256, r12vrr_stack+1674, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+1578);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1834, r12vrr_stack+376, r12vrr_stack+1734, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+1614);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+226, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+229, r12vrr_stack+27, r12vrr_stack+226, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+235, r12vrr_stack+180, r12vrr_stack+229, r12vrr_stack+21, r12vrr_stack+27, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+245, r12vrr_stack+186, r12vrr_stack+235, r12vrr_stack+210, r12vrr_stack+180, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+260, r12vrr_stack+867, r12vrr_stack+245, NULL, NULL, r12vrr_stack+186);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+305, r12vrr_stack+882, r12vrr_stack+260, r12vrr_stack+506, r12vrr_stack+867, r12vrr_stack+30);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1984, r12vrr_stack+927, r12vrr_stack+305, r12vrr_stack+521, r12vrr_stack+882, r12vrr_stack+1674);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2134, r12vrr_stack+1017, r12vrr_stack+1984, r12vrr_stack+611, r12vrr_stack+927, r12vrr_stack+1734);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+2359, r12vrr_stack+1317, r12vrr_stack+2134, r12vrr_stack+1167, r12vrr_stack+1017, r12vrr_stack+1834);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+30, r12vrr_stack+506, r12vrr_stack+867, r12vrr_stack+111, r12vrr_stack+216, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+51, r12vrr_stack+476, r12vrr_stack+506, r12vrr_stack+121, r12vrr_stack+111, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+395, r12vrr_stack+51, r12vrr_stack+30, NULL, NULL, r12vrr_stack+506);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+72, r12vrr_stack+491, r12vrr_stack+476, r12vrr_stack+170, r12vrr_stack+121, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+93, r12vrr_stack+72, r12vrr_stack+51, NULL, NULL, r12vrr_stack+476);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1542, r12vrr_stack+867, r12vrr_stack+245, r12vrr_stack+216, r12vrr_stack+186, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1563, r12vrr_stack+30, r12vrr_stack+1542, NULL, NULL, r12vrr_stack+867);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1626, r12vrr_stack+395, r12vrr_stack+1563, r12vrr_stack+51, r12vrr_stack+30, r12vrr_stack+882);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1752, r12vrr_stack+93, r12vrr_stack+395, r12vrr_stack+72, r12vrr_stack+51, r12vrr_stack+521);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2674, r12vrr_stack+1752, r12vrr_stack+1626, r12vrr_stack+93, r12vrr_stack+395, r12vrr_stack+927);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+521, r12vrr_stack+717, r12vrr_stack+491, r12vrr_stack+707, r12vrr_stack+170, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+882, r12vrr_stack+521, r12vrr_stack+72, NULL, NULL, r12vrr_stack+491);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2884, r12vrr_stack+882, r12vrr_stack+93, r12vrr_stack+521, r12vrr_stack+72, r12vrr_stack+566);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3010, r12vrr_stack+2884, r12vrr_stack+1752, r12vrr_stack+882, r12vrr_stack+93, r12vrr_stack+611);

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+542, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+545, r12vrr_stack+226, r12vrr_stack+542, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+551, r12vrr_stack+229, r12vrr_stack+545, r12vrr_stack+27, r12vrr_stack+226, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+561, r12vrr_stack+235, r12vrr_stack+551, r12vrr_stack+180, r12vrr_stack+229, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+576, r12vrr_stack+245, r12vrr_stack+561, r12vrr_stack+186, r12vrr_stack+235, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+597, r12vrr_stack+1542, r12vrr_stack+576, NULL, NULL, r12vrr_stack+245);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3220, r12vrr_stack+1563, r12vrr_stack+597, r12vrr_stack+30, r12vrr_stack+1542, r12vrr_stack+260);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3346, r12vrr_stack+1626, r12vrr_stack+3220, r12vrr_stack+395, r12vrr_stack+1563, r12vrr_stack+305);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+3556, r12vrr_stack+2674, r12vrr_stack+3346, r12vrr_stack+1752, r12vrr_stack+1626, r12vrr_stack+1984);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+3871, r12vrr_stack+3010, r12vrr_stack+2674, r12vrr_stack+2884, r12vrr_stack+1752, r12vrr_stack+1017);
 tmp = r12vrr_stack + 3871;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+4186, r12vrr_stack+3871, r12vrr_stack+3556, r12vrr_stack+3010, r12vrr_stack+2674, r12vrr_stack+2134);
 tmp = r12vrr_stack + 4186;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+260, r12vrr_stack+51, r12vrr_stack+30, r12vrr_stack+476, r12vrr_stack+506, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+288, r12vrr_stack+72, r12vrr_stack+51, r12vrr_stack+491, r12vrr_stack+476, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+316, r12vrr_stack+30, r12vrr_stack+1542, r12vrr_stack+506, r12vrr_stack+867, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+945, r12vrr_stack+260, r12vrr_stack+316, NULL, NULL, r12vrr_stack+30);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1029, r12vrr_stack+288, r12vrr_stack+260, NULL, NULL, r12vrr_stack+51);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+1878, r12vrr_stack+1029, r12vrr_stack+945, r12vrr_stack+288, r12vrr_stack+260, r12vrr_stack+395);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+344, r12vrr_stack+521, r12vrr_stack+72, r12vrr_stack+717, r12vrr_stack+491, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+372, r12vrr_stack+344, r12vrr_stack+288, NULL, NULL, r12vrr_stack+72);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+2046, r12vrr_stack+372, r12vrr_stack+1029, r12vrr_stack+344, r12vrr_stack+288, r12vrr_stack+93);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+93, r12vrr_stack+1542, r12vrr_stack+576, r12vrr_stack+867, r12vrr_stack+245, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+121, r12vrr_stack+316, r12vrr_stack+93, NULL, NULL, r12vrr_stack+1542);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4627, r12vrr_stack+945, r12vrr_stack+121, r12vrr_stack+260, r12vrr_stack+316, r12vrr_stack+1563);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4795, r12vrr_stack+1878, r12vrr_stack+4627, r12vrr_stack+1029, r12vrr_stack+945, r12vrr_stack+1626);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+5075, r12vrr_stack+2046, r12vrr_stack+1878, r12vrr_stack+372, r12vrr_stack+1029, r12vrr_stack+1752);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+5355, r12vrr_stack+5075, r12vrr_stack+4795, r12vrr_stack+2046, r12vrr_stack+1878, r12vrr_stack+2674);
 tmp = r12vrr_stack + 5355;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+27, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+2674, r12vrr_stack+542, r12vrr_stack+27, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+2680, r12vrr_stack+545, r12vrr_stack+2674, r12vrr_stack+226, r12vrr_stack+542, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+867, r12vrr_stack+551, r12vrr_stack+2680, r12vrr_stack+229, r12vrr_stack+545, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2674, r12vrr_stack+561, r12vrr_stack+867, r12vrr_stack+235, r12vrr_stack+551, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2695, r12vrr_stack+576, r12vrr_stack+2674, r12vrr_stack+245, r12vrr_stack+561, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+2723, r12vrr_stack+93, r12vrr_stack+2695, NULL, NULL, r12vrr_stack+576);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+1563, r12vrr_stack+121, r12vrr_stack+2723, r12vrr_stack+316, r12vrr_stack+93, r12vrr_stack+597);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+5775, r12vrr_stack+4627, r12vrr_stack+1563, r12vrr_stack+945, r12vrr_stack+121, r12vrr_stack+3220);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+6055, r12vrr_stack+4795, r12vrr_stack+5775, r12vrr_stack+1878, r12vrr_stack+4627, r12vrr_stack+3346);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+6475, r12vrr_stack+5355, r12vrr_stack+6055, r12vrr_stack+5075, r12vrr_stack+4795, r12vrr_stack+3556);

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5775, r12vrr_stack+260, r12vrr_stack+316, r12vrr_stack+51, r12vrr_stack+30, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5811, r12vrr_stack+288, r12vrr_stack+260, r12vrr_stack+72, r12vrr_stack+51, NULL);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5847, r12vrr_stack+316, r12vrr_stack+93, r12vrr_stack+30, r12vrr_stack+1542, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5883, r12vrr_stack+5775, r12vrr_stack+5847, NULL, NULL, r12vrr_stack+316);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5991, r12vrr_stack+5811, r12vrr_stack+5775, NULL, NULL, r12vrr_stack+260);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6099, r12vrr_stack+5991, r12vrr_stack+5883, r12vrr_stack+5811, r12vrr_stack+5775, r12vrr_stack+945);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+945, r12vrr_stack+344, r12vrr_stack+288, r12vrr_stack+521, r12vrr_stack+72, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6315, r12vrr_stack+945, r12vrr_stack+5811, NULL, NULL, r12vrr_stack+288);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3220, r12vrr_stack+6315, r12vrr_stack+5991, r12vrr_stack+945, r12vrr_stack+5811, r12vrr_stack+1029);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5811, r12vrr_stack+93, r12vrr_stack+2695, r12vrr_stack+1542, r12vrr_stack+576, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1542, r12vrr_stack+5847, r12vrr_stack+5811, NULL, NULL, r12vrr_stack+93);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1650, r12vrr_stack+5883, r12vrr_stack+1542, r12vrr_stack+5775, r12vrr_stack+5847, r12vrr_stack+121);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3436, r12vrr_stack+6099, r12vrr_stack+1650, r12vrr_stack+5991, r12vrr_stack+5883, r12vrr_stack+4627);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7063, r12vrr_stack+3220, r12vrr_stack+6099, r12vrr_stack+6315, r12vrr_stack+5991, r12vrr_stack+1878);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7423, r12vrr_stack+7063, r12vrr_stack+3436, r12vrr_stack+3220, r12vrr_stack+6099, r12vrr_stack+4795);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+3220, &(Data->ss_r12_ss), NULL, r12vrr_stack+24, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+3223, r12vrr_stack+3220, &(Data->ss_r12_ss), r12vrr_stack+701, r12vrr_stack+24, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+3229, r12vrr_stack+3223, r12vrr_stack+3220, r12vrr_stack+707, r12vrr_stack+701, r12vrr_stack+24, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+867, r12vrr_stack+3229, r12vrr_stack+3223, r12vrr_stack+717, r12vrr_stack+707, r12vrr_stack+701, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+3239, r12vrr_stack+867, r12vrr_stack+3229, r12vrr_stack+521, r12vrr_stack+717, r12vrr_stack+707, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+3260, r12vrr_stack+3239, NULL, r12vrr_stack+882, r12vrr_stack+521, NULL, r12vrr_stack+717);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+3323, r12vrr_stack+3260, r12vrr_stack+3239, r12vrr_stack+2884, r12vrr_stack+882, r12vrr_stack+521, r12vrr_stack+732);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+2674, r12vrr_stack+3323, r12vrr_stack+3260, r12vrr_stack+3010, r12vrr_stack+2884, r12vrr_stack+882, r12vrr_stack+777);

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+3260, r12vrr_stack+3239, r12vrr_stack+867, r12vrr_stack+344, r12vrr_stack+521, r12vrr_stack+717, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+3449, r12vrr_stack+3260, NULL, r12vrr_stack+372, r12vrr_stack+344, NULL, r12vrr_stack+521);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+3533, r12vrr_stack+3449, r12vrr_stack+3260, r12vrr_stack+2046, r12vrr_stack+372, r12vrr_stack+344, r12vrr_stack+882);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+4627, r12vrr_stack+3533, r12vrr_stack+3449, r12vrr_stack+5075, r12vrr_stack+2046, r12vrr_stack+372, r12vrr_stack+2884);

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5775, r12vrr_stack+3871, r12vrr_stack+5355, r12vrr_stack+4186, r12vrr_stack+2359, r12vrr_stack+1317);
 tmp = r12vrr_stack + 5775;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1317, r12vrr_stack+5355, r12vrr_stack+7423, r12vrr_stack+6475, r12vrr_stack+4186, r12vrr_stack+3871);
 tmp = r12vrr_stack + 1317;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6090, r12vrr_stack+3871, r12vrr_stack+4186, r12vrr_stack+5355, r12vrr_stack+5075, r12vrr_stack+3010);
 tmp = r12vrr_stack + 6090;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4186, r12vrr_stack+5355, r12vrr_stack+6475, r12vrr_stack+7423, r12vrr_stack+7063, r12vrr_stack+5075);
 tmp = r12vrr_stack + 4186;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+6405, r12vrr_stack+2674, r12vrr_stack+3323, r12vrr_stack+3871, r12vrr_stack+3010, r12vrr_stack+2884, r12vrr_stack+1167);
 tmp = r12vrr_stack + 6405;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+3701, r12vrr_stack+4627, r12vrr_stack+3533, r12vrr_stack+5355, r12vrr_stack+5075, r12vrr_stack+2046, r12vrr_stack+3010);
 tmp = r12vrr_stack + 3701;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];


}

