/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_ppdp(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (p0|p0)^0 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, NULL, NULL, Data->F+1);

 /*--- compute (p0|00)^1 ---*/
 _BUILD_p000(Data,r12vrr_stack+15, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+18, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (p0|p0)^1 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21, r12vrr_stack+0, r12vrr_stack+18, NULL, NULL, Data->F+2);

 /*--- compute (d0|p0)^0 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+30, r12vrr_stack+6, r12vrr_stack+21, r12vrr_stack+3, r12vrr_stack+0, r12vrr_stack+15);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+0, r12vrr_stack+18, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+54, r12vrr_stack+3, r12vrr_stack+0, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+60, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+63, r12vrr_stack+18, r12vrr_stack+60, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+69, r12vrr_stack+48, r12vrr_stack+63, NULL, NULL, r12vrr_stack+18);

 /*--- compute (p0|d0)^0 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+87, r12vrr_stack+54, r12vrr_stack+48, NULL, NULL, r12vrr_stack+0);
 tmp = r12vrr_stack + 87;
 target_ptr = Libr12->gvrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|d0)^0 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+105, r12vrr_stack+87, r12vrr_stack+69, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+21);
 tmp = r12vrr_stack + 105;
 target_ptr = Libr12->gvrr_classes[2][2];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+141, r12vrr_stack+48, r12vrr_stack+63, r12vrr_stack+0, r12vrr_stack+18, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+151, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+161, r12vrr_stack+151, r12vrr_stack+141, NULL, NULL, r12vrr_stack+48);
 tmp = r12vrr_stack + 161;
 target_ptr = Libr12->gvrr_classes[1][3];
 for(i=0;i<30;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+191, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+194, r12vrr_stack+60, r12vrr_stack+191, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+200, r12vrr_stack+63, r12vrr_stack+194, r12vrr_stack+18, r12vrr_stack+60, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+210, r12vrr_stack+141, r12vrr_stack+200, NULL, NULL, r12vrr_stack+63);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+240, r12vrr_stack+161, r12vrr_stack+210, r12vrr_stack+151, r12vrr_stack+141, r12vrr_stack+69);
 tmp = r12vrr_stack + 240;
 target_ptr = Libr12->gvrr_classes[2][3];
 for(i=0;i<60;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+300, r12vrr_stack+141, r12vrr_stack+200, r12vrr_stack+48, r12vrr_stack+63, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+315, r12vrr_stack+151, r12vrr_stack+141, r12vrr_stack+54, r12vrr_stack+48, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+330, r12vrr_stack+315, r12vrr_stack+300, NULL, NULL, r12vrr_stack+141);
 tmp = r12vrr_stack + 330;
 target_ptr = Libr12->gvrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^2 ---*/
 _BUILD_p000(Data,r12vrr_stack+375, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (d0|00)^1 ---*/
 _BUILD_d000(Data,r12vrr_stack+378, r12vrr_stack+15, r12vrr_stack+375, Data->F+1, Data->F+2, NULL);

 /*--- compute (p0|p0)^2 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+384, r12vrr_stack+18, r12vrr_stack+60, NULL, NULL, Data->F+3);

 /*--- compute (d0|p0)^1 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+393, r12vrr_stack+21, r12vrr_stack+384, r12vrr_stack+0, r12vrr_stack+18, r12vrr_stack+375);

 /*--- compute (f0|p0)^0 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+411, r12vrr_stack+30, r12vrr_stack+393, r12vrr_stack+6, r12vrr_stack+21, r12vrr_stack+378);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+441, r12vrr_stack+63, r12vrr_stack+194, NULL, NULL, r12vrr_stack+60);

 /*--- compute (d0|d0)^1 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+459, r12vrr_stack+69, r12vrr_stack+441, r12vrr_stack+48, r12vrr_stack+63, r12vrr_stack+384);

 /*--- compute (f0|d0)^0 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+495, r12vrr_stack+105, r12vrr_stack+459, r12vrr_stack+87, r12vrr_stack+69, r12vrr_stack+393);
 tmp = r12vrr_stack + 495;
 target_ptr = Libr12->gvrr_classes[3][2];
 for(i=0;i<60;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+191, r12vrr_stack+0, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+69, r12vrr_stack+194, r12vrr_stack+48, r12vrr_stack+60, r12vrr_stack+191, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+375, r12vrr_stack+200, r12vrr_stack+69, NULL, NULL, r12vrr_stack+194);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+555, r12vrr_stack+210, r12vrr_stack+375, r12vrr_stack+141, r12vrr_stack+200, r12vrr_stack+441);

 /*--- compute (f0|f0)^0 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+615, r12vrr_stack+240, r12vrr_stack+555, r12vrr_stack+161, r12vrr_stack+210, r12vrr_stack+459);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+15, r12vrr_stack+200, r12vrr_stack+69, r12vrr_stack+63, r12vrr_stack+194, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+555, r12vrr_stack+300, r12vrr_stack+15, NULL, NULL, r12vrr_stack+200);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+715, r12vrr_stack+330, r12vrr_stack+555, r12vrr_stack+315, r12vrr_stack+300, r12vrr_stack+210);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+0, &(Data->ss_r12_ss), NULL, r12vrr_stack+3, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+0, &(Data->ss_r12_ss), r12vrr_stack+54, r12vrr_stack+3, Data->F+0, NULL);

 /*--- compute (p0||d0)^0 ---*/
 _R_BUILD_p0d0(Data,r12vrr_stack+555, r12vrr_stack+48, NULL, r12vrr_stack+87, r12vrr_stack+54, NULL, r12vrr_stack+3);
 tmp = r12vrr_stack + 555;
 target_ptr = Libr12->rvrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+141, r12vrr_stack+48, r12vrr_stack+0, r12vrr_stack+151, r12vrr_stack+54, r12vrr_stack+3, NULL);

 /*--- compute (p0||f0)^0 ---*/
 _R_BUILD_p0f0(Data,r12vrr_stack+573, r12vrr_stack+141, NULL, r12vrr_stack+161, r12vrr_stack+151, NULL, r12vrr_stack+54);
 tmp = r12vrr_stack + 573;
 target_ptr = Libr12->rvrr_classes[1][3];
 for(i=0;i<30;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|d0)^0 ---*/
 _T2_BUILD_p0d0(Data,&(Libr12->ShellQuartet),r12vrr_stack+441, r12vrr_stack+87, r12vrr_stack+161, r12vrr_stack+105, r12vrr_stack+30, r12vrr_stack+6);
 tmp = r12vrr_stack + 441;
 target_ptr = Libr12->t2vrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|f0)^0 ---*/
 _T2_BUILD_p0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+459, r12vrr_stack+161, r12vrr_stack+330, r12vrr_stack+240, r12vrr_stack+105, r12vrr_stack+87);
 tmp = r12vrr_stack + 459;
 target_ptr = Libr12->t2vrr_classes[1][3];
 for(i=0;i<30;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|d0)^0 ---*/
 _T2_BUILD_d0d0(Data,&(Libr12->ShellQuartet),r12vrr_stack+375, r12vrr_stack+105, r12vrr_stack+240, r12vrr_stack+495, r12vrr_stack+411, r12vrr_stack+30);
 tmp = r12vrr_stack + 375;
 target_ptr = Libr12->t2vrr_classes[2][2];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|f0)^0 ---*/
 _T2_BUILD_d0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+805, r12vrr_stack+240, r12vrr_stack+715, r12vrr_stack+615, r12vrr_stack+495, r12vrr_stack+105);
 tmp = r12vrr_stack + 805;
 target_ptr = Libr12->t2vrr_classes[2][3];
 for(i=0;i<60;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|d0)^0 ---*/
 _T1_BUILD_p0d0(Data,&(Libr12->ShellQuartet),r12vrr_stack+411, r12vrr_stack+87, r12vrr_stack+105, r12vrr_stack+161, r12vrr_stack+151, r12vrr_stack+54);
 tmp = r12vrr_stack + 411;
 target_ptr = Libr12->t1vrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|f0)^0 ---*/
 _T1_BUILD_p0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+15, r12vrr_stack+161, r12vrr_stack+240, r12vrr_stack+330, r12vrr_stack+315, r12vrr_stack+151);
 tmp = r12vrr_stack + 15;
 target_ptr = Libr12->t1vrr_classes[1][3];
 for(i=0;i<30;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|d0)^0 ---*/
 _T1_BUILD_d0d0(Data,&(Libr12->ShellQuartet),r12vrr_stack+191, r12vrr_stack+105, r12vrr_stack+495, r12vrr_stack+240, r12vrr_stack+161, r12vrr_stack+87);
 tmp = r12vrr_stack + 191;
 target_ptr = Libr12->t1vrr_classes[2][2];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|f0)^0 ---*/
 _T1_BUILD_d0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+489, r12vrr_stack+240, r12vrr_stack+615, r12vrr_stack+715, r12vrr_stack+330, r12vrr_stack+161);
 tmp = r12vrr_stack + 489;
 target_ptr = Libr12->t1vrr_classes[2][3];
 for(i=0;i<60;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||d0)^0 ---*/
 _R_BUILD_d0d0(Data,r12vrr_stack+300, r12vrr_stack+555, r12vrr_stack+48, r12vrr_stack+105, r12vrr_stack+87, r12vrr_stack+54, r12vrr_stack+6);
 tmp = r12vrr_stack + 300;
 target_ptr = Libr12->rvrr_classes[2][2];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||f0)^0 ---*/
 _R_BUILD_d0f0(Data,r12vrr_stack+603, r12vrr_stack+573, r12vrr_stack+141, r12vrr_stack+240, r12vrr_stack+161, r12vrr_stack+151, r12vrr_stack+87);
 tmp = r12vrr_stack + 603;
 target_ptr = Libr12->rvrr_classes[2][3];
 for(i=0;i<60;i++)
   target_ptr[i] += tmp[i];


}

