/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_hghg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hg|hg) integrals */

void d12hrr_order_hghg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[9][9][11] = int_stack + 0;
 Libderiv->deriv_classes[9][9][10] = int_stack + 3025;
 Libderiv->deriv_classes[9][9][9] = int_stack + 6050;
 Libderiv->deriv_classes[9][9][8] = int_stack + 9075;
 Libderiv->deriv_classes[9][9][7] = int_stack + 12100;
 Libderiv->dvrr_classes[9][8] = int_stack + 15125;
 Libderiv->deriv_classes[9][9][6] = int_stack + 17600;
 Libderiv->deriv_classes[9][9][2] = int_stack + 20625;
 Libderiv->deriv_classes[9][9][1] = int_stack + 23650;
 Libderiv->dvrr_classes[8][9] = int_stack + 26675;
 Libderiv->deriv_classes[9][9][0] = int_stack + 29150;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 32175;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 32616;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 33204;
 Libderiv->deriv2_classes[5][8][143] = int_stack + 33960;
 Libderiv->deriv2_classes[5][9][143] = int_stack + 34905;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 36060;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 36648;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 37432;
 Libderiv->deriv2_classes[6][8][143] = int_stack + 38440;
 Libderiv->deriv2_classes[6][9][143] = int_stack + 39700;
 Libderiv->deriv2_classes[7][5][143] = int_stack + 41240;
 Libderiv->deriv2_classes[7][6][143] = int_stack + 41996;
 Libderiv->deriv2_classes[7][7][143] = int_stack + 43004;
 Libderiv->deriv2_classes[7][8][143] = int_stack + 44300;
 Libderiv->deriv2_classes[7][9][143] = int_stack + 45920;
 Libderiv->deriv2_classes[8][5][143] = int_stack + 47900;
 Libderiv->deriv2_classes[8][6][143] = int_stack + 48845;
 Libderiv->deriv2_classes[8][7][143] = int_stack + 50105;
 Libderiv->deriv2_classes[8][8][143] = int_stack + 51725;
 Libderiv->deriv2_classes[8][9][143] = int_stack + 53750;
 Libderiv->deriv2_classes[9][5][143] = int_stack + 56225;
 Libderiv->deriv2_classes[9][6][143] = int_stack + 57380;
 Libderiv->deriv2_classes[9][7][143] = int_stack + 58920;
 Libderiv->deriv2_classes[9][8][143] = int_stack + 60900;
 Libderiv->deriv2_classes[9][9][143] = int_stack + 63375;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 66400;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 66841;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 67429;
 Libderiv->deriv2_classes[5][8][131] = int_stack + 68185;
 Libderiv->deriv2_classes[5][9][131] = int_stack + 69130;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 70285;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 70873;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 71657;
 Libderiv->deriv2_classes[6][8][131] = int_stack + 72665;
 Libderiv->deriv2_classes[6][9][131] = int_stack + 73925;
 Libderiv->deriv2_classes[7][5][131] = int_stack + 75465;
 Libderiv->deriv2_classes[7][6][131] = int_stack + 76221;
 Libderiv->deriv2_classes[7][7][131] = int_stack + 77229;
 Libderiv->deriv2_classes[7][8][131] = int_stack + 78525;
 Libderiv->deriv2_classes[7][9][131] = int_stack + 80145;
 Libderiv->deriv2_classes[8][5][131] = int_stack + 82125;
 Libderiv->deriv2_classes[8][6][131] = int_stack + 83070;
 Libderiv->deriv2_classes[8][7][131] = int_stack + 84330;
 Libderiv->deriv2_classes[8][8][131] = int_stack + 85950;
 Libderiv->deriv2_classes[8][9][131] = int_stack + 87975;
 Libderiv->deriv2_classes[9][5][131] = int_stack + 90450;
 Libderiv->deriv2_classes[9][6][131] = int_stack + 91605;
 Libderiv->deriv2_classes[9][7][131] = int_stack + 93145;
 Libderiv->deriv2_classes[9][8][131] = int_stack + 95125;
 Libderiv->deriv2_classes[9][9][131] = int_stack + 97600;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 100625;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 101066;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 101654;
 Libderiv->deriv2_classes[5][8][130] = int_stack + 102410;
 Libderiv->deriv2_classes[5][9][130] = int_stack + 103355;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 104510;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 105098;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 105882;
 Libderiv->deriv2_classes[6][8][130] = int_stack + 106890;
 Libderiv->deriv2_classes[6][9][130] = int_stack + 108150;
 Libderiv->deriv2_classes[7][5][130] = int_stack + 109690;
 Libderiv->deriv2_classes[7][6][130] = int_stack + 110446;
 Libderiv->deriv2_classes[7][7][130] = int_stack + 111454;
 Libderiv->deriv2_classes[7][8][130] = int_stack + 112750;
 Libderiv->deriv2_classes[7][9][130] = int_stack + 114370;
 Libderiv->deriv2_classes[8][5][130] = int_stack + 116350;
 Libderiv->deriv2_classes[8][6][130] = int_stack + 117295;
 Libderiv->deriv2_classes[8][7][130] = int_stack + 118555;
 Libderiv->deriv2_classes[8][8][130] = int_stack + 120175;
 Libderiv->deriv2_classes[8][9][130] = int_stack + 122200;
 Libderiv->deriv2_classes[9][5][130] = int_stack + 124675;
 Libderiv->deriv2_classes[9][6][130] = int_stack + 125830;
 Libderiv->deriv2_classes[9][7][130] = int_stack + 127370;
 Libderiv->deriv2_classes[9][8][130] = int_stack + 129350;
 Libderiv->deriv2_classes[9][9][130] = int_stack + 131825;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 134850;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 135291;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 135879;
 Libderiv->deriv2_classes[5][8][119] = int_stack + 136635;
 Libderiv->deriv2_classes[5][9][119] = int_stack + 137580;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 138735;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 139323;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 140107;
 Libderiv->deriv2_classes[6][8][119] = int_stack + 141115;
 Libderiv->deriv2_classes[6][9][119] = int_stack + 142375;
 Libderiv->deriv2_classes[7][5][119] = int_stack + 143915;
 Libderiv->deriv2_classes[7][6][119] = int_stack + 144671;
 Libderiv->deriv2_classes[7][7][119] = int_stack + 145679;
 Libderiv->deriv2_classes[7][8][119] = int_stack + 146975;
 Libderiv->deriv2_classes[7][9][119] = int_stack + 148595;
 Libderiv->deriv2_classes[8][5][119] = int_stack + 150575;
 Libderiv->deriv2_classes[8][6][119] = int_stack + 151520;
 Libderiv->deriv2_classes[8][7][119] = int_stack + 152780;
 Libderiv->deriv2_classes[8][8][119] = int_stack + 154400;
 Libderiv->deriv2_classes[8][9][119] = int_stack + 156425;
 Libderiv->deriv2_classes[9][5][119] = int_stack + 158900;
 Libderiv->deriv2_classes[9][6][119] = int_stack + 160055;
 Libderiv->deriv2_classes[9][7][119] = int_stack + 161595;
 Libderiv->deriv2_classes[9][8][119] = int_stack + 163575;
 Libderiv->deriv2_classes[9][9][119] = int_stack + 166050;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 169075;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 169516;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 170104;
 Libderiv->deriv2_classes[5][8][118] = int_stack + 170860;
 Libderiv->deriv2_classes[5][9][118] = int_stack + 171805;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 172960;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 173548;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 174332;
 Libderiv->deriv2_classes[6][8][118] = int_stack + 175340;
 Libderiv->deriv2_classes[6][9][118] = int_stack + 176600;
 Libderiv->deriv2_classes[7][5][118] = int_stack + 178140;
 Libderiv->deriv2_classes[7][6][118] = int_stack + 178896;
 Libderiv->deriv2_classes[7][7][118] = int_stack + 179904;
 Libderiv->deriv2_classes[7][8][118] = int_stack + 181200;
 Libderiv->deriv2_classes[7][9][118] = int_stack + 182820;
 Libderiv->deriv2_classes[8][5][118] = int_stack + 184800;
 Libderiv->deriv2_classes[8][6][118] = int_stack + 185745;
 Libderiv->deriv2_classes[8][7][118] = int_stack + 187005;
 Libderiv->deriv2_classes[8][8][118] = int_stack + 188625;
 Libderiv->deriv2_classes[8][9][118] = int_stack + 190650;
 Libderiv->deriv2_classes[9][5][118] = int_stack + 193125;
 Libderiv->deriv2_classes[9][6][118] = int_stack + 194280;
 Libderiv->deriv2_classes[9][7][118] = int_stack + 195820;
 Libderiv->deriv2_classes[9][8][118] = int_stack + 197800;
 Libderiv->deriv2_classes[9][9][118] = int_stack + 200275;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 203300;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 203741;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 204329;
 Libderiv->deriv2_classes[5][8][117] = int_stack + 205085;
 Libderiv->deriv2_classes[5][9][117] = int_stack + 206030;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 207185;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 207773;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 208557;
 Libderiv->deriv2_classes[6][8][117] = int_stack + 209565;
 Libderiv->deriv2_classes[6][9][117] = int_stack + 210825;
 Libderiv->deriv2_classes[7][5][117] = int_stack + 212365;
 Libderiv->deriv2_classes[7][6][117] = int_stack + 213121;
 Libderiv->deriv2_classes[7][7][117] = int_stack + 214129;
 Libderiv->deriv2_classes[7][8][117] = int_stack + 215425;
 Libderiv->deriv2_classes[7][9][117] = int_stack + 217045;
 Libderiv->deriv2_classes[8][5][117] = int_stack + 219025;
 Libderiv->deriv2_classes[8][6][117] = int_stack + 219970;
 Libderiv->deriv2_classes[8][7][117] = int_stack + 221230;
 Libderiv->deriv2_classes[8][8][117] = int_stack + 222850;
 Libderiv->deriv2_classes[8][9][117] = int_stack + 224875;
 Libderiv->deriv2_classes[9][5][117] = int_stack + 227350;
 Libderiv->deriv2_classes[9][6][117] = int_stack + 228505;
 Libderiv->deriv2_classes[9][7][117] = int_stack + 230045;
 Libderiv->deriv2_classes[9][8][117] = int_stack + 232025;
 Libderiv->deriv2_classes[9][9][117] = int_stack + 234500;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 237525;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 237966;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 238554;
 Libderiv->deriv2_classes[5][8][107] = int_stack + 239310;
 Libderiv->deriv2_classes[5][9][107] = int_stack + 240255;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 241410;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 241998;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 242782;
 Libderiv->deriv2_classes[6][8][107] = int_stack + 243790;
 Libderiv->deriv2_classes[6][9][107] = int_stack + 245050;
 Libderiv->deriv2_classes[7][5][107] = int_stack + 246590;
 Libderiv->deriv2_classes[7][6][107] = int_stack + 247346;
 Libderiv->deriv2_classes[7][7][107] = int_stack + 248354;
 Libderiv->deriv2_classes[7][8][107] = int_stack + 249650;
 Libderiv->deriv2_classes[7][9][107] = int_stack + 251270;
 Libderiv->deriv2_classes[8][5][107] = int_stack + 253250;
 Libderiv->deriv2_classes[8][6][107] = int_stack + 254195;
 Libderiv->deriv2_classes[8][7][107] = int_stack + 255455;
 Libderiv->deriv2_classes[8][8][107] = int_stack + 257075;
 Libderiv->deriv2_classes[8][9][107] = int_stack + 259100;
 Libderiv->deriv2_classes[9][5][107] = int_stack + 261575;
 Libderiv->deriv2_classes[9][6][107] = int_stack + 262730;
 Libderiv->deriv2_classes[9][7][107] = int_stack + 264270;
 Libderiv->deriv2_classes[9][8][107] = int_stack + 266250;
 Libderiv->deriv2_classes[9][9][107] = int_stack + 268725;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 271750;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 272191;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 272779;
 Libderiv->deriv2_classes[5][8][106] = int_stack + 273535;
 Libderiv->deriv2_classes[5][9][106] = int_stack + 274480;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 275635;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 276223;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 277007;
 Libderiv->deriv2_classes[6][8][106] = int_stack + 278015;
 Libderiv->deriv2_classes[6][9][106] = int_stack + 279275;
 Libderiv->deriv2_classes[7][5][106] = int_stack + 280815;
 Libderiv->deriv2_classes[7][6][106] = int_stack + 281571;
 Libderiv->deriv2_classes[7][7][106] = int_stack + 282579;
 Libderiv->deriv2_classes[7][8][106] = int_stack + 283875;
 Libderiv->deriv2_classes[7][9][106] = int_stack + 285495;
 Libderiv->deriv2_classes[8][5][106] = int_stack + 287475;
 Libderiv->deriv2_classes[8][6][106] = int_stack + 288420;
 Libderiv->deriv2_classes[8][7][106] = int_stack + 289680;
 Libderiv->deriv2_classes[8][8][106] = int_stack + 291300;
 Libderiv->deriv2_classes[8][9][106] = int_stack + 293325;
 Libderiv->deriv2_classes[9][5][106] = int_stack + 295800;
 Libderiv->deriv2_classes[9][6][106] = int_stack + 296955;
 Libderiv->deriv2_classes[9][7][106] = int_stack + 298495;
 Libderiv->deriv2_classes[9][8][106] = int_stack + 300475;
 Libderiv->deriv2_classes[9][9][106] = int_stack + 302950;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 305975;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 306416;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 307004;
 Libderiv->deriv2_classes[5][8][105] = int_stack + 307760;
 Libderiv->deriv2_classes[5][9][105] = int_stack + 308705;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 309860;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 310448;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 311232;
 Libderiv->deriv2_classes[6][8][105] = int_stack + 312240;
 Libderiv->deriv2_classes[6][9][105] = int_stack + 313500;
 Libderiv->deriv2_classes[7][5][105] = int_stack + 315040;
 Libderiv->deriv2_classes[7][6][105] = int_stack + 315796;
 Libderiv->deriv2_classes[7][7][105] = int_stack + 316804;
 Libderiv->deriv2_classes[7][8][105] = int_stack + 318100;
 Libderiv->deriv2_classes[7][9][105] = int_stack + 319720;
 Libderiv->deriv2_classes[8][5][105] = int_stack + 321700;
 Libderiv->deriv2_classes[8][6][105] = int_stack + 322645;
 Libderiv->deriv2_classes[8][7][105] = int_stack + 323905;
 Libderiv->deriv2_classes[8][8][105] = int_stack + 325525;
 Libderiv->deriv2_classes[8][9][105] = int_stack + 327550;
 Libderiv->deriv2_classes[9][5][105] = int_stack + 330025;
 Libderiv->deriv2_classes[9][6][105] = int_stack + 331180;
 Libderiv->deriv2_classes[9][7][105] = int_stack + 332720;
 Libderiv->deriv2_classes[9][8][105] = int_stack + 334700;
 Libderiv->deriv2_classes[9][9][105] = int_stack + 337175;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 340200;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 340641;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 341229;
 Libderiv->deriv2_classes[5][8][104] = int_stack + 341985;
 Libderiv->deriv2_classes[5][9][104] = int_stack + 342930;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 344085;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 344673;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 345457;
 Libderiv->deriv2_classes[6][8][104] = int_stack + 346465;
 Libderiv->deriv2_classes[6][9][104] = int_stack + 347725;
 Libderiv->deriv2_classes[7][5][104] = int_stack + 349265;
 Libderiv->deriv2_classes[7][6][104] = int_stack + 350021;
 Libderiv->deriv2_classes[7][7][104] = int_stack + 351029;
 Libderiv->deriv2_classes[7][8][104] = int_stack + 352325;
 Libderiv->deriv2_classes[7][9][104] = int_stack + 353945;
 Libderiv->deriv2_classes[8][5][104] = int_stack + 355925;
 Libderiv->deriv2_classes[8][6][104] = int_stack + 356870;
 Libderiv->deriv2_classes[8][7][104] = int_stack + 358130;
 Libderiv->deriv2_classes[8][8][104] = int_stack + 359750;
 Libderiv->deriv2_classes[8][9][104] = int_stack + 361775;
 Libderiv->deriv2_classes[9][5][104] = int_stack + 364250;
 Libderiv->deriv2_classes[9][6][104] = int_stack + 365405;
 Libderiv->deriv2_classes[9][7][104] = int_stack + 366945;
 Libderiv->deriv2_classes[9][8][104] = int_stack + 368925;
 Libderiv->deriv2_classes[9][9][104] = int_stack + 371400;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 374425;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 374866;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 375454;
 Libderiv->deriv2_classes[5][8][95] = int_stack + 376210;
 Libderiv->deriv2_classes[5][9][95] = int_stack + 377155;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 378310;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 378898;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 379682;
 Libderiv->deriv2_classes[6][8][95] = int_stack + 380690;
 Libderiv->deriv2_classes[6][9][95] = int_stack + 381950;
 Libderiv->deriv2_classes[7][5][95] = int_stack + 383490;
 Libderiv->deriv2_classes[7][6][95] = int_stack + 384246;
 Libderiv->deriv2_classes[7][7][95] = int_stack + 385254;
 Libderiv->deriv2_classes[7][8][95] = int_stack + 386550;
 Libderiv->deriv2_classes[7][9][95] = int_stack + 388170;
 Libderiv->deriv2_classes[8][5][95] = int_stack + 390150;
 Libderiv->deriv2_classes[8][6][95] = int_stack + 391095;
 Libderiv->deriv2_classes[8][7][95] = int_stack + 392355;
 Libderiv->deriv2_classes[8][8][95] = int_stack + 393975;
 Libderiv->deriv2_classes[8][9][95] = int_stack + 396000;
 Libderiv->deriv2_classes[9][5][95] = int_stack + 398475;
 Libderiv->deriv2_classes[9][6][95] = int_stack + 399630;
 Libderiv->deriv2_classes[9][7][95] = int_stack + 401170;
 Libderiv->deriv2_classes[9][8][95] = int_stack + 403150;
 Libderiv->deriv2_classes[9][9][95] = int_stack + 405625;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 408650;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 409091;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 409679;
 Libderiv->deriv2_classes[5][8][94] = int_stack + 410435;
 Libderiv->deriv2_classes[5][9][94] = int_stack + 411380;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 412535;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 413123;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 413907;
 Libderiv->deriv2_classes[6][8][94] = int_stack + 414915;
 Libderiv->deriv2_classes[6][9][94] = int_stack + 416175;
 Libderiv->deriv2_classes[7][5][94] = int_stack + 417715;
 Libderiv->deriv2_classes[7][6][94] = int_stack + 418471;
 Libderiv->deriv2_classes[7][7][94] = int_stack + 419479;
 Libderiv->deriv2_classes[7][8][94] = int_stack + 420775;
 Libderiv->deriv2_classes[7][9][94] = int_stack + 422395;
 Libderiv->deriv2_classes[8][5][94] = int_stack + 424375;
 Libderiv->deriv2_classes[8][6][94] = int_stack + 425320;
 Libderiv->deriv2_classes[8][7][94] = int_stack + 426580;
 Libderiv->deriv2_classes[8][8][94] = int_stack + 428200;
 Libderiv->deriv2_classes[8][9][94] = int_stack + 430225;
 Libderiv->deriv2_classes[9][5][94] = int_stack + 432700;
 Libderiv->deriv2_classes[9][6][94] = int_stack + 433855;
 Libderiv->deriv2_classes[9][7][94] = int_stack + 435395;
 Libderiv->deriv2_classes[9][8][94] = int_stack + 437375;
 Libderiv->deriv2_classes[9][9][94] = int_stack + 439850;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 442875;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 443316;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 443904;
 Libderiv->deriv2_classes[5][8][93] = int_stack + 444660;
 Libderiv->deriv2_classes[5][9][93] = int_stack + 445605;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 446760;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 447348;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 448132;
 Libderiv->deriv2_classes[6][8][93] = int_stack + 449140;
 Libderiv->deriv2_classes[6][9][93] = int_stack + 450400;
 Libderiv->deriv2_classes[7][5][93] = int_stack + 451940;
 Libderiv->deriv2_classes[7][6][93] = int_stack + 452696;
 Libderiv->deriv2_classes[7][7][93] = int_stack + 453704;
 Libderiv->deriv2_classes[7][8][93] = int_stack + 455000;
 Libderiv->deriv2_classes[7][9][93] = int_stack + 456620;
 Libderiv->deriv2_classes[8][5][93] = int_stack + 458600;
 Libderiv->deriv2_classes[8][6][93] = int_stack + 459545;
 Libderiv->deriv2_classes[8][7][93] = int_stack + 460805;
 Libderiv->deriv2_classes[8][8][93] = int_stack + 462425;
 Libderiv->deriv2_classes[8][9][93] = int_stack + 464450;
 Libderiv->deriv2_classes[9][5][93] = int_stack + 466925;
 Libderiv->deriv2_classes[9][6][93] = int_stack + 468080;
 Libderiv->deriv2_classes[9][7][93] = int_stack + 469620;
 Libderiv->deriv2_classes[9][8][93] = int_stack + 471600;
 Libderiv->deriv2_classes[9][9][93] = int_stack + 474075;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 477100;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 477541;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 478129;
 Libderiv->deriv2_classes[5][8][92] = int_stack + 478885;
 Libderiv->deriv2_classes[5][9][92] = int_stack + 479830;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 480985;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 481573;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 482357;
 Libderiv->deriv2_classes[6][8][92] = int_stack + 483365;
 Libderiv->deriv2_classes[6][9][92] = int_stack + 484625;
 Libderiv->deriv2_classes[7][5][92] = int_stack + 486165;
 Libderiv->deriv2_classes[7][6][92] = int_stack + 486921;
 Libderiv->deriv2_classes[7][7][92] = int_stack + 487929;
 Libderiv->deriv2_classes[7][8][92] = int_stack + 489225;
 Libderiv->deriv2_classes[7][9][92] = int_stack + 490845;
 Libderiv->deriv2_classes[8][5][92] = int_stack + 492825;
 Libderiv->deriv2_classes[8][6][92] = int_stack + 493770;
 Libderiv->deriv2_classes[8][7][92] = int_stack + 495030;
 Libderiv->deriv2_classes[8][8][92] = int_stack + 496650;
 Libderiv->deriv2_classes[8][9][92] = int_stack + 498675;
 Libderiv->deriv2_classes[9][5][92] = int_stack + 501150;
 Libderiv->deriv2_classes[9][6][92] = int_stack + 502305;
 Libderiv->deriv2_classes[9][7][92] = int_stack + 503845;
 Libderiv->deriv2_classes[9][8][92] = int_stack + 505825;
 Libderiv->deriv2_classes[9][9][92] = int_stack + 508300;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 511325;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 511766;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 512354;
 Libderiv->deriv2_classes[5][8][91] = int_stack + 513110;
 Libderiv->deriv2_classes[5][9][91] = int_stack + 514055;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 515210;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 515798;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 516582;
 Libderiv->deriv2_classes[6][8][91] = int_stack + 517590;
 Libderiv->deriv2_classes[6][9][91] = int_stack + 518850;
 Libderiv->deriv2_classes[7][5][91] = int_stack + 520390;
 Libderiv->deriv2_classes[7][6][91] = int_stack + 521146;
 Libderiv->deriv2_classes[7][7][91] = int_stack + 522154;
 Libderiv->deriv2_classes[7][8][91] = int_stack + 523450;
 Libderiv->deriv2_classes[7][9][91] = int_stack + 525070;
 Libderiv->deriv2_classes[8][5][91] = int_stack + 527050;
 Libderiv->deriv2_classes[8][6][91] = int_stack + 527995;
 Libderiv->deriv2_classes[8][7][91] = int_stack + 529255;
 Libderiv->deriv2_classes[8][8][91] = int_stack + 530875;
 Libderiv->deriv2_classes[8][9][91] = int_stack + 532900;
 Libderiv->deriv2_classes[9][5][91] = int_stack + 535375;
 Libderiv->deriv2_classes[9][6][91] = int_stack + 536530;
 Libderiv->deriv2_classes[9][7][91] = int_stack + 538070;
 Libderiv->deriv2_classes[9][8][91] = int_stack + 540050;
 Libderiv->deriv2_classes[9][9][91] = int_stack + 542525;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 545550;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 545991;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 546579;
 Libderiv->deriv2_classes[5][8][83] = int_stack + 547335;
 Libderiv->deriv2_classes[5][9][83] = int_stack + 548280;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 549435;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 550023;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 550807;
 Libderiv->deriv2_classes[6][8][83] = int_stack + 551815;
 Libderiv->deriv2_classes[6][9][83] = int_stack + 553075;
 Libderiv->deriv2_classes[7][5][83] = int_stack + 554615;
 Libderiv->deriv2_classes[7][6][83] = int_stack + 555371;
 Libderiv->deriv2_classes[7][7][83] = int_stack + 556379;
 Libderiv->deriv2_classes[7][8][83] = int_stack + 557675;
 Libderiv->deriv2_classes[7][9][83] = int_stack + 559295;
 Libderiv->deriv2_classes[8][5][83] = int_stack + 561275;
 Libderiv->deriv2_classes[8][6][83] = int_stack + 562220;
 Libderiv->deriv2_classes[8][7][83] = int_stack + 563480;
 Libderiv->deriv2_classes[8][8][83] = int_stack + 565100;
 Libderiv->deriv2_classes[8][9][83] = int_stack + 567125;
 Libderiv->deriv_classes[9][5][11] = int_stack + 569600;
 Libderiv->deriv2_classes[9][5][83] = int_stack + 570755;
 Libderiv->deriv_classes[9][6][11] = int_stack + 571910;
 Libderiv->deriv2_classes[9][6][83] = int_stack + 573450;
 Libderiv->deriv_classes[9][7][11] = int_stack + 574990;
 Libderiv->deriv2_classes[9][7][83] = int_stack + 576970;
 Libderiv->deriv_classes[9][8][11] = int_stack + 578950;
 Libderiv->deriv2_classes[9][8][83] = int_stack + 581425;
 Libderiv->deriv2_classes[9][9][83] = int_stack + 583900;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 586925;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 587366;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 587954;
 Libderiv->deriv2_classes[5][8][82] = int_stack + 588710;
 Libderiv->deriv2_classes[5][9][82] = int_stack + 589655;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 590810;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 591398;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 592182;
 Libderiv->deriv2_classes[6][8][82] = int_stack + 593190;
 Libderiv->deriv2_classes[6][9][82] = int_stack + 594450;
 Libderiv->deriv2_classes[7][5][82] = int_stack + 595990;
 Libderiv->deriv2_classes[7][6][82] = int_stack + 596746;
 Libderiv->deriv2_classes[7][7][82] = int_stack + 597754;
 Libderiv->deriv2_classes[7][8][82] = int_stack + 599050;
 Libderiv->deriv2_classes[7][9][82] = int_stack + 600670;
 Libderiv->deriv2_classes[8][5][82] = int_stack + 602650;
 Libderiv->deriv2_classes[8][6][82] = int_stack + 603595;
 Libderiv->deriv2_classes[8][7][82] = int_stack + 604855;
 Libderiv->deriv2_classes[8][8][82] = int_stack + 606475;
 Libderiv->deriv2_classes[8][9][82] = int_stack + 608500;
 Libderiv->deriv_classes[9][5][10] = int_stack + 610975;
 Libderiv->deriv2_classes[9][5][82] = int_stack + 612130;
 Libderiv->deriv_classes[9][6][10] = int_stack + 613285;
 Libderiv->deriv2_classes[9][6][82] = int_stack + 614825;
 Libderiv->deriv_classes[9][7][10] = int_stack + 616365;
 Libderiv->deriv2_classes[9][7][82] = int_stack + 618345;
 Libderiv->deriv_classes[9][8][10] = int_stack + 620325;
 Libderiv->deriv2_classes[9][8][82] = int_stack + 622800;
 Libderiv->deriv2_classes[9][9][82] = int_stack + 625275;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 628300;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 628741;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 629329;
 Libderiv->deriv2_classes[5][8][81] = int_stack + 630085;
 Libderiv->deriv2_classes[5][9][81] = int_stack + 631030;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 632185;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 632773;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 633557;
 Libderiv->deriv2_classes[6][8][81] = int_stack + 634565;
 Libderiv->deriv2_classes[6][9][81] = int_stack + 635825;
 Libderiv->deriv2_classes[7][5][81] = int_stack + 637365;
 Libderiv->deriv2_classes[7][6][81] = int_stack + 638121;
 Libderiv->deriv2_classes[7][7][81] = int_stack + 639129;
 Libderiv->deriv2_classes[7][8][81] = int_stack + 640425;
 Libderiv->deriv2_classes[7][9][81] = int_stack + 642045;
 Libderiv->deriv2_classes[8][5][81] = int_stack + 644025;
 Libderiv->deriv2_classes[8][6][81] = int_stack + 644970;
 Libderiv->deriv2_classes[8][7][81] = int_stack + 646230;
 Libderiv->deriv2_classes[8][8][81] = int_stack + 647850;
 Libderiv->deriv2_classes[8][9][81] = int_stack + 649875;
 Libderiv->deriv_classes[9][5][9] = int_stack + 652350;
 Libderiv->deriv2_classes[9][5][81] = int_stack + 653505;
 Libderiv->deriv_classes[9][6][9] = int_stack + 654660;
 Libderiv->deriv2_classes[9][6][81] = int_stack + 656200;
 Libderiv->deriv_classes[9][7][9] = int_stack + 657740;
 Libderiv->deriv2_classes[9][7][81] = int_stack + 659720;
 Libderiv->deriv_classes[9][8][9] = int_stack + 661700;
 Libderiv->deriv2_classes[9][8][81] = int_stack + 664175;
 Libderiv->deriv2_classes[9][9][81] = int_stack + 666650;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 669675;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 670116;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 670704;
 Libderiv->deriv2_classes[5][8][80] = int_stack + 671460;
 Libderiv->deriv2_classes[5][9][80] = int_stack + 672405;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 673560;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 674148;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 674932;
 Libderiv->deriv2_classes[6][8][80] = int_stack + 675940;
 Libderiv->deriv2_classes[6][9][80] = int_stack + 677200;
 Libderiv->deriv2_classes[7][5][80] = int_stack + 678740;
 Libderiv->deriv2_classes[7][6][80] = int_stack + 679496;
 Libderiv->deriv2_classes[7][7][80] = int_stack + 680504;
 Libderiv->deriv2_classes[7][8][80] = int_stack + 681800;
 Libderiv->deriv2_classes[7][9][80] = int_stack + 683420;
 Libderiv->deriv2_classes[8][5][80] = int_stack + 685400;
 Libderiv->deriv2_classes[8][6][80] = int_stack + 686345;
 Libderiv->deriv2_classes[8][7][80] = int_stack + 687605;
 Libderiv->deriv2_classes[8][8][80] = int_stack + 689225;
 Libderiv->deriv2_classes[8][9][80] = int_stack + 691250;
 Libderiv->deriv_classes[9][5][8] = int_stack + 693725;
 Libderiv->deriv2_classes[9][5][80] = int_stack + 694880;
 Libderiv->deriv_classes[9][6][8] = int_stack + 696035;
 Libderiv->deriv2_classes[9][6][80] = int_stack + 697575;
 Libderiv->deriv_classes[9][7][8] = int_stack + 699115;
 Libderiv->deriv2_classes[9][7][80] = int_stack + 701095;
 Libderiv->deriv_classes[9][8][8] = int_stack + 703075;
 Libderiv->deriv2_classes[9][8][80] = int_stack + 705550;
 Libderiv->deriv2_classes[9][9][80] = int_stack + 708025;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 711050;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 711491;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 712079;
 Libderiv->deriv2_classes[5][8][79] = int_stack + 712835;
 Libderiv->deriv2_classes[5][9][79] = int_stack + 713780;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 714935;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 715523;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 716307;
 Libderiv->deriv2_classes[6][8][79] = int_stack + 717315;
 Libderiv->deriv2_classes[6][9][79] = int_stack + 718575;
 Libderiv->deriv2_classes[7][5][79] = int_stack + 720115;
 Libderiv->deriv2_classes[7][6][79] = int_stack + 720871;
 Libderiv->deriv2_classes[7][7][79] = int_stack + 721879;
 Libderiv->deriv2_classes[7][8][79] = int_stack + 723175;
 Libderiv->deriv2_classes[7][9][79] = int_stack + 724795;
 Libderiv->deriv2_classes[8][5][79] = int_stack + 726775;
 Libderiv->deriv2_classes[8][6][79] = int_stack + 727720;
 Libderiv->deriv2_classes[8][7][79] = int_stack + 728980;
 Libderiv->deriv2_classes[8][8][79] = int_stack + 730600;
 Libderiv->deriv2_classes[8][9][79] = int_stack + 732625;
 Libderiv->deriv_classes[9][5][7] = int_stack + 735100;
 Libderiv->deriv2_classes[9][5][79] = int_stack + 736255;
 Libderiv->deriv_classes[9][6][7] = int_stack + 737410;
 Libderiv->deriv2_classes[9][6][79] = int_stack + 738950;
 Libderiv->deriv_classes[9][7][7] = int_stack + 740490;
 Libderiv->deriv2_classes[9][7][79] = int_stack + 742470;
 Libderiv->deriv_classes[9][8][7] = int_stack + 744450;
 Libderiv->deriv2_classes[9][8][79] = int_stack + 746925;
 Libderiv->deriv2_classes[9][9][79] = int_stack + 749400;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 752425;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 752866;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 753454;
 Libderiv->deriv2_classes[5][8][78] = int_stack + 754210;
 Libderiv->deriv2_classes[5][9][78] = int_stack + 755155;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 756310;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 756898;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 757682;
 Libderiv->deriv2_classes[6][8][78] = int_stack + 758690;
 Libderiv->deriv2_classes[6][9][78] = int_stack + 759950;
 Libderiv->deriv2_classes[7][5][78] = int_stack + 761490;
 Libderiv->deriv2_classes[7][6][78] = int_stack + 762246;
 Libderiv->deriv2_classes[7][7][78] = int_stack + 763254;
 Libderiv->deriv2_classes[7][8][78] = int_stack + 764550;
 Libderiv->deriv2_classes[7][9][78] = int_stack + 766170;
 Libderiv->deriv2_classes[8][5][78] = int_stack + 768150;
 Libderiv->deriv2_classes[8][6][78] = int_stack + 769095;
 Libderiv->deriv2_classes[8][7][78] = int_stack + 770355;
 Libderiv->deriv2_classes[8][8][78] = int_stack + 771975;
 Libderiv->deriv2_classes[8][9][78] = int_stack + 774000;
 Libderiv->dvrr_classes[9][5] = int_stack + 776475;
 Libderiv->deriv_classes[9][5][6] = int_stack + 777630;
 Libderiv->deriv2_classes[9][5][78] = int_stack + 778785;
 Libderiv->dvrr_classes[9][6] = int_stack + 779940;
 Libderiv->deriv_classes[9][6][6] = int_stack + 781480;
 Libderiv->deriv2_classes[9][6][78] = int_stack + 783020;
 Libderiv->dvrr_classes[9][7] = int_stack + 784560;
 Libderiv->deriv_classes[9][7][6] = int_stack + 786540;
 Libderiv->deriv2_classes[9][7][78] = int_stack + 788520;
 Libderiv->deriv_classes[9][8][6] = int_stack + 790500;
 Libderiv->deriv2_classes[9][8][78] = int_stack + 792975;
 Libderiv->deriv2_classes[9][9][78] = int_stack + 795450;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 798475;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 798916;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 799504;
 Libderiv->deriv2_classes[5][8][35] = int_stack + 800260;
 Libderiv->deriv2_classes[5][9][35] = int_stack + 801205;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 802360;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 802948;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 803732;
 Libderiv->deriv2_classes[6][8][35] = int_stack + 804740;
 Libderiv->deriv2_classes[6][9][35] = int_stack + 806000;
 Libderiv->deriv2_classes[7][5][35] = int_stack + 807540;
 Libderiv->deriv2_classes[7][6][35] = int_stack + 808296;
 Libderiv->deriv2_classes[7][7][35] = int_stack + 809304;
 Libderiv->deriv2_classes[7][8][35] = int_stack + 810600;
 Libderiv->deriv2_classes[7][9][35] = int_stack + 812220;
 Libderiv->deriv2_classes[8][5][35] = int_stack + 814200;
 Libderiv->deriv2_classes[8][6][35] = int_stack + 815145;
 Libderiv->deriv2_classes[8][7][35] = int_stack + 816405;
 Libderiv->deriv2_classes[8][8][35] = int_stack + 818025;
 Libderiv->deriv2_classes[8][9][35] = int_stack + 820050;
 Libderiv->deriv2_classes[9][5][35] = int_stack + 822525;
 Libderiv->deriv2_classes[9][6][35] = int_stack + 823680;
 Libderiv->deriv2_classes[9][7][35] = int_stack + 825220;
 Libderiv->deriv2_classes[9][8][35] = int_stack + 827200;
 Libderiv->deriv2_classes[9][9][35] = int_stack + 829675;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 832700;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 833141;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 833729;
 Libderiv->deriv2_classes[5][8][34] = int_stack + 834485;
 Libderiv->deriv2_classes[5][9][34] = int_stack + 835430;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 836585;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 837173;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 837957;
 Libderiv->deriv2_classes[6][8][34] = int_stack + 838965;
 Libderiv->deriv2_classes[6][9][34] = int_stack + 840225;
 Libderiv->deriv2_classes[7][5][34] = int_stack + 841765;
 Libderiv->deriv2_classes[7][6][34] = int_stack + 842521;
 Libderiv->deriv2_classes[7][7][34] = int_stack + 843529;
 Libderiv->deriv2_classes[7][8][34] = int_stack + 844825;
 Libderiv->deriv2_classes[7][9][34] = int_stack + 846445;
 Libderiv->deriv2_classes[8][5][34] = int_stack + 848425;
 Libderiv->deriv2_classes[8][6][34] = int_stack + 849370;
 Libderiv->deriv2_classes[8][7][34] = int_stack + 850630;
 Libderiv->deriv2_classes[8][8][34] = int_stack + 852250;
 Libderiv->deriv2_classes[8][9][34] = int_stack + 854275;
 Libderiv->deriv2_classes[9][5][34] = int_stack + 856750;
 Libderiv->deriv2_classes[9][6][34] = int_stack + 857905;
 Libderiv->deriv2_classes[9][7][34] = int_stack + 859445;
 Libderiv->deriv2_classes[9][8][34] = int_stack + 861425;
 Libderiv->deriv2_classes[9][9][34] = int_stack + 863900;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 866925;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 867366;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 867954;
 Libderiv->deriv2_classes[5][8][33] = int_stack + 868710;
 Libderiv->deriv2_classes[5][9][33] = int_stack + 869655;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 870810;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 871398;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 872182;
 Libderiv->deriv2_classes[6][8][33] = int_stack + 873190;
 Libderiv->deriv2_classes[6][9][33] = int_stack + 874450;
 Libderiv->deriv2_classes[7][5][33] = int_stack + 875990;
 Libderiv->deriv2_classes[7][6][33] = int_stack + 876746;
 Libderiv->deriv2_classes[7][7][33] = int_stack + 877754;
 Libderiv->deriv2_classes[7][8][33] = int_stack + 879050;
 Libderiv->deriv2_classes[7][9][33] = int_stack + 880670;
 Libderiv->deriv2_classes[8][5][33] = int_stack + 882650;
 Libderiv->deriv2_classes[8][6][33] = int_stack + 883595;
 Libderiv->deriv2_classes[8][7][33] = int_stack + 884855;
 Libderiv->deriv2_classes[8][8][33] = int_stack + 886475;
 Libderiv->deriv2_classes[8][9][33] = int_stack + 888500;
 Libderiv->deriv2_classes[9][5][33] = int_stack + 890975;
 Libderiv->deriv2_classes[9][6][33] = int_stack + 892130;
 Libderiv->deriv2_classes[9][7][33] = int_stack + 893670;
 Libderiv->deriv2_classes[9][8][33] = int_stack + 895650;
 Libderiv->deriv2_classes[9][9][33] = int_stack + 898125;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 901150;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 901591;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 902179;
 Libderiv->deriv2_classes[5][8][32] = int_stack + 902935;
 Libderiv->deriv2_classes[5][9][32] = int_stack + 903880;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 905035;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 905623;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 906407;
 Libderiv->deriv2_classes[6][8][32] = int_stack + 907415;
 Libderiv->deriv2_classes[6][9][32] = int_stack + 908675;
 Libderiv->deriv2_classes[7][5][32] = int_stack + 910215;
 Libderiv->deriv2_classes[7][6][32] = int_stack + 910971;
 Libderiv->deriv2_classes[7][7][32] = int_stack + 911979;
 Libderiv->deriv2_classes[7][8][32] = int_stack + 913275;
 Libderiv->deriv2_classes[7][9][32] = int_stack + 914895;
 Libderiv->deriv2_classes[8][5][32] = int_stack + 916875;
 Libderiv->deriv2_classes[8][6][32] = int_stack + 917820;
 Libderiv->deriv2_classes[8][7][32] = int_stack + 919080;
 Libderiv->deriv2_classes[8][8][32] = int_stack + 920700;
 Libderiv->deriv2_classes[8][9][32] = int_stack + 922725;
 Libderiv->deriv2_classes[9][5][32] = int_stack + 925200;
 Libderiv->deriv2_classes[9][6][32] = int_stack + 926355;
 Libderiv->deriv2_classes[9][7][32] = int_stack + 927895;
 Libderiv->deriv2_classes[9][8][32] = int_stack + 929875;
 Libderiv->deriv2_classes[9][9][32] = int_stack + 932350;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 935375;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 935816;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 936404;
 Libderiv->deriv2_classes[5][8][31] = int_stack + 937160;
 Libderiv->deriv2_classes[5][9][31] = int_stack + 938105;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 939260;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 939848;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 940632;
 Libderiv->deriv2_classes[6][8][31] = int_stack + 941640;
 Libderiv->deriv2_classes[6][9][31] = int_stack + 942900;
 Libderiv->deriv2_classes[7][5][31] = int_stack + 944440;
 Libderiv->deriv2_classes[7][6][31] = int_stack + 945196;
 Libderiv->deriv2_classes[7][7][31] = int_stack + 946204;
 Libderiv->deriv2_classes[7][8][31] = int_stack + 947500;
 Libderiv->deriv2_classes[7][9][31] = int_stack + 949120;
 Libderiv->deriv2_classes[8][5][31] = int_stack + 951100;
 Libderiv->deriv2_classes[8][6][31] = int_stack + 952045;
 Libderiv->deriv2_classes[8][7][31] = int_stack + 953305;
 Libderiv->deriv2_classes[8][8][31] = int_stack + 954925;
 Libderiv->deriv2_classes[8][9][31] = int_stack + 956950;
 Libderiv->deriv2_classes[9][5][31] = int_stack + 959425;
 Libderiv->deriv2_classes[9][6][31] = int_stack + 960580;
 Libderiv->deriv2_classes[9][7][31] = int_stack + 962120;
 Libderiv->deriv2_classes[9][8][31] = int_stack + 964100;
 Libderiv->deriv2_classes[9][9][31] = int_stack + 966575;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 969600;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 970041;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 970629;
 Libderiv->deriv2_classes[5][8][30] = int_stack + 971385;
 Libderiv->deriv2_classes[5][9][30] = int_stack + 972330;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 973485;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 974073;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 974857;
 Libderiv->deriv2_classes[6][8][30] = int_stack + 975865;
 Libderiv->deriv2_classes[6][9][30] = int_stack + 977125;
 Libderiv->deriv2_classes[7][5][30] = int_stack + 978665;
 Libderiv->deriv2_classes[7][6][30] = int_stack + 979421;
 Libderiv->deriv2_classes[7][7][30] = int_stack + 980429;
 Libderiv->deriv2_classes[7][8][30] = int_stack + 981725;
 Libderiv->deriv2_classes[7][9][30] = int_stack + 983345;
 Libderiv->deriv2_classes[8][5][30] = int_stack + 985325;
 Libderiv->deriv2_classes[8][6][30] = int_stack + 986270;
 Libderiv->deriv2_classes[8][7][30] = int_stack + 987530;
 Libderiv->deriv2_classes[8][8][30] = int_stack + 989150;
 Libderiv->deriv2_classes[8][9][30] = int_stack + 991175;
 Libderiv->deriv_classes[9][5][2] = int_stack + 993650;
 Libderiv->deriv2_classes[9][5][30] = int_stack + 994805;
 Libderiv->deriv_classes[9][6][2] = int_stack + 995960;
 Libderiv->deriv2_classes[9][6][30] = int_stack + 997500;
 Libderiv->deriv_classes[9][7][2] = int_stack + 999040;
 Libderiv->deriv2_classes[9][7][30] = int_stack + 1001020;
 Libderiv->deriv_classes[9][8][2] = int_stack + 1003000;
 Libderiv->deriv2_classes[9][8][30] = int_stack + 1005475;
 Libderiv->deriv2_classes[9][9][30] = int_stack + 1007950;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 1010975;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 1011416;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 1012004;
 Libderiv->deriv2_classes[5][8][26] = int_stack + 1012760;
 Libderiv->deriv2_classes[5][9][26] = int_stack + 1013705;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 1014860;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 1015448;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 1016232;
 Libderiv->deriv2_classes[6][8][26] = int_stack + 1017240;
 Libderiv->deriv2_classes[6][9][26] = int_stack + 1018500;
 Libderiv->deriv2_classes[7][5][26] = int_stack + 1020040;
 Libderiv->deriv2_classes[7][6][26] = int_stack + 1020796;
 Libderiv->deriv2_classes[7][7][26] = int_stack + 1021804;
 Libderiv->deriv2_classes[7][8][26] = int_stack + 1023100;
 Libderiv->deriv2_classes[7][9][26] = int_stack + 1024720;
 Libderiv->deriv2_classes[8][5][26] = int_stack + 1026700;
 Libderiv->deriv2_classes[8][6][26] = int_stack + 1027645;
 Libderiv->deriv2_classes[8][7][26] = int_stack + 1028905;
 Libderiv->deriv2_classes[8][8][26] = int_stack + 1030525;
 Libderiv->deriv2_classes[8][9][26] = int_stack + 1032550;
 Libderiv->deriv2_classes[9][5][26] = int_stack + 1035025;
 Libderiv->deriv2_classes[9][6][26] = int_stack + 1036180;
 Libderiv->deriv2_classes[9][7][26] = int_stack + 1037720;
 Libderiv->deriv2_classes[9][8][26] = int_stack + 1039700;
 Libderiv->deriv2_classes[9][9][26] = int_stack + 1042175;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 1045200;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 1045641;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 1046229;
 Libderiv->deriv2_classes[5][8][23] = int_stack + 1046985;
 Libderiv->deriv2_classes[5][9][23] = int_stack + 1047930;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 1049085;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 1049673;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 1050457;
 Libderiv->deriv2_classes[6][8][23] = int_stack + 1051465;
 Libderiv->deriv2_classes[6][9][23] = int_stack + 1052725;
 Libderiv->deriv2_classes[7][5][23] = int_stack + 1054265;
 Libderiv->deriv2_classes[7][6][23] = int_stack + 1055021;
 Libderiv->deriv2_classes[7][7][23] = int_stack + 1056029;
 Libderiv->deriv2_classes[7][8][23] = int_stack + 1057325;
 Libderiv->deriv2_classes[7][9][23] = int_stack + 1058945;
 Libderiv->deriv2_classes[8][5][23] = int_stack + 1060925;
 Libderiv->deriv2_classes[8][6][23] = int_stack + 1061870;
 Libderiv->deriv2_classes[8][7][23] = int_stack + 1063130;
 Libderiv->deriv2_classes[8][8][23] = int_stack + 1064750;
 Libderiv->deriv2_classes[8][9][23] = int_stack + 1066775;
 Libderiv->deriv2_classes[9][5][23] = int_stack + 1069250;
 Libderiv->deriv2_classes[9][6][23] = int_stack + 1070405;
 Libderiv->deriv2_classes[9][7][23] = int_stack + 1071945;
 Libderiv->deriv2_classes[9][8][23] = int_stack + 1073925;
 Libderiv->deriv2_classes[9][9][23] = int_stack + 1076400;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 1079425;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 1079866;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 1080454;
 Libderiv->deriv2_classes[5][8][22] = int_stack + 1081210;
 Libderiv->deriv2_classes[5][9][22] = int_stack + 1082155;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 1083310;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 1083898;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 1084682;
 Libderiv->deriv2_classes[6][8][22] = int_stack + 1085690;
 Libderiv->deriv2_classes[6][9][22] = int_stack + 1086950;
 Libderiv->deriv2_classes[7][5][22] = int_stack + 1088490;
 Libderiv->deriv2_classes[7][6][22] = int_stack + 1089246;
 Libderiv->deriv2_classes[7][7][22] = int_stack + 1090254;
 Libderiv->deriv2_classes[7][8][22] = int_stack + 1091550;
 Libderiv->deriv2_classes[7][9][22] = int_stack + 1093170;
 Libderiv->deriv2_classes[8][5][22] = int_stack + 1095150;
 Libderiv->deriv2_classes[8][6][22] = int_stack + 1096095;
 Libderiv->deriv2_classes[8][7][22] = int_stack + 1097355;
 Libderiv->deriv2_classes[8][8][22] = int_stack + 1098975;
 Libderiv->deriv2_classes[8][9][22] = int_stack + 1101000;
 Libderiv->deriv2_classes[9][5][22] = int_stack + 1103475;
 Libderiv->deriv2_classes[9][6][22] = int_stack + 1104630;
 Libderiv->deriv2_classes[9][7][22] = int_stack + 1106170;
 Libderiv->deriv2_classes[9][8][22] = int_stack + 1108150;
 Libderiv->deriv2_classes[9][9][22] = int_stack + 1110625;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 1113650;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 1114091;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 1114679;
 Libderiv->deriv2_classes[5][8][21] = int_stack + 1115435;
 Libderiv->deriv2_classes[5][9][21] = int_stack + 1116380;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 1117535;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 1118123;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 1118907;
 Libderiv->deriv2_classes[6][8][21] = int_stack + 1119915;
 Libderiv->deriv2_classes[6][9][21] = int_stack + 1121175;
 Libderiv->deriv2_classes[7][5][21] = int_stack + 1122715;
 Libderiv->deriv2_classes[7][6][21] = int_stack + 1123471;
 Libderiv->deriv2_classes[7][7][21] = int_stack + 1124479;
 Libderiv->deriv2_classes[7][8][21] = int_stack + 1125775;
 Libderiv->deriv2_classes[7][9][21] = int_stack + 1127395;
 Libderiv->deriv2_classes[8][5][21] = int_stack + 1129375;
 Libderiv->deriv2_classes[8][6][21] = int_stack + 1130320;
 Libderiv->deriv2_classes[8][7][21] = int_stack + 1131580;
 Libderiv->deriv2_classes[8][8][21] = int_stack + 1133200;
 Libderiv->deriv2_classes[8][9][21] = int_stack + 1135225;
 Libderiv->deriv2_classes[9][5][21] = int_stack + 1137700;
 Libderiv->deriv2_classes[9][6][21] = int_stack + 1138855;
 Libderiv->deriv2_classes[9][7][21] = int_stack + 1140395;
 Libderiv->deriv2_classes[9][8][21] = int_stack + 1142375;
 Libderiv->deriv2_classes[9][9][21] = int_stack + 1144850;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 1147875;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 1148316;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 1148904;
 Libderiv->deriv2_classes[5][8][20] = int_stack + 1149660;
 Libderiv->deriv2_classes[5][9][20] = int_stack + 1150605;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 1151760;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 1152348;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 1153132;
 Libderiv->deriv2_classes[6][8][20] = int_stack + 1154140;
 Libderiv->deriv2_classes[6][9][20] = int_stack + 1155400;
 Libderiv->deriv2_classes[7][5][20] = int_stack + 1156940;
 Libderiv->deriv2_classes[7][6][20] = int_stack + 1157696;
 Libderiv->deriv2_classes[7][7][20] = int_stack + 1158704;
 Libderiv->deriv2_classes[7][8][20] = int_stack + 1160000;
 Libderiv->deriv2_classes[7][9][20] = int_stack + 1161620;
 Libderiv->deriv2_classes[8][5][20] = int_stack + 1163600;
 Libderiv->deriv2_classes[8][6][20] = int_stack + 1164545;
 Libderiv->deriv2_classes[8][7][20] = int_stack + 1165805;
 Libderiv->deriv2_classes[8][8][20] = int_stack + 1167425;
 Libderiv->deriv2_classes[8][9][20] = int_stack + 1169450;
 Libderiv->deriv2_classes[9][5][20] = int_stack + 1171925;
 Libderiv->deriv2_classes[9][6][20] = int_stack + 1173080;
 Libderiv->deriv2_classes[9][7][20] = int_stack + 1174620;
 Libderiv->deriv2_classes[9][8][20] = int_stack + 1176600;
 Libderiv->deriv2_classes[9][9][20] = int_stack + 1179075;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 1182100;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 1182541;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 1183129;
 Libderiv->deriv2_classes[5][8][19] = int_stack + 1183885;
 Libderiv->deriv2_classes[5][9][19] = int_stack + 1184830;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 1185985;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 1186573;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 1187357;
 Libderiv->deriv2_classes[6][8][19] = int_stack + 1188365;
 Libderiv->deriv2_classes[6][9][19] = int_stack + 1189625;
 Libderiv->deriv2_classes[7][5][19] = int_stack + 1191165;
 Libderiv->deriv2_classes[7][6][19] = int_stack + 1191921;
 Libderiv->deriv2_classes[7][7][19] = int_stack + 1192929;
 Libderiv->deriv2_classes[7][8][19] = int_stack + 1194225;
 Libderiv->deriv2_classes[7][9][19] = int_stack + 1195845;
 Libderiv->deriv2_classes[8][5][19] = int_stack + 1197825;
 Libderiv->deriv2_classes[8][6][19] = int_stack + 1198770;
 Libderiv->deriv2_classes[8][7][19] = int_stack + 1200030;
 Libderiv->deriv2_classes[8][8][19] = int_stack + 1201650;
 Libderiv->deriv2_classes[8][9][19] = int_stack + 1203675;
 Libderiv->deriv2_classes[9][5][19] = int_stack + 1206150;
 Libderiv->deriv2_classes[9][6][19] = int_stack + 1207305;
 Libderiv->deriv2_classes[9][7][19] = int_stack + 1208845;
 Libderiv->deriv2_classes[9][8][19] = int_stack + 1210825;
 Libderiv->deriv2_classes[9][9][19] = int_stack + 1213300;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 1216325;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 1216766;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 1217354;
 Libderiv->deriv2_classes[5][8][18] = int_stack + 1218110;
 Libderiv->deriv2_classes[5][9][18] = int_stack + 1219055;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 1220210;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 1220798;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 1221582;
 Libderiv->deriv2_classes[6][8][18] = int_stack + 1222590;
 Libderiv->deriv2_classes[6][9][18] = int_stack + 1223850;
 Libderiv->deriv2_classes[7][5][18] = int_stack + 1225390;
 Libderiv->deriv2_classes[7][6][18] = int_stack + 1226146;
 Libderiv->deriv2_classes[7][7][18] = int_stack + 1227154;
 Libderiv->deriv2_classes[7][8][18] = int_stack + 1228450;
 Libderiv->deriv2_classes[7][9][18] = int_stack + 1230070;
 Libderiv->deriv2_classes[8][5][18] = int_stack + 1232050;
 Libderiv->deriv2_classes[8][6][18] = int_stack + 1232995;
 Libderiv->deriv2_classes[8][7][18] = int_stack + 1234255;
 Libderiv->deriv2_classes[8][8][18] = int_stack + 1235875;
 Libderiv->deriv2_classes[8][9][18] = int_stack + 1237900;
 Libderiv->deriv_classes[9][5][1] = int_stack + 1240375;
 Libderiv->deriv2_classes[9][5][18] = int_stack + 1241530;
 Libderiv->deriv_classes[9][6][1] = int_stack + 1242685;
 Libderiv->deriv2_classes[9][6][18] = int_stack + 1244225;
 Libderiv->deriv_classes[9][7][1] = int_stack + 1245765;
 Libderiv->deriv2_classes[9][7][18] = int_stack + 1247745;
 Libderiv->deriv_classes[9][8][1] = int_stack + 1249725;
 Libderiv->deriv2_classes[9][8][18] = int_stack + 1252200;
 Libderiv->deriv2_classes[9][9][18] = int_stack + 1254675;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 1257700;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 1258141;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 1258729;
 Libderiv->deriv2_classes[5][8][14] = int_stack + 1259485;
 Libderiv->deriv2_classes[5][9][14] = int_stack + 1260430;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 1261585;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 1262173;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 1262957;
 Libderiv->deriv2_classes[6][8][14] = int_stack + 1263965;
 Libderiv->deriv2_classes[6][9][14] = int_stack + 1265225;
 Libderiv->deriv2_classes[7][5][14] = int_stack + 1266765;
 Libderiv->deriv2_classes[7][6][14] = int_stack + 1267521;
 Libderiv->deriv2_classes[7][7][14] = int_stack + 1268529;
 Libderiv->deriv2_classes[7][8][14] = int_stack + 1269825;
 Libderiv->deriv2_classes[7][9][14] = int_stack + 1271445;
 Libderiv->deriv2_classes[8][5][14] = int_stack + 1273425;
 Libderiv->deriv2_classes[8][6][14] = int_stack + 1274370;
 Libderiv->deriv2_classes[8][7][14] = int_stack + 1275630;
 Libderiv->deriv2_classes[8][8][14] = int_stack + 1277250;
 Libderiv->deriv2_classes[8][9][14] = int_stack + 1279275;
 Libderiv->deriv2_classes[9][5][14] = int_stack + 1281750;
 Libderiv->deriv2_classes[9][6][14] = int_stack + 1282905;
 Libderiv->deriv2_classes[9][7][14] = int_stack + 1284445;
 Libderiv->deriv2_classes[9][8][14] = int_stack + 1286425;
 Libderiv->deriv2_classes[9][9][14] = int_stack + 1288900;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 1291925;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 1292366;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 1292954;
 Libderiv->deriv2_classes[5][8][13] = int_stack + 1293710;
 Libderiv->deriv2_classes[5][9][13] = int_stack + 1294655;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 1295810;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 1296398;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 1297182;
 Libderiv->deriv2_classes[6][8][13] = int_stack + 1298190;
 Libderiv->deriv2_classes[6][9][13] = int_stack + 1299450;
 Libderiv->deriv2_classes[7][5][13] = int_stack + 1300990;
 Libderiv->deriv2_classes[7][6][13] = int_stack + 1301746;
 Libderiv->deriv2_classes[7][7][13] = int_stack + 1302754;
 Libderiv->deriv2_classes[7][8][13] = int_stack + 1304050;
 Libderiv->deriv2_classes[7][9][13] = int_stack + 1305670;
 Libderiv->deriv2_classes[8][5][13] = int_stack + 1307650;
 Libderiv->deriv2_classes[8][6][13] = int_stack + 1308595;
 Libderiv->deriv2_classes[8][7][13] = int_stack + 1309855;
 Libderiv->deriv2_classes[8][8][13] = int_stack + 1311475;
 Libderiv->deriv2_classes[8][9][13] = int_stack + 1313500;
 Libderiv->deriv2_classes[9][5][13] = int_stack + 1315975;
 Libderiv->deriv2_classes[9][6][13] = int_stack + 1317130;
 Libderiv->deriv2_classes[9][7][13] = int_stack + 1318670;
 Libderiv->deriv2_classes[9][8][13] = int_stack + 1320650;
 Libderiv->deriv2_classes[9][9][13] = int_stack + 1323125;
 Libderiv->deriv_classes[5][5][11] = int_stack + 1326150;
 Libderiv->deriv_classes[5][6][11] = int_stack + 1326591;
 Libderiv->deriv_classes[5][7][11] = int_stack + 1327179;
 Libderiv->deriv_classes[5][8][11] = int_stack + 1327935;
 Libderiv->deriv_classes[5][9][11] = int_stack + 1328880;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 1330035;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 1330476;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 1331064;
 Libderiv->deriv2_classes[5][8][11] = int_stack + 1331820;
 Libderiv->deriv2_classes[5][9][11] = int_stack + 1332765;
 Libderiv->deriv_classes[6][5][11] = int_stack + 1333920;
 Libderiv->deriv_classes[6][6][11] = int_stack + 1334508;
 Libderiv->deriv_classes[6][7][11] = int_stack + 1335292;
 Libderiv->deriv_classes[6][8][11] = int_stack + 1336300;
 Libderiv->deriv_classes[6][9][11] = int_stack + 1337560;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 1339100;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 1339688;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 1340472;
 Libderiv->deriv2_classes[6][8][11] = int_stack + 1341480;
 Libderiv->deriv2_classes[6][9][11] = int_stack + 1342740;
 Libderiv->deriv_classes[7][5][11] = int_stack + 1344280;
 Libderiv->deriv_classes[7][6][11] = int_stack + 1345036;
 Libderiv->deriv_classes[7][7][11] = int_stack + 1346044;
 Libderiv->deriv_classes[7][8][11] = int_stack + 1347340;
 Libderiv->deriv_classes[7][9][11] = int_stack + 1348960;
 Libderiv->deriv2_classes[7][5][11] = int_stack + 1350940;
 Libderiv->deriv2_classes[7][6][11] = int_stack + 1351696;
 Libderiv->deriv2_classes[7][7][11] = int_stack + 1352704;
 Libderiv->deriv2_classes[7][8][11] = int_stack + 1354000;
 Libderiv->deriv2_classes[7][9][11] = int_stack + 1355620;
 Libderiv->deriv_classes[8][5][11] = int_stack + 1357600;
 Libderiv->deriv_classes[8][6][11] = int_stack + 1358545;
 Libderiv->deriv_classes[8][7][11] = int_stack + 1359805;
 Libderiv->deriv_classes[8][8][11] = int_stack + 1361425;
 Libderiv->deriv_classes[8][9][11] = int_stack + 1363450;
 Libderiv->deriv2_classes[8][5][11] = int_stack + 1365925;
 Libderiv->deriv2_classes[8][6][11] = int_stack + 1366870;
 Libderiv->deriv2_classes[8][7][11] = int_stack + 1368130;
 Libderiv->deriv2_classes[8][8][11] = int_stack + 1369750;
 Libderiv->deriv2_classes[8][9][11] = int_stack + 1371775;
 Libderiv->deriv2_classes[9][5][11] = int_stack + 1374250;
 Libderiv->deriv2_classes[9][6][11] = int_stack + 1375405;
 Libderiv->deriv2_classes[9][7][11] = int_stack + 1376945;
 Libderiv->deriv2_classes[9][8][11] = int_stack + 1378925;
 Libderiv->deriv2_classes[9][9][11] = int_stack + 1381400;
 Libderiv->deriv_classes[5][5][10] = int_stack + 1384425;
 Libderiv->deriv_classes[5][6][10] = int_stack + 1384866;
 Libderiv->deriv_classes[5][7][10] = int_stack + 1385454;
 Libderiv->deriv_classes[5][8][10] = int_stack + 1386210;
 Libderiv->deriv_classes[5][9][10] = int_stack + 1387155;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 1388310;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 1388751;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 1389339;
 Libderiv->deriv2_classes[5][8][10] = int_stack + 1390095;
 Libderiv->deriv2_classes[5][9][10] = int_stack + 1391040;
 Libderiv->deriv_classes[6][5][10] = int_stack + 1392195;
 Libderiv->deriv_classes[6][6][10] = int_stack + 1392783;
 Libderiv->deriv_classes[6][7][10] = int_stack + 1393567;
 Libderiv->deriv_classes[6][8][10] = int_stack + 1394575;
 Libderiv->deriv_classes[6][9][10] = int_stack + 1395835;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 1397375;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 1397963;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 1398747;
 Libderiv->deriv2_classes[6][8][10] = int_stack + 1399755;
 Libderiv->deriv2_classes[6][9][10] = int_stack + 1401015;
 Libderiv->deriv_classes[7][5][10] = int_stack + 1402555;
 Libderiv->deriv_classes[7][6][10] = int_stack + 1403311;
 Libderiv->deriv_classes[7][7][10] = int_stack + 1404319;
 Libderiv->deriv_classes[7][8][10] = int_stack + 1405615;
 Libderiv->deriv_classes[7][9][10] = int_stack + 1407235;
 Libderiv->deriv2_classes[7][5][10] = int_stack + 1409215;
 Libderiv->deriv2_classes[7][6][10] = int_stack + 1409971;
 Libderiv->deriv2_classes[7][7][10] = int_stack + 1410979;
 Libderiv->deriv2_classes[7][8][10] = int_stack + 1412275;
 Libderiv->deriv2_classes[7][9][10] = int_stack + 1413895;
 Libderiv->deriv_classes[8][5][10] = int_stack + 1415875;
 Libderiv->deriv_classes[8][6][10] = int_stack + 1416820;
 Libderiv->deriv_classes[8][7][10] = int_stack + 1418080;
 Libderiv->deriv_classes[8][8][10] = int_stack + 1419700;
 Libderiv->deriv_classes[8][9][10] = int_stack + 1421725;
 Libderiv->deriv2_classes[8][5][10] = int_stack + 1424200;
 Libderiv->deriv2_classes[8][6][10] = int_stack + 1425145;
 Libderiv->deriv2_classes[8][7][10] = int_stack + 1426405;
 Libderiv->deriv2_classes[8][8][10] = int_stack + 1428025;
 Libderiv->deriv2_classes[8][9][10] = int_stack + 1430050;
 Libderiv->deriv2_classes[9][5][10] = int_stack + 1432525;
 Libderiv->deriv2_classes[9][6][10] = int_stack + 1433680;
 Libderiv->deriv2_classes[9][7][10] = int_stack + 1435220;
 Libderiv->deriv2_classes[9][8][10] = int_stack + 1437200;
 Libderiv->deriv2_classes[9][9][10] = int_stack + 1439675;
 Libderiv->deriv_classes[5][5][9] = int_stack + 1442700;
 Libderiv->deriv_classes[5][6][9] = int_stack + 1443141;
 Libderiv->deriv_classes[5][7][9] = int_stack + 1443729;
 Libderiv->deriv_classes[5][8][9] = int_stack + 1444485;
 Libderiv->deriv_classes[5][9][9] = int_stack + 1445430;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 1446585;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 1447026;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 1447614;
 Libderiv->deriv2_classes[5][8][9] = int_stack + 1448370;
 Libderiv->deriv2_classes[5][9][9] = int_stack + 1449315;
 Libderiv->deriv_classes[6][5][9] = int_stack + 1450470;
 Libderiv->deriv_classes[6][6][9] = int_stack + 1451058;
 Libderiv->deriv_classes[6][7][9] = int_stack + 1451842;
 Libderiv->deriv_classes[6][8][9] = int_stack + 1452850;
 Libderiv->deriv_classes[6][9][9] = int_stack + 1454110;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 1455650;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 1456238;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 1457022;
 Libderiv->deriv2_classes[6][8][9] = int_stack + 1458030;
 Libderiv->deriv2_classes[6][9][9] = int_stack + 1459290;
 Libderiv->deriv_classes[7][5][9] = int_stack + 1460830;
 Libderiv->deriv_classes[7][6][9] = int_stack + 1461586;
 Libderiv->deriv_classes[7][7][9] = int_stack + 1462594;
 Libderiv->deriv_classes[7][8][9] = int_stack + 1463890;
 Libderiv->deriv_classes[7][9][9] = int_stack + 1465510;
 Libderiv->deriv2_classes[7][5][9] = int_stack + 1467490;
 Libderiv->deriv2_classes[7][6][9] = int_stack + 1468246;
 Libderiv->deriv2_classes[7][7][9] = int_stack + 1469254;
 Libderiv->deriv2_classes[7][8][9] = int_stack + 1470550;
 Libderiv->deriv2_classes[7][9][9] = int_stack + 1472170;
 Libderiv->deriv_classes[8][5][9] = int_stack + 1474150;
 Libderiv->deriv_classes[8][6][9] = int_stack + 1475095;
 Libderiv->deriv_classes[8][7][9] = int_stack + 1476355;
 Libderiv->deriv_classes[8][8][9] = int_stack + 1477975;
 Libderiv->deriv_classes[8][9][9] = int_stack + 1480000;
 Libderiv->deriv2_classes[8][5][9] = int_stack + 1482475;
 Libderiv->deriv2_classes[8][6][9] = int_stack + 1483420;
 Libderiv->deriv2_classes[8][7][9] = int_stack + 1484680;
 Libderiv->deriv2_classes[8][8][9] = int_stack + 1486300;
 Libderiv->deriv2_classes[8][9][9] = int_stack + 1488325;
 Libderiv->deriv2_classes[9][5][9] = int_stack + 1490800;
 Libderiv->deriv2_classes[9][6][9] = int_stack + 1491955;
 Libderiv->deriv2_classes[9][7][9] = int_stack + 1493495;
 Libderiv->deriv2_classes[9][8][9] = int_stack + 1495475;
 Libderiv->deriv2_classes[9][9][9] = int_stack + 1497950;
 Libderiv->deriv_classes[5][5][8] = int_stack + 1500975;
 Libderiv->deriv_classes[5][6][8] = int_stack + 1501416;
 Libderiv->deriv_classes[5][7][8] = int_stack + 1502004;
 Libderiv->deriv_classes[5][8][8] = int_stack + 1502760;
 Libderiv->deriv_classes[5][9][8] = int_stack + 1503705;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 1504860;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 1505301;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 1505889;
 Libderiv->deriv2_classes[5][8][8] = int_stack + 1506645;
 Libderiv->deriv2_classes[5][9][8] = int_stack + 1507590;
 Libderiv->deriv_classes[6][5][8] = int_stack + 1508745;
 Libderiv->deriv_classes[6][6][8] = int_stack + 1509333;
 Libderiv->deriv_classes[6][7][8] = int_stack + 1510117;
 Libderiv->deriv_classes[6][8][8] = int_stack + 1511125;
 Libderiv->deriv_classes[6][9][8] = int_stack + 1512385;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 1513925;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 1514513;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 1515297;
 Libderiv->deriv2_classes[6][8][8] = int_stack + 1516305;
 Libderiv->deriv2_classes[6][9][8] = int_stack + 1517565;
 Libderiv->deriv_classes[7][5][8] = int_stack + 1519105;
 Libderiv->deriv_classes[7][6][8] = int_stack + 1519861;
 Libderiv->deriv_classes[7][7][8] = int_stack + 1520869;
 Libderiv->deriv_classes[7][8][8] = int_stack + 1522165;
 Libderiv->deriv_classes[7][9][8] = int_stack + 1523785;
 Libderiv->deriv2_classes[7][5][8] = int_stack + 1525765;
 Libderiv->deriv2_classes[7][6][8] = int_stack + 1526521;
 Libderiv->deriv2_classes[7][7][8] = int_stack + 1527529;
 Libderiv->deriv2_classes[7][8][8] = int_stack + 1528825;
 Libderiv->deriv2_classes[7][9][8] = int_stack + 1530445;
 Libderiv->deriv_classes[8][5][8] = int_stack + 1532425;
 Libderiv->deriv_classes[8][6][8] = int_stack + 1533370;
 Libderiv->deriv_classes[8][7][8] = int_stack + 1534630;
 Libderiv->deriv_classes[8][8][8] = int_stack + 1536250;
 Libderiv->deriv_classes[8][9][8] = int_stack + 1538275;
 Libderiv->deriv2_classes[8][5][8] = int_stack + 1540750;
 Libderiv->deriv2_classes[8][6][8] = int_stack + 1541695;
 Libderiv->deriv2_classes[8][7][8] = int_stack + 1542955;
 Libderiv->deriv2_classes[8][8][8] = int_stack + 1544575;
 Libderiv->deriv2_classes[8][9][8] = int_stack + 1546600;
 Libderiv->deriv2_classes[9][5][8] = int_stack + 1549075;
 Libderiv->deriv2_classes[9][6][8] = int_stack + 1550230;
 Libderiv->deriv2_classes[9][7][8] = int_stack + 1551770;
 Libderiv->deriv2_classes[9][8][8] = int_stack + 1553750;
 Libderiv->deriv2_classes[9][9][8] = int_stack + 1556225;
 Libderiv->deriv_classes[5][5][7] = int_stack + 1559250;
 Libderiv->deriv_classes[5][6][7] = int_stack + 1559691;
 Libderiv->deriv_classes[5][7][7] = int_stack + 1560279;
 Libderiv->deriv_classes[5][8][7] = int_stack + 1561035;
 Libderiv->deriv_classes[5][9][7] = int_stack + 1561980;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 1563135;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 1563576;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 1564164;
 Libderiv->deriv2_classes[5][8][7] = int_stack + 1564920;
 Libderiv->deriv2_classes[5][9][7] = int_stack + 1565865;
 Libderiv->deriv_classes[6][5][7] = int_stack + 1567020;
 Libderiv->deriv_classes[6][6][7] = int_stack + 1567608;
 Libderiv->deriv_classes[6][7][7] = int_stack + 1568392;
 Libderiv->deriv_classes[6][8][7] = int_stack + 1569400;
 Libderiv->deriv_classes[6][9][7] = int_stack + 1570660;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 1572200;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 1572788;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 1573572;
 Libderiv->deriv2_classes[6][8][7] = int_stack + 1574580;
 Libderiv->deriv2_classes[6][9][7] = int_stack + 1575840;
 Libderiv->deriv_classes[7][5][7] = int_stack + 1577380;
 Libderiv->deriv_classes[7][6][7] = int_stack + 1578136;
 Libderiv->deriv_classes[7][7][7] = int_stack + 1579144;
 Libderiv->deriv_classes[7][8][7] = int_stack + 1580440;
 Libderiv->deriv_classes[7][9][7] = int_stack + 1582060;
 Libderiv->deriv2_classes[7][5][7] = int_stack + 1584040;
 Libderiv->deriv2_classes[7][6][7] = int_stack + 1584796;
 Libderiv->deriv2_classes[7][7][7] = int_stack + 1585804;
 Libderiv->deriv2_classes[7][8][7] = int_stack + 1587100;
 Libderiv->deriv2_classes[7][9][7] = int_stack + 1588720;
 Libderiv->deriv_classes[8][5][7] = int_stack + 1590700;
 Libderiv->deriv_classes[8][6][7] = int_stack + 1591645;
 Libderiv->deriv_classes[8][7][7] = int_stack + 1592905;
 Libderiv->deriv_classes[8][8][7] = int_stack + 1594525;
 Libderiv->deriv_classes[8][9][7] = int_stack + 1596550;
 Libderiv->deriv2_classes[8][5][7] = int_stack + 1599025;
 Libderiv->deriv2_classes[8][6][7] = int_stack + 1599970;
 Libderiv->deriv2_classes[8][7][7] = int_stack + 1601230;
 Libderiv->deriv2_classes[8][8][7] = int_stack + 1602850;
 Libderiv->deriv2_classes[8][9][7] = int_stack + 1604875;
 Libderiv->deriv2_classes[9][5][7] = int_stack + 1607350;
 Libderiv->deriv2_classes[9][6][7] = int_stack + 1608505;
 Libderiv->deriv2_classes[9][7][7] = int_stack + 1610045;
 Libderiv->deriv2_classes[9][8][7] = int_stack + 1612025;
 Libderiv->deriv2_classes[9][9][7] = int_stack + 1614500;
 Libderiv->deriv_classes[5][5][6] = int_stack + 1617525;
 Libderiv->deriv_classes[5][6][6] = int_stack + 1617966;
 Libderiv->deriv_classes[5][7][6] = int_stack + 1618554;
 Libderiv->deriv_classes[5][8][6] = int_stack + 1619310;
 Libderiv->deriv_classes[5][9][6] = int_stack + 1620255;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 1621410;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 1621851;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 1622439;
 Libderiv->deriv2_classes[5][8][6] = int_stack + 1623195;
 Libderiv->deriv2_classes[5][9][6] = int_stack + 1624140;
 Libderiv->deriv_classes[6][5][6] = int_stack + 1625295;
 Libderiv->deriv_classes[6][6][6] = int_stack + 1625883;
 Libderiv->deriv_classes[6][7][6] = int_stack + 1626667;
 Libderiv->deriv_classes[6][8][6] = int_stack + 1627675;
 Libderiv->deriv_classes[6][9][6] = int_stack + 1628935;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 1630475;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 1631063;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 1631847;
 Libderiv->deriv2_classes[6][8][6] = int_stack + 1632855;
 Libderiv->deriv2_classes[6][9][6] = int_stack + 1634115;
 Libderiv->deriv_classes[7][5][6] = int_stack + 1635655;
 Libderiv->deriv_classes[7][6][6] = int_stack + 1636411;
 Libderiv->deriv_classes[7][7][6] = int_stack + 1637419;
 Libderiv->deriv_classes[7][8][6] = int_stack + 1638715;
 Libderiv->deriv_classes[7][9][6] = int_stack + 1640335;
 Libderiv->deriv2_classes[7][5][6] = int_stack + 1642315;
 Libderiv->deriv2_classes[7][6][6] = int_stack + 1643071;
 Libderiv->deriv2_classes[7][7][6] = int_stack + 1644079;
 Libderiv->deriv2_classes[7][8][6] = int_stack + 1645375;
 Libderiv->deriv2_classes[7][9][6] = int_stack + 1646995;
 Libderiv->dvrr_classes[8][5] = int_stack + 1648975;
 Libderiv->deriv_classes[8][5][6] = int_stack + 1649920;
 Libderiv->dvrr_classes[8][6] = int_stack + 1650865;
 Libderiv->deriv_classes[8][6][6] = int_stack + 1652125;
 Libderiv->dvrr_classes[8][7] = int_stack + 1653385;
 Libderiv->deriv_classes[8][7][6] = int_stack + 1655005;
 Libderiv->dvrr_classes[8][8] = int_stack + 1656625;
 Libderiv->deriv_classes[8][8][6] = int_stack + 1658650;
 Libderiv->deriv_classes[8][9][6] = int_stack + 1660675;
 Libderiv->deriv2_classes[8][5][6] = int_stack + 1663150;
 Libderiv->deriv2_classes[8][6][6] = int_stack + 1664095;
 Libderiv->deriv2_classes[8][7][6] = int_stack + 1665355;
 Libderiv->deriv2_classes[8][8][6] = int_stack + 1666975;
 Libderiv->deriv2_classes[8][9][6] = int_stack + 1669000;
 Libderiv->deriv_classes[9][5][0] = int_stack + 1671475;
 Libderiv->deriv2_classes[9][5][6] = int_stack + 1672630;
 Libderiv->deriv_classes[9][6][0] = int_stack + 1673785;
 Libderiv->deriv2_classes[9][6][6] = int_stack + 1675325;
 Libderiv->deriv_classes[9][7][0] = int_stack + 1676865;
 Libderiv->deriv2_classes[9][7][6] = int_stack + 1678845;
 Libderiv->deriv_classes[9][8][0] = int_stack + 1680825;
 Libderiv->deriv2_classes[9][8][6] = int_stack + 1683300;
 Libderiv->deriv2_classes[9][9][6] = int_stack + 1685775;
 Libderiv->deriv_classes[5][5][2] = int_stack + 1688800;
 Libderiv->deriv_classes[5][6][2] = int_stack + 1689241;
 Libderiv->deriv_classes[5][7][2] = int_stack + 1689829;
 Libderiv->deriv_classes[5][8][2] = int_stack + 1690585;
 Libderiv->deriv_classes[5][9][2] = int_stack + 1691530;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 1692685;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 1693126;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 1693714;
 Libderiv->deriv2_classes[5][8][2] = int_stack + 1694470;
 Libderiv->deriv2_classes[5][9][2] = int_stack + 1695415;
 Libderiv->deriv_classes[6][5][2] = int_stack + 1696570;
 Libderiv->deriv_classes[6][6][2] = int_stack + 1697158;
 Libderiv->deriv_classes[6][7][2] = int_stack + 1697942;
 Libderiv->deriv_classes[6][8][2] = int_stack + 1698950;
 Libderiv->deriv_classes[6][9][2] = int_stack + 1700210;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 1701750;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 1702338;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 1703122;
 Libderiv->deriv2_classes[6][8][2] = int_stack + 1704130;
 Libderiv->deriv2_classes[6][9][2] = int_stack + 1705390;
 Libderiv->deriv_classes[7][5][2] = int_stack + 1706930;
 Libderiv->deriv_classes[7][6][2] = int_stack + 1707686;
 Libderiv->deriv_classes[7][7][2] = int_stack + 1708694;
 Libderiv->deriv_classes[7][8][2] = int_stack + 1709990;
 Libderiv->deriv_classes[7][9][2] = int_stack + 1711610;
 Libderiv->deriv2_classes[7][5][2] = int_stack + 1713590;
 Libderiv->deriv2_classes[7][6][2] = int_stack + 1714346;
 Libderiv->deriv2_classes[7][7][2] = int_stack + 1715354;
 Libderiv->deriv2_classes[7][8][2] = int_stack + 1716650;
 Libderiv->deriv2_classes[7][9][2] = int_stack + 1718270;
 Libderiv->deriv_classes[8][5][2] = int_stack + 1720250;
 Libderiv->deriv_classes[8][6][2] = int_stack + 1721195;
 Libderiv->deriv_classes[8][7][2] = int_stack + 1722455;
 Libderiv->deriv_classes[8][8][2] = int_stack + 1724075;
 Libderiv->deriv_classes[8][9][2] = int_stack + 1726100;
 Libderiv->deriv2_classes[8][5][2] = int_stack + 1728575;
 Libderiv->deriv2_classes[8][6][2] = int_stack + 1729520;
 Libderiv->deriv2_classes[8][7][2] = int_stack + 1730780;
 Libderiv->deriv2_classes[8][8][2] = int_stack + 1732400;
 Libderiv->deriv2_classes[8][9][2] = int_stack + 1734425;
 Libderiv->deriv2_classes[9][5][2] = int_stack + 1736900;
 Libderiv->deriv2_classes[9][6][2] = int_stack + 1738055;
 Libderiv->deriv2_classes[9][7][2] = int_stack + 1739595;
 Libderiv->deriv2_classes[9][8][2] = int_stack + 1741575;
 Libderiv->deriv2_classes[9][9][2] = int_stack + 1744050;
 Libderiv->deriv_classes[5][5][1] = int_stack + 1747075;
 Libderiv->deriv_classes[5][6][1] = int_stack + 1747516;
 Libderiv->deriv_classes[5][7][1] = int_stack + 1748104;
 Libderiv->deriv_classes[5][8][1] = int_stack + 1748860;
 Libderiv->deriv_classes[5][9][1] = int_stack + 1749805;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 1750960;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 1751401;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 1751989;
 Libderiv->deriv2_classes[5][8][1] = int_stack + 1752745;
 Libderiv->deriv2_classes[5][9][1] = int_stack + 1753690;
 Libderiv->deriv_classes[6][5][1] = int_stack + 1754845;
 Libderiv->deriv_classes[6][6][1] = int_stack + 1755433;
 Libderiv->deriv_classes[6][7][1] = int_stack + 1756217;
 Libderiv->deriv_classes[6][8][1] = int_stack + 1757225;
 Libderiv->deriv_classes[6][9][1] = int_stack + 1758485;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 1760025;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 1760613;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 1761397;
 Libderiv->deriv2_classes[6][8][1] = int_stack + 1762405;
 Libderiv->deriv2_classes[6][9][1] = int_stack + 1763665;
 Libderiv->deriv_classes[7][5][1] = int_stack + 1765205;
 Libderiv->deriv_classes[7][6][1] = int_stack + 1765961;
 Libderiv->deriv_classes[7][7][1] = int_stack + 1766969;
 Libderiv->deriv_classes[7][8][1] = int_stack + 1768265;
 Libderiv->deriv_classes[7][9][1] = int_stack + 1769885;
 Libderiv->deriv2_classes[7][5][1] = int_stack + 1771865;
 Libderiv->deriv2_classes[7][6][1] = int_stack + 1772621;
 Libderiv->deriv2_classes[7][7][1] = int_stack + 1773629;
 Libderiv->deriv2_classes[7][8][1] = int_stack + 1774925;
 Libderiv->deriv2_classes[7][9][1] = int_stack + 1776545;
 Libderiv->deriv_classes[8][5][1] = int_stack + 1778525;
 Libderiv->deriv_classes[8][6][1] = int_stack + 1779470;
 Libderiv->deriv_classes[8][7][1] = int_stack + 1780730;
 Libderiv->deriv_classes[8][8][1] = int_stack + 1782350;
 Libderiv->deriv_classes[8][9][1] = int_stack + 1784375;
 Libderiv->deriv2_classes[8][5][1] = int_stack + 1786850;
 Libderiv->deriv2_classes[8][6][1] = int_stack + 1787795;
 Libderiv->deriv2_classes[8][7][1] = int_stack + 1789055;
 Libderiv->deriv2_classes[8][8][1] = int_stack + 1790675;
 Libderiv->deriv2_classes[8][9][1] = int_stack + 1792700;
 Libderiv->deriv2_classes[9][5][1] = int_stack + 1795175;
 Libderiv->deriv2_classes[9][6][1] = int_stack + 1796330;
 Libderiv->deriv2_classes[9][7][1] = int_stack + 1797870;
 Libderiv->deriv2_classes[9][8][1] = int_stack + 1799850;
 Libderiv->deriv2_classes[9][9][1] = int_stack + 1802325;
 Libderiv->dvrr_classes[5][5] = int_stack + 1805350;
 Libderiv->dvrr_classes[5][6] = int_stack + 1805791;
 Libderiv->dvrr_classes[5][7] = int_stack + 1806379;
 Libderiv->dvrr_classes[5][8] = int_stack + 1807135;
 Libderiv->dvrr_classes[5][9] = int_stack + 1808080;
 Libderiv->deriv_classes[5][5][0] = int_stack + 1809235;
 Libderiv->deriv_classes[5][6][0] = int_stack + 1809676;
 Libderiv->deriv_classes[5][7][0] = int_stack + 1810264;
 Libderiv->deriv_classes[5][8][0] = int_stack + 1811020;
 Libderiv->deriv_classes[5][9][0] = int_stack + 1811965;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 1813120;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 1813561;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 1814149;
 Libderiv->deriv2_classes[5][8][0] = int_stack + 1814905;
 Libderiv->deriv2_classes[5][9][0] = int_stack + 1815850;
 Libderiv->dvrr_classes[6][5] = int_stack + 1817005;
 Libderiv->dvrr_classes[6][6] = int_stack + 1817593;
 Libderiv->dvrr_classes[6][7] = int_stack + 1818377;
 Libderiv->dvrr_classes[6][8] = int_stack + 1819385;
 Libderiv->dvrr_classes[6][9] = int_stack + 1820645;
 Libderiv->deriv_classes[6][5][0] = int_stack + 1822185;
 Libderiv->deriv_classes[6][6][0] = int_stack + 1822773;
 Libderiv->deriv_classes[6][7][0] = int_stack + 1823557;
 Libderiv->deriv_classes[6][8][0] = int_stack + 1824565;
 Libderiv->deriv_classes[6][9][0] = int_stack + 1825825;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 1827365;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 1827953;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 1828737;
 Libderiv->deriv2_classes[6][8][0] = int_stack + 1829745;
 Libderiv->deriv2_classes[6][9][0] = int_stack + 1831005;
 Libderiv->dvrr_classes[7][5] = int_stack + 1832545;
 Libderiv->dvrr_classes[7][6] = int_stack + 1833301;
 Libderiv->dvrr_classes[7][7] = int_stack + 1834309;
 Libderiv->dvrr_classes[7][8] = int_stack + 1835605;
 Libderiv->dvrr_classes[7][9] = int_stack + 1837225;
 Libderiv->deriv_classes[7][5][0] = int_stack + 1839205;
 Libderiv->deriv_classes[7][6][0] = int_stack + 1839961;
 Libderiv->deriv_classes[7][7][0] = int_stack + 1840969;
 Libderiv->deriv_classes[7][8][0] = int_stack + 1842265;
 Libderiv->deriv_classes[7][9][0] = int_stack + 1843885;
 Libderiv->deriv2_classes[7][5][0] = int_stack + 1845865;
 Libderiv->deriv2_classes[7][6][0] = int_stack + 1846621;
 Libderiv->deriv2_classes[7][7][0] = int_stack + 1847629;
 Libderiv->deriv2_classes[7][8][0] = int_stack + 1848925;
 Libderiv->deriv2_classes[7][9][0] = int_stack + 1850545;
 Libderiv->deriv_classes[8][5][0] = int_stack + 1852525;
 Libderiv->deriv_classes[8][6][0] = int_stack + 1853470;
 Libderiv->deriv_classes[8][7][0] = int_stack + 1854730;
 Libderiv->deriv_classes[8][8][0] = int_stack + 1856350;
 Libderiv->deriv_classes[8][9][0] = int_stack + 1858375;
 Libderiv->deriv2_classes[8][5][0] = int_stack + 1860850;
 Libderiv->deriv2_classes[8][6][0] = int_stack + 1861795;
 Libderiv->deriv2_classes[8][7][0] = int_stack + 1863055;
 Libderiv->deriv2_classes[8][8][0] = int_stack + 1864675;
 Libderiv->deriv2_classes[8][9][0] = int_stack + 1866700;
 Libderiv->deriv2_classes[9][5][0] = int_stack + 1869175;
 Libderiv->deriv2_classes[9][6][0] = int_stack + 1870330;
 Libderiv->deriv2_classes[9][7][0] = int_stack + 1871870;
 Libderiv->deriv2_classes[9][8][0] = int_stack + 1873850;
 Libderiv->deriv2_classes[9][9][0] = int_stack + 1876325;
 memset(int_stack,0,15034800);

 Libderiv->dvrr_stack = int_stack + 11136795;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_hghg(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1879350,int_stack+1805791,int_stack+1805350,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1880673,int_stack+1806379,int_stack+1805791,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1882437,int_stack+1880673,int_stack+1879350,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1885083,int_stack+1807135,int_stack+1806379,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1887351,int_stack+1885083,int_stack+1880673,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1890879,int_stack+1887351,int_stack+1882437,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1895289,int_stack+1326591,int_stack+1326150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1805350,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1896612,int_stack+1327179,int_stack+1326591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1805791,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1898376,int_stack+1896612,int_stack+1895289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879350,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1901022,int_stack+1327935,int_stack+1327179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1806379,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1903290,int_stack+1901022,int_stack+1896612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1880673,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1906818,int_stack+1903290,int_stack+1898376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1882437,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1911228,int_stack+1328880,int_stack+1327935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1807135,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1914063,int_stack+1911228,int_stack+1901022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1885083,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1918599,int_stack+1914063,int_stack+1903290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1887351,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1911228,int_stack+1918599,int_stack+1906818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890879,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1917843,int_stack+1817593,int_stack+1817005,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1919607,int_stack+1818377,int_stack+1817593,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1921959,int_stack+1919607,int_stack+1917843,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1925487,int_stack+1819385,int_stack+1818377,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1928511,int_stack+1925487,int_stack+1919607,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1933215,int_stack+1928511,int_stack+1921959,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1939095,int_stack+1334508,int_stack+1333920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817005,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1940859,int_stack+1335292,int_stack+1334508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817593,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1943211,int_stack+1940859,int_stack+1939095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1917843,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1946739,int_stack+1336300,int_stack+1335292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1818377,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1949763,int_stack+1946739,int_stack+1940859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1919607,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1954467,int_stack+1949763,int_stack+1943211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921959,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1960347,int_stack+1337560,int_stack+1336300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1819385,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1964127,int_stack+1960347,int_stack+1946739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1925487,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1970175,int_stack+1964127,int_stack+1949763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1928511,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1960347,int_stack+1970175,int_stack+1954467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1933215,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1969167,int_stack+1960347,int_stack+1911228,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1989012,int_stack+1833301,int_stack+1832545,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1991280,int_stack+1834309,int_stack+1833301,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1994304,int_stack+1991280,int_stack+1989012,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1998840,int_stack+1835605,int_stack+1834309,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2002728,int_stack+1998840,int_stack+1991280,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2008776,int_stack+2002728,int_stack+1994304,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2016336,int_stack+1345036,int_stack+1344280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1832545,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2018604,int_stack+1346044,int_stack+1345036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1833301,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2021628,int_stack+2018604,int_stack+2016336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1989012,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2026164,int_stack+1347340,int_stack+1346044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1834309,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2030052,int_stack+2026164,int_stack+2018604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1991280,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2036100,int_stack+2030052,int_stack+2021628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1994304,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2043660,int_stack+1348960,int_stack+1347340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1835605,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2048520,int_stack+2043660,int_stack+2026164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1998840,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2056296,int_stack+2048520,int_stack+2030052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2002728,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2043660,int_stack+2056296,int_stack+2036100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2008776,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2055000,int_stack+2043660,int_stack+1960347,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2081460,int_stack+2055000,int_stack+1969167,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2121150,int_stack+1650865,int_stack+1648975,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2123985,int_stack+1653385,int_stack+1650865,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2127765,int_stack+2123985,int_stack+2121150,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2133435,int_stack+1656625,int_stack+1653385,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2138295,int_stack+2133435,int_stack+2123985,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2145855,int_stack+2138295,int_stack+2127765,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2155305,int_stack+1358545,int_stack+1357600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1648975,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2158140,int_stack+1359805,int_stack+1358545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1650865,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2161920,int_stack+2158140,int_stack+2155305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2121150,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2167590,int_stack+1361425,int_stack+1359805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1653385,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2172450,int_stack+2167590,int_stack+2158140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2123985,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2180010,int_stack+2172450,int_stack+2161920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2127765,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2189460,int_stack+1363450,int_stack+1361425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1656625,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2195535,int_stack+2189460,int_stack+2167590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2133435,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2205255,int_stack+2195535,int_stack+2172450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2138295,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2189460,int_stack+2205255,int_stack+2180010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2145855,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2203635,int_stack+2189460,int_stack+2043660,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2237655,int_stack+2203635,int_stack+2055000,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2290575,int_stack+2237655,int_stack+2081460,315);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2356725,int_stack+779940,int_stack+776475,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2360190,int_stack+784560,int_stack+779940,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2364810,int_stack+2360190,int_stack+2356725,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2371740,int_stack+15125,int_stack+784560,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2377680,int_stack+2371740,int_stack+2360190,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2386920,int_stack+2377680,int_stack+2364810,55);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2398470,int_stack+571910,int_stack+569600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776475,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2401935,int_stack+574990,int_stack+571910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+779940,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2406555,int_stack+2401935,int_stack+2398470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2356725,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2413485,int_stack+578950,int_stack+574990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+784560,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2419425,int_stack+2413485,int_stack+2401935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2360190,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2428665,int_stack+2419425,int_stack+2406555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2364810,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2440215,int_stack+0,int_stack+578950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15125,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2447640,int_stack+2440215,int_stack+2413485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371740,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2459520,int_stack+2447640,int_stack+2419425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2377680,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2440215,int_stack+2459520,int_stack+2428665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2386920,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+2457540,int_stack+2440215,int_stack+2189460,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+2500065,int_stack+2457540,int_stack+2203635,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+2568105,int_stack+2500065,int_stack+2237655,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2440215,int_stack+1384866,int_stack+1384425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1805350, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2441538,int_stack+1385454,int_stack+1384866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1805791, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2443302,int_stack+2441538,int_stack+2440215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879350, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2445948,int_stack+1386210,int_stack+1385454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1806379, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2448216,int_stack+2445948,int_stack+2441538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1880673, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2451744,int_stack+2448216,int_stack+2443302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1882437, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2456154,int_stack+1387155,int_stack+1386210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1807135, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2458989,int_stack+2456154,int_stack+2445948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1885083, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2463525,int_stack+2458989,int_stack+2448216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1887351, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2456154,int_stack+2463525,int_stack+2451744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890879, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2462769,int_stack+1392783,int_stack+1392195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817005, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2464533,int_stack+1393567,int_stack+1392783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817593, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2466885,int_stack+2464533,int_stack+2462769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1917843, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2470413,int_stack+1394575,int_stack+1393567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1818377, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2473437,int_stack+2470413,int_stack+2464533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1919607, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2478141,int_stack+2473437,int_stack+2466885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921959, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2484021,int_stack+1395835,int_stack+1394575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1819385, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2487801,int_stack+2484021,int_stack+2470413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1925487, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2493849,int_stack+2487801,int_stack+2473437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1928511, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2484021,int_stack+2493849,int_stack+2478141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1933215, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2492841,int_stack+2484021,int_stack+2456154,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2512686,int_stack+1403311,int_stack+1402555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1832545, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2514954,int_stack+1404319,int_stack+1403311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1833301, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2517978,int_stack+2514954,int_stack+2512686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1989012, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2522514,int_stack+1405615,int_stack+1404319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1834309, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2526402,int_stack+2522514,int_stack+2514954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1991280, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2532450,int_stack+2526402,int_stack+2517978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1994304, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2540010,int_stack+1407235,int_stack+1405615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1835605, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2544870,int_stack+2540010,int_stack+2522514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1998840, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2552646,int_stack+2544870,int_stack+2526402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2002728, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2540010,int_stack+2552646,int_stack+2532450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2008776, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2656305,int_stack+2540010,int_stack+2484021,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2682765,int_stack+2656305,int_stack+2492841,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2551350,int_stack+1416820,int_stack+1415875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1648975, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2554185,int_stack+1418080,int_stack+1416820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1650865, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2557965,int_stack+2554185,int_stack+2551350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2121150, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2722455,int_stack+1419700,int_stack+1418080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1653385, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2727315,int_stack+2722455,int_stack+2554185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2123985, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2734875,int_stack+2727315,int_stack+2557965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2127765, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2744325,int_stack+1421725,int_stack+1419700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1656625, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2750400,int_stack+2744325,int_stack+2722455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2133435, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2760120,int_stack+2750400,int_stack+2727315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2138295, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2744325,int_stack+2760120,int_stack+2734875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2145855, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2758500,int_stack+2744325,int_stack+2540010,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2792520,int_stack+2758500,int_stack+2656305,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2845440,int_stack+2792520,int_stack+2682765,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2563635,int_stack+613285,int_stack+610975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776475, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2911590,int_stack+616365,int_stack+613285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+779940, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2916210,int_stack+2911590,int_stack+2563635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2356725, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2923140,int_stack+620325,int_stack+616365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+784560, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2929080,int_stack+2923140,int_stack+2911590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2360190, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2938320,int_stack+2929080,int_stack+2916210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2364810, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2949870,int_stack+3025,int_stack+620325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15125, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2957295,int_stack+2949870,int_stack+2923140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371740, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2969175,int_stack+2957295,int_stack+2929080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2377680, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2949870,int_stack+2969175,int_stack+2938320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2386920, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+2967195,int_stack+2949870,int_stack+2744325,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+3009720,int_stack+2967195,int_stack+2758500,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+3077760,int_stack+3009720,int_stack+2792520,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2949870,int_stack+1443141,int_stack+1442700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1805350, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2951193,int_stack+1443729,int_stack+1443141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1805791, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2952957,int_stack+2951193,int_stack+2949870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2955603,int_stack+1444485,int_stack+1443729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1806379, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2957871,int_stack+2955603,int_stack+2951193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1880673, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2961399,int_stack+2957871,int_stack+2952957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1882437, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2965809,int_stack+1445430,int_stack+1444485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1807135, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2968644,int_stack+2965809,int_stack+2955603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1885083, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2973180,int_stack+2968644,int_stack+2957871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1887351, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2965809,int_stack+2973180,int_stack+2961399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890879, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2972424,int_stack+1451058,int_stack+1450470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817005, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2974188,int_stack+1451842,int_stack+1451058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817593, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2976540,int_stack+2974188,int_stack+2972424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2980068,int_stack+1452850,int_stack+1451842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1818377, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2983092,int_stack+2980068,int_stack+2974188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1919607, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2987796,int_stack+2983092,int_stack+2976540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921959, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2993676,int_stack+1454110,int_stack+1452850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1819385, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2997456,int_stack+2993676,int_stack+2980068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1925487, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3003504,int_stack+2997456,int_stack+2983092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1928511, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2993676,int_stack+3003504,int_stack+2987796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1933215, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3002496,int_stack+2993676,int_stack+2965809,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3022341,int_stack+1461586,int_stack+1460830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1832545, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3024609,int_stack+1462594,int_stack+1461586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1833301, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3027633,int_stack+3024609,int_stack+3022341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3032169,int_stack+1463890,int_stack+1462594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1834309, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3036057,int_stack+3032169,int_stack+3024609, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1991280, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3042105,int_stack+3036057,int_stack+3027633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1994304, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3049665,int_stack+1465510,int_stack+1463890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1835605, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3054525,int_stack+3049665,int_stack+3032169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1998840, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3062301,int_stack+3054525,int_stack+3036057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2002728, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3049665,int_stack+3062301,int_stack+3042105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2008776, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3165960,int_stack+3049665,int_stack+2993676,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3192420,int_stack+3165960,int_stack+3002496,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3061005,int_stack+1475095,int_stack+1474150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1648975, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3063840,int_stack+1476355,int_stack+1475095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1650865, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3067620,int_stack+3063840,int_stack+3061005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2121150, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+1477975,int_stack+1476355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1653385, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3232110,int_stack+0,int_stack+3063840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2123985, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3239670,int_stack+3232110,int_stack+3067620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2127765, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3249120,int_stack+1480000,int_stack+1477975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1656625, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3255195,int_stack+3249120,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2133435, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3264915,int_stack+3255195,int_stack+3232110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2138295, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3249120,int_stack+3264915,int_stack+3239670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2145855, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3263295,int_stack+3249120,int_stack+3049665,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3297315,int_stack+3263295,int_stack+3165960,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3350235,int_stack+3297315,int_stack+3192420,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3073290,int_stack+654660,int_stack+652350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776475, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3416385,int_stack+657740,int_stack+654660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+779940, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3421005,int_stack+3416385,int_stack+3073290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3427935,int_stack+661700,int_stack+657740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+784560, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3433875,int_stack+3427935,int_stack+3416385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2360190, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3443115,int_stack+3433875,int_stack+3421005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2364810, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3454665,int_stack+6050,int_stack+661700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15125, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3462090,int_stack+3454665,int_stack+3427935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371740, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3473970,int_stack+3462090,int_stack+3433875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2377680, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3454665,int_stack+3473970,int_stack+3443115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2386920, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+3471990,int_stack+3454665,int_stack+3249120,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+3514515,int_stack+3471990,int_stack+3263295,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+3582555,int_stack+3514515,int_stack+3297315,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3454665,int_stack+1501416,int_stack+1500975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1805350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3455988,int_stack+1502004,int_stack+1501416, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1805791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3457752,int_stack+3455988,int_stack+3454665, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3460398,int_stack+1502760,int_stack+1502004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1806379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3462666,int_stack+3460398,int_stack+3455988, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1880673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3466194,int_stack+3462666,int_stack+3457752, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1882437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3470604,int_stack+1503705,int_stack+1502760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1807135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3473439,int_stack+3470604,int_stack+3460398, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1885083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3477975,int_stack+3473439,int_stack+3462666, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1887351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3470604,int_stack+3477975,int_stack+3466194, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3477219,int_stack+1509333,int_stack+1508745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3478983,int_stack+1510117,int_stack+1509333, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3481335,int_stack+3478983,int_stack+3477219, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3484863,int_stack+1511125,int_stack+1510117, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1818377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3487887,int_stack+3484863,int_stack+3478983, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1919607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3492591,int_stack+3487887,int_stack+3481335, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3498471,int_stack+1512385,int_stack+1511125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1819385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3502251,int_stack+3498471,int_stack+3484863, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1925487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3508299,int_stack+3502251,int_stack+3487887, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1928511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3498471,int_stack+3508299,int_stack+3492591, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1933215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3507291,int_stack+3498471,int_stack+3470604,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3527136,int_stack+1519861,int_stack+1519105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1832545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3529404,int_stack+1520869,int_stack+1519861, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1833301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3532428,int_stack+3529404,int_stack+3527136, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3536964,int_stack+1522165,int_stack+1520869, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1834309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3540852,int_stack+3536964,int_stack+3529404, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1991280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3546900,int_stack+3540852,int_stack+3532428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1994304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3554460,int_stack+1523785,int_stack+1522165, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1835605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3559320,int_stack+3554460,int_stack+3536964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1998840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3567096,int_stack+3559320,int_stack+3540852, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2002728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3554460,int_stack+3567096,int_stack+3546900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2008776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3670755,int_stack+3554460,int_stack+3498471,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3697215,int_stack+3670755,int_stack+3507291,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3565800,int_stack+1533370,int_stack+1532425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1648975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3568635,int_stack+1534630,int_stack+1533370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1650865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3572415,int_stack+3568635,int_stack+3565800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2121150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3736905,int_stack+1536250,int_stack+1534630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1653385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3741765,int_stack+3736905,int_stack+3568635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2123985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749325,int_stack+3741765,int_stack+3572415, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2127765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3758775,int_stack+1538275,int_stack+1536250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1656625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3764850,int_stack+3758775,int_stack+3736905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2133435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3774570,int_stack+3764850,int_stack+3741765, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2138295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758775,int_stack+3774570,int_stack+3749325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2145855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3772950,int_stack+3758775,int_stack+3554460,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3806970,int_stack+3772950,int_stack+3670755,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3859890,int_stack+3806970,int_stack+3697215,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3578085,int_stack+696035,int_stack+693725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3926040,int_stack+699115,int_stack+696035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+779940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3930660,int_stack+3926040,int_stack+3578085, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3937590,int_stack+703075,int_stack+699115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+784560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3943530,int_stack+3937590,int_stack+3926040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2360190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3952770,int_stack+3943530,int_stack+3930660, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2364810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3964320,int_stack+9075,int_stack+703075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3971745,int_stack+3964320,int_stack+3937590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3983625,int_stack+3971745,int_stack+3943530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2377680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3964320,int_stack+3983625,int_stack+3952770, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2386920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+3981645,int_stack+3964320,int_stack+3758775,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+4024170,int_stack+3981645,int_stack+3772950,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+4092210,int_stack+4024170,int_stack+3806970,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3964320,int_stack+1559691,int_stack+1559250, 0.0, zero_stack, 1.0, int_stack+1805350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3965643,int_stack+1560279,int_stack+1559691, 0.0, zero_stack, 1.0, int_stack+1805791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3967407,int_stack+3965643,int_stack+3964320, 0.0, zero_stack, 1.0, int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3970053,int_stack+1561035,int_stack+1560279, 0.0, zero_stack, 1.0, int_stack+1806379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3972321,int_stack+3970053,int_stack+3965643, 0.0, zero_stack, 1.0, int_stack+1880673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3975849,int_stack+3972321,int_stack+3967407, 0.0, zero_stack, 1.0, int_stack+1882437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3980259,int_stack+1561980,int_stack+1561035, 0.0, zero_stack, 1.0, int_stack+1807135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3983094,int_stack+3980259,int_stack+3970053, 0.0, zero_stack, 1.0, int_stack+1885083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3987630,int_stack+3983094,int_stack+3972321, 0.0, zero_stack, 1.0, int_stack+1887351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3980259,int_stack+3987630,int_stack+3975849, 0.0, zero_stack, 1.0, int_stack+1890879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3986874,int_stack+1567608,int_stack+1567020, 0.0, zero_stack, 1.0, int_stack+1817005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3988638,int_stack+1568392,int_stack+1567608, 0.0, zero_stack, 1.0, int_stack+1817593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3990990,int_stack+3988638,int_stack+3986874, 0.0, zero_stack, 1.0, int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3994518,int_stack+1569400,int_stack+1568392, 0.0, zero_stack, 1.0, int_stack+1818377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3997542,int_stack+3994518,int_stack+3988638, 0.0, zero_stack, 1.0, int_stack+1919607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4002246,int_stack+3997542,int_stack+3990990, 0.0, zero_stack, 1.0, int_stack+1921959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4008126,int_stack+1570660,int_stack+1569400, 0.0, zero_stack, 1.0, int_stack+1819385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4011906,int_stack+4008126,int_stack+3994518, 0.0, zero_stack, 1.0, int_stack+1925487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4017954,int_stack+4011906,int_stack+3997542, 0.0, zero_stack, 1.0, int_stack+1928511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4008126,int_stack+4017954,int_stack+4002246, 0.0, zero_stack, 1.0, int_stack+1933215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4016946,int_stack+4008126,int_stack+3980259,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4036791,int_stack+1578136,int_stack+1577380, 0.0, zero_stack, 1.0, int_stack+1832545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4039059,int_stack+1579144,int_stack+1578136, 0.0, zero_stack, 1.0, int_stack+1833301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4042083,int_stack+4039059,int_stack+4036791, 0.0, zero_stack, 1.0, int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4046619,int_stack+1580440,int_stack+1579144, 0.0, zero_stack, 1.0, int_stack+1834309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4050507,int_stack+4046619,int_stack+4039059, 0.0, zero_stack, 1.0, int_stack+1991280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4056555,int_stack+4050507,int_stack+4042083, 0.0, zero_stack, 1.0, int_stack+1994304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4064115,int_stack+1582060,int_stack+1580440, 0.0, zero_stack, 1.0, int_stack+1835605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4068975,int_stack+4064115,int_stack+4046619, 0.0, zero_stack, 1.0, int_stack+1998840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4076751,int_stack+4068975,int_stack+4050507, 0.0, zero_stack, 1.0, int_stack+2002728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4064115,int_stack+4076751,int_stack+4056555, 0.0, zero_stack, 1.0, int_stack+2008776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+4180410,int_stack+4064115,int_stack+4008126,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+4206870,int_stack+4180410,int_stack+4016946,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4075455,int_stack+1591645,int_stack+1590700, 0.0, zero_stack, 1.0, int_stack+1648975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4078290,int_stack+1592905,int_stack+1591645, 0.0, zero_stack, 1.0, int_stack+1650865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4082070,int_stack+4078290,int_stack+4075455, 0.0, zero_stack, 1.0, int_stack+2121150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4860,int_stack+1594525,int_stack+1592905, 0.0, zero_stack, 1.0, int_stack+1653385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4246560,int_stack+4860,int_stack+4078290, 0.0, zero_stack, 1.0, int_stack+2123985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4254120,int_stack+4246560,int_stack+4082070, 0.0, zero_stack, 1.0, int_stack+2127765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4263570,int_stack+1596550,int_stack+1594525, 0.0, zero_stack, 1.0, int_stack+1656625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4269645,int_stack+4263570,int_stack+4860, 0.0, zero_stack, 1.0, int_stack+2133435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4279365,int_stack+4269645,int_stack+4246560, 0.0, zero_stack, 1.0, int_stack+2138295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4263570,int_stack+4279365,int_stack+4254120, 0.0, zero_stack, 1.0, int_stack+2145855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+4277745,int_stack+4263570,int_stack+4064115,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4311765,int_stack+4277745,int_stack+4180410,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4364685,int_stack+4311765,int_stack+4206870,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4087740,int_stack+737410,int_stack+735100, 0.0, zero_stack, 1.0, int_stack+776475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4430835,int_stack+740490,int_stack+737410, 0.0, zero_stack, 1.0, int_stack+779940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4435455,int_stack+4430835,int_stack+4087740, 0.0, zero_stack, 1.0, int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4442385,int_stack+744450,int_stack+740490, 0.0, zero_stack, 1.0, int_stack+784560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4448325,int_stack+4442385,int_stack+4430835, 0.0, zero_stack, 1.0, int_stack+2360190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4457565,int_stack+4448325,int_stack+4435455, 0.0, zero_stack, 1.0, int_stack+2364810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4469115,int_stack+12100,int_stack+744450, 0.0, zero_stack, 1.0, int_stack+15125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4476540,int_stack+4469115,int_stack+4442385, 0.0, zero_stack, 1.0, int_stack+2371740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4488420,int_stack+4476540,int_stack+4448325, 0.0, zero_stack, 1.0, int_stack+2377680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4469115,int_stack+4488420,int_stack+4457565, 0.0, zero_stack, 1.0, int_stack+2386920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+4486440,int_stack+4469115,int_stack+4263570,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+4528965,int_stack+4486440,int_stack+4277745,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+4597005,int_stack+4528965,int_stack+4311765,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4469115,int_stack+1617966,int_stack+1617525, 1.0, int_stack+1805350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4470438,int_stack+1618554,int_stack+1617966, 1.0, int_stack+1805791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4472202,int_stack+4470438,int_stack+4469115, 1.0, int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4474848,int_stack+1619310,int_stack+1618554, 1.0, int_stack+1806379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4477116,int_stack+4474848,int_stack+4470438, 1.0, int_stack+1880673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4480644,int_stack+4477116,int_stack+4472202, 1.0, int_stack+1882437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1879350,int_stack+1620255,int_stack+1619310, 1.0, int_stack+1807135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4485054,int_stack+1879350,int_stack+4474848, 1.0, int_stack+1885083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4489590,int_stack+4485054,int_stack+4477116, 1.0, int_stack+1887351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4495470,int_stack+4489590,int_stack+4480644, 1.0, int_stack+1890879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4485054,int_stack+1625883,int_stack+1625295, 1.0, int_stack+1817005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4486818,int_stack+1626667,int_stack+1625883, 1.0, int_stack+1817593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4489170,int_stack+4486818,int_stack+4485054, 1.0, int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1879350,int_stack+1627675,int_stack+1626667, 1.0, int_stack+1818377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4502085,int_stack+1879350,int_stack+4486818, 1.0, int_stack+1919607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4506789,int_stack+4502085,int_stack+4489170, 1.0, int_stack+1921959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1917843,int_stack+1628935,int_stack+1627675, 1.0, int_stack+1819385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4512669,int_stack+1917843,int_stack+1879350, 1.0, int_stack+1925487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4518717,int_stack+4512669,int_stack+4502085, 1.0, int_stack+1928511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4526557,int_stack+4518717,int_stack+4506789, 1.0, int_stack+1933215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4535377,int_stack+4526557,int_stack+4495470,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4512669,int_stack+1636411,int_stack+1635655, 1.0, int_stack+1832545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4514937,int_stack+1637419,int_stack+1636411, 1.0, int_stack+1833301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4517961,int_stack+4514937,int_stack+4512669, 1.0, int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4522497,int_stack+1638715,int_stack+1637419, 1.0, int_stack+1834309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1917843,int_stack+4522497,int_stack+4514937, 1.0, int_stack+1991280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4555222,int_stack+1917843,int_stack+4517961, 1.0, int_stack+1994304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1989012,int_stack+1640335,int_stack+1638715, 1.0, int_stack+1835605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4562782,int_stack+1989012,int_stack+4522497, 1.0, int_stack+1998840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4570558,int_stack+4562782,int_stack+1917843, 1.0, int_stack+2002728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4580638,int_stack+4570558,int_stack+4555222, 1.0, int_stack+2008776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+4685205,int_stack+4580638,int_stack+4526557,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+4711665,int_stack+4685205,int_stack+4535377,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4562782,int_stack+1652125,int_stack+1649920, 1.0, int_stack+1648975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4565617,int_stack+1655005,int_stack+1652125, 1.0, int_stack+1650865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4569397,int_stack+4565617,int_stack+4562782, 1.0, int_stack+2121150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4575067,int_stack+1658650,int_stack+1655005, 1.0, int_stack+1653385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1989012,int_stack+4575067,int_stack+4565617, 1.0, int_stack+2123985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4751355,int_stack+1989012,int_stack+4569397, 1.0, int_stack+2127765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2121150,int_stack+1660675,int_stack+1658650, 1.0, int_stack+1656625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4760805,int_stack+2121150,int_stack+4575067, 1.0, int_stack+2133435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4770525,int_stack+4760805,int_stack+1989012, 1.0, int_stack+2138295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4783125,int_stack+4770525,int_stack+4751355, 1.0, int_stack+2145855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+4797300,int_stack+4783125,int_stack+4580638,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4831320,int_stack+4797300,int_stack+4685205,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4884240,int_stack+4831320,int_stack+4711665,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4760805,int_stack+781480,int_stack+777630, 1.0, int_stack+776475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4764270,int_stack+786540,int_stack+781480, 1.0, int_stack+779940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4768890,int_stack+4764270,int_stack+4760805, 1.0, int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4775820,int_stack+790500,int_stack+786540, 1.0, int_stack+784560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2121150,int_stack+4775820,int_stack+4764270, 1.0, int_stack+2360190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+2121150,int_stack+4768890, 1.0, int_stack+2364810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2356725,int_stack+17600,int_stack+790500, 1.0, int_stack+15125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4961940,int_stack+2356725,int_stack+4775820, 1.0, int_stack+2371740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2356725,int_stack+4961940,int_stack+2121150, 1.0, int_stack+2377680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4961940,int_stack+2356725,int_stack+4950390, 1.0, int_stack+2386920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+4979265,int_stack+4961940,int_stack+4783125,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+5021790,int_stack+4979265,int_stack+4797300,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+5089830,int_stack+5021790,int_stack+4831320,315);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4961940,int_stack+1808080,int_stack+1807135,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4964775,int_stack+4961940,int_stack+1885083,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4969311,int_stack+4964775,int_stack+1887351,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+4961940,int_stack+4969311,int_stack+1890879,21);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4968555,int_stack+1820645,int_stack+1819385,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4972335,int_stack+4968555,int_stack+1925487,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4978383,int_stack+4972335,int_stack+1928511,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+4968555,int_stack+4978383,int_stack+1933215,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4977375,int_stack+4968555,int_stack+4961940,315);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4997220,int_stack+1837225,int_stack+1835605,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5002080,int_stack+4997220,int_stack+1998840,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5009856,int_stack+5002080,int_stack+2002728,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+4997220,int_stack+5009856,int_stack+2008776,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+5008560,int_stack+4997220,int_stack+4968555,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+5035020,int_stack+5008560,int_stack+4977375,315);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5074710,int_stack+26675,int_stack+1656625,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2356725,int_stack+5074710,int_stack+2133435,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5074710,int_stack+2356725,int_stack+2138295,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+5074710,int_stack+2145855,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5178030,int_stack+2356725,int_stack+4997220,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5212050,int_stack+5178030,int_stack+5008560,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+5264970,int_stack+5212050,int_stack+5035020,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5074710,int_stack+1689241,int_stack+1688800,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5076033,int_stack+1689829,int_stack+1689241,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5077797,int_stack+5076033,int_stack+5074710,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5080443,int_stack+1690585,int_stack+1689829,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5082711,int_stack+5080443,int_stack+5076033,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2370900,int_stack+5082711,int_stack+5077797,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5086239,int_stack+1691530,int_stack+1690585,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2375310,int_stack+5086239,int_stack+5080443,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2379846,int_stack+2375310,int_stack+5082711,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2385726,int_stack+2379846,int_stack+2370900,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2375310,int_stack+1697158,int_stack+1696570,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2377074,int_stack+1697942,int_stack+1697158,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2379426,int_stack+2377074,int_stack+2375310,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5086239,int_stack+1698950,int_stack+1697942,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2392341,int_stack+5086239,int_stack+2377074,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2130390,int_stack+2392341,int_stack+2379426,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2136270,int_stack+1700210,int_stack+1698950,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2140050,int_stack+2136270,int_stack+5086239,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2146098,int_stack+2140050,int_stack+2392341,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2136270,int_stack+2146098,int_stack+2130390,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+5331120,int_stack+2136270,int_stack+2385726, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4961940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2145090,int_stack+1707686,int_stack+1706930,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2147358,int_stack+1708694,int_stack+1707686,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2150382,int_stack+2147358,int_stack+2145090,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1996572,int_stack+1709990,int_stack+1708694,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2000460,int_stack+1996572,int_stack+2147358,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2006508,int_stack+2000460,int_stack+2150382,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1832545,int_stack+1711610,int_stack+1709990,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1923891,int_stack+1832545,int_stack+1996572,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1882374,int_stack+1923891,int_stack+2000460,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1923891,int_stack+1882374,int_stack+2006508,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+5350965,int_stack+1923891,int_stack+2136270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4968555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+5377425,int_stack+5350965,int_stack+5331120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4977375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1882374,int_stack+1721195,int_stack+1720250,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1885209,int_stack+1722455,int_stack+1721195,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1888989,int_stack+1885209,int_stack+1882374,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1832545,int_stack+1724075,int_stack+1722455,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9720,int_stack+1832545,int_stack+1885209,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+9720,int_stack+1888989,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5426565,int_stack+1726100,int_stack+1724075,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5432640,int_stack+5426565,int_stack+1832545,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5442360,int_stack+5432640,int_stack+9720,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5426565,int_stack+5442360,int_stack+5417115,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+5440740,int_stack+5426565,int_stack+1923891, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4997220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5474760,int_stack+5440740,int_stack+5350965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5008560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5527680,int_stack+5474760,int_stack+5377425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5035020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1935231,int_stack+995960,int_stack+993650,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1817005,int_stack+999040,int_stack+995960,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5593830,int_stack+1817005,int_stack+1935231,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5600760,int_stack+1003000,int_stack+999040,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5606700,int_stack+5600760,int_stack+1817005,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5615940,int_stack+5606700,int_stack+5593830,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5627490,int_stack+20625,int_stack+1003000,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5634915,int_stack+5627490,int_stack+5600760,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5646795,int_stack+5634915,int_stack+5606700,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5627490,int_stack+5646795,int_stack+5615940,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+5644815,int_stack+5627490,int_stack+5426565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+5687340,int_stack+5644815,int_stack+5440740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+5755380,int_stack+5687340,int_stack+5474760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5212050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5627490,int_stack+1747516,int_stack+1747075,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5628813,int_stack+1748104,int_stack+1747516,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5630577,int_stack+5628813,int_stack+5627490,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2014068,int_stack+1748860,int_stack+1748104,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5633223,int_stack+2014068,int_stack+5628813,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5636751,int_stack+5633223,int_stack+5630577,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5641161,int_stack+1749805,int_stack+1748860,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5643996,int_stack+5641161,int_stack+2014068,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5648532,int_stack+5643996,int_stack+5633223,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5641161,int_stack+5648532,int_stack+5636751,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5647776,int_stack+1755433,int_stack+1754845,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5649540,int_stack+1756217,int_stack+1755433,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5651892,int_stack+5649540,int_stack+5647776,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5655420,int_stack+1757225,int_stack+1756217,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5658444,int_stack+5655420,int_stack+5649540,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5663148,int_stack+5658444,int_stack+5651892,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5669028,int_stack+1758485,int_stack+1757225,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5672808,int_stack+5669028,int_stack+5655420,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5678856,int_stack+5672808,int_stack+5658444,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5669028,int_stack+5678856,int_stack+5663148,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+5677848,int_stack+5669028,int_stack+5641161, 0.0, zero_stack, 1.0, int_stack+4961940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5697693,int_stack+1765961,int_stack+1765205,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5699961,int_stack+1766969,int_stack+1765961,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5702985,int_stack+5699961,int_stack+5697693,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5707521,int_stack+1768265,int_stack+1766969,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5711409,int_stack+5707521,int_stack+5699961,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5717457,int_stack+5711409,int_stack+5702985,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5725017,int_stack+1769885,int_stack+1768265,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5729877,int_stack+5725017,int_stack+5707521,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5737653,int_stack+5729877,int_stack+5711409,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5725017,int_stack+5737653,int_stack+5717457,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+5843580,int_stack+5725017,int_stack+5669028, 0.0, zero_stack, 1.0, int_stack+4968555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+5870040,int_stack+5843580,int_stack+5677848, 0.0, zero_stack, 1.0, int_stack+4977375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5736357,int_stack+1779470,int_stack+1778525,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5739192,int_stack+1780730,int_stack+1779470,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5742972,int_stack+5739192,int_stack+5736357,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5748642,int_stack+1782350,int_stack+1780730,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5909730,int_stack+5748642,int_stack+5739192,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5917290,int_stack+5909730,int_stack+5742972,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+17280,int_stack+1784375,int_stack+1782350,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5926740,int_stack+17280,int_stack+5748642,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5936460,int_stack+5926740,int_stack+5909730,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5949060,int_stack+5936460,int_stack+5917290,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+5963235,int_stack+5949060,int_stack+5725017, 0.0, zero_stack, 1.0, int_stack+4997220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5997255,int_stack+5963235,int_stack+5843580, 0.0, zero_stack, 1.0, int_stack+5008560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+6050175,int_stack+5997255,int_stack+5870040, 0.0, zero_stack, 1.0, int_stack+5035020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5926740,int_stack+1242685,int_stack+1240375,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5930205,int_stack+1245765,int_stack+1242685,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5934825,int_stack+5930205,int_stack+5926740,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5941755,int_stack+1249725,int_stack+1245765,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6116325,int_stack+5941755,int_stack+5930205,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6125565,int_stack+6116325,int_stack+5934825,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6137115,int_stack+23650,int_stack+1249725,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6144540,int_stack+6137115,int_stack+5941755,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6156420,int_stack+6144540,int_stack+6116325,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6137115,int_stack+6156420,int_stack+6125565,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+6154440,int_stack+6137115,int_stack+5949060, 0.0, zero_stack, 1.0, int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+6196965,int_stack+6154440,int_stack+5963235, 0.0, zero_stack, 1.0, int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+6265005,int_stack+6196965,int_stack+5997255, 0.0, zero_stack, 1.0, int_stack+5212050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6137115,int_stack+1809676,int_stack+1809235,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6138438,int_stack+1810264,int_stack+1809676,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6140202,int_stack+6138438,int_stack+6137115,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6142848,int_stack+1811020,int_stack+1810264,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6145116,int_stack+6142848,int_stack+6138438,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6148644,int_stack+6145116,int_stack+6140202,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6153054,int_stack+1811965,int_stack+1811020,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6155889,int_stack+6153054,int_stack+6142848,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6160425,int_stack+6155889,int_stack+6145116,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6153054,int_stack+6160425,int_stack+6148644,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6159669,int_stack+1822773,int_stack+1822185,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6161433,int_stack+1823557,int_stack+1822773,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6163785,int_stack+6161433,int_stack+6159669,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6167313,int_stack+1824565,int_stack+1823557,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6170337,int_stack+6167313,int_stack+6161433,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6175041,int_stack+6170337,int_stack+6163785,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6180921,int_stack+1825825,int_stack+1824565,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6184701,int_stack+6180921,int_stack+6167313,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6190749,int_stack+6184701,int_stack+6170337,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6180921,int_stack+6190749,int_stack+6175041,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+6189741,int_stack+6180921,int_stack+6153054, 1.0, int_stack+4961940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4961940,int_stack+1839961,int_stack+1839205,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4964208,int_stack+1840969,int_stack+1839961,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6209586,int_stack+4964208,int_stack+4961940,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6214122,int_stack+1842265,int_stack+1840969,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6218010,int_stack+6214122,int_stack+4964208,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6224058,int_stack+6218010,int_stack+6209586,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6231618,int_stack+1843885,int_stack+1842265,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6236478,int_stack+6231618,int_stack+6214122,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6244254,int_stack+6236478,int_stack+6218010,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6231618,int_stack+6244254,int_stack+6224058,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+6353205,int_stack+6231618,int_stack+6180921, 1.0, int_stack+4968555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6379665,int_stack+6353205,int_stack+6189741, 1.0, int_stack+4977375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6242958,int_stack+1853470,int_stack+1852525,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6245793,int_stack+1854730,int_stack+1853470,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6249573,int_stack+6245793,int_stack+6242958,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6255243,int_stack+1856350,int_stack+1854730,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4967232,int_stack+6255243,int_stack+6245793,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+4974792,int_stack+4967232,int_stack+6249573,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4984242,int_stack+1858375,int_stack+1856350,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+17280,int_stack+4984242,int_stack+6255243,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4984242,int_stack+17280,int_stack+4967232,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6419355,int_stack+4984242,int_stack+4974792,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6433530,int_stack+6419355,int_stack+6231618, 1.0, int_stack+4997220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+6467550,int_stack+6433530,int_stack+6353205, 1.0, int_stack+5008560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+6520470,int_stack+6467550,int_stack+6379665, 1.0, int_stack+5035020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4984242,int_stack+1673785,int_stack+1671475,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4987707,int_stack+1676865,int_stack+1673785,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+4992327,int_stack+4987707,int_stack+4984242,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4999257,int_stack+1680825,int_stack+1676865,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5005197,int_stack+4999257,int_stack+4987707,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5014437,int_stack+5005197,int_stack+4992327,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5025987,int_stack+29150,int_stack+1680825,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5033412,int_stack+5025987,int_stack+4999257,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5045292,int_stack+5033412,int_stack+5005197,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5025987,int_stack+5045292,int_stack+5014437,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+6586620,int_stack+5025987,int_stack+6419355, 1.0, int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+6629145,int_stack+6586620,int_stack+6433530, 1.0, int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+6697185,int_stack+6629145,int_stack+6467550, 1.0, int_stack+5212050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+32616,int_stack+32175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1326150,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5179353,int_stack+33204,int_stack+32616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1326591,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5181117,int_stack+5179353,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1895289,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5183763,int_stack+33960,int_stack+33204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1327179,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5186031,int_stack+5183763,int_stack+5179353, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1896612,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5189559,int_stack+5186031,int_stack+5181117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1898376,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+34905,int_stack+33960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1327935,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5193969,int_stack+5178030,int_stack+5183763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1901022,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5193969,int_stack+5186031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1903290,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5193969,int_stack+5178030,int_stack+5189559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1906818,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+36648,int_stack+36060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1333920,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5179794,int_stack+37432,int_stack+36648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1334508,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5182146,int_stack+5179794,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1939095,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5185674,int_stack+38440,int_stack+37432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1335292,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5188698,int_stack+5185674,int_stack+5179794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1940859,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5200584,int_stack+5188698,int_stack+5182146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1943211,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+39700,int_stack+38440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1336300,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5206464,int_stack+5178030,int_stack+5185674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1946739,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5206464,int_stack+5188698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1949763,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5206464,int_stack+5178030,int_stack+5200584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1954467,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5215284,int_stack+5206464,int_stack+5193969,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+41996,int_stack+41240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1344280,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5180298,int_stack+43004,int_stack+41996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1345036,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5183322,int_stack+5180298,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2016336,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5187858,int_stack+44300,int_stack+43004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1346044,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5191746,int_stack+5187858,int_stack+5180298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2018604,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5197794,int_stack+5191746,int_stack+5183322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2021628,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+45920,int_stack+44300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1347340,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5235129,int_stack+5178030,int_stack+5187858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2026164,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5235129,int_stack+5191746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2030052,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5235129,int_stack+5178030,int_stack+5197794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2036100,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+5178030,int_stack+5235129,int_stack+5206464,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+6586620,int_stack+5178030,int_stack+5215284,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5204490,int_stack+48845,int_stack+47900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1357600,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5207325,int_stack+50105,int_stack+48845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1358545,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5211105,int_stack+5207325,int_stack+5204490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2155305,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5216775,int_stack+51725,int_stack+50105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1359805,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5221635,int_stack+5216775,int_stack+5207325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2158140,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5246469,int_stack+5221635,int_stack+5211105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2161920,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5204490,int_stack+53750,int_stack+51725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1361425,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6626310,int_stack+5204490,int_stack+5216775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2167590,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5204490,int_stack+6626310,int_stack+5221635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2172450,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+5204490,int_stack+5246469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2180010,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+6626310,int_stack+2356725,int_stack+5235129,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5204490,int_stack+6626310,int_stack+5178030,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+6785385,int_stack+5204490,int_stack+6586620,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6586620,int_stack+57380,int_stack+56225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+569600,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6590085,int_stack+58920,int_stack+57380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+571910,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6594705,int_stack+6590085,int_stack+6586620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2398470,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6601635,int_stack+60900,int_stack+58920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+574990,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6607575,int_stack+6601635,int_stack+6590085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2401935,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5178030,int_stack+6607575,int_stack+6594705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2406555,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6586620,int_stack+63375,int_stack+60900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+578950,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5189580,int_stack+6586620,int_stack+6601635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2413485,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6586620,int_stack+5189580,int_stack+6607575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2419425,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6602020,int_stack+6586620,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2428665,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5025987,int_stack+6602020,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+6851535,int_stack+5025987,int_stack+6626310,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+6586620,int_stack+6851535,int_stack+5204490,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6851535,int_stack+66841,int_stack+66400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326150, 1.0, int_stack+1384425,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6852858,int_stack+67429,int_stack+66841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326591, 1.0, int_stack+1384866,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6854622,int_stack+6852858,int_stack+6851535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1895289, 1.0, int_stack+2440215,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6857268,int_stack+68185,int_stack+67429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1327179, 1.0, int_stack+1385454,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6859536,int_stack+6857268,int_stack+6852858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1896612, 1.0, int_stack+2441538,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6863064,int_stack+6859536,int_stack+6854622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1898376, 1.0, int_stack+2443302,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6851535,int_stack+69130,int_stack+68185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1327935, 1.0, int_stack+1386210,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6867474,int_stack+6851535,int_stack+6857268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1901022, 1.0, int_stack+2445948,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6851535,int_stack+6867474,int_stack+6859536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1903290, 1.0, int_stack+2448216,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6867474,int_stack+6851535,int_stack+6863064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1906818, 1.0, int_stack+2451744,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6851535,int_stack+70873,int_stack+70285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1333920, 1.0, int_stack+1392195,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6853299,int_stack+71657,int_stack+70873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1334508, 1.0, int_stack+1392783,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6855651,int_stack+6853299,int_stack+6851535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1939095, 1.0, int_stack+2462769,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6859179,int_stack+72665,int_stack+71657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1335292, 1.0, int_stack+1393567,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6862203,int_stack+6859179,int_stack+6853299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1940859, 1.0, int_stack+2464533,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6874089,int_stack+6862203,int_stack+6855651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1943211, 1.0, int_stack+2466885,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6851535,int_stack+73925,int_stack+72665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336300, 1.0, int_stack+1394575,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6879969,int_stack+6851535,int_stack+6859179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1946739, 1.0, int_stack+2470413,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6851535,int_stack+6879969,int_stack+6862203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1949763, 1.0, int_stack+2473437,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6879969,int_stack+6851535,int_stack+6874089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1954467, 1.0, int_stack+2478141,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+6888789,int_stack+6879969,int_stack+6867474,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6851535,int_stack+76221,int_stack+75465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1344280, 1.0, int_stack+1402555,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6853803,int_stack+77229,int_stack+76221, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1345036, 1.0, int_stack+1403311,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6856827,int_stack+6853803,int_stack+6851535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2016336, 1.0, int_stack+2512686,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6861363,int_stack+78525,int_stack+77229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1346044, 1.0, int_stack+1404319,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6865251,int_stack+6861363,int_stack+6853803, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2018604, 1.0, int_stack+2514954,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6871299,int_stack+6865251,int_stack+6856827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2021628, 1.0, int_stack+2517978,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6851535,int_stack+80145,int_stack+78525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1347340, 1.0, int_stack+1405615,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6908634,int_stack+6851535,int_stack+6861363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2026164, 1.0, int_stack+2522514,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6851535,int_stack+6908634,int_stack+6865251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2030052, 1.0, int_stack+2526402,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6908634,int_stack+6851535,int_stack+6871299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2036100, 1.0, int_stack+2532450,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+6851535,int_stack+6908634,int_stack+6879969,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+5025987,int_stack+6851535,int_stack+6888789,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6877995,int_stack+83070,int_stack+82125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1357600, 1.0, int_stack+1415875,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6880830,int_stack+84330,int_stack+83070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358545, 1.0, int_stack+1416820,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6884610,int_stack+6880830,int_stack+6877995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2155305, 1.0, int_stack+2551350,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6890280,int_stack+85950,int_stack+84330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1359805, 1.0, int_stack+1418080,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6895140,int_stack+6890280,int_stack+6880830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2158140, 1.0, int_stack+2554185,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2356725,int_stack+6895140,int_stack+6884610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2161920, 1.0, int_stack+2557965,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6877995,int_stack+87975,int_stack+85950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1361425, 1.0, int_stack+1419700,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5178030,int_stack+6877995,int_stack+6890280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2167590, 1.0, int_stack+2722455,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6877995,int_stack+5178030,int_stack+6895140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2172450, 1.0, int_stack+2727315,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5178030,int_stack+6877995,int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2180010, 1.0, int_stack+2734875,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5192205,int_stack+5178030,int_stack+6908634,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+17280,int_stack+5192205,int_stack+6851535,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+6851535,int_stack+17280,int_stack+5025987,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5025987,int_stack+91605,int_stack+90450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569600, 1.0, int_stack+610975,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5029452,int_stack+93145,int_stack+91605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571910, 1.0, int_stack+613285,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5034072,int_stack+5029452,int_stack+5025987, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2398470, 1.0, int_stack+2563635,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5041002,int_stack+95125,int_stack+93145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574990, 1.0, int_stack+616365,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5046942,int_stack+5041002,int_stack+5029452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2401935, 1.0, int_stack+2911590,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5056182,int_stack+5046942,int_stack+5034072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2406555, 1.0, int_stack+2916210,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5025987,int_stack+97600,int_stack+95125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578950, 1.0, int_stack+620325,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2356725,int_stack+5025987,int_stack+5041002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2413485, 1.0, int_stack+2923140,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5025987,int_stack+2356725,int_stack+5046942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2419425, 1.0, int_stack+2929080,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5226225,int_stack+5025987,int_stack+5056182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2428665, 1.0, int_stack+2938320,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5025987,int_stack+5226225,int_stack+5178030,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+6917685,int_stack+5025987,int_stack+5192205,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+6985725,int_stack+6917685,int_stack+17280,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17280,int_stack+101066,int_stack+100625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1384425, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18603,int_stack+101654,int_stack+101066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1384866, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+20367,int_stack+18603,int_stack+17280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2440215, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+23013,int_stack+102410,int_stack+101654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1385454, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+25281,int_stack+23013,int_stack+18603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2441538, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28809,int_stack+25281,int_stack+20367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2443302, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+17280,int_stack+103355,int_stack+102410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1386210, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+33219,int_stack+17280,int_stack+23013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2445948, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17280,int_stack+33219,int_stack+25281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2448216, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+33219,int_stack+17280,int_stack+28809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2451744, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17280,int_stack+105098,int_stack+104510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1392195, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19044,int_stack+105882,int_stack+105098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1392783, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21396,int_stack+19044,int_stack+17280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2462769, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+24924,int_stack+106890,int_stack+105882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1393567, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+27948,int_stack+24924,int_stack+19044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2464533, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+39834,int_stack+27948,int_stack+21396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2466885, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+17280,int_stack+108150,int_stack+106890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1394575, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+45714,int_stack+17280,int_stack+24924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2470413, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17280,int_stack+45714,int_stack+27948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2473437, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+45714,int_stack+17280,int_stack+39834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2478141, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+54534,int_stack+45714,int_stack+33219,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17280,int_stack+110446,int_stack+109690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1402555, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19548,int_stack+111454,int_stack+110446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1403311, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22572,int_stack+19548,int_stack+17280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2512686, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+27108,int_stack+112750,int_stack+111454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1404319, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+30996,int_stack+27108,int_stack+19548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2514954, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+37044,int_stack+30996,int_stack+22572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2517978, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+17280,int_stack+114370,int_stack+112750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1405615, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+74379,int_stack+17280,int_stack+27108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2522514, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17280,int_stack+74379,int_stack+30996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2526402, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+74379,int_stack+17280,int_stack+37044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2532450, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+17280,int_stack+74379,int_stack+45714,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+6917685,int_stack+17280,int_stack+54534,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+43740,int_stack+117295,int_stack+116350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1415875, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+46575,int_stack+118555,int_stack+117295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1416820, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50355,int_stack+46575,int_stack+43740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2551350, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+56025,int_stack+120175,int_stack+118555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1418080, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+60885,int_stack+56025,int_stack+46575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2554185, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+85719,int_stack+60885,int_stack+50355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2557965, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+43740,int_stack+122200,int_stack+120175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1419700, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+95169,int_stack+43740,int_stack+56025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2722455, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+43740,int_stack+95169,int_stack+60885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2727315, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+43740,int_stack+85719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2734875, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+85719,int_stack+2356725,int_stack+74379,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5178030,int_stack+85719,int_stack+17280,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+17280,int_stack+5178030,int_stack+6917685,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6917685,int_stack+125830,int_stack+124675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+610975, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6921150,int_stack+127370,int_stack+125830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+613285, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6925770,int_stack+6921150,int_stack+6917685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2563635, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6932700,int_stack+129350,int_stack+127370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+616365, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6938640,int_stack+6932700,int_stack+6921150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2911590, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6947880,int_stack+6938640,int_stack+6925770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2916210, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6917685,int_stack+131825,int_stack+129350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+620325, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6959430,int_stack+6917685,int_stack+6932700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2923140, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6917685,int_stack+6959430,int_stack+6938640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2929080, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6959430,int_stack+6917685,int_stack+6947880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2938320, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5025987,int_stack+6959430,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+6917685,int_stack+5025987,int_stack+85719,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+7073925,int_stack+6917685,int_stack+5178030,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+135291,int_stack+134850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326150, 0.0, zero_stack, 1.0, int_stack+1442700,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5179353,int_stack+135879,int_stack+135291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326591, 0.0, zero_stack, 1.0, int_stack+1443141,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5181117,int_stack+5179353,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1895289, 0.0, zero_stack, 1.0, int_stack+2949870,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5183763,int_stack+136635,int_stack+135879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1327179, 0.0, zero_stack, 1.0, int_stack+1443729,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5186031,int_stack+5183763,int_stack+5179353, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1896612, 0.0, zero_stack, 1.0, int_stack+2951193,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5189559,int_stack+5186031,int_stack+5181117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1898376, 0.0, zero_stack, 1.0, int_stack+2952957,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+137580,int_stack+136635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1327935, 0.0, zero_stack, 1.0, int_stack+1444485,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5193969,int_stack+5178030,int_stack+5183763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1901022, 0.0, zero_stack, 1.0, int_stack+2955603,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5193969,int_stack+5186031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1903290, 0.0, zero_stack, 1.0, int_stack+2957871,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5193969,int_stack+5178030,int_stack+5189559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1906818, 0.0, zero_stack, 1.0, int_stack+2961399,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+139323,int_stack+138735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1333920, 0.0, zero_stack, 1.0, int_stack+1450470,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5179794,int_stack+140107,int_stack+139323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1334508, 0.0, zero_stack, 1.0, int_stack+1451058,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5182146,int_stack+5179794,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1939095, 0.0, zero_stack, 1.0, int_stack+2972424,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5185674,int_stack+141115,int_stack+140107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1335292, 0.0, zero_stack, 1.0, int_stack+1451842,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5188698,int_stack+5185674,int_stack+5179794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1940859, 0.0, zero_stack, 1.0, int_stack+2974188,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5200584,int_stack+5188698,int_stack+5182146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1943211, 0.0, zero_stack, 1.0, int_stack+2976540,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+142375,int_stack+141115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336300, 0.0, zero_stack, 1.0, int_stack+1452850,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5206464,int_stack+5178030,int_stack+5185674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1946739, 0.0, zero_stack, 1.0, int_stack+2980068,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5206464,int_stack+5188698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1949763, 0.0, zero_stack, 1.0, int_stack+2983092,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5206464,int_stack+5178030,int_stack+5200584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1954467, 0.0, zero_stack, 1.0, int_stack+2987796,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5215284,int_stack+5206464,int_stack+5193969,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+144671,int_stack+143915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1344280, 0.0, zero_stack, 1.0, int_stack+1460830,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5180298,int_stack+145679,int_stack+144671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1345036, 0.0, zero_stack, 1.0, int_stack+1461586,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5183322,int_stack+5180298,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2016336, 0.0, zero_stack, 1.0, int_stack+3022341,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5187858,int_stack+146975,int_stack+145679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1346044, 0.0, zero_stack, 1.0, int_stack+1462594,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5191746,int_stack+5187858,int_stack+5180298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2018604, 0.0, zero_stack, 1.0, int_stack+3024609,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5197794,int_stack+5191746,int_stack+5183322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2021628, 0.0, zero_stack, 1.0, int_stack+3027633,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+148595,int_stack+146975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1347340, 0.0, zero_stack, 1.0, int_stack+1463890,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5235129,int_stack+5178030,int_stack+5187858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2026164, 0.0, zero_stack, 1.0, int_stack+3032169,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5235129,int_stack+5191746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2030052, 0.0, zero_stack, 1.0, int_stack+3036057,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5235129,int_stack+5178030,int_stack+5197794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2036100, 0.0, zero_stack, 1.0, int_stack+3042105,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+5178030,int_stack+5235129,int_stack+5206464,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+6917685,int_stack+5178030,int_stack+5215284,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5204490,int_stack+151520,int_stack+150575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1357600, 0.0, zero_stack, 1.0, int_stack+1474150,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5207325,int_stack+152780,int_stack+151520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358545, 0.0, zero_stack, 1.0, int_stack+1475095,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5211105,int_stack+5207325,int_stack+5204490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2155305, 0.0, zero_stack, 1.0, int_stack+3061005,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5216775,int_stack+154400,int_stack+152780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1359805, 0.0, zero_stack, 1.0, int_stack+1476355,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5221635,int_stack+5216775,int_stack+5207325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2158140, 0.0, zero_stack, 1.0, int_stack+3063840,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5246469,int_stack+5221635,int_stack+5211105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2161920, 0.0, zero_stack, 1.0, int_stack+3067620,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5204490,int_stack+156425,int_stack+154400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1361425, 0.0, zero_stack, 1.0, int_stack+1477975,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6957375,int_stack+5204490,int_stack+5216775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2167590, 0.0, zero_stack, 1.0, int_stack+0,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5204490,int_stack+6957375,int_stack+5221635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2172450, 0.0, zero_stack, 1.0, int_stack+3232110,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+5204490,int_stack+5246469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2180010, 0.0, zero_stack, 1.0, int_stack+3239670,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5025987,int_stack+2356725,int_stack+5235129,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5204490,int_stack+5025987,int_stack+5178030,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+83430,int_stack+5204490,int_stack+6917685,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6917685,int_stack+160055,int_stack+158900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569600, 0.0, zero_stack, 1.0, int_stack+652350,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6921150,int_stack+161595,int_stack+160055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571910, 0.0, zero_stack, 1.0, int_stack+654660,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6925770,int_stack+6921150,int_stack+6917685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2398470, 0.0, zero_stack, 1.0, int_stack+3073290,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6932700,int_stack+163575,int_stack+161595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574990, 0.0, zero_stack, 1.0, int_stack+657740,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6938640,int_stack+6932700,int_stack+6921150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2401935, 0.0, zero_stack, 1.0, int_stack+3416385,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6947880,int_stack+6938640,int_stack+6925770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2406555, 0.0, zero_stack, 1.0, int_stack+3421005,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6917685,int_stack+166050,int_stack+163575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578950, 0.0, zero_stack, 1.0, int_stack+661700,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6959430,int_stack+6917685,int_stack+6932700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2413485, 0.0, zero_stack, 1.0, int_stack+3427935,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6917685,int_stack+6959430,int_stack+6938640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2419425, 0.0, zero_stack, 1.0, int_stack+3433875,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6959430,int_stack+6917685,int_stack+6947880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2428665, 0.0, zero_stack, 1.0, int_stack+3443115,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+7162125,int_stack+6959430,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+6917685,int_stack+7162125,int_stack+5025987,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+7162125,int_stack+6917685,int_stack+5204490,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6917685,int_stack+169516,int_stack+169075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1384425, 1.0, int_stack+1442700, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6919008,int_stack+170104,int_stack+169516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1384866, 1.0, int_stack+1443141, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6920772,int_stack+6919008,int_stack+6917685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2440215, 1.0, int_stack+2949870, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6923418,int_stack+170860,int_stack+170104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1385454, 1.0, int_stack+1443729, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6925686,int_stack+6923418,int_stack+6919008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2441538, 1.0, int_stack+2951193, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6929214,int_stack+6925686,int_stack+6920772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2443302, 1.0, int_stack+2952957, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6917685,int_stack+171805,int_stack+170860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1386210, 1.0, int_stack+1444485, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6933624,int_stack+6917685,int_stack+6923418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2445948, 1.0, int_stack+2955603, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6917685,int_stack+6933624,int_stack+6925686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2448216, 1.0, int_stack+2957871, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6933624,int_stack+6917685,int_stack+6929214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2451744, 1.0, int_stack+2961399, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6917685,int_stack+173548,int_stack+172960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1392195, 1.0, int_stack+1450470, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6919449,int_stack+174332,int_stack+173548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1392783, 1.0, int_stack+1451058, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6921801,int_stack+6919449,int_stack+6917685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2462769, 1.0, int_stack+2972424, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6925329,int_stack+175340,int_stack+174332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1393567, 1.0, int_stack+1451842, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6928353,int_stack+6925329,int_stack+6919449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2464533, 1.0, int_stack+2974188, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6940239,int_stack+6928353,int_stack+6921801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2466885, 1.0, int_stack+2976540, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6917685,int_stack+176600,int_stack+175340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1394575, 1.0, int_stack+1452850, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6946119,int_stack+6917685,int_stack+6925329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2470413, 1.0, int_stack+2980068, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6917685,int_stack+6946119,int_stack+6928353, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2473437, 1.0, int_stack+2983092, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6946119,int_stack+6917685,int_stack+6940239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2478141, 1.0, int_stack+2987796, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+6954939,int_stack+6946119,int_stack+6933624,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6917685,int_stack+178896,int_stack+178140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1402555, 1.0, int_stack+1460830, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6919953,int_stack+179904,int_stack+178896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1403311, 1.0, int_stack+1461586, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6922977,int_stack+6919953,int_stack+6917685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2512686, 1.0, int_stack+3022341, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6927513,int_stack+181200,int_stack+179904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1404319, 1.0, int_stack+1462594, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6931401,int_stack+6927513,int_stack+6919953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2514954, 1.0, int_stack+3024609, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6937449,int_stack+6931401,int_stack+6922977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2517978, 1.0, int_stack+3027633, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6917685,int_stack+182820,int_stack+181200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1405615, 1.0, int_stack+1463890, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6974784,int_stack+6917685,int_stack+6927513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2522514, 1.0, int_stack+3032169, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6917685,int_stack+6974784,int_stack+6931401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2526402, 1.0, int_stack+3036057, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5025987,int_stack+6917685,int_stack+6937449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2532450, 1.0, int_stack+3042105, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+6917685,int_stack+5025987,int_stack+6946119,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+5178030,int_stack+6917685,int_stack+6954939,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6944145,int_stack+185745,int_stack+184800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1415875, 1.0, int_stack+1474150, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6946980,int_stack+187005,int_stack+185745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1416820, 1.0, int_stack+1475095, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6950760,int_stack+6946980,int_stack+6944145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2551350, 1.0, int_stack+3061005, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6956430,int_stack+188625,int_stack+187005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1418080, 1.0, int_stack+1476355, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6961290,int_stack+6956430,int_stack+6946980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2554185, 1.0, int_stack+3063840, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6968850,int_stack+6961290,int_stack+6950760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2557965, 1.0, int_stack+3067620, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6944145,int_stack+190650,int_stack+188625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1419700, 1.0, int_stack+1477975, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5037327,int_stack+6944145,int_stack+6956430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2722455, 1.0, int_stack+0, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6944145,int_stack+5037327,int_stack+6961290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2727315, 1.0, int_stack+3232110, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+6944145,int_stack+6968850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2734875, 1.0, int_stack+3239670, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+6944145,int_stack+2356725,int_stack+5025987,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+6944145,int_stack+6917685,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+7303245,int_stack+7250325,int_stack+5178030,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+194280,int_stack+193125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610975, 1.0, int_stack+652350, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5181495,int_stack+195820,int_stack+194280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613285, 1.0, int_stack+654660, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5186115,int_stack+5181495,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2563635, 1.0, int_stack+3073290, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5193045,int_stack+197800,int_stack+195820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+616365, 1.0, int_stack+657740, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5198985,int_stack+5193045,int_stack+5181495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2911590, 1.0, int_stack+3416385, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5208225,int_stack+5198985,int_stack+5186115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2916210, 1.0, int_stack+3421005, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+200275,int_stack+197800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+620325, 1.0, int_stack+661700, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5219775,int_stack+5178030,int_stack+5193045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2923140, 1.0, int_stack+3427935, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5219775,int_stack+5198985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2929080, 1.0, int_stack+3433875, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5219775,int_stack+5178030,int_stack+5208225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2938320, 1.0, int_stack+3443115, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5025987,int_stack+5219775,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+5178030,int_stack+5025987,int_stack+6944145,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+7369395,int_stack+5178030,int_stack+7250325,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+203741,int_stack+203300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1442700, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+204329,int_stack+203741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1443141, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2949870, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+205085,int_stack+204329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1443729, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2951193, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2952957, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+206030,int_stack+205085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1444485, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2955603, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2957871, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2961399, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+207773,int_stack+207185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1450470, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+208557,int_stack+207773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1451058, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2972424, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+209565,int_stack+208557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1451842, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2974188, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2976540, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+210825,int_stack+209565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1452850, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7257969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2980068, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7260993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2983092, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2987796, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5178030,int_stack+7278759,int_stack+7266264,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+213121,int_stack+212365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1460830, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+214129,int_stack+213121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1461586, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3022341, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+215425,int_stack+214129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1462594, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7264041,int_stack+7260153,int_stack+7252593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3024609, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7270089,int_stack+7264041,int_stack+7255617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3027633, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+217045,int_stack+215425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1463890, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3032169, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+7264041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3036057, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7270089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3042105, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+5197875,int_stack+7250325,int_stack+5178030,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+219970,int_stack+219025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1474150, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5180865,int_stack+221230,int_stack+219970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1475095, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5184645,int_stack+5180865,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3061005, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5190315,int_stack+222850,int_stack+221230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1476355, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7276785,int_stack+5190315,int_stack+5180865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3063840, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5237565,int_stack+7276785,int_stack+5184645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3067620, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+224875,int_stack+222850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1477975, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5247015,int_stack+5178030,int_stack+5190315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5247015,int_stack+7276785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3232110, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+5178030,int_stack+5237565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3239670, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5025987,int_stack+2356725,int_stack+7287579,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+6917685,int_stack+5025987,int_stack+7250325,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+149580,int_stack+6917685,int_stack+5197875,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+228505,int_stack+227350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+652350, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253790,int_stack+230045,int_stack+228505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+654660, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7258410,int_stack+7253790,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3073290, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7265340,int_stack+232025,int_stack+230045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+657740, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7271280,int_stack+7265340,int_stack+7253790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3416385, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7280520,int_stack+7271280,int_stack+7258410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3421005, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+234500,int_stack+232025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+661700, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5178030,int_stack+7250325,int_stack+7265340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3427935, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+5178030,int_stack+7271280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3433875, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5178030,int_stack+7250325,int_stack+7280520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3443115, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+7250325,int_stack+5178030,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+5178030,int_stack+7250325,int_stack+5025987,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+7457595,int_stack+5178030,int_stack+6917685,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6917685,int_stack+237966,int_stack+237525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1500975,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6919008,int_stack+238554,int_stack+237966, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326591, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1501416,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6920772,int_stack+6919008,int_stack+6917685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1895289, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3454665,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6923418,int_stack+239310,int_stack+238554, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1327179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1502004,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6925686,int_stack+6923418,int_stack+6919008, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1896612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3455988,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6929214,int_stack+6925686,int_stack+6920772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1898376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3457752,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6917685,int_stack+240255,int_stack+239310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1327935, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1502760,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6933624,int_stack+6917685,int_stack+6923418, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1901022, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3460398,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6917685,int_stack+6933624,int_stack+6925686, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1903290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3462666,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6933624,int_stack+6917685,int_stack+6929214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1906818, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3466194,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6917685,int_stack+241998,int_stack+241410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1333920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1508745,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6919449,int_stack+242782,int_stack+241998, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1334508, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1509333,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6921801,int_stack+6919449,int_stack+6917685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1939095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3477219,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6925329,int_stack+243790,int_stack+242782, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1335292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1510117,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6928353,int_stack+6925329,int_stack+6919449, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1940859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3478983,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6940239,int_stack+6928353,int_stack+6921801, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1943211, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3481335,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6917685,int_stack+245050,int_stack+243790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1511125,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6946119,int_stack+6917685,int_stack+6925329, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1946739, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3484863,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6917685,int_stack+6946119,int_stack+6928353, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1949763, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3487887,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6946119,int_stack+6917685,int_stack+6940239, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1954467, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3492591,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+6954939,int_stack+6946119,int_stack+6933624,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6917685,int_stack+247346,int_stack+246590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1344280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1519105,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6919953,int_stack+248354,int_stack+247346, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1345036, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1519861,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6922977,int_stack+6919953,int_stack+6917685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2016336, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3527136,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6927513,int_stack+249650,int_stack+248354, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1346044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1520869,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6931401,int_stack+6927513,int_stack+6919953, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2018604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3529404,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6937449,int_stack+6931401,int_stack+6922977, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2021628, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3532428,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6917685,int_stack+251270,int_stack+249650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1347340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1522165,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6974784,int_stack+6917685,int_stack+6927513, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2026164, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3536964,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6917685,int_stack+6974784,int_stack+6931401, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2030052, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3540852,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5178030,int_stack+6917685,int_stack+6937449, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2036100, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3546900,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+6917685,int_stack+5178030,int_stack+6946119,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+5189370,int_stack+6917685,int_stack+6954939,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6944145,int_stack+254195,int_stack+253250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1357600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1532425,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6946980,int_stack+255455,int_stack+254195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1533370,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6950760,int_stack+6946980,int_stack+6944145, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2155305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3565800,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6956430,int_stack+257075,int_stack+255455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1359805, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1534630,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6961290,int_stack+6956430,int_stack+6946980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2158140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3568635,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6968850,int_stack+6961290,int_stack+6950760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2161920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3572415,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6944145,int_stack+259100,int_stack+257075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1361425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1536250,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5229060,int_stack+6944145,int_stack+6956430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2167590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3736905,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6944145,int_stack+5229060,int_stack+6961290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2172450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3741765,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+6944145,int_stack+6968850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2180010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3749325,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+6944145,int_stack+2356725,int_stack+5178030,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+6944145,int_stack+6917685,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+7545795,int_stack+7250325,int_stack+5189370,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6917685,int_stack+262730,int_stack+261575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693725,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6921150,int_stack+264270,int_stack+262730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696035,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6925770,int_stack+6921150,int_stack+6917685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2398470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3578085,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6932700,int_stack+266250,int_stack+264270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574990, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+699115,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5178030,int_stack+6932700,int_stack+6921150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2401935, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3926040,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5187270,int_stack+5178030,int_stack+6925770, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2406555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3930660,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6917685,int_stack+268725,int_stack+266250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703075,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5198820,int_stack+6917685,int_stack+6932700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2413485, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3937590,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6917685,int_stack+5198820,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2419425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3943530,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5198820,int_stack+6917685,int_stack+5187270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2428665, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3952770,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5216145,int_stack+5198820,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+7611945,int_stack+5216145,int_stack+6944145,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+7679985,int_stack+7611945,int_stack+7250325,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+272191,int_stack+271750, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1384425, 0.0, zero_stack, 1.0, int_stack+1500975, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+272779,int_stack+272191, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1384866, 0.0, zero_stack, 1.0, int_stack+1501416, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2440215, 0.0, zero_stack, 1.0, int_stack+3454665, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+273535,int_stack+272779, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1385454, 0.0, zero_stack, 1.0, int_stack+1502004, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2441538, 0.0, zero_stack, 1.0, int_stack+3455988, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2443302, 0.0, zero_stack, 1.0, int_stack+3457752, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+274480,int_stack+273535, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1386210, 0.0, zero_stack, 1.0, int_stack+1502760, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2445948, 0.0, zero_stack, 1.0, int_stack+3460398, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2448216, 0.0, zero_stack, 1.0, int_stack+3462666, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2451744, 0.0, zero_stack, 1.0, int_stack+3466194, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+276223,int_stack+275635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1392195, 0.0, zero_stack, 1.0, int_stack+1508745, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+277007,int_stack+276223, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1392783, 0.0, zero_stack, 1.0, int_stack+1509333, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2462769, 0.0, zero_stack, 1.0, int_stack+3477219, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+278015,int_stack+277007, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1393567, 0.0, zero_stack, 1.0, int_stack+1510117, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2464533, 0.0, zero_stack, 1.0, int_stack+3478983, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2466885, 0.0, zero_stack, 1.0, int_stack+3481335, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+279275,int_stack+278015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1394575, 0.0, zero_stack, 1.0, int_stack+1511125, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7257969, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2470413, 0.0, zero_stack, 1.0, int_stack+3484863, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7260993, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2473437, 0.0, zero_stack, 1.0, int_stack+3487887, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2478141, 0.0, zero_stack, 1.0, int_stack+3492591, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7611945,int_stack+7278759,int_stack+7266264,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+281571,int_stack+280815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1402555, 0.0, zero_stack, 1.0, int_stack+1519105, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+282579,int_stack+281571, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1403311, 0.0, zero_stack, 1.0, int_stack+1519861, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2512686, 0.0, zero_stack, 1.0, int_stack+3527136, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+283875,int_stack+282579, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1404319, 0.0, zero_stack, 1.0, int_stack+1520869, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7264041,int_stack+7260153,int_stack+7252593, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2514954, 0.0, zero_stack, 1.0, int_stack+3529404, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7270089,int_stack+7264041,int_stack+7255617, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2517978, 0.0, zero_stack, 1.0, int_stack+3532428, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+285495,int_stack+283875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1405615, 0.0, zero_stack, 1.0, int_stack+1522165, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2522514, 0.0, zero_stack, 1.0, int_stack+3536964, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+7264041, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2526402, 0.0, zero_stack, 1.0, int_stack+3540852, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7270089, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2532450, 0.0, zero_stack, 1.0, int_stack+3546900, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7631790,int_stack+7250325,int_stack+7611945,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+288420,int_stack+287475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1415875, 0.0, zero_stack, 1.0, int_stack+1532425, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7614780,int_stack+289680,int_stack+288420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1416820, 0.0, zero_stack, 1.0, int_stack+1533370, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7618560,int_stack+7614780,int_stack+7611945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2551350, 0.0, zero_stack, 1.0, int_stack+3565800, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7624230,int_stack+291300,int_stack+289680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1418080, 0.0, zero_stack, 1.0, int_stack+1534630, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7276785,int_stack+7624230,int_stack+7614780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2554185, 0.0, zero_stack, 1.0, int_stack+3568635, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2356725,int_stack+7276785,int_stack+7618560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2557965, 0.0, zero_stack, 1.0, int_stack+3572415, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+293325,int_stack+291300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1419700, 0.0, zero_stack, 1.0, int_stack+1536250, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6917685,int_stack+7611945,int_stack+7624230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2722455, 0.0, zero_stack, 1.0, int_stack+3736905, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+6917685,int_stack+7276785, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2727315, 0.0, zero_stack, 1.0, int_stack+3741765, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6917685,int_stack+7611945,int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2734875, 0.0, zero_stack, 1.0, int_stack+3749325, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+6931860,int_stack+6917685,int_stack+7287579,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5178030,int_stack+6931860,int_stack+7250325,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+215730,int_stack+5178030,int_stack+7631790,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+296955,int_stack+295800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610975, 0.0, zero_stack, 1.0, int_stack+693725, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253790,int_stack+298495,int_stack+296955, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613285, 0.0, zero_stack, 1.0, int_stack+696035, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7258410,int_stack+7253790,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2563635, 0.0, zero_stack, 1.0, int_stack+3578085, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7265340,int_stack+300475,int_stack+298495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+616365, 0.0, zero_stack, 1.0, int_stack+699115, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7271280,int_stack+7265340,int_stack+7253790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2911590, 0.0, zero_stack, 1.0, int_stack+3926040, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7280520,int_stack+7271280,int_stack+7258410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2916210, 0.0, zero_stack, 1.0, int_stack+3930660, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+302950,int_stack+300475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+620325, 0.0, zero_stack, 1.0, int_stack+703075, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2356725,int_stack+7250325,int_stack+7265340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2923140, 0.0, zero_stack, 1.0, int_stack+3937590, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+2356725,int_stack+7271280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2929080, 0.0, zero_stack, 1.0, int_stack+3943530, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7611945,int_stack+7250325,int_stack+7280520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2938320, 0.0, zero_stack, 1.0, int_stack+3952770, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+7250325,int_stack+7611945,int_stack+6917685,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+7611945,int_stack+7250325,int_stack+6931860,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+7768185,int_stack+7611945,int_stack+5178030,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+306416,int_stack+305975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1442700, 1.0, int_stack+1500975, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5179353,int_stack+307004,int_stack+306416, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1443141, 1.0, int_stack+1501416, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5181117,int_stack+5179353,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2949870, 1.0, int_stack+3454665, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5183763,int_stack+307760,int_stack+307004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1443729, 1.0, int_stack+1502004, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5186031,int_stack+5183763,int_stack+5179353, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2951193, 1.0, int_stack+3455988, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5189559,int_stack+5186031,int_stack+5181117, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2952957, 1.0, int_stack+3457752, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+308705,int_stack+307760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1444485, 1.0, int_stack+1502760, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5193969,int_stack+5178030,int_stack+5183763, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2955603, 1.0, int_stack+3460398, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5193969,int_stack+5186031, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2957871, 1.0, int_stack+3462666, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5193969,int_stack+5178030,int_stack+5189559, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2961399, 1.0, int_stack+3466194, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+310448,int_stack+309860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1450470, 1.0, int_stack+1508745, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5179794,int_stack+311232,int_stack+310448, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1451058, 1.0, int_stack+1509333, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5182146,int_stack+5179794,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2972424, 1.0, int_stack+3477219, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5185674,int_stack+312240,int_stack+311232, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1451842, 1.0, int_stack+1510117, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5188698,int_stack+5185674,int_stack+5179794, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2974188, 1.0, int_stack+3478983, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5200584,int_stack+5188698,int_stack+5182146, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2976540, 1.0, int_stack+3481335, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+313500,int_stack+312240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1452850, 1.0, int_stack+1511125, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5206464,int_stack+5178030,int_stack+5185674, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2980068, 1.0, int_stack+3484863, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5206464,int_stack+5188698, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2983092, 1.0, int_stack+3487887, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5206464,int_stack+5178030,int_stack+5200584, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2987796, 1.0, int_stack+3492591, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5215284,int_stack+5206464,int_stack+5193969,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+315796,int_stack+315040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1460830, 1.0, int_stack+1519105, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5180298,int_stack+316804,int_stack+315796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1461586, 1.0, int_stack+1519861, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5183322,int_stack+5180298,int_stack+5178030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3022341, 1.0, int_stack+3527136, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5187858,int_stack+318100,int_stack+316804, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1462594, 1.0, int_stack+1520869, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5191746,int_stack+5187858,int_stack+5180298, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024609, 1.0, int_stack+3529404, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5197794,int_stack+5191746,int_stack+5183322, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3027633, 1.0, int_stack+3532428, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+319720,int_stack+318100, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1463890, 1.0, int_stack+1522165, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5235129,int_stack+5178030,int_stack+5187858, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3032169, 1.0, int_stack+3536964, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5235129,int_stack+5191746, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3036057, 1.0, int_stack+3540852, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5235129,int_stack+5178030,int_stack+5197794, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3042105, 1.0, int_stack+3546900, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+5178030,int_stack+5235129,int_stack+5206464,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7611945,int_stack+5178030,int_stack+5215284,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5204490,int_stack+322645,int_stack+321700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1474150, 1.0, int_stack+1532425, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5207325,int_stack+323905,int_stack+322645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1475095, 1.0, int_stack+1533370, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5211105,int_stack+5207325,int_stack+5204490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3061005, 1.0, int_stack+3565800, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5216775,int_stack+325525,int_stack+323905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1476355, 1.0, int_stack+1534630, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5221635,int_stack+5216775,int_stack+5207325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3063840, 1.0, int_stack+3568635, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5246469,int_stack+5221635,int_stack+5211105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3067620, 1.0, int_stack+3572415, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5204490,int_stack+327550,int_stack+325525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1477975, 1.0, int_stack+1536250, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7651635,int_stack+5204490,int_stack+5216775, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+3736905, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5204490,int_stack+7651635,int_stack+5221635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3232110, 1.0, int_stack+3741765, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+5204490,int_stack+5246469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3239670, 1.0, int_stack+3749325, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7250325,int_stack+2356725,int_stack+5235129,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5204490,int_stack+7250325,int_stack+5178030,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+6917685,int_stack+5204490,int_stack+7611945,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+331180,int_stack+330025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+652350, 1.0, int_stack+693725, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7615410,int_stack+332720,int_stack+331180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654660, 1.0, int_stack+696035, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7620030,int_stack+7615410,int_stack+7611945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3073290, 1.0, int_stack+3578085, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7626960,int_stack+334700,int_stack+332720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657740, 1.0, int_stack+699115, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7632900,int_stack+7626960,int_stack+7615410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3416385, 1.0, int_stack+3926040, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7642140,int_stack+7632900,int_stack+7620030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3421005, 1.0, int_stack+3930660, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+337175,int_stack+334700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+661700, 1.0, int_stack+703075, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7653690,int_stack+7611945,int_stack+7626960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3427935, 1.0, int_stack+3937590, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7653690,int_stack+7632900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3433875, 1.0, int_stack+3943530, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7653690,int_stack+7611945,int_stack+7642140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3443115, 1.0, int_stack+3952770, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5025987,int_stack+7653690,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+7611945,int_stack+5025987,int_stack+7250325,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+7856385,int_stack+7611945,int_stack+5204490,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+340641,int_stack+340200, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1500975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7613268,int_stack+341229,int_stack+340641, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1501416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7615032,int_stack+7613268,int_stack+7611945, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3454665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7617678,int_stack+341985,int_stack+341229, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1502004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7619946,int_stack+7617678,int_stack+7613268, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3455988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7623474,int_stack+7619946,int_stack+7615032, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3457752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+342930,int_stack+341985, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1502760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7627884,int_stack+7611945,int_stack+7617678, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3460398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7627884,int_stack+7619946, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3462666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7627884,int_stack+7611945,int_stack+7623474, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3466194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+344673,int_stack+344085, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1508745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7613709,int_stack+345457,int_stack+344673, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1509333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7616061,int_stack+7613709,int_stack+7611945, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3477219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7619589,int_stack+346465,int_stack+345457, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1510117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7622613,int_stack+7619589,int_stack+7613709, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3478983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7634499,int_stack+7622613,int_stack+7616061, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3481335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+347725,int_stack+346465, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1511125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7640379,int_stack+7611945,int_stack+7619589, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3484863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7640379,int_stack+7622613, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3487887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7640379,int_stack+7611945,int_stack+7634499, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3492591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7649199,int_stack+7640379,int_stack+7627884,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+350021,int_stack+349265, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1519105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7614213,int_stack+351029,int_stack+350021, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1519861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7617237,int_stack+7614213,int_stack+7611945, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3527136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7621773,int_stack+352325,int_stack+351029, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1520869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7625661,int_stack+7621773,int_stack+7614213, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3529404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7631709,int_stack+7625661,int_stack+7617237, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3532428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+353945,int_stack+352325, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1522165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7669044,int_stack+7611945,int_stack+7621773, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3536964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7669044,int_stack+7625661, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3540852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7250325,int_stack+7611945,int_stack+7631709, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3546900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7611945,int_stack+7250325,int_stack+7640379,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7261665,int_stack+7611945,int_stack+7649199,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7638405,int_stack+356870,int_stack+355925, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1532425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7641240,int_stack+358130,int_stack+356870, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1533370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7645020,int_stack+7641240,int_stack+7638405, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3565800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7650690,int_stack+359750,int_stack+358130, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1534630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7655550,int_stack+7650690,int_stack+7641240, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3568635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7663110,int_stack+7655550,int_stack+7645020, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3572415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7638405,int_stack+361775,int_stack+359750, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1536250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5025987,int_stack+7638405,int_stack+7650690, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3736905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7638405,int_stack+5025987,int_stack+7655550, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3741765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+7638405,int_stack+7663110, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3749325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7638405,int_stack+2356725,int_stack+7250325,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5178030,int_stack+7638405,int_stack+7611945,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+281880,int_stack+5178030,int_stack+7261665,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+365405,int_stack+364250, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+693725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7615410,int_stack+366945,int_stack+365405, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+696035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7620030,int_stack+7615410,int_stack+7611945, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3578085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7626960,int_stack+368925,int_stack+366945, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+699115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7250325,int_stack+7626960,int_stack+7615410, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3926040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7259565,int_stack+7250325,int_stack+7620030, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3930660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+371400,int_stack+368925, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+703075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7271115,int_stack+7611945,int_stack+7626960, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3937590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7271115,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3943530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7271115,int_stack+7611945,int_stack+7259565, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3952770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5025987,int_stack+7271115,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+7944585,int_stack+5025987,int_stack+7638405,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+8012625,int_stack+7944585,int_stack+5178030,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+374866,int_stack+374425, 0.0, zero_stack, 1.0, int_stack+1326150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1559250,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5179353,int_stack+375454,int_stack+374866, 0.0, zero_stack, 1.0, int_stack+1326591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1559691,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5181117,int_stack+5179353,int_stack+5178030, 0.0, zero_stack, 1.0, int_stack+1895289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3964320,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5183763,int_stack+376210,int_stack+375454, 0.0, zero_stack, 1.0, int_stack+1327179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1560279,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5186031,int_stack+5183763,int_stack+5179353, 0.0, zero_stack, 1.0, int_stack+1896612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3965643,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5189559,int_stack+5186031,int_stack+5181117, 0.0, zero_stack, 1.0, int_stack+1898376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3967407,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+377155,int_stack+376210, 0.0, zero_stack, 1.0, int_stack+1327935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1561035,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5193969,int_stack+5178030,int_stack+5183763, 0.0, zero_stack, 1.0, int_stack+1901022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3970053,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5193969,int_stack+5186031, 0.0, zero_stack, 1.0, int_stack+1903290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3972321,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5193969,int_stack+5178030,int_stack+5189559, 0.0, zero_stack, 1.0, int_stack+1906818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3975849,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+378898,int_stack+378310, 0.0, zero_stack, 1.0, int_stack+1333920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1567020,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5179794,int_stack+379682,int_stack+378898, 0.0, zero_stack, 1.0, int_stack+1334508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1567608,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5182146,int_stack+5179794,int_stack+5178030, 0.0, zero_stack, 1.0, int_stack+1939095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3986874,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5185674,int_stack+380690,int_stack+379682, 0.0, zero_stack, 1.0, int_stack+1335292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1568392,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5188698,int_stack+5185674,int_stack+5179794, 0.0, zero_stack, 1.0, int_stack+1940859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3988638,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5200584,int_stack+5188698,int_stack+5182146, 0.0, zero_stack, 1.0, int_stack+1943211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3990990,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+381950,int_stack+380690, 0.0, zero_stack, 1.0, int_stack+1336300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1569400,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5206464,int_stack+5178030,int_stack+5185674, 0.0, zero_stack, 1.0, int_stack+1946739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3994518,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5206464,int_stack+5188698, 0.0, zero_stack, 1.0, int_stack+1949763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3997542,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5206464,int_stack+5178030,int_stack+5200584, 0.0, zero_stack, 1.0, int_stack+1954467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4002246,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5215284,int_stack+5206464,int_stack+5193969,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5178030,int_stack+384246,int_stack+383490, 0.0, zero_stack, 1.0, int_stack+1344280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1577380,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5180298,int_stack+385254,int_stack+384246, 0.0, zero_stack, 1.0, int_stack+1345036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1578136,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5183322,int_stack+5180298,int_stack+5178030, 0.0, zero_stack, 1.0, int_stack+2016336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4036791,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5187858,int_stack+386550,int_stack+385254, 0.0, zero_stack, 1.0, int_stack+1346044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1579144,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5191746,int_stack+5187858,int_stack+5180298, 0.0, zero_stack, 1.0, int_stack+2018604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4039059,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5197794,int_stack+5191746,int_stack+5183322, 0.0, zero_stack, 1.0, int_stack+2021628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4042083,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5178030,int_stack+388170,int_stack+386550, 0.0, zero_stack, 1.0, int_stack+1347340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1580440,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5235129,int_stack+5178030,int_stack+5187858, 0.0, zero_stack, 1.0, int_stack+2026164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4046619,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5178030,int_stack+5235129,int_stack+5191746, 0.0, zero_stack, 1.0, int_stack+2030052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4050507,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5235129,int_stack+5178030,int_stack+5197794, 0.0, zero_stack, 1.0, int_stack+2036100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4056555,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+5178030,int_stack+5235129,int_stack+5206464,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7944585,int_stack+5178030,int_stack+5215284,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5204490,int_stack+391095,int_stack+390150, 0.0, zero_stack, 1.0, int_stack+1357600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1590700,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5207325,int_stack+392355,int_stack+391095, 0.0, zero_stack, 1.0, int_stack+1358545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1591645,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5211105,int_stack+5207325,int_stack+5204490, 0.0, zero_stack, 1.0, int_stack+2155305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4075455,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5216775,int_stack+393975,int_stack+392355, 0.0, zero_stack, 1.0, int_stack+1359805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1592905,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5221635,int_stack+5216775,int_stack+5207325, 0.0, zero_stack, 1.0, int_stack+2158140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4078290,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5246469,int_stack+5221635,int_stack+5211105, 0.0, zero_stack, 1.0, int_stack+2161920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4082070,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5204490,int_stack+396000,int_stack+393975, 0.0, zero_stack, 1.0, int_stack+1361425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1594525,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7984275,int_stack+5204490,int_stack+5216775, 0.0, zero_stack, 1.0, int_stack+2167590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5204490,int_stack+7984275,int_stack+5221635, 0.0, zero_stack, 1.0, int_stack+2172450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4246560,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+5204490,int_stack+5246469, 0.0, zero_stack, 1.0, int_stack+2180010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4254120,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5025987,int_stack+2356725,int_stack+5235129,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+5025987,int_stack+5178030,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+5178030,int_stack+7250325,int_stack+7944585,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7944585,int_stack+399630,int_stack+398475, 0.0, zero_stack, 1.0, int_stack+569600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+735100,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7948050,int_stack+401170,int_stack+399630, 0.0, zero_stack, 1.0, int_stack+571910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+737410,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7952670,int_stack+7948050,int_stack+7944585, 0.0, zero_stack, 1.0, int_stack+2398470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4087740,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7959600,int_stack+403150,int_stack+401170, 0.0, zero_stack, 1.0, int_stack+574990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+740490,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7965540,int_stack+7959600,int_stack+7948050, 0.0, zero_stack, 1.0, int_stack+2401935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4430835,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7974780,int_stack+7965540,int_stack+7952670, 0.0, zero_stack, 1.0, int_stack+2406555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4435455,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7944585,int_stack+405625,int_stack+403150, 0.0, zero_stack, 1.0, int_stack+578950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+744450,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7986330,int_stack+7944585,int_stack+7959600, 0.0, zero_stack, 1.0, int_stack+2413485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4442385,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7944585,int_stack+7986330,int_stack+7965540, 0.0, zero_stack, 1.0, int_stack+2419425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4448325,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7986330,int_stack+7944585,int_stack+7974780, 0.0, zero_stack, 1.0, int_stack+2428665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4457565,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+7611945,int_stack+7986330,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+7944585,int_stack+7611945,int_stack+5025987,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+8100825,int_stack+7944585,int_stack+7250325,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+409091,int_stack+408650, 0.0, zero_stack, 1.0, int_stack+1384425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1559250, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+409679,int_stack+409091, 0.0, zero_stack, 1.0, int_stack+1384866, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1559691, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+2440215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3964320, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+410435,int_stack+409679, 0.0, zero_stack, 1.0, int_stack+1385454, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1560279, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 1.0, int_stack+2441538, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3965643, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 1.0, int_stack+2443302, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3967407, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+411380,int_stack+410435, 0.0, zero_stack, 1.0, int_stack+1386210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1561035, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 1.0, int_stack+2445948, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3970053, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 1.0, int_stack+2448216, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3972321, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 1.0, int_stack+2451744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3975849, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+413123,int_stack+412535, 0.0, zero_stack, 1.0, int_stack+1392195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1567020, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+413907,int_stack+413123, 0.0, zero_stack, 1.0, int_stack+1392783, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1567608, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+2462769, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3986874, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+414915,int_stack+413907, 0.0, zero_stack, 1.0, int_stack+1393567, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1568392, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 0.0, zero_stack, 1.0, int_stack+2464533, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3988638, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 0.0, zero_stack, 1.0, int_stack+2466885, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3990990, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+416175,int_stack+414915, 0.0, zero_stack, 1.0, int_stack+1394575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1569400, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7257969, 0.0, zero_stack, 1.0, int_stack+2470413, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3994518, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7260993, 0.0, zero_stack, 1.0, int_stack+2473437, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3997542, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879, 0.0, zero_stack, 1.0, int_stack+2478141, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4002246, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7944585,int_stack+7278759,int_stack+7266264,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+418471,int_stack+417715, 0.0, zero_stack, 1.0, int_stack+1402555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1577380, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+419479,int_stack+418471, 0.0, zero_stack, 1.0, int_stack+1403311, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1578136, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+2512686, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4036791, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+420775,int_stack+419479, 0.0, zero_stack, 1.0, int_stack+1404319, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1579144, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7264041,int_stack+7260153,int_stack+7252593, 0.0, zero_stack, 1.0, int_stack+2514954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4039059, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7270089,int_stack+7264041,int_stack+7255617, 0.0, zero_stack, 1.0, int_stack+2517978, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4042083, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+422395,int_stack+420775, 0.0, zero_stack, 1.0, int_stack+1405615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1580440, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153, 0.0, zero_stack, 1.0, int_stack+2522514, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4046619, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+7264041, 0.0, zero_stack, 1.0, int_stack+2526402, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4050507, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7270089, 0.0, zero_stack, 1.0, int_stack+2532450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4056555, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7964430,int_stack+7250325,int_stack+7944585,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7944585,int_stack+425320,int_stack+424375, 0.0, zero_stack, 1.0, int_stack+1415875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1590700, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7947420,int_stack+426580,int_stack+425320, 0.0, zero_stack, 1.0, int_stack+1416820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1591645, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7951200,int_stack+7947420,int_stack+7944585, 0.0, zero_stack, 1.0, int_stack+2551350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4075455, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7956870,int_stack+428200,int_stack+426580, 0.0, zero_stack, 1.0, int_stack+1418080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1592905, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7276785,int_stack+7956870,int_stack+7947420, 0.0, zero_stack, 1.0, int_stack+2554185, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4078290, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5025987,int_stack+7276785,int_stack+7951200, 0.0, zero_stack, 1.0, int_stack+2557965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4082070, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7944585,int_stack+430225,int_stack+428200, 0.0, zero_stack, 1.0, int_stack+1419700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1594525, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5035437,int_stack+7944585,int_stack+7956870, 0.0, zero_stack, 1.0, int_stack+2722455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7944585,int_stack+5035437,int_stack+7276785, 0.0, zero_stack, 1.0, int_stack+2727315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4246560, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+7944585,int_stack+5025987, 0.0, zero_stack, 1.0, int_stack+2734875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4254120, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5025987,int_stack+2356725,int_stack+7287579,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7611945,int_stack+5025987,int_stack+7250325,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+348030,int_stack+7611945,int_stack+7964430,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+433855,int_stack+432700, 0.0, zero_stack, 1.0, int_stack+610975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+735100, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253790,int_stack+435395,int_stack+433855, 0.0, zero_stack, 1.0, int_stack+613285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+737410, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7258410,int_stack+7253790,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+2563635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4087740, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7265340,int_stack+437375,int_stack+435395, 0.0, zero_stack, 1.0, int_stack+616365, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+740490, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7271280,int_stack+7265340,int_stack+7253790, 0.0, zero_stack, 1.0, int_stack+2911590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4430835, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7280520,int_stack+7271280,int_stack+7258410, 0.0, zero_stack, 1.0, int_stack+2916210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4435455, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+439850,int_stack+437375, 0.0, zero_stack, 1.0, int_stack+620325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+744450, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5060007,int_stack+7250325,int_stack+7265340, 0.0, zero_stack, 1.0, int_stack+2923140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4442385, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+5060007,int_stack+7271280, 0.0, zero_stack, 1.0, int_stack+2929080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4448325, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7944585,int_stack+7250325,int_stack+7280520, 0.0, zero_stack, 1.0, int_stack+2938320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4457565, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+7250325,int_stack+7944585,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+7944585,int_stack+7250325,int_stack+5025987,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+8189025,int_stack+7944585,int_stack+7611945,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+443316,int_stack+442875, 0.0, zero_stack, 1.0, int_stack+1442700, 0.0, zero_stack, 1.0, int_stack+1559250, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7613268,int_stack+443904,int_stack+443316, 0.0, zero_stack, 1.0, int_stack+1443141, 0.0, zero_stack, 1.0, int_stack+1559691, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7615032,int_stack+7613268,int_stack+7611945, 0.0, zero_stack, 1.0, int_stack+2949870, 0.0, zero_stack, 1.0, int_stack+3964320, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7617678,int_stack+444660,int_stack+443904, 0.0, zero_stack, 1.0, int_stack+1443729, 0.0, zero_stack, 1.0, int_stack+1560279, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7619946,int_stack+7617678,int_stack+7613268, 0.0, zero_stack, 1.0, int_stack+2951193, 0.0, zero_stack, 1.0, int_stack+3965643, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7623474,int_stack+7619946,int_stack+7615032, 0.0, zero_stack, 1.0, int_stack+2952957, 0.0, zero_stack, 1.0, int_stack+3967407, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+445605,int_stack+444660, 0.0, zero_stack, 1.0, int_stack+1444485, 0.0, zero_stack, 1.0, int_stack+1561035, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7627884,int_stack+7611945,int_stack+7617678, 0.0, zero_stack, 1.0, int_stack+2955603, 0.0, zero_stack, 1.0, int_stack+3970053, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7627884,int_stack+7619946, 0.0, zero_stack, 1.0, int_stack+2957871, 0.0, zero_stack, 1.0, int_stack+3972321, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7627884,int_stack+7611945,int_stack+7623474, 0.0, zero_stack, 1.0, int_stack+2961399, 0.0, zero_stack, 1.0, int_stack+3975849, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+447348,int_stack+446760, 0.0, zero_stack, 1.0, int_stack+1450470, 0.0, zero_stack, 1.0, int_stack+1567020, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7613709,int_stack+448132,int_stack+447348, 0.0, zero_stack, 1.0, int_stack+1451058, 0.0, zero_stack, 1.0, int_stack+1567608, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7616061,int_stack+7613709,int_stack+7611945, 0.0, zero_stack, 1.0, int_stack+2972424, 0.0, zero_stack, 1.0, int_stack+3986874, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7619589,int_stack+449140,int_stack+448132, 0.0, zero_stack, 1.0, int_stack+1451842, 0.0, zero_stack, 1.0, int_stack+1568392, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7622613,int_stack+7619589,int_stack+7613709, 0.0, zero_stack, 1.0, int_stack+2974188, 0.0, zero_stack, 1.0, int_stack+3988638, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7634499,int_stack+7622613,int_stack+7616061, 0.0, zero_stack, 1.0, int_stack+2976540, 0.0, zero_stack, 1.0, int_stack+3990990, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+450400,int_stack+449140, 0.0, zero_stack, 1.0, int_stack+1452850, 0.0, zero_stack, 1.0, int_stack+1569400, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7640379,int_stack+7611945,int_stack+7619589, 0.0, zero_stack, 1.0, int_stack+2980068, 0.0, zero_stack, 1.0, int_stack+3994518, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7640379,int_stack+7622613, 0.0, zero_stack, 1.0, int_stack+2983092, 0.0, zero_stack, 1.0, int_stack+3997542, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7640379,int_stack+7611945,int_stack+7634499, 0.0, zero_stack, 1.0, int_stack+2987796, 0.0, zero_stack, 1.0, int_stack+4002246, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7649199,int_stack+7640379,int_stack+7627884,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+452696,int_stack+451940, 0.0, zero_stack, 1.0, int_stack+1460830, 0.0, zero_stack, 1.0, int_stack+1577380, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7614213,int_stack+453704,int_stack+452696, 0.0, zero_stack, 1.0, int_stack+1461586, 0.0, zero_stack, 1.0, int_stack+1578136, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7617237,int_stack+7614213,int_stack+7611945, 0.0, zero_stack, 1.0, int_stack+3022341, 0.0, zero_stack, 1.0, int_stack+4036791, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7621773,int_stack+455000,int_stack+453704, 0.0, zero_stack, 1.0, int_stack+1462594, 0.0, zero_stack, 1.0, int_stack+1579144, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7625661,int_stack+7621773,int_stack+7614213, 0.0, zero_stack, 1.0, int_stack+3024609, 0.0, zero_stack, 1.0, int_stack+4039059, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7631709,int_stack+7625661,int_stack+7617237, 0.0, zero_stack, 1.0, int_stack+3027633, 0.0, zero_stack, 1.0, int_stack+4042083, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+456620,int_stack+455000, 0.0, zero_stack, 1.0, int_stack+1463890, 0.0, zero_stack, 1.0, int_stack+1580440, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7669044,int_stack+7611945,int_stack+7621773, 0.0, zero_stack, 1.0, int_stack+3032169, 0.0, zero_stack, 1.0, int_stack+4046619, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7669044,int_stack+7625661, 0.0, zero_stack, 1.0, int_stack+3036057, 0.0, zero_stack, 1.0, int_stack+4050507, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7944585,int_stack+7611945,int_stack+7631709, 0.0, zero_stack, 1.0, int_stack+3042105, 0.0, zero_stack, 1.0, int_stack+4056555, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7611945,int_stack+7944585,int_stack+7640379,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7955925,int_stack+7611945,int_stack+7649199,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7638405,int_stack+459545,int_stack+458600, 0.0, zero_stack, 1.0, int_stack+1474150, 0.0, zero_stack, 1.0, int_stack+1590700, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7641240,int_stack+460805,int_stack+459545, 0.0, zero_stack, 1.0, int_stack+1475095, 0.0, zero_stack, 1.0, int_stack+1591645, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7645020,int_stack+7641240,int_stack+7638405, 0.0, zero_stack, 1.0, int_stack+3061005, 0.0, zero_stack, 1.0, int_stack+4075455, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7650690,int_stack+462425,int_stack+460805, 0.0, zero_stack, 1.0, int_stack+1476355, 0.0, zero_stack, 1.0, int_stack+1592905, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7655550,int_stack+7650690,int_stack+7641240, 0.0, zero_stack, 1.0, int_stack+3063840, 0.0, zero_stack, 1.0, int_stack+4078290, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7663110,int_stack+7655550,int_stack+7645020, 0.0, zero_stack, 1.0, int_stack+3067620, 0.0, zero_stack, 1.0, int_stack+4082070, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7638405,int_stack+464450,int_stack+462425, 0.0, zero_stack, 1.0, int_stack+1477975, 0.0, zero_stack, 1.0, int_stack+1594525, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7995615,int_stack+7638405,int_stack+7650690, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7638405,int_stack+7995615,int_stack+7655550, 0.0, zero_stack, 1.0, int_stack+3232110, 0.0, zero_stack, 1.0, int_stack+4246560, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+7638405,int_stack+7663110, 0.0, zero_stack, 1.0, int_stack+3239670, 0.0, zero_stack, 1.0, int_stack+4254120, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7638405,int_stack+2356725,int_stack+7944585,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+7638405,int_stack+7611945,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+8277225,int_stack+7250325,int_stack+7955925,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+468080,int_stack+466925, 0.0, zero_stack, 1.0, int_stack+652350, 0.0, zero_stack, 1.0, int_stack+735100, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7615410,int_stack+469620,int_stack+468080, 0.0, zero_stack, 1.0, int_stack+654660, 0.0, zero_stack, 1.0, int_stack+737410, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7620030,int_stack+7615410,int_stack+7611945, 0.0, zero_stack, 1.0, int_stack+3073290, 0.0, zero_stack, 1.0, int_stack+4087740, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7626960,int_stack+471600,int_stack+469620, 0.0, zero_stack, 1.0, int_stack+657740, 0.0, zero_stack, 1.0, int_stack+740490, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7944585,int_stack+7626960,int_stack+7615410, 0.0, zero_stack, 1.0, int_stack+3416385, 0.0, zero_stack, 1.0, int_stack+4430835, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7953825,int_stack+7944585,int_stack+7620030, 0.0, zero_stack, 1.0, int_stack+3421005, 0.0, zero_stack, 1.0, int_stack+4435455, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+474075,int_stack+471600, 0.0, zero_stack, 1.0, int_stack+661700, 0.0, zero_stack, 1.0, int_stack+744450, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7965375,int_stack+7611945,int_stack+7626960, 0.0, zero_stack, 1.0, int_stack+3427935, 0.0, zero_stack, 1.0, int_stack+4442385, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7965375,int_stack+7944585, 0.0, zero_stack, 1.0, int_stack+3433875, 0.0, zero_stack, 1.0, int_stack+4448325, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7965375,int_stack+7611945,int_stack+7953825, 0.0, zero_stack, 1.0, int_stack+3443115, 0.0, zero_stack, 1.0, int_stack+4457565, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5025987,int_stack+7965375,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+7944585,int_stack+5025987,int_stack+7638405,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+8343375,int_stack+7944585,int_stack+7250325,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+477541,int_stack+477100, 0.0, zero_stack, 1.0, int_stack+1500975, 1.0, int_stack+1559250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+478129,int_stack+477541, 0.0, zero_stack, 1.0, int_stack+1501416, 1.0, int_stack+1559691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+3454665, 1.0, int_stack+3964320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+478885,int_stack+478129, 0.0, zero_stack, 1.0, int_stack+1502004, 1.0, int_stack+1560279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 1.0, int_stack+3455988, 1.0, int_stack+3965643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 1.0, int_stack+3457752, 1.0, int_stack+3967407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+479830,int_stack+478885, 0.0, zero_stack, 1.0, int_stack+1502760, 1.0, int_stack+1561035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 1.0, int_stack+3460398, 1.0, int_stack+3970053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 1.0, int_stack+3462666, 1.0, int_stack+3972321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 1.0, int_stack+3466194, 1.0, int_stack+3975849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+481573,int_stack+480985, 0.0, zero_stack, 1.0, int_stack+1508745, 1.0, int_stack+1567020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+482357,int_stack+481573, 0.0, zero_stack, 1.0, int_stack+1509333, 1.0, int_stack+1567608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+3477219, 1.0, int_stack+3986874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+483365,int_stack+482357, 0.0, zero_stack, 1.0, int_stack+1510117, 1.0, int_stack+1568392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 0.0, zero_stack, 1.0, int_stack+3478983, 1.0, int_stack+3988638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 0.0, zero_stack, 1.0, int_stack+3481335, 1.0, int_stack+3990990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+484625,int_stack+483365, 0.0, zero_stack, 1.0, int_stack+1511125, 1.0, int_stack+1569400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7257969, 0.0, zero_stack, 1.0, int_stack+3484863, 1.0, int_stack+3994518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7260993, 0.0, zero_stack, 1.0, int_stack+3487887, 1.0, int_stack+3997542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879, 0.0, zero_stack, 1.0, int_stack+3492591, 1.0, int_stack+4002246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7944585,int_stack+7278759,int_stack+7266264,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+486921,int_stack+486165, 0.0, zero_stack, 1.0, int_stack+1519105, 1.0, int_stack+1577380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+487929,int_stack+486921, 0.0, zero_stack, 1.0, int_stack+1519861, 1.0, int_stack+1578136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+3527136, 1.0, int_stack+4036791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+489225,int_stack+487929, 0.0, zero_stack, 1.0, int_stack+1520869, 1.0, int_stack+1579144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7264041,int_stack+7260153,int_stack+7252593, 0.0, zero_stack, 1.0, int_stack+3529404, 1.0, int_stack+4039059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7270089,int_stack+7264041,int_stack+7255617, 0.0, zero_stack, 1.0, int_stack+3532428, 1.0, int_stack+4042083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+490845,int_stack+489225, 0.0, zero_stack, 1.0, int_stack+1522165, 1.0, int_stack+1580440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153, 0.0, zero_stack, 1.0, int_stack+3536964, 1.0, int_stack+4046619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+7264041, 0.0, zero_stack, 1.0, int_stack+3540852, 1.0, int_stack+4050507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7270089, 0.0, zero_stack, 1.0, int_stack+3546900, 1.0, int_stack+4056555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7964430,int_stack+7250325,int_stack+7944585,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7944585,int_stack+493770,int_stack+492825, 0.0, zero_stack, 1.0, int_stack+1532425, 1.0, int_stack+1590700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7947420,int_stack+495030,int_stack+493770, 0.0, zero_stack, 1.0, int_stack+1533370, 1.0, int_stack+1591645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7951200,int_stack+7947420,int_stack+7944585, 0.0, zero_stack, 1.0, int_stack+3565800, 1.0, int_stack+4075455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7956870,int_stack+496650,int_stack+495030, 0.0, zero_stack, 1.0, int_stack+1534630, 1.0, int_stack+1592905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7276785,int_stack+7956870,int_stack+7947420, 0.0, zero_stack, 1.0, int_stack+3568635, 1.0, int_stack+4078290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5025987,int_stack+7276785,int_stack+7951200, 0.0, zero_stack, 1.0, int_stack+3572415, 1.0, int_stack+4082070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7944585,int_stack+498675,int_stack+496650, 0.0, zero_stack, 1.0, int_stack+1536250, 1.0, int_stack+1594525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5035437,int_stack+7944585,int_stack+7956870, 0.0, zero_stack, 1.0, int_stack+3736905, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7944585,int_stack+5035437,int_stack+7276785, 0.0, zero_stack, 1.0, int_stack+3741765, 1.0, int_stack+4246560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+7944585,int_stack+5025987, 0.0, zero_stack, 1.0, int_stack+3749325, 1.0, int_stack+4254120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5025987,int_stack+2356725,int_stack+7287579,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7611945,int_stack+5025987,int_stack+7250325,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+414180,int_stack+7611945,int_stack+7964430,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+502305,int_stack+501150, 0.0, zero_stack, 1.0, int_stack+693725, 1.0, int_stack+735100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253790,int_stack+503845,int_stack+502305, 0.0, zero_stack, 1.0, int_stack+696035, 1.0, int_stack+737410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7258410,int_stack+7253790,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+3578085, 1.0, int_stack+4087740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7265340,int_stack+505825,int_stack+503845, 0.0, zero_stack, 1.0, int_stack+699115, 1.0, int_stack+740490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7271280,int_stack+7265340,int_stack+7253790, 0.0, zero_stack, 1.0, int_stack+3926040, 1.0, int_stack+4430835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7280520,int_stack+7271280,int_stack+7258410, 0.0, zero_stack, 1.0, int_stack+3930660, 1.0, int_stack+4435455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+508300,int_stack+505825, 0.0, zero_stack, 1.0, int_stack+703075, 1.0, int_stack+744450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5060007,int_stack+7250325,int_stack+7265340, 0.0, zero_stack, 1.0, int_stack+3937590, 1.0, int_stack+4442385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+5060007,int_stack+7271280, 0.0, zero_stack, 1.0, int_stack+3943530, 1.0, int_stack+4448325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7944585,int_stack+7250325,int_stack+7280520, 0.0, zero_stack, 1.0, int_stack+3952770, 1.0, int_stack+4457565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+7250325,int_stack+7944585,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+7944585,int_stack+7250325,int_stack+5025987,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+8431575,int_stack+7944585,int_stack+7611945,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+511766,int_stack+511325, 0.0, zero_stack, 2.0, int_stack+1559250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7613268,int_stack+512354,int_stack+511766, 0.0, zero_stack, 2.0, int_stack+1559691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7615032,int_stack+7613268,int_stack+7611945, 0.0, zero_stack, 2.0, int_stack+3964320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7617678,int_stack+513110,int_stack+512354, 0.0, zero_stack, 2.0, int_stack+1560279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7619946,int_stack+7617678,int_stack+7613268, 0.0, zero_stack, 2.0, int_stack+3965643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7623474,int_stack+7619946,int_stack+7615032, 0.0, zero_stack, 2.0, int_stack+3967407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+514055,int_stack+513110, 0.0, zero_stack, 2.0, int_stack+1561035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7627884,int_stack+7611945,int_stack+7617678, 0.0, zero_stack, 2.0, int_stack+3970053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7627884,int_stack+7619946, 0.0, zero_stack, 2.0, int_stack+3972321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7627884,int_stack+7611945,int_stack+7623474, 0.0, zero_stack, 2.0, int_stack+3975849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+515798,int_stack+515210, 0.0, zero_stack, 2.0, int_stack+1567020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7613709,int_stack+516582,int_stack+515798, 0.0, zero_stack, 2.0, int_stack+1567608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7616061,int_stack+7613709,int_stack+7611945, 0.0, zero_stack, 2.0, int_stack+3986874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7619589,int_stack+517590,int_stack+516582, 0.0, zero_stack, 2.0, int_stack+1568392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7622613,int_stack+7619589,int_stack+7613709, 0.0, zero_stack, 2.0, int_stack+3988638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7634499,int_stack+7622613,int_stack+7616061, 0.0, zero_stack, 2.0, int_stack+3990990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+518850,int_stack+517590, 0.0, zero_stack, 2.0, int_stack+1569400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7640379,int_stack+7611945,int_stack+7619589, 0.0, zero_stack, 2.0, int_stack+3994518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7640379,int_stack+7622613, 0.0, zero_stack, 2.0, int_stack+3997542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7640379,int_stack+7611945,int_stack+7634499, 0.0, zero_stack, 2.0, int_stack+4002246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7649199,int_stack+7640379,int_stack+7627884,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+521146,int_stack+520390, 0.0, zero_stack, 2.0, int_stack+1577380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7614213,int_stack+522154,int_stack+521146, 0.0, zero_stack, 2.0, int_stack+1578136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7617237,int_stack+7614213,int_stack+7611945, 0.0, zero_stack, 2.0, int_stack+4036791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7621773,int_stack+523450,int_stack+522154, 0.0, zero_stack, 2.0, int_stack+1579144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7625661,int_stack+7621773,int_stack+7614213, 0.0, zero_stack, 2.0, int_stack+4039059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7631709,int_stack+7625661,int_stack+7617237, 0.0, zero_stack, 2.0, int_stack+4042083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+525070,int_stack+523450, 0.0, zero_stack, 2.0, int_stack+1580440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7669044,int_stack+7611945,int_stack+7621773, 0.0, zero_stack, 2.0, int_stack+4046619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7669044,int_stack+7625661, 0.0, zero_stack, 2.0, int_stack+4050507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7944585,int_stack+7611945,int_stack+7631709, 0.0, zero_stack, 2.0, int_stack+4056555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7611945,int_stack+7944585,int_stack+7640379,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7955925,int_stack+7611945,int_stack+7649199,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7638405,int_stack+527995,int_stack+527050, 0.0, zero_stack, 2.0, int_stack+1590700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7641240,int_stack+529255,int_stack+527995, 0.0, zero_stack, 2.0, int_stack+1591645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7645020,int_stack+7641240,int_stack+7638405, 0.0, zero_stack, 2.0, int_stack+4075455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7650690,int_stack+530875,int_stack+529255, 0.0, zero_stack, 2.0, int_stack+1592905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7655550,int_stack+7650690,int_stack+7641240, 0.0, zero_stack, 2.0, int_stack+4078290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7663110,int_stack+7655550,int_stack+7645020, 0.0, zero_stack, 2.0, int_stack+4082070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7638405,int_stack+532900,int_stack+530875, 0.0, zero_stack, 2.0, int_stack+1594525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7995615,int_stack+7638405,int_stack+7650690, 0.0, zero_stack, 2.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7638405,int_stack+7995615,int_stack+7655550, 0.0, zero_stack, 2.0, int_stack+4246560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+7638405,int_stack+7663110, 0.0, zero_stack, 2.0, int_stack+4254120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7638405,int_stack+2356725,int_stack+7944585,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+7638405,int_stack+7611945,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+8519775,int_stack+7250325,int_stack+7955925,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+536530,int_stack+535375, 0.0, zero_stack, 2.0, int_stack+735100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7615410,int_stack+538070,int_stack+536530, 0.0, zero_stack, 2.0, int_stack+737410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7620030,int_stack+7615410,int_stack+7611945, 0.0, zero_stack, 2.0, int_stack+4087740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7626960,int_stack+540050,int_stack+538070, 0.0, zero_stack, 2.0, int_stack+740490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7944585,int_stack+7626960,int_stack+7615410, 0.0, zero_stack, 2.0, int_stack+4430835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7953825,int_stack+7944585,int_stack+7620030, 0.0, zero_stack, 2.0, int_stack+4435455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+542525,int_stack+540050, 0.0, zero_stack, 2.0, int_stack+744450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7965375,int_stack+7611945,int_stack+7626960, 0.0, zero_stack, 2.0, int_stack+4442385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7965375,int_stack+7944585, 0.0, zero_stack, 2.0, int_stack+4448325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7965375,int_stack+7611945,int_stack+7953825, 0.0, zero_stack, 2.0, int_stack+4457565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5025987,int_stack+7965375,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+7944585,int_stack+5025987,int_stack+7638405,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+8585925,int_stack+7944585,int_stack+7250325,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+545991,int_stack+545550, 1.0, int_stack+1326150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1617525,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+546579,int_stack+545991, 1.0, int_stack+1326591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1617966,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 1.0, int_stack+1895289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4469115,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+547335,int_stack+546579, 1.0, int_stack+1327179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1618554,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 1.0, int_stack+1896612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4470438,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 1.0, int_stack+1898376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4472202,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+548280,int_stack+547335, 1.0, int_stack+1327935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1619310,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 1.0, int_stack+1901022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4474848,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 1.0, int_stack+1903290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4477116,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 1.0, int_stack+1906818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4480644,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+550023,int_stack+549435, 1.0, int_stack+1333920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1625295,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+550807,int_stack+550023, 1.0, int_stack+1334508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1625883,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 1.0, int_stack+1939095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4485054,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+551815,int_stack+550807, 1.0, int_stack+1335292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1626667,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 1.0, int_stack+1940859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4486818,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 1.0, int_stack+1943211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4489170,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+553075,int_stack+551815, 1.0, int_stack+1336300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1627675,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7257969, 1.0, int_stack+1946739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879350,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7260993, 1.0, int_stack+1949763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4502085,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879, 1.0, int_stack+1954467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4506789,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7944585,int_stack+7278759,int_stack+7266264,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+555371,int_stack+554615, 1.0, int_stack+1344280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1635655,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+556379,int_stack+555371, 1.0, int_stack+1345036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1636411,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325, 1.0, int_stack+2016336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4512669,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+557675,int_stack+556379, 1.0, int_stack+1346044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1637419,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7264041,int_stack+7260153,int_stack+7252593, 1.0, int_stack+2018604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4514937,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7270089,int_stack+7264041,int_stack+7255617, 1.0, int_stack+2021628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4517961,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2016336,int_stack+559295,int_stack+557675, 1.0, int_stack+1347340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1638715,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7250325,int_stack+2016336,int_stack+7260153, 1.0, int_stack+2026164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4522497,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2016336,int_stack+7250325,int_stack+7264041, 1.0, int_stack+2030052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1917843,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7250325,int_stack+2016336,int_stack+7270089, 1.0, int_stack+2036100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4555222,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2016336,int_stack+7250325,int_stack+7278759,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7261665,int_stack+2016336,int_stack+7944585,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7944585,int_stack+562220,int_stack+561275, 1.0, int_stack+1357600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1649920,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7947420,int_stack+563480,int_stack+562220, 1.0, int_stack+1358545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1652125,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7951200,int_stack+7947420,int_stack+7944585, 1.0, int_stack+2155305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4562782,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7956870,int_stack+565100,int_stack+563480, 1.0, int_stack+1359805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1655005,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7961730,int_stack+7956870,int_stack+7947420, 1.0, int_stack+2158140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4565617,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7969290,int_stack+7961730,int_stack+7951200, 1.0, int_stack+2161920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4569397,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7944585,int_stack+567125,int_stack+565100, 1.0, int_stack+1361425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1658650,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7978740,int_stack+7944585,int_stack+7956870, 1.0, int_stack+2167590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4575067,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7944585,int_stack+7978740,int_stack+7961730, 1.0, int_stack+2172450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1989012,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+7944585,int_stack+7969290, 1.0, int_stack+2180010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4751355,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7944585,int_stack+2356725,int_stack+7250325,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7611945,int_stack+7944585,int_stack+2016336,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+480330,int_stack+7611945,int_stack+7261665,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2016336,int_stack+573450,int_stack+570755, 1.0, int_stack+569600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777630,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2019801,int_stack+576970,int_stack+573450, 1.0, int_stack+571910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+781480,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2024421,int_stack+2019801,int_stack+2016336, 1.0, int_stack+2398470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4760805,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2031351,int_stack+581425,int_stack+576970, 1.0, int_stack+574990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+786540,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7250325,int_stack+2031351,int_stack+2019801, 1.0, int_stack+2401935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4764270,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7259565,int_stack+7250325,int_stack+2024421, 1.0, int_stack+2406555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4768890,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2016336,int_stack+583900,int_stack+581425, 1.0, int_stack+578950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+790500,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7271115,int_stack+2016336,int_stack+2031351, 1.0, int_stack+2413485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4775820,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2016336,int_stack+7271115,int_stack+7250325, 1.0, int_stack+2419425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2121150,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7271115,int_stack+2016336,int_stack+7259565, 1.0, int_stack+2428665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4950390,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5025987,int_stack+7271115,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+8674125,int_stack+5025987,int_stack+7944585,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+8742165,int_stack+8674125,int_stack+7611945,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+587366,int_stack+586925, 1.0, int_stack+1384425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1617525, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7613268,int_stack+587954,int_stack+587366, 1.0, int_stack+1384866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1617966, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7615032,int_stack+7613268,int_stack+7611945, 1.0, int_stack+2440215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4469115, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7617678,int_stack+588710,int_stack+587954, 1.0, int_stack+1385454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1618554, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7619946,int_stack+7617678,int_stack+7613268, 1.0, int_stack+2441538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4470438, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7623474,int_stack+7619946,int_stack+7615032, 1.0, int_stack+2443302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4472202, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7611945,int_stack+589655,int_stack+588710, 1.0, int_stack+1386210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1619310, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7627884,int_stack+7611945,int_stack+7617678, 1.0, int_stack+2445948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4474848, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7611945,int_stack+7627884,int_stack+7619946, 1.0, int_stack+2448216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4477116, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7627884,int_stack+7611945,int_stack+7623474, 1.0, int_stack+2451744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4480644, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+591398,int_stack+590810, 1.0, int_stack+1392195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1625295, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7613709,int_stack+592182,int_stack+591398, 1.0, int_stack+1392783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1625883, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7616061,int_stack+7613709,int_stack+7611945, 1.0, int_stack+2462769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4485054, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7619589,int_stack+593190,int_stack+592182, 1.0, int_stack+1393567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1626667, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7622613,int_stack+7619589,int_stack+7613709, 1.0, int_stack+2464533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4486818, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7634499,int_stack+7622613,int_stack+7616061, 1.0, int_stack+2466885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4489170, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2462769,int_stack+594450,int_stack+593190, 1.0, int_stack+1394575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1627675, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7611945,int_stack+2462769,int_stack+7619589, 1.0, int_stack+2470413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879350, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2462769,int_stack+7611945,int_stack+7622613, 1.0, int_stack+2473437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4502085, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7611945,int_stack+2462769,int_stack+7634499, 1.0, int_stack+2478141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4506789, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7634499,int_stack+7611945,int_stack+7627884,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7654344,int_stack+596746,int_stack+595990, 1.0, int_stack+1402555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1635655, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7656612,int_stack+597754,int_stack+596746, 1.0, int_stack+1403311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1636411, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7659636,int_stack+7656612,int_stack+7654344, 1.0, int_stack+2512686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4512669, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7664172,int_stack+599050,int_stack+597754, 1.0, int_stack+1404319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1637419, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7668060,int_stack+7664172,int_stack+7656612, 1.0, int_stack+2514954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4514937, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2462769,int_stack+7668060,int_stack+7659636, 1.0, int_stack+2517978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4517961, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2512686,int_stack+600670,int_stack+599050, 1.0, int_stack+1405615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1638715, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7654344,int_stack+2512686,int_stack+7664172, 1.0, int_stack+2522514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4522497, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2512686,int_stack+7654344,int_stack+7668060, 1.0, int_stack+2526402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1917843, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7654344,int_stack+2512686,int_stack+2462769, 1.0, int_stack+2532450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4555222, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2512686,int_stack+7654344,int_stack+7611945,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+8674125,int_stack+2512686,int_stack+7634499,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7611945,int_stack+603595,int_stack+602650, 1.0, int_stack+1415875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1649920, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7614780,int_stack+604855,int_stack+603595, 1.0, int_stack+1416820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1652125, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7618560,int_stack+7614780,int_stack+7611945, 1.0, int_stack+2551350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4562782, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7624230,int_stack+606475,int_stack+604855, 1.0, int_stack+1418080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1655005, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7629090,int_stack+7624230,int_stack+7614780, 1.0, int_stack+2554185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4565617, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7636650,int_stack+7629090,int_stack+7618560, 1.0, int_stack+2557965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4569397, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2551350,int_stack+608500,int_stack+606475, 1.0, int_stack+1419700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1658650, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7611945,int_stack+2551350,int_stack+7624230, 1.0, int_stack+2722455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4575067, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2462769,int_stack+7611945,int_stack+7629090, 1.0, int_stack+2727315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1989012, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+2462769,int_stack+7636650, 1.0, int_stack+2734875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4751355, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7611945,int_stack+2356725,int_stack+7654344,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+7611945,int_stack+2512686,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+7944585,int_stack+7250325,int_stack+8674125,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8674125,int_stack+614825,int_stack+612130, 1.0, int_stack+610975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777630, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8677590,int_stack+618345,int_stack+614825, 1.0, int_stack+613285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+781480, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8682210,int_stack+8677590,int_stack+8674125, 1.0, int_stack+2563635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4760805, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8689140,int_stack+622800,int_stack+618345, 1.0, int_stack+616365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+786540, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8695080,int_stack+8689140,int_stack+8677590, 1.0, int_stack+2911590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4764270, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8704320,int_stack+8695080,int_stack+8682210, 1.0, int_stack+2916210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4768890, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2911590,int_stack+625275,int_stack+622800, 1.0, int_stack+620325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+790500, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8674125,int_stack+2911590,int_stack+8689140, 1.0, int_stack+2923140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4775820, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2911590,int_stack+8674125,int_stack+8695080, 1.0, int_stack+2929080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2121150, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8674125,int_stack+2911590,int_stack+8704320, 1.0, int_stack+2938320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4950390, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+8691450,int_stack+8674125,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+546480,int_stack+8691450,int_stack+7611945,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+8830365,int_stack+546480,int_stack+7250325,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+628741,int_stack+628300, 1.0, int_stack+1442700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1617525, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+629329,int_stack+628741, 1.0, int_stack+1443141, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1617966, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 1.0, int_stack+2949870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4469115, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+630085,int_stack+629329, 1.0, int_stack+1443729, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1618554, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 1.0, int_stack+2951193, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4470438, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 1.0, int_stack+2952957, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4472202, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+631030,int_stack+630085, 1.0, int_stack+1444485, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1619310, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 1.0, int_stack+2955603, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4474848, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 1.0, int_stack+2957871, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4477116, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 1.0, int_stack+2961399, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4480644, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+632773,int_stack+632185, 1.0, int_stack+1450470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1625295, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+633557,int_stack+632773, 1.0, int_stack+1451058, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1625883, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 1.0, int_stack+2972424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4485054, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+634565,int_stack+633557, 1.0, int_stack+1451842, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1626667, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 1.0, int_stack+2974188, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4486818, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 1.0, int_stack+2976540, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4489170, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2972424,int_stack+635825,int_stack+634565, 1.0, int_stack+1452850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1627675, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7250325,int_stack+2972424,int_stack+7257969, 1.0, int_stack+2980068, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2972424,int_stack+7250325,int_stack+7260993, 1.0, int_stack+2983092, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4502085, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7250325,int_stack+2972424,int_stack+7272879, 1.0, int_stack+2987796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4506789, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7272879,int_stack+7250325,int_stack+7266264,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7292724,int_stack+638121,int_stack+637365, 1.0, int_stack+1460830, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1635655, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7294992,int_stack+639129,int_stack+638121, 1.0, int_stack+1461586, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1636411, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7298016,int_stack+7294992,int_stack+7292724, 1.0, int_stack+3022341, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4512669, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2972424,int_stack+640425,int_stack+639129, 1.0, int_stack+1462594, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1637419, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2976312,int_stack+2972424,int_stack+7294992, 1.0, int_stack+3024609, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4514937, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2982360,int_stack+2976312,int_stack+7298016, 1.0, int_stack+3027633, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4517961, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3022341,int_stack+642045,int_stack+640425, 1.0, int_stack+1463890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1638715, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7292724,int_stack+3022341,int_stack+2972424, 1.0, int_stack+3032169, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4522497, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3022341,int_stack+7292724,int_stack+2976312, 1.0, int_stack+3036057, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7259145,int_stack+3022341,int_stack+2982360, 1.0, int_stack+3042105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4555222, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3022341,int_stack+7259145,int_stack+7250325,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+546480,int_stack+3022341,int_stack+7272879,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+644970,int_stack+644025, 1.0, int_stack+1474150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1649920, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253160,int_stack+646230,int_stack+644970, 1.0, int_stack+1475095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1652125, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2972424,int_stack+7253160,int_stack+7250325, 1.0, int_stack+3061005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4562782, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2978094,int_stack+647850,int_stack+646230, 1.0, int_stack+1476355, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1655005, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2982954,int_stack+2978094,int_stack+7253160, 1.0, int_stack+3063840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4565617, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7270485,int_stack+2982954,int_stack+2972424, 1.0, int_stack+3067620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4569397, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3061005,int_stack+649875,int_stack+647850, 1.0, int_stack+1477975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1658650, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7279935,int_stack+3061005,int_stack+2978094, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4575067, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7289655,int_stack+7279935,int_stack+2982954, 1.0, int_stack+3232110, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+7289655,int_stack+7270485, 1.0, int_stack+3239670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4751355, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+586170,int_stack+2356725,int_stack+7259145,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+586170,int_stack+3022341,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+7611945,int_stack+7250325,int_stack+546480,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+546480,int_stack+656200,int_stack+653505, 1.0, int_stack+652350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777630, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+549945,int_stack+659720,int_stack+656200, 1.0, int_stack+654660, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+781480, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+554565,int_stack+549945,int_stack+546480, 1.0, int_stack+3073290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4760805, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+561495,int_stack+664175,int_stack+659720, 1.0, int_stack+657740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+786540, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+567435,int_stack+561495,int_stack+549945, 1.0, int_stack+3416385, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4764270, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3022341,int_stack+567435,int_stack+554565, 1.0, int_stack+3421005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4768890, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3416385,int_stack+666650,int_stack+664175, 1.0, int_stack+661700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+790500, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+546480,int_stack+3416385,int_stack+561495, 1.0, int_stack+3427935, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4775820, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3416385,int_stack+546480,int_stack+567435, 1.0, int_stack+3433875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2121150, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+546480,int_stack+3416385,int_stack+3022341, 1.0, int_stack+3443115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+620190,int_stack+546480,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+8674125,int_stack+620190,int_stack+586170,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+546480,int_stack+8674125,int_stack+7250325,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+670116,int_stack+669675, 1.0, int_stack+1500975, 0.0, zero_stack, 1.0, int_stack+1617525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+670704,int_stack+670116, 1.0, int_stack+1501416, 0.0, zero_stack, 1.0, int_stack+1617966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 1.0, int_stack+3454665, 0.0, zero_stack, 1.0, int_stack+4469115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+671460,int_stack+670704, 1.0, int_stack+1502004, 0.0, zero_stack, 1.0, int_stack+1618554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 1.0, int_stack+3455988, 0.0, zero_stack, 1.0, int_stack+4470438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 1.0, int_stack+3457752, 0.0, zero_stack, 1.0, int_stack+4472202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+672405,int_stack+671460, 1.0, int_stack+1502760, 0.0, zero_stack, 1.0, int_stack+1619310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 1.0, int_stack+3460398, 0.0, zero_stack, 1.0, int_stack+4474848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 1.0, int_stack+3462666, 0.0, zero_stack, 1.0, int_stack+4477116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 1.0, int_stack+3466194, 0.0, zero_stack, 1.0, int_stack+4480644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+674148,int_stack+673560, 1.0, int_stack+1508745, 0.0, zero_stack, 1.0, int_stack+1625295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+674932,int_stack+674148, 1.0, int_stack+1509333, 0.0, zero_stack, 1.0, int_stack+1625883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 1.0, int_stack+3477219, 0.0, zero_stack, 1.0, int_stack+4485054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+675940,int_stack+674932, 1.0, int_stack+1510117, 0.0, zero_stack, 1.0, int_stack+1626667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 1.0, int_stack+3478983, 0.0, zero_stack, 1.0, int_stack+4486818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 1.0, int_stack+3481335, 0.0, zero_stack, 1.0, int_stack+4489170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3477219,int_stack+677200,int_stack+675940, 1.0, int_stack+1511125, 0.0, zero_stack, 1.0, int_stack+1627675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7250325,int_stack+3477219,int_stack+7257969, 1.0, int_stack+3484863, 0.0, zero_stack, 1.0, int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3477219,int_stack+7250325,int_stack+7260993, 1.0, int_stack+3487887, 0.0, zero_stack, 1.0, int_stack+4502085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7250325,int_stack+3477219,int_stack+7272879, 1.0, int_stack+3492591, 0.0, zero_stack, 1.0, int_stack+4506789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7272879,int_stack+7250325,int_stack+7266264,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7292724,int_stack+679496,int_stack+678740, 1.0, int_stack+1519105, 0.0, zero_stack, 1.0, int_stack+1635655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7294992,int_stack+680504,int_stack+679496, 1.0, int_stack+1519861, 0.0, zero_stack, 1.0, int_stack+1636411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7298016,int_stack+7294992,int_stack+7292724, 1.0, int_stack+3527136, 0.0, zero_stack, 1.0, int_stack+4512669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3477219,int_stack+681800,int_stack+680504, 1.0, int_stack+1520869, 0.0, zero_stack, 1.0, int_stack+1637419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3481107,int_stack+3477219,int_stack+7294992, 1.0, int_stack+3529404, 0.0, zero_stack, 1.0, int_stack+4514937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3487155,int_stack+3481107,int_stack+7298016, 1.0, int_stack+3532428, 0.0, zero_stack, 1.0, int_stack+4517961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+683420,int_stack+681800, 1.0, int_stack+1522165, 0.0, zero_stack, 1.0, int_stack+1638715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3527136,int_stack+0,int_stack+3477219, 1.0, int_stack+3536964, 0.0, zero_stack, 1.0, int_stack+4522497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7292724,int_stack+3527136,int_stack+3481107, 1.0, int_stack+3540852, 0.0, zero_stack, 1.0, int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3527136,int_stack+7292724,int_stack+3487155, 1.0, int_stack+3546900, 0.0, zero_stack, 1.0, int_stack+4555222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+8674125,int_stack+3527136,int_stack+7250325,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+8700585,int_stack+8674125,int_stack+7272879,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+686345,int_stack+685400, 1.0, int_stack+1532425, 0.0, zero_stack, 1.0, int_stack+1649920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253160,int_stack+687605,int_stack+686345, 1.0, int_stack+1533370, 0.0, zero_stack, 1.0, int_stack+1652125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7256940,int_stack+7253160,int_stack+7250325, 1.0, int_stack+3565800, 0.0, zero_stack, 1.0, int_stack+4562782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+689225,int_stack+687605, 1.0, int_stack+1534630, 0.0, zero_stack, 1.0, int_stack+1655005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7262610,int_stack+0,int_stack+7253160, 1.0, int_stack+3568635, 0.0, zero_stack, 1.0, int_stack+4565617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7270170,int_stack+7262610,int_stack+7256940, 1.0, int_stack+3572415, 0.0, zero_stack, 1.0, int_stack+4569397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3565800,int_stack+691250,int_stack+689225, 1.0, int_stack+1536250, 0.0, zero_stack, 1.0, int_stack+1658650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7250325,int_stack+3565800,int_stack+0, 1.0, int_stack+3736905, 0.0, zero_stack, 1.0, int_stack+4575067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7279620,int_stack+7250325,int_stack+7262610, 1.0, int_stack+3741765, 0.0, zero_stack, 1.0, int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+7279620,int_stack+7270170, 1.0, int_stack+3749325, 0.0, zero_stack, 1.0, int_stack+4751355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7250325,int_stack+2356725,int_stack+3527136,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+634680,int_stack+7250325,int_stack+8674125,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+8918565,int_stack+634680,int_stack+8700585,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8674125,int_stack+697575,int_stack+694880, 1.0, int_stack+693725, 0.0, zero_stack, 1.0, int_stack+777630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8677590,int_stack+701095,int_stack+697575, 1.0, int_stack+696035, 0.0, zero_stack, 1.0, int_stack+781480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8682210,int_stack+8677590,int_stack+8674125, 1.0, int_stack+3578085, 0.0, zero_stack, 1.0, int_stack+4760805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8689140,int_stack+705550,int_stack+701095, 1.0, int_stack+699115, 0.0, zero_stack, 1.0, int_stack+786540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8695080,int_stack+8689140,int_stack+8677590, 1.0, int_stack+3926040, 0.0, zero_stack, 1.0, int_stack+4764270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8704320,int_stack+8695080,int_stack+8682210, 1.0, int_stack+3930660, 0.0, zero_stack, 1.0, int_stack+4768890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3926040,int_stack+708025,int_stack+705550, 1.0, int_stack+703075, 0.0, zero_stack, 1.0, int_stack+790500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8674125,int_stack+3926040,int_stack+8689140, 1.0, int_stack+3937590, 0.0, zero_stack, 1.0, int_stack+4775820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3926040,int_stack+8674125,int_stack+8695080, 1.0, int_stack+3943530, 0.0, zero_stack, 1.0, int_stack+2121150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8674125,int_stack+3926040,int_stack+8704320, 1.0, int_stack+3952770, 0.0, zero_stack, 1.0, int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+8691450,int_stack+8674125,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+8984715,int_stack+8691450,int_stack+7250325,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+9052755,int_stack+8984715,int_stack+634680,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+634680,int_stack+711491,int_stack+711050, 1.0, int_stack+1559250, 1.0, int_stack+1617525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+636003,int_stack+712079,int_stack+711491, 1.0, int_stack+1559691, 1.0, int_stack+1617966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+637767,int_stack+636003,int_stack+634680, 1.0, int_stack+3964320, 1.0, int_stack+4469115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+640413,int_stack+712835,int_stack+712079, 1.0, int_stack+1560279, 1.0, int_stack+1618554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+642681,int_stack+640413,int_stack+636003, 1.0, int_stack+3965643, 1.0, int_stack+4470438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+646209,int_stack+642681,int_stack+637767, 1.0, int_stack+3967407, 1.0, int_stack+4472202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+634680,int_stack+713780,int_stack+712835, 1.0, int_stack+1561035, 1.0, int_stack+1619310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+650619,int_stack+634680,int_stack+640413, 1.0, int_stack+3970053, 1.0, int_stack+4474848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+634680,int_stack+650619,int_stack+642681, 1.0, int_stack+3972321, 1.0, int_stack+4477116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+650619,int_stack+634680,int_stack+646209, 1.0, int_stack+3975849, 1.0, int_stack+4480644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+634680,int_stack+715523,int_stack+714935, 1.0, int_stack+1567020, 1.0, int_stack+1625295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+636444,int_stack+716307,int_stack+715523, 1.0, int_stack+1567608, 1.0, int_stack+1625883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+638796,int_stack+636444,int_stack+634680, 1.0, int_stack+3986874, 1.0, int_stack+4485054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+642324,int_stack+717315,int_stack+716307, 1.0, int_stack+1568392, 1.0, int_stack+1626667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+645348,int_stack+642324,int_stack+636444, 1.0, int_stack+3988638, 1.0, int_stack+4486818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+657234,int_stack+645348,int_stack+638796, 1.0, int_stack+3990990, 1.0, int_stack+4489170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3986874,int_stack+718575,int_stack+717315, 1.0, int_stack+1569400, 1.0, int_stack+1627675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+634680,int_stack+3986874,int_stack+642324, 1.0, int_stack+3994518, 1.0, int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3986874,int_stack+634680,int_stack+645348, 1.0, int_stack+3997542, 1.0, int_stack+4502085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+634680,int_stack+3986874,int_stack+657234, 1.0, int_stack+4002246, 1.0, int_stack+4506789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+657234,int_stack+634680,int_stack+650619,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+677079,int_stack+720871,int_stack+720115, 1.0, int_stack+1577380, 1.0, int_stack+1635655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+679347,int_stack+721879,int_stack+720871, 1.0, int_stack+1578136, 1.0, int_stack+1636411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+682371,int_stack+679347,int_stack+677079, 1.0, int_stack+4036791, 1.0, int_stack+4512669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+686907,int_stack+723175,int_stack+721879, 1.0, int_stack+1579144, 1.0, int_stack+1637419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+690795,int_stack+686907,int_stack+679347, 1.0, int_stack+4039059, 1.0, int_stack+4514937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+696843,int_stack+690795,int_stack+682371, 1.0, int_stack+4042083, 1.0, int_stack+4517961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+724795,int_stack+723175, 1.0, int_stack+1580440, 1.0, int_stack+1638715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4036791,int_stack+0,int_stack+686907, 1.0, int_stack+4046619, 1.0, int_stack+4522497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+677079,int_stack+4036791,int_stack+690795, 1.0, int_stack+4050507, 1.0, int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4036791,int_stack+677079,int_stack+696843, 1.0, int_stack+4056555, 1.0, int_stack+4555222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+677079,int_stack+4036791,int_stack+634680,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+8984715,int_stack+677079,int_stack+657234,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+634680,int_stack+727720,int_stack+726775, 1.0, int_stack+1590700, 1.0, int_stack+1649920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+637515,int_stack+728980,int_stack+727720, 1.0, int_stack+1591645, 1.0, int_stack+1652125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+641295,int_stack+637515,int_stack+634680, 1.0, int_stack+4075455, 1.0, int_stack+4562782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+730600,int_stack+728980, 1.0, int_stack+1592905, 1.0, int_stack+1655005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+646965,int_stack+0,int_stack+637515, 1.0, int_stack+4078290, 1.0, int_stack+4565617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+654525,int_stack+646965,int_stack+641295, 1.0, int_stack+4082070, 1.0, int_stack+4569397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4075455,int_stack+732625,int_stack+730600, 1.0, int_stack+1594525, 1.0, int_stack+1658650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+634680,int_stack+4075455,int_stack+0, 1.0, int_stack+4860, 1.0, int_stack+4575067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+663975,int_stack+634680,int_stack+646965, 1.0, int_stack+4246560, 1.0, int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+663975,int_stack+654525, 1.0, int_stack+4254120, 1.0, int_stack+4751355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+2356725,int_stack+4036791,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+677079,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+668700,int_stack+7250325,int_stack+8984715,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8984715,int_stack+738950,int_stack+736255, 1.0, int_stack+735100, 1.0, int_stack+777630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8988180,int_stack+742470,int_stack+738950, 1.0, int_stack+737410, 1.0, int_stack+781480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8992800,int_stack+8988180,int_stack+8984715, 1.0, int_stack+4087740, 1.0, int_stack+4760805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8999730,int_stack+746925,int_stack+742470, 1.0, int_stack+740490, 1.0, int_stack+786540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9005670,int_stack+8999730,int_stack+8988180, 1.0, int_stack+4430835, 1.0, int_stack+4764270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+9014910,int_stack+9005670,int_stack+8992800, 1.0, int_stack+4435455, 1.0, int_stack+4768890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4430835,int_stack+749400,int_stack+746925, 1.0, int_stack+744450, 1.0, int_stack+790500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8984715,int_stack+4430835,int_stack+8999730, 1.0, int_stack+4442385, 1.0, int_stack+4775820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4430835,int_stack+8984715,int_stack+9005670, 1.0, int_stack+4448325, 1.0, int_stack+2121150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8984715,int_stack+4430835,int_stack+9014910, 1.0, int_stack+4457565, 1.0, int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+9002040,int_stack+8984715,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+8674125,int_stack+9002040,int_stack+634680,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+9140955,int_stack+8674125,int_stack+7250325,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+752866,int_stack+752425, 2.0, int_stack+1617525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+753454,int_stack+752866, 2.0, int_stack+1617966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 2.0, int_stack+4469115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+754210,int_stack+753454, 2.0, int_stack+1618554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 2.0, int_stack+4470438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 2.0, int_stack+4472202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+755155,int_stack+754210, 2.0, int_stack+1619310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 2.0, int_stack+4474848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 2.0, int_stack+4477116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 2.0, int_stack+4480644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+756898,int_stack+756310, 2.0, int_stack+1625295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+757682,int_stack+756898, 2.0, int_stack+1625883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 2.0, int_stack+4485054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+758690,int_stack+757682, 2.0, int_stack+1626667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 2.0, int_stack+4486818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 2.0, int_stack+4489170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+759950,int_stack+758690, 2.0, int_stack+1627675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7257969, 2.0, int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7260993, 2.0, int_stack+4502085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879, 2.0, int_stack+4506789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+8674125,int_stack+7278759,int_stack+7266264,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+762246,int_stack+761490, 2.0, int_stack+1635655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1879350,int_stack+763254,int_stack+762246, 2.0, int_stack+1636411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7252593,int_stack+1879350,int_stack+7250325, 2.0, int_stack+4512669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257129,int_stack+764550,int_stack+763254, 2.0, int_stack+1637419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7261017,int_stack+7257129,int_stack+1879350, 2.0, int_stack+4514937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7267065,int_stack+7261017,int_stack+7252593, 2.0, int_stack+4517961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+766170,int_stack+764550, 2.0, int_stack+1638715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4502085,int_stack+7250325,int_stack+7257129, 2.0, int_stack+4522497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+4502085,int_stack+7261017, 2.0, int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4502085,int_stack+7250325,int_stack+7267065, 2.0, int_stack+4555222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+4502085,int_stack+7278759,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+8693970,int_stack+7250325,int_stack+8674125,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8674125,int_stack+769095,int_stack+768150, 2.0, int_stack+1649920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8676960,int_stack+770355,int_stack+769095, 2.0, int_stack+1652125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8680740,int_stack+8676960,int_stack+8674125, 2.0, int_stack+4562782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8686410,int_stack+771975,int_stack+770355, 2.0, int_stack+1655005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4555222,int_stack+8686410,int_stack+8676960, 2.0, int_stack+4565617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7276785,int_stack+4555222,int_stack+8680740, 2.0, int_stack+4569397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8674125,int_stack+774000,int_stack+771975, 2.0, int_stack+1658650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+8674125,int_stack+8686410, 2.0, int_stack+4575067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8674125,int_stack+0,int_stack+4555222, 2.0, int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+8674125,int_stack+7276785, 2.0, int_stack+4751355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+2356725,int_stack+4502085,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+8984715,int_stack+634680,int_stack+7250325,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+9229155,int_stack+8984715,int_stack+8693970,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+783020,int_stack+778785, 2.0, int_stack+777630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253790,int_stack+788520,int_stack+783020, 2.0, int_stack+781480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7258410,int_stack+7253790,int_stack+7250325, 2.0, int_stack+4760805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7265340,int_stack+792975,int_stack+788520, 2.0, int_stack+786540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7271280,int_stack+7265340,int_stack+7253790, 2.0, int_stack+4764270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7280520,int_stack+7271280,int_stack+7258410, 2.0, int_stack+4768890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+795450,int_stack+792975, 2.0, int_stack+790500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4502085,int_stack+7250325,int_stack+7265340, 2.0, int_stack+4775820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+4502085,int_stack+7271280, 2.0, int_stack+2121150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4502085,int_stack+7250325,int_stack+7280520, 2.0, int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+7250325,int_stack+4502085,int_stack+2356725,315);
 /*--- compute (kd|hg) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+8674125,int_stack+7250325,int_stack+634680,315);
 /*--- compute (if|hg) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+9295305,int_stack+8674125,int_stack+8984715,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8984715,int_stack+798916,int_stack+798475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1688800,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8986038,int_stack+799504,int_stack+798916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1689241,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8987802,int_stack+8986038,int_stack+8984715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5074710,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8990448,int_stack+800260,int_stack+799504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1689829,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8992716,int_stack+8990448,int_stack+8986038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5076033,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8996244,int_stack+8992716,int_stack+8987802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5077797,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8984715,int_stack+801205,int_stack+800260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1690585,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9000654,int_stack+8984715,int_stack+8990448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5080443,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8984715,int_stack+9000654,int_stack+8992716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5082711,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+9000654,int_stack+8984715,int_stack+8996244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2370900,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8984715,int_stack+802948,int_stack+802360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1696570,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8986479,int_stack+803732,int_stack+802948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1697158,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8988831,int_stack+8986479,int_stack+8984715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2375310,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1879350,int_stack+804740,int_stack+803732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1697942,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8992359,int_stack+1879350,int_stack+8986479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2377074,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+9007269,int_stack+8992359,int_stack+8988831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2379426,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8984715,int_stack+806000,int_stack+804740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1698950,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+8984715,int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5086239,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+9013149,int_stack+1917843,int_stack+8992359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2392341,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8984715,int_stack+9013149,int_stack+9007269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2130390,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+9007269,int_stack+8984715,int_stack+9000654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1911228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9027114,int_stack+808296,int_stack+807540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1706930,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1879350,int_stack+809304,int_stack+808296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1707686,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9029382,int_stack+1879350,int_stack+9027114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2145090,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9033918,int_stack+810600,int_stack+809304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1708694,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1917843,int_stack+9033918,int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2147358,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1989012,int_stack+1917843,int_stack+9029382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2150382,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9027114,int_stack+812220,int_stack+810600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1709990,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9037806,int_stack+9027114,int_stack+9033918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1996572,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+9027114,int_stack+9037806,int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2000460,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+9037194,int_stack+9027114,int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2006508,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+8674125,int_stack+9037194,int_stack+8984715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1960347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+8700585,int_stack+8674125,int_stack+9007269, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1969167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8984715,int_stack+815145,int_stack+814200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1720250,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8987550,int_stack+816405,int_stack+815145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1721195,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8991330,int_stack+8987550,int_stack+8984715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1882374,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8997000,int_stack+818025,int_stack+816405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1722455,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1989012,int_stack+8997000,int_stack+8987550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1885209,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+9001860,int_stack+1989012,int_stack+8991330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1888989,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8984715,int_stack+820050,int_stack+818025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1724075,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+8984715,int_stack+8997000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1832545,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8984715,int_stack+0,int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9720,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+8984715,int_stack+9001860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5417115,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+2356725,int_stack+9037194, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2043660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+8674125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2055000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+8984715,int_stack+7250325,int_stack+8700585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2081460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8674125,int_stack+823680,int_stack+822525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+993650,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8677590,int_stack+825220,int_stack+823680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+995960,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8682210,int_stack+8677590,int_stack+8674125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1935231,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8689140,int_stack+827200,int_stack+825220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999040,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2121150,int_stack+8689140,int_stack+8677590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817005,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+2121150,int_stack+8682210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5593830,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8674125,int_stack+829675,int_stack+827200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003000,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8695080,int_stack+8674125,int_stack+8689140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5600760,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8674125,int_stack+8695080,int_stack+2121150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5606700,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8689525,int_stack+8674125,int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5615940,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4430835,int_stack+8689525,int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2189460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+8674125,int_stack+4430835,int_stack+634680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2203635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+734850,int_stack+8674125,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2237655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+833141,int_stack+832700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1688800, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+833729,int_stack+833141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1689241, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5074710, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+834485,int_stack+833729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1689829, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5076033, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5077797, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+835430,int_stack+834485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1690585, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5080443, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5082711, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2370900, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+837173,int_stack+836585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1696570, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+837957,int_stack+837173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1697158, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2375310, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1879350,int_stack+838965,int_stack+837957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1697942, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7257969,int_stack+1879350,int_stack+7252089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2377074, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7257969,int_stack+7254441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2379426, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+840225,int_stack+838965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1698950, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+7250325,int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5086239, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7278759,int_stack+1917843,int_stack+7257969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2392341, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2130390, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+7272879,int_stack+7250325,int_stack+7266264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2456154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7292724,int_stack+842521,int_stack+841765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1706930, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1879350,int_stack+843529,int_stack+842521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1707686, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7294992,int_stack+1879350,int_stack+7292724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2145090, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1917843,int_stack+844825,int_stack+843529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1708694, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7259145,int_stack+1917843,int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2147358, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1989012,int_stack+7259145,int_stack+7294992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2150382, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7292724,int_stack+846445,int_stack+844825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1709990, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8674125,int_stack+7292724,int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1996572, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7292724,int_stack+8674125,int_stack+7259145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2000460, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7259145,int_stack+7292724,int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2006508, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+8674125,int_stack+7259145,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2484021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+8700585,int_stack+8674125,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2492841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+849370,int_stack+848425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1720250, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253160,int_stack+850630,int_stack+849370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1721195, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1989012,int_stack+7253160,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1882374, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7270485,int_stack+852250,int_stack+850630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1722455, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7275345,int_stack+7270485,int_stack+7253160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1885209, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7282905,int_stack+7275345,int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1888989, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1989012,int_stack+854275,int_stack+852250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1724075, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+1989012,int_stack+7270485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1832545, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+634680,int_stack+0,int_stack+7275345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9720, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+634680,int_stack+7282905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5417115, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+2356725,int_stack+7259145, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2540010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+8674125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2656305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+9383505,int_stack+7250325,int_stack+8700585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2682765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8674125,int_stack+857905,int_stack+856750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+993650, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8677590,int_stack+859445,int_stack+857905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+995960, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8682210,int_stack+8677590,int_stack+8674125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1935231, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8689140,int_stack+861425,int_stack+859445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999040, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2121150,int_stack+8689140,int_stack+8677590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817005, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+2121150,int_stack+8682210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5593830, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8674125,int_stack+863900,int_stack+861425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003000, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8695080,int_stack+8674125,int_stack+8689140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5600760, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8674125,int_stack+8695080,int_stack+2121150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5606700, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8689525,int_stack+8674125,int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5615940, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4430835,int_stack+8689525,int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2744325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+8674125,int_stack+4430835,int_stack+634680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2758500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+9449655,int_stack+8674125,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2792520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+867366,int_stack+866925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1688800, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+867954,int_stack+867366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1689241, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5074710, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+868710,int_stack+867954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1689829, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5076033, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5077797, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+869655,int_stack+868710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1690585, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5080443, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5082711, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2370900, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+871398,int_stack+870810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1696570, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+872182,int_stack+871398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1697158, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2375310, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1879350,int_stack+873190,int_stack+872182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1697942, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7257969,int_stack+1879350,int_stack+7252089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2377074, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7257969,int_stack+7254441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2379426, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+874450,int_stack+873190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1698950, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+7250325,int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5086239, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7278759,int_stack+1917843,int_stack+7257969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2392341, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2130390, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+7272879,int_stack+7250325,int_stack+7266264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2965809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7292724,int_stack+876746,int_stack+875990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1706930, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1879350,int_stack+877754,int_stack+876746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1707686, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7294992,int_stack+1879350,int_stack+7292724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2145090, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1917843,int_stack+879050,int_stack+877754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1708694, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7259145,int_stack+1917843,int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2147358, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1989012,int_stack+7259145,int_stack+7294992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2150382, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7292724,int_stack+880670,int_stack+879050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1709990, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8674125,int_stack+7292724,int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1996572, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7292724,int_stack+8674125,int_stack+7259145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2000460, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7259145,int_stack+7292724,int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2006508, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+8674125,int_stack+7259145,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2993676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+8700585,int_stack+8674125,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3002496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+883595,int_stack+882650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1720250, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253160,int_stack+884855,int_stack+883595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1721195, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1989012,int_stack+7253160,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1882374, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7270485,int_stack+886475,int_stack+884855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1722455, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7275345,int_stack+7270485,int_stack+7253160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1885209, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7282905,int_stack+7275345,int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1888989, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1989012,int_stack+888500,int_stack+886475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1724075, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+1989012,int_stack+7270485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1832545, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+634680,int_stack+0,int_stack+7275345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9720, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+634680,int_stack+7282905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5417115, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+2356725,int_stack+7259145, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3049665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+8674125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3165960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+823050,int_stack+7250325,int_stack+8700585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3192420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8674125,int_stack+892130,int_stack+890975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+993650, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8677590,int_stack+893670,int_stack+892130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+995960, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8682210,int_stack+8677590,int_stack+8674125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1935231, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8689140,int_stack+895650,int_stack+893670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999040, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2121150,int_stack+8689140,int_stack+8677590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817005, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+2121150,int_stack+8682210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5593830, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8674125,int_stack+898125,int_stack+895650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003000, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8695080,int_stack+8674125,int_stack+8689140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5600760, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8674125,int_stack+8695080,int_stack+2121150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5606700, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8689525,int_stack+8674125,int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5615940, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4430835,int_stack+8689525,int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3249120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+8674125,int_stack+4430835,int_stack+634680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3263295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+9537855,int_stack+8674125,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3297315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+901591,int_stack+901150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1688800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+902179,int_stack+901591, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1689241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5074710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+902935,int_stack+902179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1689829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5076033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5077797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+903880,int_stack+902935, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1690585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5080443, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5082711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2370900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+905623,int_stack+905035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1696570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+906407,int_stack+905623, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1697158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2375310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1879350,int_stack+907415,int_stack+906407, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1697942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7257969,int_stack+1879350,int_stack+7252089, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2377074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7257969,int_stack+7254441, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2379426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+908675,int_stack+907415, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1698950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+7250325,int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5086239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7278759,int_stack+1917843,int_stack+7257969, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2392341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2130390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+7272879,int_stack+7250325,int_stack+7266264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3470604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7292724,int_stack+910971,int_stack+910215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1706930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1879350,int_stack+911979,int_stack+910971, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1707686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7294992,int_stack+1879350,int_stack+7292724, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2145090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1917843,int_stack+913275,int_stack+911979, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1708694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7259145,int_stack+1917843,int_stack+1879350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2147358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1989012,int_stack+7259145,int_stack+7294992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2150382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7292724,int_stack+914895,int_stack+913275, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1709990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8674125,int_stack+7292724,int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1996572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7292724,int_stack+8674125,int_stack+7259145, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2000460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7259145,int_stack+7292724,int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2006508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+8674125,int_stack+7259145,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3498471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+8700585,int_stack+8674125,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3507291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+917820,int_stack+916875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1720250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253160,int_stack+919080,int_stack+917820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1721195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1989012,int_stack+7253160,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1882374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7270485,int_stack+920700,int_stack+919080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1722455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7275345,int_stack+7270485,int_stack+7253160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1885209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7282905,int_stack+7275345,int_stack+1989012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1888989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1989012,int_stack+922725,int_stack+920700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1724075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+1989012,int_stack+7270485, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1832545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+634680,int_stack+0,int_stack+7275345, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+634680,int_stack+7282905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5417115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+2356725,int_stack+7259145, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3554460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+8674125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3670755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+9626055,int_stack+7250325,int_stack+8700585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3697215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8674125,int_stack+926355,int_stack+925200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+993650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8677590,int_stack+927895,int_stack+926355, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+995960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8682210,int_stack+8677590,int_stack+8674125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1935231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8689140,int_stack+929875,int_stack+927895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2121150,int_stack+8689140,int_stack+8677590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+2121150,int_stack+8682210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5593830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8674125,int_stack+932350,int_stack+929875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8695080,int_stack+8674125,int_stack+8689140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5600760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8674125,int_stack+8695080,int_stack+2121150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5606700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8689525,int_stack+8674125,int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5615940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4430835,int_stack+8689525,int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3758775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+8674125,int_stack+4430835,int_stack+634680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3772950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+9692205,int_stack+8674125,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3806970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+935816,int_stack+935375, 0.0, zero_stack, 1.0, int_stack+1688800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+936404,int_stack+935816, 0.0, zero_stack, 1.0, int_stack+1689241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+5074710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+937160,int_stack+936404, 0.0, zero_stack, 1.0, int_stack+1689829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 1.0, int_stack+5076033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 1.0, int_stack+5077797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+938105,int_stack+937160, 0.0, zero_stack, 1.0, int_stack+1690585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 1.0, int_stack+5080443, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 1.0, int_stack+5082711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 1.0, int_stack+2370900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+939848,int_stack+939260, 0.0, zero_stack, 1.0, int_stack+1696570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+940632,int_stack+939848, 0.0, zero_stack, 1.0, int_stack+1697158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+2375310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1879350,int_stack+941640,int_stack+940632, 0.0, zero_stack, 1.0, int_stack+1697942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7257969,int_stack+1879350,int_stack+7252089, 0.0, zero_stack, 1.0, int_stack+2377074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7257969,int_stack+7254441, 0.0, zero_stack, 1.0, int_stack+2379426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+942900,int_stack+941640, 0.0, zero_stack, 1.0, int_stack+1698950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+7250325,int_stack+1879350, 0.0, zero_stack, 1.0, int_stack+5086239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7278759,int_stack+1917843,int_stack+7257969, 0.0, zero_stack, 1.0, int_stack+2392341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7272879, 0.0, zero_stack, 1.0, int_stack+2130390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+7272879,int_stack+7250325,int_stack+7266264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3980259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7292724,int_stack+945196,int_stack+944440, 0.0, zero_stack, 1.0, int_stack+1706930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1879350,int_stack+946204,int_stack+945196, 0.0, zero_stack, 1.0, int_stack+1707686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7294992,int_stack+1879350,int_stack+7292724, 0.0, zero_stack, 1.0, int_stack+2145090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1917843,int_stack+947500,int_stack+946204, 0.0, zero_stack, 1.0, int_stack+1708694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7259145,int_stack+1917843,int_stack+1879350, 0.0, zero_stack, 1.0, int_stack+2147358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1989012,int_stack+7259145,int_stack+7294992, 0.0, zero_stack, 1.0, int_stack+2150382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7292724,int_stack+949120,int_stack+947500, 0.0, zero_stack, 1.0, int_stack+1709990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8674125,int_stack+7292724,int_stack+1917843, 0.0, zero_stack, 1.0, int_stack+1996572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7292724,int_stack+8674125,int_stack+7259145, 0.0, zero_stack, 1.0, int_stack+2000460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7259145,int_stack+7292724,int_stack+1989012, 0.0, zero_stack, 1.0, int_stack+2006508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+8674125,int_stack+7259145,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4008126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+8700585,int_stack+8674125,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4016946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+952045,int_stack+951100, 0.0, zero_stack, 1.0, int_stack+1720250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253160,int_stack+953305,int_stack+952045, 0.0, zero_stack, 1.0, int_stack+1721195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1989012,int_stack+7253160,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+1882374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7270485,int_stack+954925,int_stack+953305, 0.0, zero_stack, 1.0, int_stack+1722455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7275345,int_stack+7270485,int_stack+7253160, 0.0, zero_stack, 1.0, int_stack+1885209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7282905,int_stack+7275345,int_stack+1989012, 0.0, zero_stack, 1.0, int_stack+1888989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1989012,int_stack+956950,int_stack+954925, 0.0, zero_stack, 1.0, int_stack+1724075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+1989012,int_stack+7270485, 0.0, zero_stack, 1.0, int_stack+1832545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+634680,int_stack+0,int_stack+7275345, 0.0, zero_stack, 1.0, int_stack+9720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2356725,int_stack+634680,int_stack+7282905, 0.0, zero_stack, 1.0, int_stack+5417115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+2356725,int_stack+7259145, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4064115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+8674125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4180410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+889200,int_stack+7250325,int_stack+8700585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4206870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8674125,int_stack+960580,int_stack+959425, 0.0, zero_stack, 1.0, int_stack+993650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8677590,int_stack+962120,int_stack+960580, 0.0, zero_stack, 1.0, int_stack+995960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8682210,int_stack+8677590,int_stack+8674125, 0.0, zero_stack, 1.0, int_stack+1935231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8689140,int_stack+964100,int_stack+962120, 0.0, zero_stack, 1.0, int_stack+999040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2121150,int_stack+8689140,int_stack+8677590, 0.0, zero_stack, 1.0, int_stack+1817005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+2121150,int_stack+8682210, 0.0, zero_stack, 1.0, int_stack+5593830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8674125,int_stack+966575,int_stack+964100, 0.0, zero_stack, 1.0, int_stack+1003000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8695080,int_stack+8674125,int_stack+8689140, 0.0, zero_stack, 1.0, int_stack+5600760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8674125,int_stack+8695080,int_stack+2121150, 0.0, zero_stack, 1.0, int_stack+5606700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8689525,int_stack+8674125,int_stack+4950390, 0.0, zero_stack, 1.0, int_stack+5615940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4430835,int_stack+8689525,int_stack+2356725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4263570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+8674125,int_stack+4430835,int_stack+634680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4277745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+9780405,int_stack+8674125,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4311765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+970041,int_stack+969600, 1.0, int_stack+1688800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+970629,int_stack+970041, 1.0, int_stack+1689241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 1.0, int_stack+5074710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+971385,int_stack+970629, 1.0, int_stack+1689829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 1.0, int_stack+5076033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 1.0, int_stack+5077797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+972330,int_stack+971385, 1.0, int_stack+1690585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 1.0, int_stack+5080443, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 1.0, int_stack+5082711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 1.0, int_stack+2370900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+974073,int_stack+973485, 1.0, int_stack+1696570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+974857,int_stack+974073, 1.0, int_stack+1697158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 1.0, int_stack+2375310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1879350,int_stack+975865,int_stack+974857, 1.0, int_stack+1697942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7257969,int_stack+1879350,int_stack+7252089, 1.0, int_stack+2377074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7257969,int_stack+7254441, 1.0, int_stack+2379426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+977125,int_stack+975865, 1.0, int_stack+1698950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+7250325,int_stack+1879350, 1.0, int_stack+5086239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7278759,int_stack+1917843,int_stack+7257969, 1.0, int_stack+2392341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2392341,int_stack+7278759,int_stack+7272879, 1.0, int_stack+2130390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+7272879,int_stack+2392341,int_stack+7266264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4495470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7292724,int_stack+979421,int_stack+978665, 1.0, int_stack+1706930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1879350,int_stack+980429,int_stack+979421, 1.0, int_stack+1707686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7294992,int_stack+1879350,int_stack+7292724, 1.0, int_stack+2145090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2401161,int_stack+981725,int_stack+980429, 1.0, int_stack+1708694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1917843,int_stack+2401161,int_stack+1879350, 1.0, int_stack+2147358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1989012,int_stack+1917843,int_stack+7294992, 1.0, int_stack+2150382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2145090,int_stack+983345,int_stack+981725, 1.0, int_stack+1709990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2149950,int_stack+2145090,int_stack+2401161, 1.0, int_stack+1996572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2401161,int_stack+2149950,int_stack+1917843, 1.0, int_stack+2000460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2411241,int_stack+2401161,int_stack+1989012, 1.0, int_stack+2006508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2422581,int_stack+2411241,int_stack+2392341, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4526557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2145090,int_stack+2422581,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4535377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2392341,int_stack+986270,int_stack+985325, 1.0, int_stack+1720250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2395176,int_stack+987530,int_stack+986270, 1.0, int_stack+1721195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2398956,int_stack+2395176,int_stack+2392341, 1.0, int_stack+1882374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2404626,int_stack+989150,int_stack+987530, 1.0, int_stack+1722455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1989012,int_stack+2404626,int_stack+2395176, 1.0, int_stack+1885209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1996572,int_stack+1989012,int_stack+2398956, 1.0, int_stack+1888989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2392341,int_stack+991175,int_stack+989150, 1.0, int_stack+1724075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+2392341,int_stack+2404626, 1.0, int_stack+1832545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2392341,int_stack+0,int_stack+1989012, 1.0, int_stack+9720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+2392341,int_stack+1996572, 1.0, int_stack+5417115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+2411241, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4580638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+2422581, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4685205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+8674125,int_stack+7250325,int_stack+2145090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4711665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2145090,int_stack+997500,int_stack+994805, 1.0, int_stack+993650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2148555,int_stack+1001020,int_stack+997500, 1.0, int_stack+995960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2153175,int_stack+2148555,int_stack+2145090, 1.0, int_stack+1935231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1935231,int_stack+1005475,int_stack+1001020, 1.0, int_stack+999040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1941171,int_stack+1935231,int_stack+2148555, 1.0, int_stack+1817005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+1941171,int_stack+2153175, 1.0, int_stack+5593830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1950411,int_stack+1007950,int_stack+1005475, 1.0, int_stack+1003000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2145090,int_stack+1950411,int_stack+1935231, 1.0, int_stack+5600760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2156970,int_stack+2145090,int_stack+1941171, 1.0, int_stack+5606700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1935231,int_stack+2156970,int_stack+4950390, 1.0, int_stack+5615940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+2145090,int_stack+1935231,int_stack+1648975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4783125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+9868605,int_stack+2145090,int_stack+634680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4797300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+9936645,int_stack+9868605,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4831320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1011416,int_stack+1010975,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+1012004,int_stack+1011416,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+1012760,int_stack+1012004,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1013705,int_stack+1012760,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1015448,int_stack+1014860,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+1016232,int_stack+1015448,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+1017240,int_stack+1016232,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1018500,int_stack+1017240,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+7250325,int_stack+7257969,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+1917843,int_stack+7260993,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+9868605,int_stack+7278759,int_stack+7266264, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2385726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1020796,int_stack+1020040,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+1021804,int_stack+1020796,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+1023100,int_stack+1021804,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1917843,int_stack+7260153,int_stack+7252593,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7264041,int_stack+1917843,int_stack+7255617,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1024720,int_stack+1023100,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+1917843,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7264041,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2136270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+9888450,int_stack+7250325,int_stack+9868605, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5331120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+9868605,int_stack+1027645,int_stack+1026700,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9871440,int_stack+1028905,int_stack+1027645,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9875220,int_stack+9871440,int_stack+9868605,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9880890,int_stack+1030525,int_stack+1028905,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7276785,int_stack+9880890,int_stack+9871440,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+7276785,int_stack+9875220,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9868605,int_stack+1032550,int_stack+1030525,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+634680,int_stack+9868605,int_stack+9880890,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+9868605,int_stack+634680,int_stack+7276785,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+9868605,int_stack+5417115,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+7287579, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1923891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2392341,int_stack+634680,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5350965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+955350,int_stack+2392341,int_stack+9888450, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5377425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1036180,int_stack+1035025,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7253790,int_stack+1037720,int_stack+1036180,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7258410,int_stack+7253790,int_stack+7250325,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7265340,int_stack+1039700,int_stack+1037720,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7271280,int_stack+7265340,int_stack+7253790,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+7271280,int_stack+7258410,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1042175,int_stack+1039700,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7280520,int_stack+7250325,int_stack+7265340,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7280520,int_stack+7271280,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7265725,int_stack+7250325,int_stack+4950390,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+9868605,int_stack+7265725,int_stack+1648975, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5426565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+10024845,int_stack+9868605,int_stack+634680, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5440740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+10092885,int_stack+10024845,int_stack+2392341, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5474760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2392341,int_stack+1045641,int_stack+1045200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1747075,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2393664,int_stack+1046229,int_stack+1045641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1747516,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2395428,int_stack+2393664,int_stack+2392341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5627490,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2398074,int_stack+1046985,int_stack+1046229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1748104,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2400342,int_stack+2398074,int_stack+2393664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5628813,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2403870,int_stack+2400342,int_stack+2395428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5630577,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2392341,int_stack+1047930,int_stack+1046985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1748860,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2408280,int_stack+2392341,int_stack+2398074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2014068,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2392341,int_stack+2408280,int_stack+2400342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5633223,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2408280,int_stack+2392341,int_stack+2403870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5636751,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2392341,int_stack+1049673,int_stack+1049085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1754845,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2394105,int_stack+1050457,int_stack+1049673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1755433,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2396457,int_stack+2394105,int_stack+2392341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5647776,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2399985,int_stack+1051465,int_stack+1050457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1756217,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2403009,int_stack+2399985,int_stack+2394105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5649540,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2414895,int_stack+2403009,int_stack+2396457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5651892,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2392341,int_stack+1052725,int_stack+1051465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1757225,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+2392341,int_stack+2399985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5655420,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2392341,int_stack+1917843,int_stack+2403009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5658444,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2420775,int_stack+2392341,int_stack+2414895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5663148,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2429595,int_stack+2420775,int_stack+2408280, 0.0, zero_stack, 1.0, int_stack+1911228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2392341,int_stack+1055021,int_stack+1054265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1765205,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2394609,int_stack+1056029,int_stack+1055021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1765961,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2397633,int_stack+2394609,int_stack+2392341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5697693,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2402169,int_stack+1057325,int_stack+1056029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1766969,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1917843,int_stack+2402169,int_stack+2394609, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5699961,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2406057,int_stack+1917843,int_stack+2397633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5702985,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2392341,int_stack+1058945,int_stack+1057325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1768265,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10024845,int_stack+2392341,int_stack+2402169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5707521,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2392341,int_stack+10024845,int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5711409,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10024845,int_stack+2392341,int_stack+2406057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5717457,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2392341,int_stack+10024845,int_stack+2420775, 0.0, zero_stack, 1.0, int_stack+1960347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+10036185,int_stack+2392341,int_stack+2429595, 0.0, zero_stack, 1.0, int_stack+1969167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2418801,int_stack+1061870,int_stack+1060925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1778525,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2421636,int_stack+1063130,int_stack+1061870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1779470,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2425416,int_stack+2421636,int_stack+2418801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5736357,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2431086,int_stack+1064750,int_stack+1063130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1780730,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2435946,int_stack+2431086,int_stack+2421636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5739192,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+2435946,int_stack+2425416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5742972,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2418801,int_stack+1066775,int_stack+1064750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1782350,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2443506,int_stack+2418801,int_stack+2431086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5748642,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2418801,int_stack+2443506,int_stack+2435946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5909730,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+2418801,int_stack+5417115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5917290,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+10024845, 0.0, zero_stack, 1.0, int_stack+2043660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+2392341, 0.0, zero_stack, 1.0, int_stack+2055000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+9868605,int_stack+7250325,int_stack+10036185, 0.0, zero_stack, 1.0, int_stack+2081460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2392341,int_stack+1070405,int_stack+1069250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240375,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2395806,int_stack+1071945,int_stack+1070405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1242685,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2400426,int_stack+2395806,int_stack+2392341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5926740,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2407356,int_stack+1073925,int_stack+1071945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1245765,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2413296,int_stack+2407356,int_stack+2395806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5930205,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+2413296,int_stack+2400426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5934825,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2392341,int_stack+1076400,int_stack+1073925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1249725,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2422536,int_stack+2392341,int_stack+2407356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5941755,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2392341,int_stack+2422536,int_stack+2413296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6116325,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2407741,int_stack+2392341,int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6125565,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+10024845,int_stack+2407741,int_stack+1648975, 0.0, zero_stack, 1.0, int_stack+2189460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+10181085,int_stack+10024845,int_stack+634680, 0.0, zero_stack, 1.0, int_stack+2203635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+10249125,int_stack+10181085,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+2237655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1079866,int_stack+1079425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1747075, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+1080454,int_stack+1079866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1747516, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5627490, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+1081210,int_stack+1080454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1748104, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5628813, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5630577, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1082155,int_stack+1081210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1748860, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2014068, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5633223, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5636751, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1083898,int_stack+1083310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1754845, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+1084682,int_stack+1083898, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1755433, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5647776, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+1085690,int_stack+1084682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1756217, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5649540, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5651892, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1086950,int_stack+1085690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1757225, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+7250325,int_stack+7257969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5655420, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+1917843,int_stack+7260993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5658444, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5663148, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+10181085,int_stack+7278759,int_stack+7266264, 0.0, zero_stack, 1.0, int_stack+2456154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1089246,int_stack+1088490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1765205, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+1090254,int_stack+1089246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1765961, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5697693, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+1091550,int_stack+1090254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1766969, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1917843,int_stack+7260153,int_stack+7252593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5699961, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7264041,int_stack+1917843,int_stack+7255617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5702985, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1093170,int_stack+1091550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1768265, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5707521, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5711409, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7264041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5717457, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759, 0.0, zero_stack, 1.0, int_stack+2484021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+10200930,int_stack+7250325,int_stack+10181085, 0.0, zero_stack, 1.0, int_stack+2492841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10181085,int_stack+1096095,int_stack+1095150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1778525, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10183920,int_stack+1097355,int_stack+1096095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1779470, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10187700,int_stack+10183920,int_stack+10181085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5736357, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10193370,int_stack+1098975,int_stack+1097355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1780730, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7276785,int_stack+10193370,int_stack+10183920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5739192, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+7276785,int_stack+10187700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5742972, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10181085,int_stack+1101000,int_stack+1098975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1782350, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+634680,int_stack+10181085,int_stack+10193370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5748642, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10181085,int_stack+634680,int_stack+7276785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5909730, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+10181085,int_stack+5417115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5917290, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+7287579, 0.0, zero_stack, 1.0, int_stack+2540010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+10024845,int_stack+634680,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+2656305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1021500,int_stack+10024845,int_stack+10200930, 0.0, zero_stack, 1.0, int_stack+2682765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1104630,int_stack+1103475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240375, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253790,int_stack+1106170,int_stack+1104630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1242685, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7258410,int_stack+7253790,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5926740, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7265340,int_stack+1108150,int_stack+1106170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1245765, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7271280,int_stack+7265340,int_stack+7253790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5930205, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+7271280,int_stack+7258410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5934825, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1110625,int_stack+1108150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1249725, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7280520,int_stack+7250325,int_stack+7265340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5941755, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7280520,int_stack+7271280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6116325, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7265725,int_stack+7250325,int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6125565, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+10181085,int_stack+7265725,int_stack+1648975, 0.0, zero_stack, 1.0, int_stack+2744325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+10337325,int_stack+10181085,int_stack+634680, 0.0, zero_stack, 1.0, int_stack+2758500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+10405365,int_stack+10337325,int_stack+10024845, 0.0, zero_stack, 1.0, int_stack+2792520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10024845,int_stack+1114091,int_stack+1113650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1747075, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10026168,int_stack+1114679,int_stack+1114091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1747516, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10027932,int_stack+10026168,int_stack+10024845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5627490, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10030578,int_stack+1115435,int_stack+1114679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1748104, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10032846,int_stack+10030578,int_stack+10026168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5628813, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10036374,int_stack+10032846,int_stack+10027932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5630577, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10024845,int_stack+1116380,int_stack+1115435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1748860, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10040784,int_stack+10024845,int_stack+10030578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2014068, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10024845,int_stack+10040784,int_stack+10032846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5633223, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10040784,int_stack+10024845,int_stack+10036374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5636751, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10024845,int_stack+1118123,int_stack+1117535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1754845, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10026609,int_stack+1118907,int_stack+1118123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1755433, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10028961,int_stack+10026609,int_stack+10024845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5647776, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10032489,int_stack+1119915,int_stack+1118907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1756217, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10035513,int_stack+10032489,int_stack+10026609, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5649540, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10047399,int_stack+10035513,int_stack+10028961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5651892, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10024845,int_stack+1121175,int_stack+1119915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1757225, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+10024845,int_stack+10032489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5655420, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10024845,int_stack+1917843,int_stack+10035513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5658444, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10053279,int_stack+10024845,int_stack+10047399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5663148, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+10062099,int_stack+10053279,int_stack+10040784, 0.0, zero_stack, 1.0, int_stack+2965809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10024845,int_stack+1123471,int_stack+1122715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1765205, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10027113,int_stack+1124479,int_stack+1123471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1765961, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10030137,int_stack+10027113,int_stack+10024845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5697693, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10034673,int_stack+1125775,int_stack+1124479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1766969, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1917843,int_stack+10034673,int_stack+10027113, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5699961, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10038561,int_stack+1917843,int_stack+10030137, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5702985, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10024845,int_stack+1127395,int_stack+1125775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1768265, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10081944,int_stack+10024845,int_stack+10034673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5707521, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10024845,int_stack+10081944,int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5711409, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10337325,int_stack+10024845,int_stack+10038561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5717457, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+10024845,int_stack+10337325,int_stack+10053279, 0.0, zero_stack, 1.0, int_stack+2993676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+10348665,int_stack+10024845,int_stack+10062099, 0.0, zero_stack, 1.0, int_stack+3002496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10051305,int_stack+1130320,int_stack+1129375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1778525, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10054140,int_stack+1131580,int_stack+1130320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1779470, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10057920,int_stack+10054140,int_stack+10051305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5736357, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10063590,int_stack+1133200,int_stack+1131580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1780730, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10068450,int_stack+10063590,int_stack+10054140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5739192, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+10068450,int_stack+10057920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5742972, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10051305,int_stack+1135225,int_stack+1133200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1782350, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10076010,int_stack+10051305,int_stack+10063590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5748642, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10051305,int_stack+10076010,int_stack+10068450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5909730, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+10051305,int_stack+5417115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5917290, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+10337325, 0.0, zero_stack, 1.0, int_stack+3049665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+10024845, 0.0, zero_stack, 1.0, int_stack+3165960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+10024845,int_stack+7250325,int_stack+10348665, 0.0, zero_stack, 1.0, int_stack+3192420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10337325,int_stack+1138855,int_stack+1137700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240375, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10340790,int_stack+1140395,int_stack+1138855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1242685, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10345410,int_stack+10340790,int_stack+10337325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5926740, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10352340,int_stack+1142375,int_stack+1140395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1245765, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10358280,int_stack+10352340,int_stack+10340790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5930205, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+10358280,int_stack+10345410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5934825, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10337325,int_stack+1144850,int_stack+1142375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1249725, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10367520,int_stack+10337325,int_stack+10352340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5941755, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10337325,int_stack+10367520,int_stack+10358280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6116325, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10352725,int_stack+10337325,int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6125565, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+10181085,int_stack+10352725,int_stack+1648975, 0.0, zero_stack, 1.0, int_stack+3249120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+10337325,int_stack+10181085,int_stack+634680, 0.0, zero_stack, 1.0, int_stack+3263295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+10493565,int_stack+10337325,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+3297315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1148316,int_stack+1147875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1747075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+1148904,int_stack+1148316, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1747516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5627490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+1149660,int_stack+1148904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1748104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5628813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5630577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1150605,int_stack+1149660, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1748860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2014068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5633223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5636751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1152348,int_stack+1151760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1754845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+1153132,int_stack+1152348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1755433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5647776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+1154140,int_stack+1153132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1756217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5649540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5651892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1155400,int_stack+1154140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1757225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+7250325,int_stack+7257969, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5655420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+1917843,int_stack+7260993, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5658444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5663148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+10337325,int_stack+7278759,int_stack+7266264, 0.0, zero_stack, 1.0, int_stack+3470604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1157696,int_stack+1156940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1765205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+1158704,int_stack+1157696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1765961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5697693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+1160000,int_stack+1158704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1766969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1917843,int_stack+7260153,int_stack+7252593, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5699961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7264041,int_stack+1917843,int_stack+7255617, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5702985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1161620,int_stack+1160000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1768265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5707521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+1917843, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5711409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7264041, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5717457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759, 0.0, zero_stack, 1.0, int_stack+3498471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+10357170,int_stack+7250325,int_stack+10337325, 0.0, zero_stack, 1.0, int_stack+3507291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10337325,int_stack+1164545,int_stack+1163600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1778525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10340160,int_stack+1165805,int_stack+1164545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1779470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10343940,int_stack+10340160,int_stack+10337325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5736357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10349610,int_stack+1167425,int_stack+1165805, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1780730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7276785,int_stack+10349610,int_stack+10340160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5739192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+7276785,int_stack+10343940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5742972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10337325,int_stack+1169450,int_stack+1167425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1782350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+634680,int_stack+10337325,int_stack+10349610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5748642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10337325,int_stack+634680,int_stack+7276785, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5909730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+10337325,int_stack+5417115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5917290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+7287579, 0.0, zero_stack, 1.0, int_stack+3554460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+10181085,int_stack+634680,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+3670755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1087650,int_stack+10181085,int_stack+10357170, 0.0, zero_stack, 1.0, int_stack+3697215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1173080,int_stack+1171925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253790,int_stack+1174620,int_stack+1173080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1242685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7258410,int_stack+7253790,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5926740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7265340,int_stack+1176600,int_stack+1174620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1245765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7271280,int_stack+7265340,int_stack+7253790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5930205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+7271280,int_stack+7258410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5934825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1179075,int_stack+1176600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1249725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7280520,int_stack+7250325,int_stack+7265340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5941755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7280520,int_stack+7271280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6116325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7265725,int_stack+7250325,int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6125565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+10337325,int_stack+7265725,int_stack+1648975, 0.0, zero_stack, 1.0, int_stack+3758775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+10581765,int_stack+10337325,int_stack+634680, 0.0, zero_stack, 1.0, int_stack+3772950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+10649805,int_stack+10581765,int_stack+10181085, 0.0, zero_stack, 1.0, int_stack+3806970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10181085,int_stack+1182541,int_stack+1182100, 0.0, zero_stack, 1.0, int_stack+1747075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10182408,int_stack+1183129,int_stack+1182541, 0.0, zero_stack, 1.0, int_stack+1747516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10184172,int_stack+10182408,int_stack+10181085, 0.0, zero_stack, 1.0, int_stack+5627490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10186818,int_stack+1183885,int_stack+1183129, 0.0, zero_stack, 1.0, int_stack+1748104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10189086,int_stack+10186818,int_stack+10182408, 0.0, zero_stack, 1.0, int_stack+5628813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10192614,int_stack+10189086,int_stack+10184172, 0.0, zero_stack, 1.0, int_stack+5630577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10181085,int_stack+1184830,int_stack+1183885, 0.0, zero_stack, 1.0, int_stack+1748860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10197024,int_stack+10181085,int_stack+10186818, 0.0, zero_stack, 1.0, int_stack+2014068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10181085,int_stack+10197024,int_stack+10189086, 0.0, zero_stack, 1.0, int_stack+5633223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10197024,int_stack+10181085,int_stack+10192614, 0.0, zero_stack, 1.0, int_stack+5636751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10181085,int_stack+1186573,int_stack+1185985, 0.0, zero_stack, 1.0, int_stack+1754845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10182849,int_stack+1187357,int_stack+1186573, 0.0, zero_stack, 1.0, int_stack+1755433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10185201,int_stack+10182849,int_stack+10181085, 0.0, zero_stack, 1.0, int_stack+5647776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10188729,int_stack+1188365,int_stack+1187357, 0.0, zero_stack, 1.0, int_stack+1756217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10191753,int_stack+10188729,int_stack+10182849, 0.0, zero_stack, 1.0, int_stack+5649540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10203639,int_stack+10191753,int_stack+10185201, 0.0, zero_stack, 1.0, int_stack+5651892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10181085,int_stack+1189625,int_stack+1188365, 0.0, zero_stack, 1.0, int_stack+1757225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+10181085,int_stack+10188729, 0.0, zero_stack, 1.0, int_stack+5655420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10181085,int_stack+1917843,int_stack+10191753, 0.0, zero_stack, 1.0, int_stack+5658444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10209519,int_stack+10181085,int_stack+10203639, 0.0, zero_stack, 1.0, int_stack+5663148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+10218339,int_stack+10209519,int_stack+10197024, 0.0, zero_stack, 1.0, int_stack+3980259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10181085,int_stack+1191921,int_stack+1191165, 0.0, zero_stack, 1.0, int_stack+1765205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10183353,int_stack+1192929,int_stack+1191921, 0.0, zero_stack, 1.0, int_stack+1765961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10186377,int_stack+10183353,int_stack+10181085, 0.0, zero_stack, 1.0, int_stack+5697693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10190913,int_stack+1194225,int_stack+1192929, 0.0, zero_stack, 1.0, int_stack+1766969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1917843,int_stack+10190913,int_stack+10183353, 0.0, zero_stack, 1.0, int_stack+5699961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10194801,int_stack+1917843,int_stack+10186377, 0.0, zero_stack, 1.0, int_stack+5702985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10181085,int_stack+1195845,int_stack+1194225, 0.0, zero_stack, 1.0, int_stack+1768265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10238184,int_stack+10181085,int_stack+10190913, 0.0, zero_stack, 1.0, int_stack+5707521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10181085,int_stack+10238184,int_stack+1917843, 0.0, zero_stack, 1.0, int_stack+5711409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10581765,int_stack+10181085,int_stack+10194801, 0.0, zero_stack, 1.0, int_stack+5717457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+10181085,int_stack+10581765,int_stack+10209519, 0.0, zero_stack, 1.0, int_stack+4008126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+10593105,int_stack+10181085,int_stack+10218339, 0.0, zero_stack, 1.0, int_stack+4016946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10207545,int_stack+1198770,int_stack+1197825, 0.0, zero_stack, 1.0, int_stack+1778525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10210380,int_stack+1200030,int_stack+1198770, 0.0, zero_stack, 1.0, int_stack+1779470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10214160,int_stack+10210380,int_stack+10207545, 0.0, zero_stack, 1.0, int_stack+5736357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10219830,int_stack+1201650,int_stack+1200030, 0.0, zero_stack, 1.0, int_stack+1780730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10224690,int_stack+10219830,int_stack+10210380, 0.0, zero_stack, 1.0, int_stack+5739192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+10224690,int_stack+10214160, 0.0, zero_stack, 1.0, int_stack+5742972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10207545,int_stack+1203675,int_stack+1201650, 0.0, zero_stack, 1.0, int_stack+1782350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10232250,int_stack+10207545,int_stack+10219830, 0.0, zero_stack, 1.0, int_stack+5748642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10207545,int_stack+10232250,int_stack+10224690, 0.0, zero_stack, 1.0, int_stack+5909730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+10207545,int_stack+5417115, 0.0, zero_stack, 1.0, int_stack+5917290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+10581765, 0.0, zero_stack, 1.0, int_stack+4064115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+10181085, 0.0, zero_stack, 1.0, int_stack+4180410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+10181085,int_stack+7250325,int_stack+10593105, 0.0, zero_stack, 1.0, int_stack+4206870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10581765,int_stack+1207305,int_stack+1206150, 0.0, zero_stack, 1.0, int_stack+1240375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10585230,int_stack+1208845,int_stack+1207305, 0.0, zero_stack, 1.0, int_stack+1242685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10589850,int_stack+10585230,int_stack+10581765, 0.0, zero_stack, 1.0, int_stack+5926740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10596780,int_stack+1210825,int_stack+1208845, 0.0, zero_stack, 1.0, int_stack+1245765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10602720,int_stack+10596780,int_stack+10585230, 0.0, zero_stack, 1.0, int_stack+5930205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+10602720,int_stack+10589850, 0.0, zero_stack, 1.0, int_stack+5934825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10581765,int_stack+1213300,int_stack+1210825, 0.0, zero_stack, 1.0, int_stack+1249725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10611960,int_stack+10581765,int_stack+10596780, 0.0, zero_stack, 1.0, int_stack+5941755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10581765,int_stack+10611960,int_stack+10602720, 0.0, zero_stack, 1.0, int_stack+6116325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10597165,int_stack+10581765,int_stack+4950390, 0.0, zero_stack, 1.0, int_stack+6125565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+10337325,int_stack+10597165,int_stack+1648975, 0.0, zero_stack, 1.0, int_stack+4263570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+10581765,int_stack+10337325,int_stack+634680, 0.0, zero_stack, 1.0, int_stack+4277745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+10738005,int_stack+10581765,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+4311765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1216766,int_stack+1216325, 1.0, int_stack+1747075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+1217354,int_stack+1216766, 1.0, int_stack+1747516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 1.0, int_stack+5627490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+1218110,int_stack+1217354, 1.0, int_stack+1748104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 1.0, int_stack+5628813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 1.0, int_stack+5630577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1219055,int_stack+1218110, 1.0, int_stack+1748860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 1.0, int_stack+2014068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 1.0, int_stack+5633223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 1.0, int_stack+5636751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1220798,int_stack+1220210, 1.0, int_stack+1754845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+1221582,int_stack+1220798, 1.0, int_stack+1755433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 1.0, int_stack+5647776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+1222590,int_stack+1221582, 1.0, int_stack+1756217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 1.0, int_stack+5649540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 1.0, int_stack+5651892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5647776,int_stack+1223850,int_stack+1222590, 1.0, int_stack+1757225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+5647776,int_stack+7257969, 1.0, int_stack+5655420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5647776,int_stack+1917843,int_stack+7260993, 1.0, int_stack+5658444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7250325,int_stack+5647776,int_stack+7272879, 1.0, int_stack+5663148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+7272879,int_stack+7250325,int_stack+7266264, 0.0, zero_stack, 1.0, int_stack+4495470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7292724,int_stack+1226146,int_stack+1225390, 1.0, int_stack+1765205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7294992,int_stack+1227154,int_stack+1226146, 1.0, int_stack+1765961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7298016,int_stack+7294992,int_stack+7292724, 1.0, int_stack+5697693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5647776,int_stack+1228450,int_stack+1227154, 1.0, int_stack+1766969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1917843,int_stack+5647776,int_stack+7294992, 1.0, int_stack+5699961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5651664,int_stack+1917843,int_stack+7298016, 1.0, int_stack+5702985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5697693,int_stack+1230070,int_stack+1228450, 1.0, int_stack+1768265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7292724,int_stack+5697693,int_stack+5647776, 1.0, int_stack+5707521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5697693,int_stack+7292724,int_stack+1917843, 1.0, int_stack+5711409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7259145,int_stack+5697693,int_stack+5651664, 1.0, int_stack+5717457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+5697693,int_stack+7259145,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+4526557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+10581765,int_stack+5697693,int_stack+7272879, 0.0, zero_stack, 1.0, int_stack+4535377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1232995,int_stack+1232050, 1.0, int_stack+1778525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253160,int_stack+1234255,int_stack+1232995, 1.0, int_stack+1779470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1917843,int_stack+7253160,int_stack+7250325, 1.0, int_stack+5736357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5647776,int_stack+1235875,int_stack+1234255, 1.0, int_stack+1780730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5652636,int_stack+5647776,int_stack+7253160, 1.0, int_stack+5739192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+5652636,int_stack+1917843, 1.0, int_stack+5742972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5736357,int_stack+1237900,int_stack+1235875, 1.0, int_stack+1782350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7270485,int_stack+5736357,int_stack+5647776, 1.0, int_stack+5748642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5736357,int_stack+7270485,int_stack+5652636, 1.0, int_stack+5909730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+5736357,int_stack+5417115, 1.0, int_stack+5917290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+7259145, 0.0, zero_stack, 1.0, int_stack+4580638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+5697693, 0.0, zero_stack, 1.0, int_stack+4685205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+10337325,int_stack+7250325,int_stack+10581765, 0.0, zero_stack, 1.0, int_stack+4711665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10581765,int_stack+1244225,int_stack+1241530, 1.0, int_stack+1240375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10585230,int_stack+1247745,int_stack+1244225, 1.0, int_stack+1242685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10589850,int_stack+10585230,int_stack+10581765, 1.0, int_stack+5926740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10596780,int_stack+1252200,int_stack+1247745, 1.0, int_stack+1245765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10602720,int_stack+10596780,int_stack+10585230, 1.0, int_stack+5930205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+10602720,int_stack+10589850, 1.0, int_stack+5934825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10581765,int_stack+1254675,int_stack+1252200, 1.0, int_stack+1249725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10611960,int_stack+10581765,int_stack+10596780, 1.0, int_stack+5941755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10581765,int_stack+10611960,int_stack+10602720, 1.0, int_stack+6116325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10597165,int_stack+10581765,int_stack+4950390, 1.0, int_stack+6125565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+2392341,int_stack+10597165,int_stack+1648975, 0.0, zero_stack, 1.0, int_stack+4783125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+10581765,int_stack+2392341,int_stack+634680, 0.0, zero_stack, 1.0, int_stack+4797300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+1153800,int_stack+10581765,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+4831320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1258141,int_stack+1257700,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+1258729,int_stack+1258141,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+1259485,int_stack+1258729,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1260430,int_stack+1259485,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1262173,int_stack+1261585,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+1262957,int_stack+1262173,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+1263965,int_stack+1262957,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1265225,int_stack+1263965,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+7250325,int_stack+7257969,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+1917843,int_stack+7260993,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+10581765,int_stack+7278759,int_stack+7266264, 0.0, zero_stack, 1.0, int_stack+2385726, 1.0, int_stack+5641161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1267521,int_stack+1266765,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+1268529,int_stack+1267521,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+1269825,int_stack+1268529,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1917843,int_stack+7260153,int_stack+7252593,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7264041,int_stack+1917843,int_stack+7255617,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1271445,int_stack+1269825,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+1917843,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7264041,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759, 0.0, zero_stack, 1.0, int_stack+2136270, 1.0, int_stack+5669028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+10601610,int_stack+7250325,int_stack+10581765, 0.0, zero_stack, 1.0, int_stack+5331120, 1.0, int_stack+5677848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+10581765,int_stack+1274370,int_stack+1273425,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+10584600,int_stack+1275630,int_stack+1274370,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+10588380,int_stack+10584600,int_stack+10581765,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+10594050,int_stack+1277250,int_stack+1275630,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7276785,int_stack+10594050,int_stack+10584600,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+7276785,int_stack+10588380,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+10581765,int_stack+1279275,int_stack+1277250,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+634680,int_stack+10581765,int_stack+10594050,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+10581765,int_stack+634680,int_stack+7276785,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+10581765,int_stack+5417115,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+7287579, 0.0, zero_stack, 1.0, int_stack+1923891, 1.0, int_stack+5725017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2392341,int_stack+634680,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+5350965, 1.0, int_stack+5843580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+10826205,int_stack+2392341,int_stack+10601610, 0.0, zero_stack, 1.0, int_stack+5377425, 1.0, int_stack+5870040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1282905,int_stack+1281750,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7253790,int_stack+1284445,int_stack+1282905,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7258410,int_stack+7253790,int_stack+7250325,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7265340,int_stack+1286425,int_stack+1284445,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7271280,int_stack+7265340,int_stack+7253790,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+7271280,int_stack+7258410,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1288900,int_stack+1286425,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7280520,int_stack+7250325,int_stack+7265340,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7280520,int_stack+7271280,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7265725,int_stack+7250325,int_stack+4950390,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+10581765,int_stack+7265725,int_stack+1648975, 0.0, zero_stack, 1.0, int_stack+5426565, 1.0, int_stack+5949060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+10892355,int_stack+10581765,int_stack+634680, 0.0, zero_stack, 1.0, int_stack+5440740, 1.0, int_stack+5963235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+10960395,int_stack+10892355,int_stack+2392341, 0.0, zero_stack, 1.0, int_stack+5474760, 1.0, int_stack+5997255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2392341,int_stack+1292366,int_stack+1291925,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2393664,int_stack+1292954,int_stack+1292366,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2395428,int_stack+2393664,int_stack+2392341,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2398074,int_stack+1293710,int_stack+1292954,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2400342,int_stack+2398074,int_stack+2393664,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2403870,int_stack+2400342,int_stack+2395428,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2392341,int_stack+1294655,int_stack+1293710,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2408280,int_stack+2392341,int_stack+2398074,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2392341,int_stack+2408280,int_stack+2400342,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2408280,int_stack+2392341,int_stack+2403870,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2392341,int_stack+1296398,int_stack+1295810,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2394105,int_stack+1297182,int_stack+1296398,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2396457,int_stack+2394105,int_stack+2392341,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2399985,int_stack+1298190,int_stack+1297182,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2403009,int_stack+2399985,int_stack+2394105,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2414895,int_stack+2403009,int_stack+2396457,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2392341,int_stack+1299450,int_stack+1298190,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+2392341,int_stack+2399985,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2392341,int_stack+1917843,int_stack+2403009,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2420775,int_stack+2392341,int_stack+2414895,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2429595,int_stack+2420775,int_stack+2408280, 0.0, zero_stack, 2.0, int_stack+5641161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2392341,int_stack+1301746,int_stack+1300990,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2394609,int_stack+1302754,int_stack+1301746,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2397633,int_stack+2394609,int_stack+2392341,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2402169,int_stack+1304050,int_stack+1302754,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1917843,int_stack+2402169,int_stack+2394609,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2406057,int_stack+1917843,int_stack+2397633,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2392341,int_stack+1305670,int_stack+1304050,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+10892355,int_stack+2392341,int_stack+2402169,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2392341,int_stack+10892355,int_stack+1917843,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+10892355,int_stack+2392341,int_stack+2406057,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2392341,int_stack+10892355,int_stack+2420775, 0.0, zero_stack, 2.0, int_stack+5669028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+10903695,int_stack+2392341,int_stack+2429595, 0.0, zero_stack, 2.0, int_stack+5677848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2418801,int_stack+1308595,int_stack+1307650,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2421636,int_stack+1309855,int_stack+1308595,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2425416,int_stack+2421636,int_stack+2418801,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2431086,int_stack+1311475,int_stack+1309855,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2435946,int_stack+2431086,int_stack+2421636,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+2435946,int_stack+2425416,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2418801,int_stack+1313500,int_stack+1311475,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2443506,int_stack+2418801,int_stack+2431086,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2418801,int_stack+2443506,int_stack+2435946,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+2418801,int_stack+5417115,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+10892355, 0.0, zero_stack, 2.0, int_stack+5725017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+2392341, 0.0, zero_stack, 2.0, int_stack+5843580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+10581765,int_stack+7250325,int_stack+10903695, 0.0, zero_stack, 2.0, int_stack+5870040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2392341,int_stack+1317130,int_stack+1315975,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2395806,int_stack+1318670,int_stack+1317130,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2400426,int_stack+2395806,int_stack+2392341,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2407356,int_stack+1320650,int_stack+1318670,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2413296,int_stack+2407356,int_stack+2395806,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+2413296,int_stack+2400426,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2392341,int_stack+1323125,int_stack+1320650,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2422536,int_stack+2392341,int_stack+2407356,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2392341,int_stack+2422536,int_stack+2413296,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2407741,int_stack+2392341,int_stack+4950390,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+10892355,int_stack+2407741,int_stack+1648975, 0.0, zero_stack, 2.0, int_stack+5949060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+1242000,int_stack+10892355,int_stack+634680, 0.0, zero_stack, 2.0, int_stack+5963235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+11048595,int_stack+1242000,int_stack+7250325, 0.0, zero_stack, 2.0, int_stack+5997255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1330476,int_stack+1330035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1809235,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+1331064,int_stack+1330476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1809676,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6137115,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+1331820,int_stack+1331064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1810264,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6138438,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6140202,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1332765,int_stack+1331820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1811020,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6142848,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6145116,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6148644,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1339688,int_stack+1339100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1822185,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+1340472,int_stack+1339688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1822773,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6159669,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+1341480,int_stack+1340472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1823557,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6161433,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6163785,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1342740,int_stack+1341480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1824565,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1917843,int_stack+7250325,int_stack+7257969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6167313,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+1917843,int_stack+7260993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6170337,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6175041,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1242000,int_stack+7278759,int_stack+7266264, 1.0, int_stack+1911228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1351696,int_stack+1350940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1839205,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+1352704,int_stack+1351696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1839961,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4961940,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+1354000,int_stack+1352704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1840969,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7264041,int_stack+7260153,int_stack+7252593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4964208,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7270089,int_stack+7264041,int_stack+7255617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6209586,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1355620,int_stack+1354000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1842265,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6214122,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+7264041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6218010,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7270089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6224058,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759, 1.0, int_stack+1960347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1261845,int_stack+7250325,int_stack+1242000, 1.0, int_stack+1969167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1242000,int_stack+1366870,int_stack+1365925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1852525,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1244835,int_stack+1368130,int_stack+1366870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1853470,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1248615,int_stack+1244835,int_stack+1242000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6242958,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1254285,int_stack+1369750,int_stack+1368130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1854730,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7276785,int_stack+1254285,int_stack+1244835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6245793,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+7276785,int_stack+1248615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6249573,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1242000,int_stack+1371775,int_stack+1369750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1856350,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1301535,int_stack+1242000,int_stack+1254285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6255243,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1242000,int_stack+1301535,int_stack+7276785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4967232,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+1242000,int_stack+5417115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4974792,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+7287579, 1.0, int_stack+2043660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1301535,int_stack+634680,int_stack+7250325, 1.0, int_stack+2055000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+10892355,int_stack+1301535,int_stack+1261845, 1.0, int_stack+2081460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1375405,int_stack+1374250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1671475,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7253790,int_stack+1376945,int_stack+1375405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1673785,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7258410,int_stack+7253790,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4984242,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7265340,int_stack+1378925,int_stack+1376945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1676865,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7271280,int_stack+7265340,int_stack+7253790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4987707,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+7271280,int_stack+7258410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4992327,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1381400,int_stack+1378925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1680825,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7280520,int_stack+7250325,int_stack+7265340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4999257,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7280520,int_stack+7271280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5005197,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7265725,int_stack+7250325,int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5014437,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+1242000,int_stack+7265725,int_stack+1648975, 1.0, int_stack+2189460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+1935231,int_stack+1242000,int_stack+634680, 1.0, int_stack+2203635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+2145090,int_stack+1935231,int_stack+1301535, 1.0, int_stack+2237655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1935231,int_stack+1388751,int_stack+1388310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1809235, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1936554,int_stack+1389339,int_stack+1388751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1809676, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1938318,int_stack+1936554,int_stack+1935231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6137115, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1940964,int_stack+1390095,int_stack+1389339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1810264, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1943232,int_stack+1940964,int_stack+1936554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6138438, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1946760,int_stack+1943232,int_stack+1938318, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6140202, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1935231,int_stack+1391040,int_stack+1390095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1811020, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1951170,int_stack+1935231,int_stack+1940964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6142848, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1935231,int_stack+1951170,int_stack+1943232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6145116, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1951170,int_stack+1935231,int_stack+1946760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6148644, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1935231,int_stack+1397963,int_stack+1397375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1822185, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1936995,int_stack+1398747,int_stack+1397963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1822773, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1939347,int_stack+1936995,int_stack+1935231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6159669, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1942875,int_stack+1399755,int_stack+1398747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1823557, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1945899,int_stack+1942875,int_stack+1936995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6161433, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1957785,int_stack+1945899,int_stack+1939347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6163785, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1935231,int_stack+1401015,int_stack+1399755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1824565, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1963665,int_stack+1935231,int_stack+1942875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6167313, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1935231,int_stack+1963665,int_stack+1945899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6170337, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1963665,int_stack+1935231,int_stack+1957785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6175041, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1972485,int_stack+1963665,int_stack+1951170, 1.0, int_stack+2456154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1935231,int_stack+1409971,int_stack+1409215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1839205, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1937499,int_stack+1410979,int_stack+1409971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1839961, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1940523,int_stack+1937499,int_stack+1935231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4961940, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1945059,int_stack+1412275,int_stack+1410979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1840969, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1948947,int_stack+1945059,int_stack+1937499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4964208, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1954995,int_stack+1948947,int_stack+1940523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6209586, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1935231,int_stack+1413895,int_stack+1412275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1842265, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1992330,int_stack+1935231,int_stack+1945059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6214122, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1935231,int_stack+1992330,int_stack+1948947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6218010, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1992330,int_stack+1935231,int_stack+1954995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6224058, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1935231,int_stack+1992330,int_stack+1963665, 1.0, int_stack+2484021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2003670,int_stack+1935231,int_stack+1972485, 1.0, int_stack+2492841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1961691,int_stack+1425145,int_stack+1424200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1852525, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1964526,int_stack+1426405,int_stack+1425145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1853470, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1968306,int_stack+1964526,int_stack+1961691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6242958, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1973976,int_stack+1428025,int_stack+1426405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1854730, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1978836,int_stack+1973976,int_stack+1964526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6245793, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+1978836,int_stack+1968306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6249573, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1961691,int_stack+1430050,int_stack+1428025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1856350, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2043360,int_stack+1961691,int_stack+1973976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6255243, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1961691,int_stack+2043360,int_stack+1978836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4967232, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+1961691,int_stack+5417115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4974792, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+1992330, 1.0, int_stack+2540010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+1935231, 1.0, int_stack+2656305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1935231,int_stack+7250325,int_stack+2003670, 1.0, int_stack+2682765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2656305,int_stack+1433680,int_stack+1432525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1671475, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2659770,int_stack+1435220,int_stack+1433680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1673785, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2664390,int_stack+2659770,int_stack+2656305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4984242, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2671320,int_stack+1437200,int_stack+1435220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1676865, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2677260,int_stack+2671320,int_stack+2659770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4987707, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+2677260,int_stack+2664390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4992327, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2656305,int_stack+1439675,int_stack+1437200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1680825, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2686500,int_stack+2656305,int_stack+2671320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4999257, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2656305,int_stack+2686500,int_stack+2677260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5005197, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2671705,int_stack+2656305,int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5014437, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+2689030,int_stack+2671705,int_stack+1648975, 1.0, int_stack+2744325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+2001381,int_stack+2689030,int_stack+634680, 1.0, int_stack+2758500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+2656305,int_stack+2001381,int_stack+7250325, 1.0, int_stack+2792520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1447026,int_stack+1446585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1809235, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+1447614,int_stack+1447026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1809676, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6137115, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+1448370,int_stack+1447614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1810264, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6138438, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6140202, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1449315,int_stack+1448370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1811020, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6142848, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6145116, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6148644, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1456238,int_stack+1455650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1822185, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+1457022,int_stack+1456238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1822773, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6159669, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+1458030,int_stack+1457022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1823557, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6161433, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6163785, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1459290,int_stack+1458030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1824565, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7257969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6167313, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7260993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6170337, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6175041, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2001381,int_stack+7278759,int_stack+7266264, 1.0, int_stack+2965809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1468246,int_stack+1467490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1839205, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+1469254,int_stack+1468246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1839961, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4961940, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+1470550,int_stack+1469254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1840969, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7264041,int_stack+7260153,int_stack+7252593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4964208, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7270089,int_stack+7264041,int_stack+7255617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6209586, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1472170,int_stack+1470550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1842265, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6214122, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+7264041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6218010, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7270089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6224058, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759, 1.0, int_stack+2993676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2021226,int_stack+7250325,int_stack+2001381, 1.0, int_stack+3002496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2001381,int_stack+1483420,int_stack+1482475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1852525, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2004216,int_stack+1484680,int_stack+1483420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1853470, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2007996,int_stack+2004216,int_stack+2001381, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6242958, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2013666,int_stack+1486300,int_stack+1484680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1854730, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7276785,int_stack+2013666,int_stack+2004216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6245793, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+7276785,int_stack+2007996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6249573, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2001381,int_stack+1488325,int_stack+1486300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1856350, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2060916,int_stack+2001381,int_stack+2013666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6255243, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2001381,int_stack+2060916,int_stack+7276785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4967232, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+2001381,int_stack+5417115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4974792, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+7287579, 1.0, int_stack+3049665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2060916,int_stack+634680,int_stack+7250325, 1.0, int_stack+3165960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2744505,int_stack+2060916,int_stack+2021226, 1.0, int_stack+3192420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3165960,int_stack+1491955,int_stack+1490800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1671475, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3169425,int_stack+1493495,int_stack+1491955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1673785, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3174045,int_stack+3169425,int_stack+3165960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4984242, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3180975,int_stack+1495475,int_stack+1493495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1676865, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3186915,int_stack+3180975,int_stack+3169425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4987707, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+3186915,int_stack+3174045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4992327, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3165960,int_stack+1497950,int_stack+1495475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1680825, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3196155,int_stack+3165960,int_stack+3180975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4999257, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3165960,int_stack+3196155,int_stack+3186915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5005197, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3181360,int_stack+3165960,int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5014437, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+3198685,int_stack+3181360,int_stack+1648975, 1.0, int_stack+3249120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+1242000,int_stack+3198685,int_stack+634680, 1.0, int_stack+3263295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+3165960,int_stack+1242000,int_stack+2060916, 1.0, int_stack+3297315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1242000,int_stack+1505301,int_stack+1504860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1809235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1243323,int_stack+1505889,int_stack+1505301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1809676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1245087,int_stack+1243323,int_stack+1242000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6137115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1247733,int_stack+1506645,int_stack+1505889, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1810264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1250001,int_stack+1247733,int_stack+1243323, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6138438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1253529,int_stack+1250001,int_stack+1245087, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6140202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1242000,int_stack+1507590,int_stack+1506645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1811020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1257939,int_stack+1242000,int_stack+1247733, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6142848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1242000,int_stack+1257939,int_stack+1250001, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6145116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1257939,int_stack+1242000,int_stack+1253529, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6148644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1242000,int_stack+1514513,int_stack+1513925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1822185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1243764,int_stack+1515297,int_stack+1514513, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1822773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1246116,int_stack+1243764,int_stack+1242000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6159669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1249644,int_stack+1516305,int_stack+1515297, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1823557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1252668,int_stack+1249644,int_stack+1243764, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6161433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1264554,int_stack+1252668,int_stack+1246116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6163785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1242000,int_stack+1517565,int_stack+1516305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1824565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1270434,int_stack+1242000,int_stack+1249644, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6167313, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1242000,int_stack+1270434,int_stack+1252668, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6170337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1270434,int_stack+1242000,int_stack+1264554, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6175041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1279254,int_stack+1270434,int_stack+1257939, 1.0, int_stack+3470604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1242000,int_stack+1526521,int_stack+1525765, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1839205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1244268,int_stack+1527529,int_stack+1526521, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1839961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1247292,int_stack+1244268,int_stack+1242000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4961940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1251828,int_stack+1528825,int_stack+1527529, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1840969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1255716,int_stack+1251828,int_stack+1244268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4964208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1261764,int_stack+1255716,int_stack+1247292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6209586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1242000,int_stack+1530445,int_stack+1528825, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1842265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1299099,int_stack+1242000,int_stack+1251828, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6214122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1242000,int_stack+1299099,int_stack+1255716, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6218010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1299099,int_stack+1242000,int_stack+1261764, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6224058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1242000,int_stack+1299099,int_stack+1270434, 1.0, int_stack+3498471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1310439,int_stack+1242000,int_stack+1279254, 1.0, int_stack+3507291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1268460,int_stack+1541695,int_stack+1540750, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1852525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271295,int_stack+1542955,int_stack+1541695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1853470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1275075,int_stack+1271295,int_stack+1268460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6242958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1280745,int_stack+1544575,int_stack+1542955, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1854730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1285605,int_stack+1280745,int_stack+1271295, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6245793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+1285605,int_stack+1275075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6249573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1268460,int_stack+1546600,int_stack+1544575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1856350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1350129,int_stack+1268460,int_stack+1280745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6255243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1268460,int_stack+1350129,int_stack+1285605, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4967232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+1268460,int_stack+5417115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4974792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+1299099, 1.0, int_stack+3554460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+1242000, 1.0, int_stack+3670755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1242000,int_stack+7250325,int_stack+1310439, 1.0, int_stack+3697215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3670755,int_stack+1550230,int_stack+1549075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1671475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3674220,int_stack+1551770,int_stack+1550230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1673785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3678840,int_stack+3674220,int_stack+3670755, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4984242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3685770,int_stack+1553750,int_stack+1551770, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1676865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3691710,int_stack+3685770,int_stack+3674220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4987707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+3691710,int_stack+3678840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4992327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3670755,int_stack+1556225,int_stack+1553750, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1680825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3700950,int_stack+3670755,int_stack+3685770, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4999257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3670755,int_stack+3700950,int_stack+3691710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5005197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3686155,int_stack+3670755,int_stack+4950390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5014437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+3703480,int_stack+3686155,int_stack+1648975, 1.0, int_stack+3758775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+1308150,int_stack+3703480,int_stack+634680, 1.0, int_stack+3772950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+3670755,int_stack+1308150,int_stack+7250325, 1.0, int_stack+3806970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1563576,int_stack+1563135, 0.0, zero_stack, 1.0, int_stack+1809235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+1564164,int_stack+1563576, 0.0, zero_stack, 1.0, int_stack+1809676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+6137115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+1564920,int_stack+1564164, 0.0, zero_stack, 1.0, int_stack+1810264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648, 0.0, zero_stack, 1.0, int_stack+6138438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412, 0.0, zero_stack, 1.0, int_stack+6140202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1565865,int_stack+1564920, 0.0, zero_stack, 1.0, int_stack+1811020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058, 0.0, zero_stack, 1.0, int_stack+6142848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326, 0.0, zero_stack, 1.0, int_stack+6145116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854, 0.0, zero_stack, 1.0, int_stack+6148644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1572788,int_stack+1572200, 0.0, zero_stack, 1.0, int_stack+1822185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+1573572,int_stack+1572788, 0.0, zero_stack, 1.0, int_stack+1822773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+6159669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+1574580,int_stack+1573572, 0.0, zero_stack, 1.0, int_stack+1823557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089, 0.0, zero_stack, 1.0, int_stack+6161433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441, 0.0, zero_stack, 1.0, int_stack+6163785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1575840,int_stack+1574580, 0.0, zero_stack, 1.0, int_stack+1824565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7257969, 0.0, zero_stack, 1.0, int_stack+6167313, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7260993, 0.0, zero_stack, 1.0, int_stack+6170337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879, 0.0, zero_stack, 1.0, int_stack+6175041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1308150,int_stack+7278759,int_stack+7266264, 1.0, int_stack+3980259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1584796,int_stack+1584040, 0.0, zero_stack, 1.0, int_stack+1839205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+1585804,int_stack+1584796, 0.0, zero_stack, 1.0, int_stack+1839961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325, 0.0, zero_stack, 1.0, int_stack+4961940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+1587100,int_stack+1585804, 0.0, zero_stack, 1.0, int_stack+1840969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7264041,int_stack+7260153,int_stack+7252593, 0.0, zero_stack, 1.0, int_stack+4964208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7270089,int_stack+7264041,int_stack+7255617, 0.0, zero_stack, 1.0, int_stack+6209586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1588720,int_stack+1587100, 0.0, zero_stack, 1.0, int_stack+1842265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153, 0.0, zero_stack, 1.0, int_stack+6214122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+7264041, 0.0, zero_stack, 1.0, int_stack+6218010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7270089, 0.0, zero_stack, 1.0, int_stack+6224058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759, 1.0, int_stack+4008126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1327995,int_stack+7250325,int_stack+1308150, 1.0, int_stack+4016946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1308150,int_stack+1599970,int_stack+1599025, 0.0, zero_stack, 1.0, int_stack+1852525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1310985,int_stack+1601230,int_stack+1599970, 0.0, zero_stack, 1.0, int_stack+1853470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1314765,int_stack+1310985,int_stack+1308150, 0.0, zero_stack, 1.0, int_stack+6242958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1320435,int_stack+1602850,int_stack+1601230, 0.0, zero_stack, 1.0, int_stack+1854730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7276785,int_stack+1320435,int_stack+1310985, 0.0, zero_stack, 1.0, int_stack+6245793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+7276785,int_stack+1314765, 0.0, zero_stack, 1.0, int_stack+6249573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1308150,int_stack+1604875,int_stack+1602850, 0.0, zero_stack, 1.0, int_stack+1856350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1367685,int_stack+1308150,int_stack+1320435, 0.0, zero_stack, 1.0, int_stack+6255243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1308150,int_stack+1367685,int_stack+7276785, 0.0, zero_stack, 1.0, int_stack+4967232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1648975,int_stack+1308150,int_stack+5417115, 0.0, zero_stack, 1.0, int_stack+4974792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1648975,int_stack+7287579, 1.0, int_stack+4064115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1367685,int_stack+634680,int_stack+7250325, 1.0, int_stack+4180410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1420605,int_stack+1367685,int_stack+1327995, 1.0, int_stack+4206870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4180410,int_stack+1608505,int_stack+1607350, 0.0, zero_stack, 1.0, int_stack+1671475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4183875,int_stack+1610045,int_stack+1608505, 0.0, zero_stack, 1.0, int_stack+1673785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4188495,int_stack+4183875,int_stack+4180410, 0.0, zero_stack, 1.0, int_stack+4984242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4195425,int_stack+1612025,int_stack+1610045, 0.0, zero_stack, 1.0, int_stack+1676865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4201365,int_stack+4195425,int_stack+4183875, 0.0, zero_stack, 1.0, int_stack+4987707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4950390,int_stack+4201365,int_stack+4188495, 0.0, zero_stack, 1.0, int_stack+4992327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4180410,int_stack+1614500,int_stack+1612025, 0.0, zero_stack, 1.0, int_stack+1680825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4210605,int_stack+4180410,int_stack+4195425, 0.0, zero_stack, 1.0, int_stack+4999257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4180410,int_stack+4210605,int_stack+4201365, 0.0, zero_stack, 1.0, int_stack+5005197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4195810,int_stack+4180410,int_stack+4950390, 0.0, zero_stack, 1.0, int_stack+5014437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4213135,int_stack+4195810,int_stack+1648975, 1.0, int_stack+4263570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+1486755,int_stack+4213135,int_stack+634680, 1.0, int_stack+4277745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+4180410,int_stack+1486755,int_stack+1367685, 1.0, int_stack+4311765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1486755,int_stack+1621851,int_stack+1621410, 1.0, int_stack+1809235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1488078,int_stack+1622439,int_stack+1621851, 1.0, int_stack+1809676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1489842,int_stack+1488078,int_stack+1486755, 1.0, int_stack+6137115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1492488,int_stack+1623195,int_stack+1622439, 1.0, int_stack+1810264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1494756,int_stack+1492488,int_stack+1488078, 1.0, int_stack+6138438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1498284,int_stack+1494756,int_stack+1489842, 1.0, int_stack+6140202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1486755,int_stack+1624140,int_stack+1623195, 1.0, int_stack+1811020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1502694,int_stack+1486755,int_stack+1492488, 1.0, int_stack+6142848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1486755,int_stack+1502694,int_stack+1494756, 1.0, int_stack+6145116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1502694,int_stack+1486755,int_stack+1498284, 1.0, int_stack+6148644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1486755,int_stack+1631063,int_stack+1630475, 1.0, int_stack+1822185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1488519,int_stack+1631847,int_stack+1631063, 1.0, int_stack+1822773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1490871,int_stack+1488519,int_stack+1486755, 1.0, int_stack+6159669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1494399,int_stack+1632855,int_stack+1631847, 1.0, int_stack+1823557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1497423,int_stack+1494399,int_stack+1488519, 1.0, int_stack+6161433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1509309,int_stack+1497423,int_stack+1490871, 1.0, int_stack+6163785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6159669,int_stack+1634115,int_stack+1632855, 1.0, int_stack+1824565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1486755,int_stack+6159669,int_stack+1494399, 1.0, int_stack+6167313, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6159669,int_stack+1486755,int_stack+1497423, 1.0, int_stack+6170337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1486755,int_stack+6159669,int_stack+1509309, 1.0, int_stack+6175041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1509309,int_stack+1486755,int_stack+1502694, 1.0, int_stack+4495470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1529154,int_stack+1643071,int_stack+1642315, 1.0, int_stack+1839205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1531422,int_stack+1644079,int_stack+1643071, 1.0, int_stack+1839961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1534446,int_stack+1531422,int_stack+1529154, 1.0, int_stack+4961940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1538982,int_stack+1645375,int_stack+1644079, 1.0, int_stack+1840969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1542870,int_stack+1538982,int_stack+1531422, 1.0, int_stack+4964208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1548918,int_stack+1542870,int_stack+1534446, 1.0, int_stack+6209586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1529154,int_stack+1646995,int_stack+1645375, 1.0, int_stack+1842265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1556478,int_stack+1529154,int_stack+1538982, 1.0, int_stack+6214122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1529154,int_stack+1556478,int_stack+1542870, 1.0, int_stack+6218010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1556478,int_stack+1529154,int_stack+1548918, 1.0, int_stack+6224058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1529154,int_stack+1556478,int_stack+1486755, 1.0, int_stack+4526557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1567818,int_stack+1529154,int_stack+1509309, 1.0, int_stack+4535377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1486755,int_stack+1664095,int_stack+1663150, 1.0, int_stack+1852525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1489590,int_stack+1665355,int_stack+1664095, 1.0, int_stack+1853470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1493370,int_stack+1489590,int_stack+1486755, 1.0, int_stack+6242958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1499040,int_stack+1666975,int_stack+1665355, 1.0, int_stack+1854730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1503900,int_stack+1499040,int_stack+1489590, 1.0, int_stack+6245793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+1503900,int_stack+1493370, 1.0, int_stack+6249573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6242958,int_stack+1669000,int_stack+1666975, 1.0, int_stack+1856350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1486755,int_stack+6242958,int_stack+1499040, 1.0, int_stack+6255243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6242958,int_stack+1486755,int_stack+1503900, 1.0, int_stack+4967232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1486755,int_stack+6242958,int_stack+5417115, 1.0, int_stack+4974792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1486755,int_stack+1556478, 1.0, int_stack+4580638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+1529154, 1.0, int_stack+4685205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1500930,int_stack+7250325,int_stack+1567818, 1.0, int_stack+4711665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4685205,int_stack+1675325,int_stack+1672630, 1.0, int_stack+1671475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4688670,int_stack+1678845,int_stack+1675325, 1.0, int_stack+1673785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4693290,int_stack+4688670,int_stack+4685205, 1.0, int_stack+4984242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4700220,int_stack+1683300,int_stack+1678845, 1.0, int_stack+1676865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4706160,int_stack+4700220,int_stack+4688670, 1.0, int_stack+4987707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4715400,int_stack+4706160,int_stack+4693290, 1.0, int_stack+4992327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4685205,int_stack+1685775,int_stack+1683300, 1.0, int_stack+1680825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4726950,int_stack+4685205,int_stack+4700220, 1.0, int_stack+4999257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4685205,int_stack+4726950,int_stack+4706160, 1.0, int_stack+5005197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4726950,int_stack+4685205,int_stack+4715400, 1.0, int_stack+5014437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+1567080,int_stack+4726950,int_stack+1486755, 1.0, int_stack+4783125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+4685205,int_stack+1567080,int_stack+634680, 1.0, int_stack+4797300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+1567080,int_stack+4685205,int_stack+7250325, 1.0, int_stack+4831320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1693126,int_stack+1692685,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+1693714,int_stack+1693126,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+1694470,int_stack+1693714,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1695415,int_stack+1694470,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1702338,int_stack+1701750,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+1703122,int_stack+1702338,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+1704130,int_stack+1703122,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1705390,int_stack+1704130,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7257969,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7260993,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+4685205,int_stack+7278759,int_stack+7266264, 1.0, int_stack+2385726, 0.0, zero_stack, 1.0, int_stack+6153054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1714346,int_stack+1713590,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+1715354,int_stack+1714346,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+1716650,int_stack+1715354,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7264041,int_stack+7260153,int_stack+7252593,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7270089,int_stack+7264041,int_stack+7255617,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1718270,int_stack+1716650,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+7264041,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7270089,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759, 1.0, int_stack+2136270, 0.0, zero_stack, 1.0, int_stack+6180921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+4705050,int_stack+7250325,int_stack+4685205, 1.0, int_stack+5331120, 0.0, zero_stack, 1.0, int_stack+6189741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5331120,int_stack+1729520,int_stack+1728575,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5333955,int_stack+1730780,int_stack+1729520,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5337735,int_stack+5333955,int_stack+5331120,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5343405,int_stack+1732400,int_stack+1730780,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4685205,int_stack+5343405,int_stack+5333955,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5417115,int_stack+4685205,int_stack+5337735,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5331120,int_stack+1734425,int_stack+1732400,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4692765,int_stack+5331120,int_stack+5343405,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5331120,int_stack+4692765,int_stack+4685205,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1486755,int_stack+5331120,int_stack+5417115,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1486755,int_stack+7287579, 1.0, int_stack+1923891, 0.0, zero_stack, 1.0, int_stack+6231618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4744740,int_stack+634680,int_stack+7250325, 1.0, int_stack+5350965, 0.0, zero_stack, 1.0, int_stack+6353205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4797660,int_stack+4744740,int_stack+4705050, 1.0, int_stack+5377425, 0.0, zero_stack, 1.0, int_stack+6379665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1738055,int_stack+1736900,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7253790,int_stack+1739595,int_stack+1738055,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7258410,int_stack+7253790,int_stack+7250325,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7265340,int_stack+1741575,int_stack+1739595,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7271280,int_stack+7265340,int_stack+7253790,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7280520,int_stack+7271280,int_stack+7258410,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1744050,int_stack+1741575,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5331120,int_stack+7250325,int_stack+7265340,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+5331120,int_stack+7271280,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5331120,int_stack+7250325,int_stack+7280520,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+7250325,int_stack+5331120,int_stack+1486755, 1.0, int_stack+5426565, 0.0, zero_stack, 1.0, int_stack+6419355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+5331120,int_stack+7250325,int_stack+634680, 1.0, int_stack+5440740, 0.0, zero_stack, 1.0, int_stack+6433530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+1655280,int_stack+5331120,int_stack+4744740, 1.0, int_stack+5474760, 0.0, zero_stack, 1.0, int_stack+6467550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5331120,int_stack+1751401,int_stack+1750960,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5332443,int_stack+1751989,int_stack+1751401,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5334207,int_stack+5332443,int_stack+5331120,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5336853,int_stack+1752745,int_stack+1751989,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5339121,int_stack+5336853,int_stack+5332443,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5342649,int_stack+5339121,int_stack+5334207,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5331120,int_stack+1753690,int_stack+1752745,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5347059,int_stack+5331120,int_stack+5336853,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5331120,int_stack+5347059,int_stack+5339121,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5347059,int_stack+5331120,int_stack+5342649,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5331120,int_stack+1760613,int_stack+1760025,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5332884,int_stack+1761397,int_stack+1760613,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5335236,int_stack+5332884,int_stack+5331120,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5338764,int_stack+1762405,int_stack+1761397,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5341788,int_stack+5338764,int_stack+5332884,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5353674,int_stack+5341788,int_stack+5335236,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5331120,int_stack+1763665,int_stack+1762405,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5359554,int_stack+5331120,int_stack+5338764,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5331120,int_stack+5359554,int_stack+5341788,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5359554,int_stack+5331120,int_stack+5353674,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+5368374,int_stack+5359554,int_stack+5347059, 1.0, int_stack+5641161, 1.0, int_stack+6153054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5331120,int_stack+1772621,int_stack+1771865,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5333388,int_stack+1773629,int_stack+1772621,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5336412,int_stack+5333388,int_stack+5331120,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5340948,int_stack+1774925,int_stack+1773629,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5344836,int_stack+5340948,int_stack+5333388,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5350884,int_stack+5344836,int_stack+5336412,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5331120,int_stack+1776545,int_stack+1774925,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5388219,int_stack+5331120,int_stack+5340948,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5331120,int_stack+5388219,int_stack+5344836,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5388219,int_stack+5331120,int_stack+5350884,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+5331120,int_stack+5388219,int_stack+5359554, 1.0, int_stack+5669028, 1.0, int_stack+6180921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+5399559,int_stack+5331120,int_stack+5368374, 1.0, int_stack+5677848, 1.0, int_stack+6189741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5357580,int_stack+1787795,int_stack+1786850,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5360415,int_stack+1789055,int_stack+1787795,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5364195,int_stack+5360415,int_stack+5357580,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5369865,int_stack+1790675,int_stack+1789055,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5374725,int_stack+5369865,int_stack+5360415,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5439249,int_stack+5374725,int_stack+5364195,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5357580,int_stack+1792700,int_stack+1790675,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5448699,int_stack+5357580,int_stack+5369865,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5357580,int_stack+5448699,int_stack+5374725,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1486755,int_stack+5357580,int_stack+5439249,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1486755,int_stack+5388219, 1.0, int_stack+5725017, 1.0, int_stack+6231618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7250325,int_stack+634680,int_stack+5331120, 1.0, int_stack+5843580, 1.0, int_stack+6353205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5331120,int_stack+7250325,int_stack+5399559, 1.0, int_stack+5870040, 1.0, int_stack+6379665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5843580,int_stack+1796330,int_stack+1795175,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5847045,int_stack+1797870,int_stack+1796330,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5851665,int_stack+5847045,int_stack+5843580,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5858595,int_stack+1799850,int_stack+1797870,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5864535,int_stack+5858595,int_stack+5847045,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5873775,int_stack+5864535,int_stack+5851665,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5843580,int_stack+1802325,int_stack+1799850,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5885325,int_stack+5843580,int_stack+5858595,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5843580,int_stack+5885325,int_stack+5864535,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5885325,int_stack+5843580,int_stack+5873775,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+5902650,int_stack+5885325,int_stack+1486755, 1.0, int_stack+5949060, 1.0, int_stack+6419355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+5397270,int_stack+5902650,int_stack+634680, 1.0, int_stack+5963235, 1.0, int_stack+6433530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+5843580,int_stack+5397270,int_stack+7250325, 1.0, int_stack+5997255, 1.0, int_stack+6467550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1813561,int_stack+1813120,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7251648,int_stack+1814149,int_stack+1813561,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7253412,int_stack+7251648,int_stack+7250325,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7256058,int_stack+1814905,int_stack+1814149,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7258326,int_stack+7256058,int_stack+7251648,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7261854,int_stack+7258326,int_stack+7253412,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1815850,int_stack+1814905,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7256058,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7266264,int_stack+7258326,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7266264,int_stack+7250325,int_stack+7261854,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1827953,int_stack+1827365,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7252089,int_stack+1828737,int_stack+1827953,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7254441,int_stack+7252089,int_stack+7250325,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7257969,int_stack+1829745,int_stack+1828737,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7260993,int_stack+7257969,int_stack+7252089,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7272879,int_stack+7260993,int_stack+7254441,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1831005,int_stack+1829745,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7257969,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7278759,int_stack+7260993,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7278759,int_stack+7250325,int_stack+7272879,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+5397270,int_stack+7278759,int_stack+7266264, 2.0, int_stack+6153054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7250325,int_stack+1846621,int_stack+1845865,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7252593,int_stack+1847629,int_stack+1846621,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7255617,int_stack+7252593,int_stack+7250325,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7260153,int_stack+1848925,int_stack+1847629,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7264041,int_stack+7260153,int_stack+7252593,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7270089,int_stack+7264041,int_stack+7255617,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7250325,int_stack+1850545,int_stack+1848925,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7260153,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7250325,int_stack+7287579,int_stack+7264041,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7287579,int_stack+7250325,int_stack+7270089,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+7250325,int_stack+7287579,int_stack+7278759, 2.0, int_stack+6180921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+5417115,int_stack+7250325,int_stack+5397270, 2.0, int_stack+6189741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5397270,int_stack+1861795,int_stack+1860850,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5400105,int_stack+1863055,int_stack+1861795,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5403885,int_stack+5400105,int_stack+5397270,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5409555,int_stack+1864675,int_stack+1863055,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7276785,int_stack+5409555,int_stack+5400105,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5456805,int_stack+7276785,int_stack+5403885,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5397270,int_stack+1866700,int_stack+1864675,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5466255,int_stack+5397270,int_stack+5409555,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5397270,int_stack+5466255,int_stack+7276785,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1486755,int_stack+5397270,int_stack+5456805,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+634680,int_stack+1486755,int_stack+7287579, 2.0, int_stack+6231618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5456805,int_stack+634680,int_stack+7250325, 2.0, int_stack+6353205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5931780,int_stack+5456805,int_stack+5417115, 2.0, int_stack+6379665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6353205,int_stack+1870330,int_stack+1869175,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6356670,int_stack+1871870,int_stack+1870330,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6361290,int_stack+6356670,int_stack+6353205,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6368220,int_stack+1873850,int_stack+1871870,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6374160,int_stack+6368220,int_stack+6356670,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6383400,int_stack+6374160,int_stack+6361290,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6353205,int_stack+1876325,int_stack+1873850,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6394950,int_stack+6353205,int_stack+6368220,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6353205,int_stack+6394950,int_stack+6374160,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6394950,int_stack+6353205,int_stack+6383400,55);
 /*--- compute (lp|hg) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+7250325,int_stack+6394950,int_stack+1486755, 2.0, int_stack+6419355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (kd|hg) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+6353205,int_stack+7250325,int_stack+634680, 2.0, int_stack+6433530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (if|hg) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+4685205,int_stack+6353205,int_stack+5456805, 2.0, int_stack+6467550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+6353205,int_stack+2568105,int_stack+2290575,315);
     Libderiv->ABCD[11] = int_stack + 6353205;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+5397270,int_stack+3077760,int_stack+2845440,315);
     Libderiv->ABCD[10] = int_stack + 5397270;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+1743480,int_stack+3582555,int_stack+3350235,315);
     Libderiv->ABCD[9] = int_stack + 1743480;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+4950390,int_stack+4092210,int_stack+3859890,315);
     Libderiv->ABCD[8] = int_stack + 4950390;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+1308150,int_stack+4597005,int_stack+4364685,315);
     Libderiv->ABCD[7] = int_stack + 1308150;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+3758955,int_stack+5089830,int_stack+4884240,315);
     Libderiv->ABCD[6] = int_stack + 3758955;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+5049615,int_stack+5755380,int_stack+5527680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5264970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[2] = int_stack + 5049615;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+2001381,int_stack+6265005,int_stack+6050175, 0.0, zero_stack, 1.0, int_stack+5264970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[1] = int_stack + 2001381;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+6116325,int_stack+6697185,int_stack+6520470, 1.0, int_stack+5264970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[0] = int_stack + 6116325;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+6215550,int_stack+6586620,int_stack+6785385,315);
     Libderiv->ABCD[155] = int_stack + 6215550;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+6586620,int_stack+6985725,int_stack+6851535,315);
     Libderiv->ABCD[143] = int_stack + 6586620;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+6685845,int_stack+7073925,int_stack+17280,315);
     Libderiv->ABCD[142] = int_stack + 6685845;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+6785070,int_stack+7162125,int_stack+83430,315);
     Libderiv->ABCD[131] = int_stack + 6785070;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+5593830,int_stack+7369395,int_stack+7303245,315);
     Libderiv->ABCD[130] = int_stack + 5593830;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+5693055,int_stack+7457595,int_stack+149580,315);
     Libderiv->ABCD[129] = int_stack + 5693055;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+0,int_stack+7679985,int_stack+7545795,315);
     Libderiv->ABCD[119] = int_stack + 0;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+99225,int_stack+7768185,int_stack+215730,315);
     Libderiv->ABCD[118] = int_stack + 99225;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+4430835,int_stack+7856385,int_stack+6917685,315);
     Libderiv->ABCD[117] = int_stack + 4430835;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+6884295,int_stack+8012625,int_stack+281880,315);
     Libderiv->ABCD[116] = int_stack + 6884295;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+6983520,int_stack+8100825,int_stack+5178030,315);
     Libderiv->ABCD[107] = int_stack + 6983520;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+7082745,int_stack+8189025,int_stack+348030,315);
     Libderiv->ABCD[106] = int_stack + 7082745;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+7181970,int_stack+8343375,int_stack+8277225,315);
     Libderiv->ABCD[105] = int_stack + 7181970;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+7281195,int_stack+8431575,int_stack+414180,315);
     Libderiv->ABCD[104] = int_stack + 7281195;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+7380420,int_stack+8585925,int_stack+8519775,315);
     Libderiv->ABCD[103] = int_stack + 7380420;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+7479645,int_stack+8742165,int_stack+480330,315);
     Libderiv->ABCD[95] = int_stack + 7479645;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+5148840,int_stack+8830365,int_stack+7944585,315);
     Libderiv->ABCD[94] = int_stack + 5148840;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+198450,int_stack+546480,int_stack+7611945,315);
     Libderiv->ABCD[93] = int_stack + 198450;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+7578870,int_stack+9052755,int_stack+8918565,315);
     Libderiv->ABCD[92] = int_stack + 7578870;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+7678095,int_stack+9140955,int_stack+668700,315);
     Libderiv->ABCD[91] = int_stack + 7678095;
 /*--- compute (hg|hg) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+7777320,int_stack+9295305,int_stack+9229155,315);
     Libderiv->ABCD[90] = int_stack + 7777320;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+7876545,int_stack+734850,int_stack+8984715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2290575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[47] = int_stack + 7876545;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+7975770,int_stack+9449655,int_stack+9383505, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2845440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[46] = int_stack + 7975770;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+8074995,int_stack+9537855,int_stack+823050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3350235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[45] = int_stack + 8074995;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+8174220,int_stack+9692205,int_stack+9626055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3859890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[44] = int_stack + 8174220;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+8273445,int_stack+9780405,int_stack+889200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4364685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[43] = int_stack + 8273445;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+8372670,int_stack+9936645,int_stack+8674125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4884240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[42] = int_stack + 8372670;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+8471895,int_stack+10092885,int_stack+955350, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5527680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[38] = int_stack + 8471895;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+8571120,int_stack+10249125,int_stack+9868605, 0.0, zero_stack, 1.0, int_stack+2290575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[35] = int_stack + 8571120;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+8670345,int_stack+10405365,int_stack+1021500, 0.0, zero_stack, 1.0, int_stack+2845440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[34] = int_stack + 8670345;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+8769570,int_stack+10493565,int_stack+10024845, 0.0, zero_stack, 1.0, int_stack+3350235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[33] = int_stack + 8769570;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+8868795,int_stack+10649805,int_stack+1087650, 0.0, zero_stack, 1.0, int_stack+3859890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[32] = int_stack + 8868795;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+8968020,int_stack+10738005,int_stack+10181085, 0.0, zero_stack, 1.0, int_stack+4364685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[31] = int_stack + 8968020;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+9067245,int_stack+1153800,int_stack+10337325, 0.0, zero_stack, 1.0, int_stack+4884240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[30] = int_stack + 9067245;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+9166470,int_stack+10960395,int_stack+10826205, 0.0, zero_stack, 1.0, int_stack+5527680, 1.0, int_stack+6050175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[26] = int_stack + 9166470;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+9265695,int_stack+11048595,int_stack+10581765, 0.0, zero_stack, 2.0, int_stack+6050175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[25] = int_stack + 9265695;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+9364920,int_stack+2145090,int_stack+10892355, 1.0, int_stack+2290575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[23] = int_stack + 9364920;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+9464145,int_stack+2656305,int_stack+1935231, 1.0, int_stack+2845440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[22] = int_stack + 9464145;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+9563370,int_stack+3165960,int_stack+2744505, 1.0, int_stack+3350235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[21] = int_stack + 9563370;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+9662595,int_stack+3670755,int_stack+1242000, 1.0, int_stack+3859890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[20] = int_stack + 9662595;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+9761820,int_stack+4180410,int_stack+1420605, 1.0, int_stack+4364685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[19] = int_stack + 9761820;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+9861045,int_stack+1567080,int_stack+1500930, 1.0, int_stack+4884240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[18] = int_stack + 9861045;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+9960270,int_stack+1655280,int_stack+4797660, 1.0, int_stack+5527680, 0.0, zero_stack, 1.0, int_stack+6520470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[14] = int_stack + 9960270;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+10059495,int_stack+5843580,int_stack+5331120, 1.0, int_stack+6050175, 1.0, int_stack+6520470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[13] = int_stack + 10059495;
 /*--- compute (hg|hg) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+10158720,int_stack+4685205,int_stack+5931780, 2.0, int_stack+6520470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[12] = int_stack + 10158720;

}
