/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_hghh(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hg|hh) integrals */

void d12hrr_order_hghh(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[9][10][11] = int_stack + 0;
 Libderiv->deriv_classes[9][10][10] = int_stack + 3630;
 Libderiv->deriv_classes[9][10][9] = int_stack + 7260;
 Libderiv->deriv_classes[9][10][8] = int_stack + 10890;
 Libderiv->deriv_classes[9][10][7] = int_stack + 14520;
 Libderiv->dvrr_classes[9][9] = int_stack + 18150;
 Libderiv->deriv_classes[9][10][6] = int_stack + 21175;
 Libderiv->deriv_classes[9][10][2] = int_stack + 24805;
 Libderiv->deriv_classes[9][10][1] = int_stack + 28435;
 Libderiv->dvrr_classes[8][10] = int_stack + 32065;
 Libderiv->deriv_classes[9][10][0] = int_stack + 35035;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 38665;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 39106;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 39694;
 Libderiv->deriv2_classes[5][8][143] = int_stack + 40450;
 Libderiv->deriv2_classes[5][9][143] = int_stack + 41395;
 Libderiv->deriv2_classes[5][10][143] = int_stack + 42550;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 43936;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 44524;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 45308;
 Libderiv->deriv2_classes[6][8][143] = int_stack + 46316;
 Libderiv->deriv2_classes[6][9][143] = int_stack + 47576;
 Libderiv->deriv2_classes[6][10][143] = int_stack + 49116;
 Libderiv->deriv2_classes[7][5][143] = int_stack + 50964;
 Libderiv->deriv2_classes[7][6][143] = int_stack + 51720;
 Libderiv->deriv2_classes[7][7][143] = int_stack + 52728;
 Libderiv->deriv2_classes[7][8][143] = int_stack + 54024;
 Libderiv->deriv2_classes[7][9][143] = int_stack + 55644;
 Libderiv->deriv2_classes[7][10][143] = int_stack + 57624;
 Libderiv->deriv2_classes[8][5][143] = int_stack + 60000;
 Libderiv->deriv2_classes[8][6][143] = int_stack + 60945;
 Libderiv->deriv2_classes[8][7][143] = int_stack + 62205;
 Libderiv->deriv2_classes[8][8][143] = int_stack + 63825;
 Libderiv->deriv2_classes[8][9][143] = int_stack + 65850;
 Libderiv->deriv2_classes[8][10][143] = int_stack + 68325;
 Libderiv->deriv2_classes[9][5][143] = int_stack + 71295;
 Libderiv->deriv2_classes[9][6][143] = int_stack + 72450;
 Libderiv->deriv2_classes[9][7][143] = int_stack + 73990;
 Libderiv->deriv2_classes[9][8][143] = int_stack + 75970;
 Libderiv->deriv2_classes[9][9][143] = int_stack + 78445;
 Libderiv->deriv2_classes[9][10][143] = int_stack + 81470;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 85100;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 85541;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 86129;
 Libderiv->deriv2_classes[5][8][131] = int_stack + 86885;
 Libderiv->deriv2_classes[5][9][131] = int_stack + 87830;
 Libderiv->deriv2_classes[5][10][131] = int_stack + 88985;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 90371;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 90959;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 91743;
 Libderiv->deriv2_classes[6][8][131] = int_stack + 92751;
 Libderiv->deriv2_classes[6][9][131] = int_stack + 94011;
 Libderiv->deriv2_classes[6][10][131] = int_stack + 95551;
 Libderiv->deriv2_classes[7][5][131] = int_stack + 97399;
 Libderiv->deriv2_classes[7][6][131] = int_stack + 98155;
 Libderiv->deriv2_classes[7][7][131] = int_stack + 99163;
 Libderiv->deriv2_classes[7][8][131] = int_stack + 100459;
 Libderiv->deriv2_classes[7][9][131] = int_stack + 102079;
 Libderiv->deriv2_classes[7][10][131] = int_stack + 104059;
 Libderiv->deriv2_classes[8][5][131] = int_stack + 106435;
 Libderiv->deriv2_classes[8][6][131] = int_stack + 107380;
 Libderiv->deriv2_classes[8][7][131] = int_stack + 108640;
 Libderiv->deriv2_classes[8][8][131] = int_stack + 110260;
 Libderiv->deriv2_classes[8][9][131] = int_stack + 112285;
 Libderiv->deriv2_classes[8][10][131] = int_stack + 114760;
 Libderiv->deriv2_classes[9][5][131] = int_stack + 117730;
 Libderiv->deriv2_classes[9][6][131] = int_stack + 118885;
 Libderiv->deriv2_classes[9][7][131] = int_stack + 120425;
 Libderiv->deriv2_classes[9][8][131] = int_stack + 122405;
 Libderiv->deriv2_classes[9][9][131] = int_stack + 124880;
 Libderiv->deriv2_classes[9][10][131] = int_stack + 127905;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 131535;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 131976;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 132564;
 Libderiv->deriv2_classes[5][8][130] = int_stack + 133320;
 Libderiv->deriv2_classes[5][9][130] = int_stack + 134265;
 Libderiv->deriv2_classes[5][10][130] = int_stack + 135420;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 136806;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 137394;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 138178;
 Libderiv->deriv2_classes[6][8][130] = int_stack + 139186;
 Libderiv->deriv2_classes[6][9][130] = int_stack + 140446;
 Libderiv->deriv2_classes[6][10][130] = int_stack + 141986;
 Libderiv->deriv2_classes[7][5][130] = int_stack + 143834;
 Libderiv->deriv2_classes[7][6][130] = int_stack + 144590;
 Libderiv->deriv2_classes[7][7][130] = int_stack + 145598;
 Libderiv->deriv2_classes[7][8][130] = int_stack + 146894;
 Libderiv->deriv2_classes[7][9][130] = int_stack + 148514;
 Libderiv->deriv2_classes[7][10][130] = int_stack + 150494;
 Libderiv->deriv2_classes[8][5][130] = int_stack + 152870;
 Libderiv->deriv2_classes[8][6][130] = int_stack + 153815;
 Libderiv->deriv2_classes[8][7][130] = int_stack + 155075;
 Libderiv->deriv2_classes[8][8][130] = int_stack + 156695;
 Libderiv->deriv2_classes[8][9][130] = int_stack + 158720;
 Libderiv->deriv2_classes[8][10][130] = int_stack + 161195;
 Libderiv->deriv2_classes[9][5][130] = int_stack + 164165;
 Libderiv->deriv2_classes[9][6][130] = int_stack + 165320;
 Libderiv->deriv2_classes[9][7][130] = int_stack + 166860;
 Libderiv->deriv2_classes[9][8][130] = int_stack + 168840;
 Libderiv->deriv2_classes[9][9][130] = int_stack + 171315;
 Libderiv->deriv2_classes[9][10][130] = int_stack + 174340;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 177970;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 178411;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 178999;
 Libderiv->deriv2_classes[5][8][119] = int_stack + 179755;
 Libderiv->deriv2_classes[5][9][119] = int_stack + 180700;
 Libderiv->deriv2_classes[5][10][119] = int_stack + 181855;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 183241;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 183829;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 184613;
 Libderiv->deriv2_classes[6][8][119] = int_stack + 185621;
 Libderiv->deriv2_classes[6][9][119] = int_stack + 186881;
 Libderiv->deriv2_classes[6][10][119] = int_stack + 188421;
 Libderiv->deriv2_classes[7][5][119] = int_stack + 190269;
 Libderiv->deriv2_classes[7][6][119] = int_stack + 191025;
 Libderiv->deriv2_classes[7][7][119] = int_stack + 192033;
 Libderiv->deriv2_classes[7][8][119] = int_stack + 193329;
 Libderiv->deriv2_classes[7][9][119] = int_stack + 194949;
 Libderiv->deriv2_classes[7][10][119] = int_stack + 196929;
 Libderiv->deriv2_classes[8][5][119] = int_stack + 199305;
 Libderiv->deriv2_classes[8][6][119] = int_stack + 200250;
 Libderiv->deriv2_classes[8][7][119] = int_stack + 201510;
 Libderiv->deriv2_classes[8][8][119] = int_stack + 203130;
 Libderiv->deriv2_classes[8][9][119] = int_stack + 205155;
 Libderiv->deriv2_classes[8][10][119] = int_stack + 207630;
 Libderiv->deriv2_classes[9][5][119] = int_stack + 210600;
 Libderiv->deriv2_classes[9][6][119] = int_stack + 211755;
 Libderiv->deriv2_classes[9][7][119] = int_stack + 213295;
 Libderiv->deriv2_classes[9][8][119] = int_stack + 215275;
 Libderiv->deriv2_classes[9][9][119] = int_stack + 217750;
 Libderiv->deriv2_classes[9][10][119] = int_stack + 220775;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 224405;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 224846;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 225434;
 Libderiv->deriv2_classes[5][8][118] = int_stack + 226190;
 Libderiv->deriv2_classes[5][9][118] = int_stack + 227135;
 Libderiv->deriv2_classes[5][10][118] = int_stack + 228290;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 229676;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 230264;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 231048;
 Libderiv->deriv2_classes[6][8][118] = int_stack + 232056;
 Libderiv->deriv2_classes[6][9][118] = int_stack + 233316;
 Libderiv->deriv2_classes[6][10][118] = int_stack + 234856;
 Libderiv->deriv2_classes[7][5][118] = int_stack + 236704;
 Libderiv->deriv2_classes[7][6][118] = int_stack + 237460;
 Libderiv->deriv2_classes[7][7][118] = int_stack + 238468;
 Libderiv->deriv2_classes[7][8][118] = int_stack + 239764;
 Libderiv->deriv2_classes[7][9][118] = int_stack + 241384;
 Libderiv->deriv2_classes[7][10][118] = int_stack + 243364;
 Libderiv->deriv2_classes[8][5][118] = int_stack + 245740;
 Libderiv->deriv2_classes[8][6][118] = int_stack + 246685;
 Libderiv->deriv2_classes[8][7][118] = int_stack + 247945;
 Libderiv->deriv2_classes[8][8][118] = int_stack + 249565;
 Libderiv->deriv2_classes[8][9][118] = int_stack + 251590;
 Libderiv->deriv2_classes[8][10][118] = int_stack + 254065;
 Libderiv->deriv2_classes[9][5][118] = int_stack + 257035;
 Libderiv->deriv2_classes[9][6][118] = int_stack + 258190;
 Libderiv->deriv2_classes[9][7][118] = int_stack + 259730;
 Libderiv->deriv2_classes[9][8][118] = int_stack + 261710;
 Libderiv->deriv2_classes[9][9][118] = int_stack + 264185;
 Libderiv->deriv2_classes[9][10][118] = int_stack + 267210;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 270840;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 271281;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 271869;
 Libderiv->deriv2_classes[5][8][117] = int_stack + 272625;
 Libderiv->deriv2_classes[5][9][117] = int_stack + 273570;
 Libderiv->deriv2_classes[5][10][117] = int_stack + 274725;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 276111;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 276699;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 277483;
 Libderiv->deriv2_classes[6][8][117] = int_stack + 278491;
 Libderiv->deriv2_classes[6][9][117] = int_stack + 279751;
 Libderiv->deriv2_classes[6][10][117] = int_stack + 281291;
 Libderiv->deriv2_classes[7][5][117] = int_stack + 283139;
 Libderiv->deriv2_classes[7][6][117] = int_stack + 283895;
 Libderiv->deriv2_classes[7][7][117] = int_stack + 284903;
 Libderiv->deriv2_classes[7][8][117] = int_stack + 286199;
 Libderiv->deriv2_classes[7][9][117] = int_stack + 287819;
 Libderiv->deriv2_classes[7][10][117] = int_stack + 289799;
 Libderiv->deriv2_classes[8][5][117] = int_stack + 292175;
 Libderiv->deriv2_classes[8][6][117] = int_stack + 293120;
 Libderiv->deriv2_classes[8][7][117] = int_stack + 294380;
 Libderiv->deriv2_classes[8][8][117] = int_stack + 296000;
 Libderiv->deriv2_classes[8][9][117] = int_stack + 298025;
 Libderiv->deriv2_classes[8][10][117] = int_stack + 300500;
 Libderiv->deriv2_classes[9][5][117] = int_stack + 303470;
 Libderiv->deriv2_classes[9][6][117] = int_stack + 304625;
 Libderiv->deriv2_classes[9][7][117] = int_stack + 306165;
 Libderiv->deriv2_classes[9][8][117] = int_stack + 308145;
 Libderiv->deriv2_classes[9][9][117] = int_stack + 310620;
 Libderiv->deriv2_classes[9][10][117] = int_stack + 313645;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 317275;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 317716;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 318304;
 Libderiv->deriv2_classes[5][8][107] = int_stack + 319060;
 Libderiv->deriv2_classes[5][9][107] = int_stack + 320005;
 Libderiv->deriv2_classes[5][10][107] = int_stack + 321160;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 322546;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 323134;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 323918;
 Libderiv->deriv2_classes[6][8][107] = int_stack + 324926;
 Libderiv->deriv2_classes[6][9][107] = int_stack + 326186;
 Libderiv->deriv2_classes[6][10][107] = int_stack + 327726;
 Libderiv->deriv2_classes[7][5][107] = int_stack + 329574;
 Libderiv->deriv2_classes[7][6][107] = int_stack + 330330;
 Libderiv->deriv2_classes[7][7][107] = int_stack + 331338;
 Libderiv->deriv2_classes[7][8][107] = int_stack + 332634;
 Libderiv->deriv2_classes[7][9][107] = int_stack + 334254;
 Libderiv->deriv2_classes[7][10][107] = int_stack + 336234;
 Libderiv->deriv2_classes[8][5][107] = int_stack + 338610;
 Libderiv->deriv2_classes[8][6][107] = int_stack + 339555;
 Libderiv->deriv2_classes[8][7][107] = int_stack + 340815;
 Libderiv->deriv2_classes[8][8][107] = int_stack + 342435;
 Libderiv->deriv2_classes[8][9][107] = int_stack + 344460;
 Libderiv->deriv2_classes[8][10][107] = int_stack + 346935;
 Libderiv->deriv2_classes[9][5][107] = int_stack + 349905;
 Libderiv->deriv2_classes[9][6][107] = int_stack + 351060;
 Libderiv->deriv2_classes[9][7][107] = int_stack + 352600;
 Libderiv->deriv2_classes[9][8][107] = int_stack + 354580;
 Libderiv->deriv2_classes[9][9][107] = int_stack + 357055;
 Libderiv->deriv2_classes[9][10][107] = int_stack + 360080;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 363710;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 364151;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 364739;
 Libderiv->deriv2_classes[5][8][106] = int_stack + 365495;
 Libderiv->deriv2_classes[5][9][106] = int_stack + 366440;
 Libderiv->deriv2_classes[5][10][106] = int_stack + 367595;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 368981;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 369569;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 370353;
 Libderiv->deriv2_classes[6][8][106] = int_stack + 371361;
 Libderiv->deriv2_classes[6][9][106] = int_stack + 372621;
 Libderiv->deriv2_classes[6][10][106] = int_stack + 374161;
 Libderiv->deriv2_classes[7][5][106] = int_stack + 376009;
 Libderiv->deriv2_classes[7][6][106] = int_stack + 376765;
 Libderiv->deriv2_classes[7][7][106] = int_stack + 377773;
 Libderiv->deriv2_classes[7][8][106] = int_stack + 379069;
 Libderiv->deriv2_classes[7][9][106] = int_stack + 380689;
 Libderiv->deriv2_classes[7][10][106] = int_stack + 382669;
 Libderiv->deriv2_classes[8][5][106] = int_stack + 385045;
 Libderiv->deriv2_classes[8][6][106] = int_stack + 385990;
 Libderiv->deriv2_classes[8][7][106] = int_stack + 387250;
 Libderiv->deriv2_classes[8][8][106] = int_stack + 388870;
 Libderiv->deriv2_classes[8][9][106] = int_stack + 390895;
 Libderiv->deriv2_classes[8][10][106] = int_stack + 393370;
 Libderiv->deriv2_classes[9][5][106] = int_stack + 396340;
 Libderiv->deriv2_classes[9][6][106] = int_stack + 397495;
 Libderiv->deriv2_classes[9][7][106] = int_stack + 399035;
 Libderiv->deriv2_classes[9][8][106] = int_stack + 401015;
 Libderiv->deriv2_classes[9][9][106] = int_stack + 403490;
 Libderiv->deriv2_classes[9][10][106] = int_stack + 406515;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 410145;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 410586;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 411174;
 Libderiv->deriv2_classes[5][8][105] = int_stack + 411930;
 Libderiv->deriv2_classes[5][9][105] = int_stack + 412875;
 Libderiv->deriv2_classes[5][10][105] = int_stack + 414030;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 415416;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 416004;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 416788;
 Libderiv->deriv2_classes[6][8][105] = int_stack + 417796;
 Libderiv->deriv2_classes[6][9][105] = int_stack + 419056;
 Libderiv->deriv2_classes[6][10][105] = int_stack + 420596;
 Libderiv->deriv2_classes[7][5][105] = int_stack + 422444;
 Libderiv->deriv2_classes[7][6][105] = int_stack + 423200;
 Libderiv->deriv2_classes[7][7][105] = int_stack + 424208;
 Libderiv->deriv2_classes[7][8][105] = int_stack + 425504;
 Libderiv->deriv2_classes[7][9][105] = int_stack + 427124;
 Libderiv->deriv2_classes[7][10][105] = int_stack + 429104;
 Libderiv->deriv2_classes[8][5][105] = int_stack + 431480;
 Libderiv->deriv2_classes[8][6][105] = int_stack + 432425;
 Libderiv->deriv2_classes[8][7][105] = int_stack + 433685;
 Libderiv->deriv2_classes[8][8][105] = int_stack + 435305;
 Libderiv->deriv2_classes[8][9][105] = int_stack + 437330;
 Libderiv->deriv2_classes[8][10][105] = int_stack + 439805;
 Libderiv->deriv2_classes[9][5][105] = int_stack + 442775;
 Libderiv->deriv2_classes[9][6][105] = int_stack + 443930;
 Libderiv->deriv2_classes[9][7][105] = int_stack + 445470;
 Libderiv->deriv2_classes[9][8][105] = int_stack + 447450;
 Libderiv->deriv2_classes[9][9][105] = int_stack + 449925;
 Libderiv->deriv2_classes[9][10][105] = int_stack + 452950;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 456580;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 457021;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 457609;
 Libderiv->deriv2_classes[5][8][104] = int_stack + 458365;
 Libderiv->deriv2_classes[5][9][104] = int_stack + 459310;
 Libderiv->deriv2_classes[5][10][104] = int_stack + 460465;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 461851;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 462439;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 463223;
 Libderiv->deriv2_classes[6][8][104] = int_stack + 464231;
 Libderiv->deriv2_classes[6][9][104] = int_stack + 465491;
 Libderiv->deriv2_classes[6][10][104] = int_stack + 467031;
 Libderiv->deriv2_classes[7][5][104] = int_stack + 468879;
 Libderiv->deriv2_classes[7][6][104] = int_stack + 469635;
 Libderiv->deriv2_classes[7][7][104] = int_stack + 470643;
 Libderiv->deriv2_classes[7][8][104] = int_stack + 471939;
 Libderiv->deriv2_classes[7][9][104] = int_stack + 473559;
 Libderiv->deriv2_classes[7][10][104] = int_stack + 475539;
 Libderiv->deriv2_classes[8][5][104] = int_stack + 477915;
 Libderiv->deriv2_classes[8][6][104] = int_stack + 478860;
 Libderiv->deriv2_classes[8][7][104] = int_stack + 480120;
 Libderiv->deriv2_classes[8][8][104] = int_stack + 481740;
 Libderiv->deriv2_classes[8][9][104] = int_stack + 483765;
 Libderiv->deriv2_classes[8][10][104] = int_stack + 486240;
 Libderiv->deriv2_classes[9][5][104] = int_stack + 489210;
 Libderiv->deriv2_classes[9][6][104] = int_stack + 490365;
 Libderiv->deriv2_classes[9][7][104] = int_stack + 491905;
 Libderiv->deriv2_classes[9][8][104] = int_stack + 493885;
 Libderiv->deriv2_classes[9][9][104] = int_stack + 496360;
 Libderiv->deriv2_classes[9][10][104] = int_stack + 499385;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 503015;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 503456;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 504044;
 Libderiv->deriv2_classes[5][8][95] = int_stack + 504800;
 Libderiv->deriv2_classes[5][9][95] = int_stack + 505745;
 Libderiv->deriv2_classes[5][10][95] = int_stack + 506900;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 508286;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 508874;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 509658;
 Libderiv->deriv2_classes[6][8][95] = int_stack + 510666;
 Libderiv->deriv2_classes[6][9][95] = int_stack + 511926;
 Libderiv->deriv2_classes[6][10][95] = int_stack + 513466;
 Libderiv->deriv2_classes[7][5][95] = int_stack + 515314;
 Libderiv->deriv2_classes[7][6][95] = int_stack + 516070;
 Libderiv->deriv2_classes[7][7][95] = int_stack + 517078;
 Libderiv->deriv2_classes[7][8][95] = int_stack + 518374;
 Libderiv->deriv2_classes[7][9][95] = int_stack + 519994;
 Libderiv->deriv2_classes[7][10][95] = int_stack + 521974;
 Libderiv->deriv2_classes[8][5][95] = int_stack + 524350;
 Libderiv->deriv2_classes[8][6][95] = int_stack + 525295;
 Libderiv->deriv2_classes[8][7][95] = int_stack + 526555;
 Libderiv->deriv2_classes[8][8][95] = int_stack + 528175;
 Libderiv->deriv2_classes[8][9][95] = int_stack + 530200;
 Libderiv->deriv2_classes[8][10][95] = int_stack + 532675;
 Libderiv->deriv2_classes[9][5][95] = int_stack + 535645;
 Libderiv->deriv2_classes[9][6][95] = int_stack + 536800;
 Libderiv->deriv2_classes[9][7][95] = int_stack + 538340;
 Libderiv->deriv2_classes[9][8][95] = int_stack + 540320;
 Libderiv->deriv2_classes[9][9][95] = int_stack + 542795;
 Libderiv->deriv2_classes[9][10][95] = int_stack + 545820;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 549450;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 549891;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 550479;
 Libderiv->deriv2_classes[5][8][94] = int_stack + 551235;
 Libderiv->deriv2_classes[5][9][94] = int_stack + 552180;
 Libderiv->deriv2_classes[5][10][94] = int_stack + 553335;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 554721;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 555309;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 556093;
 Libderiv->deriv2_classes[6][8][94] = int_stack + 557101;
 Libderiv->deriv2_classes[6][9][94] = int_stack + 558361;
 Libderiv->deriv2_classes[6][10][94] = int_stack + 559901;
 Libderiv->deriv2_classes[7][5][94] = int_stack + 561749;
 Libderiv->deriv2_classes[7][6][94] = int_stack + 562505;
 Libderiv->deriv2_classes[7][7][94] = int_stack + 563513;
 Libderiv->deriv2_classes[7][8][94] = int_stack + 564809;
 Libderiv->deriv2_classes[7][9][94] = int_stack + 566429;
 Libderiv->deriv2_classes[7][10][94] = int_stack + 568409;
 Libderiv->deriv2_classes[8][5][94] = int_stack + 570785;
 Libderiv->deriv2_classes[8][6][94] = int_stack + 571730;
 Libderiv->deriv2_classes[8][7][94] = int_stack + 572990;
 Libderiv->deriv2_classes[8][8][94] = int_stack + 574610;
 Libderiv->deriv2_classes[8][9][94] = int_stack + 576635;
 Libderiv->deriv2_classes[8][10][94] = int_stack + 579110;
 Libderiv->deriv2_classes[9][5][94] = int_stack + 582080;
 Libderiv->deriv2_classes[9][6][94] = int_stack + 583235;
 Libderiv->deriv2_classes[9][7][94] = int_stack + 584775;
 Libderiv->deriv2_classes[9][8][94] = int_stack + 586755;
 Libderiv->deriv2_classes[9][9][94] = int_stack + 589230;
 Libderiv->deriv2_classes[9][10][94] = int_stack + 592255;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 595885;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 596326;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 596914;
 Libderiv->deriv2_classes[5][8][93] = int_stack + 597670;
 Libderiv->deriv2_classes[5][9][93] = int_stack + 598615;
 Libderiv->deriv2_classes[5][10][93] = int_stack + 599770;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 601156;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 601744;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 602528;
 Libderiv->deriv2_classes[6][8][93] = int_stack + 603536;
 Libderiv->deriv2_classes[6][9][93] = int_stack + 604796;
 Libderiv->deriv2_classes[6][10][93] = int_stack + 606336;
 Libderiv->deriv2_classes[7][5][93] = int_stack + 608184;
 Libderiv->deriv2_classes[7][6][93] = int_stack + 608940;
 Libderiv->deriv2_classes[7][7][93] = int_stack + 609948;
 Libderiv->deriv2_classes[7][8][93] = int_stack + 611244;
 Libderiv->deriv2_classes[7][9][93] = int_stack + 612864;
 Libderiv->deriv2_classes[7][10][93] = int_stack + 614844;
 Libderiv->deriv2_classes[8][5][93] = int_stack + 617220;
 Libderiv->deriv2_classes[8][6][93] = int_stack + 618165;
 Libderiv->deriv2_classes[8][7][93] = int_stack + 619425;
 Libderiv->deriv2_classes[8][8][93] = int_stack + 621045;
 Libderiv->deriv2_classes[8][9][93] = int_stack + 623070;
 Libderiv->deriv2_classes[8][10][93] = int_stack + 625545;
 Libderiv->deriv2_classes[9][5][93] = int_stack + 628515;
 Libderiv->deriv2_classes[9][6][93] = int_stack + 629670;
 Libderiv->deriv2_classes[9][7][93] = int_stack + 631210;
 Libderiv->deriv2_classes[9][8][93] = int_stack + 633190;
 Libderiv->deriv2_classes[9][9][93] = int_stack + 635665;
 Libderiv->deriv2_classes[9][10][93] = int_stack + 638690;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 642320;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 642761;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 643349;
 Libderiv->deriv2_classes[5][8][92] = int_stack + 644105;
 Libderiv->deriv2_classes[5][9][92] = int_stack + 645050;
 Libderiv->deriv2_classes[5][10][92] = int_stack + 646205;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 647591;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 648179;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 648963;
 Libderiv->deriv2_classes[6][8][92] = int_stack + 649971;
 Libderiv->deriv2_classes[6][9][92] = int_stack + 651231;
 Libderiv->deriv2_classes[6][10][92] = int_stack + 652771;
 Libderiv->deriv2_classes[7][5][92] = int_stack + 654619;
 Libderiv->deriv2_classes[7][6][92] = int_stack + 655375;
 Libderiv->deriv2_classes[7][7][92] = int_stack + 656383;
 Libderiv->deriv2_classes[7][8][92] = int_stack + 657679;
 Libderiv->deriv2_classes[7][9][92] = int_stack + 659299;
 Libderiv->deriv2_classes[7][10][92] = int_stack + 661279;
 Libderiv->deriv2_classes[8][5][92] = int_stack + 663655;
 Libderiv->deriv2_classes[8][6][92] = int_stack + 664600;
 Libderiv->deriv2_classes[8][7][92] = int_stack + 665860;
 Libderiv->deriv2_classes[8][8][92] = int_stack + 667480;
 Libderiv->deriv2_classes[8][9][92] = int_stack + 669505;
 Libderiv->deriv2_classes[8][10][92] = int_stack + 671980;
 Libderiv->deriv2_classes[9][5][92] = int_stack + 674950;
 Libderiv->deriv2_classes[9][6][92] = int_stack + 676105;
 Libderiv->deriv2_classes[9][7][92] = int_stack + 677645;
 Libderiv->deriv2_classes[9][8][92] = int_stack + 679625;
 Libderiv->deriv2_classes[9][9][92] = int_stack + 682100;
 Libderiv->deriv2_classes[9][10][92] = int_stack + 685125;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 688755;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 689196;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 689784;
 Libderiv->deriv2_classes[5][8][91] = int_stack + 690540;
 Libderiv->deriv2_classes[5][9][91] = int_stack + 691485;
 Libderiv->deriv2_classes[5][10][91] = int_stack + 692640;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 694026;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 694614;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 695398;
 Libderiv->deriv2_classes[6][8][91] = int_stack + 696406;
 Libderiv->deriv2_classes[6][9][91] = int_stack + 697666;
 Libderiv->deriv2_classes[6][10][91] = int_stack + 699206;
 Libderiv->deriv2_classes[7][5][91] = int_stack + 701054;
 Libderiv->deriv2_classes[7][6][91] = int_stack + 701810;
 Libderiv->deriv2_classes[7][7][91] = int_stack + 702818;
 Libderiv->deriv2_classes[7][8][91] = int_stack + 704114;
 Libderiv->deriv2_classes[7][9][91] = int_stack + 705734;
 Libderiv->deriv2_classes[7][10][91] = int_stack + 707714;
 Libderiv->deriv2_classes[8][5][91] = int_stack + 710090;
 Libderiv->deriv2_classes[8][6][91] = int_stack + 711035;
 Libderiv->deriv2_classes[8][7][91] = int_stack + 712295;
 Libderiv->deriv2_classes[8][8][91] = int_stack + 713915;
 Libderiv->deriv2_classes[8][9][91] = int_stack + 715940;
 Libderiv->deriv2_classes[8][10][91] = int_stack + 718415;
 Libderiv->deriv2_classes[9][5][91] = int_stack + 721385;
 Libderiv->deriv2_classes[9][6][91] = int_stack + 722540;
 Libderiv->deriv2_classes[9][7][91] = int_stack + 724080;
 Libderiv->deriv2_classes[9][8][91] = int_stack + 726060;
 Libderiv->deriv2_classes[9][9][91] = int_stack + 728535;
 Libderiv->deriv2_classes[9][10][91] = int_stack + 731560;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 735190;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 735631;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 736219;
 Libderiv->deriv2_classes[5][8][83] = int_stack + 736975;
 Libderiv->deriv2_classes[5][9][83] = int_stack + 737920;
 Libderiv->deriv2_classes[5][10][83] = int_stack + 739075;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 740461;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 741049;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 741833;
 Libderiv->deriv2_classes[6][8][83] = int_stack + 742841;
 Libderiv->deriv2_classes[6][9][83] = int_stack + 744101;
 Libderiv->deriv2_classes[6][10][83] = int_stack + 745641;
 Libderiv->deriv2_classes[7][5][83] = int_stack + 747489;
 Libderiv->deriv2_classes[7][6][83] = int_stack + 748245;
 Libderiv->deriv2_classes[7][7][83] = int_stack + 749253;
 Libderiv->deriv2_classes[7][8][83] = int_stack + 750549;
 Libderiv->deriv2_classes[7][9][83] = int_stack + 752169;
 Libderiv->deriv2_classes[7][10][83] = int_stack + 754149;
 Libderiv->deriv2_classes[8][5][83] = int_stack + 756525;
 Libderiv->deriv2_classes[8][6][83] = int_stack + 757470;
 Libderiv->deriv2_classes[8][7][83] = int_stack + 758730;
 Libderiv->deriv2_classes[8][8][83] = int_stack + 760350;
 Libderiv->deriv2_classes[8][9][83] = int_stack + 762375;
 Libderiv->deriv2_classes[8][10][83] = int_stack + 764850;
 Libderiv->deriv_classes[9][5][11] = int_stack + 767820;
 Libderiv->deriv2_classes[9][5][83] = int_stack + 768975;
 Libderiv->deriv_classes[9][6][11] = int_stack + 770130;
 Libderiv->deriv2_classes[9][6][83] = int_stack + 771670;
 Libderiv->deriv_classes[9][7][11] = int_stack + 773210;
 Libderiv->deriv2_classes[9][7][83] = int_stack + 775190;
 Libderiv->deriv_classes[9][8][11] = int_stack + 777170;
 Libderiv->deriv2_classes[9][8][83] = int_stack + 779645;
 Libderiv->deriv_classes[9][9][11] = int_stack + 782120;
 Libderiv->deriv2_classes[9][9][83] = int_stack + 785145;
 Libderiv->deriv2_classes[9][10][83] = int_stack + 788170;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 791800;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 792241;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 792829;
 Libderiv->deriv2_classes[5][8][82] = int_stack + 793585;
 Libderiv->deriv2_classes[5][9][82] = int_stack + 794530;
 Libderiv->deriv2_classes[5][10][82] = int_stack + 795685;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 797071;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 797659;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 798443;
 Libderiv->deriv2_classes[6][8][82] = int_stack + 799451;
 Libderiv->deriv2_classes[6][9][82] = int_stack + 800711;
 Libderiv->deriv2_classes[6][10][82] = int_stack + 802251;
 Libderiv->deriv2_classes[7][5][82] = int_stack + 804099;
 Libderiv->deriv2_classes[7][6][82] = int_stack + 804855;
 Libderiv->deriv2_classes[7][7][82] = int_stack + 805863;
 Libderiv->deriv2_classes[7][8][82] = int_stack + 807159;
 Libderiv->deriv2_classes[7][9][82] = int_stack + 808779;
 Libderiv->deriv2_classes[7][10][82] = int_stack + 810759;
 Libderiv->deriv2_classes[8][5][82] = int_stack + 813135;
 Libderiv->deriv2_classes[8][6][82] = int_stack + 814080;
 Libderiv->deriv2_classes[8][7][82] = int_stack + 815340;
 Libderiv->deriv2_classes[8][8][82] = int_stack + 816960;
 Libderiv->deriv2_classes[8][9][82] = int_stack + 818985;
 Libderiv->deriv2_classes[8][10][82] = int_stack + 821460;
 Libderiv->deriv_classes[9][5][10] = int_stack + 824430;
 Libderiv->deriv2_classes[9][5][82] = int_stack + 825585;
 Libderiv->deriv_classes[9][6][10] = int_stack + 826740;
 Libderiv->deriv2_classes[9][6][82] = int_stack + 828280;
 Libderiv->deriv_classes[9][7][10] = int_stack + 829820;
 Libderiv->deriv2_classes[9][7][82] = int_stack + 831800;
 Libderiv->deriv_classes[9][8][10] = int_stack + 833780;
 Libderiv->deriv2_classes[9][8][82] = int_stack + 836255;
 Libderiv->deriv_classes[9][9][10] = int_stack + 838730;
 Libderiv->deriv2_classes[9][9][82] = int_stack + 841755;
 Libderiv->deriv2_classes[9][10][82] = int_stack + 844780;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 848410;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 848851;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 849439;
 Libderiv->deriv2_classes[5][8][81] = int_stack + 850195;
 Libderiv->deriv2_classes[5][9][81] = int_stack + 851140;
 Libderiv->deriv2_classes[5][10][81] = int_stack + 852295;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 853681;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 854269;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 855053;
 Libderiv->deriv2_classes[6][8][81] = int_stack + 856061;
 Libderiv->deriv2_classes[6][9][81] = int_stack + 857321;
 Libderiv->deriv2_classes[6][10][81] = int_stack + 858861;
 Libderiv->deriv2_classes[7][5][81] = int_stack + 860709;
 Libderiv->deriv2_classes[7][6][81] = int_stack + 861465;
 Libderiv->deriv2_classes[7][7][81] = int_stack + 862473;
 Libderiv->deriv2_classes[7][8][81] = int_stack + 863769;
 Libderiv->deriv2_classes[7][9][81] = int_stack + 865389;
 Libderiv->deriv2_classes[7][10][81] = int_stack + 867369;
 Libderiv->deriv2_classes[8][5][81] = int_stack + 869745;
 Libderiv->deriv2_classes[8][6][81] = int_stack + 870690;
 Libderiv->deriv2_classes[8][7][81] = int_stack + 871950;
 Libderiv->deriv2_classes[8][8][81] = int_stack + 873570;
 Libderiv->deriv2_classes[8][9][81] = int_stack + 875595;
 Libderiv->deriv2_classes[8][10][81] = int_stack + 878070;
 Libderiv->deriv_classes[9][5][9] = int_stack + 881040;
 Libderiv->deriv2_classes[9][5][81] = int_stack + 882195;
 Libderiv->deriv_classes[9][6][9] = int_stack + 883350;
 Libderiv->deriv2_classes[9][6][81] = int_stack + 884890;
 Libderiv->deriv_classes[9][7][9] = int_stack + 886430;
 Libderiv->deriv2_classes[9][7][81] = int_stack + 888410;
 Libderiv->deriv_classes[9][8][9] = int_stack + 890390;
 Libderiv->deriv2_classes[9][8][81] = int_stack + 892865;
 Libderiv->deriv_classes[9][9][9] = int_stack + 895340;
 Libderiv->deriv2_classes[9][9][81] = int_stack + 898365;
 Libderiv->deriv2_classes[9][10][81] = int_stack + 901390;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 905020;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 905461;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 906049;
 Libderiv->deriv2_classes[5][8][80] = int_stack + 906805;
 Libderiv->deriv2_classes[5][9][80] = int_stack + 907750;
 Libderiv->deriv2_classes[5][10][80] = int_stack + 908905;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 910291;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 910879;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 911663;
 Libderiv->deriv2_classes[6][8][80] = int_stack + 912671;
 Libderiv->deriv2_classes[6][9][80] = int_stack + 913931;
 Libderiv->deriv2_classes[6][10][80] = int_stack + 915471;
 Libderiv->deriv2_classes[7][5][80] = int_stack + 917319;
 Libderiv->deriv2_classes[7][6][80] = int_stack + 918075;
 Libderiv->deriv2_classes[7][7][80] = int_stack + 919083;
 Libderiv->deriv2_classes[7][8][80] = int_stack + 920379;
 Libderiv->deriv2_classes[7][9][80] = int_stack + 921999;
 Libderiv->deriv2_classes[7][10][80] = int_stack + 923979;
 Libderiv->deriv2_classes[8][5][80] = int_stack + 926355;
 Libderiv->deriv2_classes[8][6][80] = int_stack + 927300;
 Libderiv->deriv2_classes[8][7][80] = int_stack + 928560;
 Libderiv->deriv2_classes[8][8][80] = int_stack + 930180;
 Libderiv->deriv2_classes[8][9][80] = int_stack + 932205;
 Libderiv->deriv2_classes[8][10][80] = int_stack + 934680;
 Libderiv->deriv_classes[9][5][8] = int_stack + 937650;
 Libderiv->deriv2_classes[9][5][80] = int_stack + 938805;
 Libderiv->deriv_classes[9][6][8] = int_stack + 939960;
 Libderiv->deriv2_classes[9][6][80] = int_stack + 941500;
 Libderiv->deriv_classes[9][7][8] = int_stack + 943040;
 Libderiv->deriv2_classes[9][7][80] = int_stack + 945020;
 Libderiv->deriv_classes[9][8][8] = int_stack + 947000;
 Libderiv->deriv2_classes[9][8][80] = int_stack + 949475;
 Libderiv->deriv_classes[9][9][8] = int_stack + 951950;
 Libderiv->deriv2_classes[9][9][80] = int_stack + 954975;
 Libderiv->deriv2_classes[9][10][80] = int_stack + 958000;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 961630;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 962071;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 962659;
 Libderiv->deriv2_classes[5][8][79] = int_stack + 963415;
 Libderiv->deriv2_classes[5][9][79] = int_stack + 964360;
 Libderiv->deriv2_classes[5][10][79] = int_stack + 965515;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 966901;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 967489;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 968273;
 Libderiv->deriv2_classes[6][8][79] = int_stack + 969281;
 Libderiv->deriv2_classes[6][9][79] = int_stack + 970541;
 Libderiv->deriv2_classes[6][10][79] = int_stack + 972081;
 Libderiv->deriv2_classes[7][5][79] = int_stack + 973929;
 Libderiv->deriv2_classes[7][6][79] = int_stack + 974685;
 Libderiv->deriv2_classes[7][7][79] = int_stack + 975693;
 Libderiv->deriv2_classes[7][8][79] = int_stack + 976989;
 Libderiv->deriv2_classes[7][9][79] = int_stack + 978609;
 Libderiv->deriv2_classes[7][10][79] = int_stack + 980589;
 Libderiv->deriv2_classes[8][5][79] = int_stack + 982965;
 Libderiv->deriv2_classes[8][6][79] = int_stack + 983910;
 Libderiv->deriv2_classes[8][7][79] = int_stack + 985170;
 Libderiv->deriv2_classes[8][8][79] = int_stack + 986790;
 Libderiv->deriv2_classes[8][9][79] = int_stack + 988815;
 Libderiv->deriv2_classes[8][10][79] = int_stack + 991290;
 Libderiv->deriv_classes[9][5][7] = int_stack + 994260;
 Libderiv->deriv2_classes[9][5][79] = int_stack + 995415;
 Libderiv->deriv_classes[9][6][7] = int_stack + 996570;
 Libderiv->deriv2_classes[9][6][79] = int_stack + 998110;
 Libderiv->deriv_classes[9][7][7] = int_stack + 999650;
 Libderiv->deriv2_classes[9][7][79] = int_stack + 1001630;
 Libderiv->deriv_classes[9][8][7] = int_stack + 1003610;
 Libderiv->deriv2_classes[9][8][79] = int_stack + 1006085;
 Libderiv->deriv_classes[9][9][7] = int_stack + 1008560;
 Libderiv->deriv2_classes[9][9][79] = int_stack + 1011585;
 Libderiv->deriv2_classes[9][10][79] = int_stack + 1014610;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 1018240;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 1018681;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 1019269;
 Libderiv->deriv2_classes[5][8][78] = int_stack + 1020025;
 Libderiv->deriv2_classes[5][9][78] = int_stack + 1020970;
 Libderiv->deriv2_classes[5][10][78] = int_stack + 1022125;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 1023511;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 1024099;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 1024883;
 Libderiv->deriv2_classes[6][8][78] = int_stack + 1025891;
 Libderiv->deriv2_classes[6][9][78] = int_stack + 1027151;
 Libderiv->deriv2_classes[6][10][78] = int_stack + 1028691;
 Libderiv->deriv2_classes[7][5][78] = int_stack + 1030539;
 Libderiv->deriv2_classes[7][6][78] = int_stack + 1031295;
 Libderiv->deriv2_classes[7][7][78] = int_stack + 1032303;
 Libderiv->deriv2_classes[7][8][78] = int_stack + 1033599;
 Libderiv->deriv2_classes[7][9][78] = int_stack + 1035219;
 Libderiv->deriv2_classes[7][10][78] = int_stack + 1037199;
 Libderiv->deriv2_classes[8][5][78] = int_stack + 1039575;
 Libderiv->deriv2_classes[8][6][78] = int_stack + 1040520;
 Libderiv->deriv2_classes[8][7][78] = int_stack + 1041780;
 Libderiv->deriv2_classes[8][8][78] = int_stack + 1043400;
 Libderiv->deriv2_classes[8][9][78] = int_stack + 1045425;
 Libderiv->deriv2_classes[8][10][78] = int_stack + 1047900;
 Libderiv->dvrr_classes[9][5] = int_stack + 1050870;
 Libderiv->deriv_classes[9][5][6] = int_stack + 1052025;
 Libderiv->deriv2_classes[9][5][78] = int_stack + 1053180;
 Libderiv->dvrr_classes[9][6] = int_stack + 1054335;
 Libderiv->deriv_classes[9][6][6] = int_stack + 1055875;
 Libderiv->deriv2_classes[9][6][78] = int_stack + 1057415;
 Libderiv->dvrr_classes[9][7] = int_stack + 1058955;
 Libderiv->deriv_classes[9][7][6] = int_stack + 1060935;
 Libderiv->deriv2_classes[9][7][78] = int_stack + 1062915;
 Libderiv->dvrr_classes[9][8] = int_stack + 1064895;
 Libderiv->deriv_classes[9][8][6] = int_stack + 1067370;
 Libderiv->deriv2_classes[9][8][78] = int_stack + 1069845;
 Libderiv->deriv_classes[9][9][6] = int_stack + 1072320;
 Libderiv->deriv2_classes[9][9][78] = int_stack + 1075345;
 Libderiv->deriv2_classes[9][10][78] = int_stack + 1078370;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 1082000;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 1082441;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 1083029;
 Libderiv->deriv2_classes[5][8][35] = int_stack + 1083785;
 Libderiv->deriv2_classes[5][9][35] = int_stack + 1084730;
 Libderiv->deriv2_classes[5][10][35] = int_stack + 1085885;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 1087271;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 1087859;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 1088643;
 Libderiv->deriv2_classes[6][8][35] = int_stack + 1089651;
 Libderiv->deriv2_classes[6][9][35] = int_stack + 1090911;
 Libderiv->deriv2_classes[6][10][35] = int_stack + 1092451;
 Libderiv->deriv2_classes[7][5][35] = int_stack + 1094299;
 Libderiv->deriv2_classes[7][6][35] = int_stack + 1095055;
 Libderiv->deriv2_classes[7][7][35] = int_stack + 1096063;
 Libderiv->deriv2_classes[7][8][35] = int_stack + 1097359;
 Libderiv->deriv2_classes[7][9][35] = int_stack + 1098979;
 Libderiv->deriv2_classes[7][10][35] = int_stack + 1100959;
 Libderiv->deriv2_classes[8][5][35] = int_stack + 1103335;
 Libderiv->deriv2_classes[8][6][35] = int_stack + 1104280;
 Libderiv->deriv2_classes[8][7][35] = int_stack + 1105540;
 Libderiv->deriv2_classes[8][8][35] = int_stack + 1107160;
 Libderiv->deriv2_classes[8][9][35] = int_stack + 1109185;
 Libderiv->deriv2_classes[8][10][35] = int_stack + 1111660;
 Libderiv->deriv2_classes[9][5][35] = int_stack + 1114630;
 Libderiv->deriv2_classes[9][6][35] = int_stack + 1115785;
 Libderiv->deriv2_classes[9][7][35] = int_stack + 1117325;
 Libderiv->deriv2_classes[9][8][35] = int_stack + 1119305;
 Libderiv->deriv2_classes[9][9][35] = int_stack + 1121780;
 Libderiv->deriv2_classes[9][10][35] = int_stack + 1124805;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 1128435;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 1128876;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 1129464;
 Libderiv->deriv2_classes[5][8][34] = int_stack + 1130220;
 Libderiv->deriv2_classes[5][9][34] = int_stack + 1131165;
 Libderiv->deriv2_classes[5][10][34] = int_stack + 1132320;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 1133706;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 1134294;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 1135078;
 Libderiv->deriv2_classes[6][8][34] = int_stack + 1136086;
 Libderiv->deriv2_classes[6][9][34] = int_stack + 1137346;
 Libderiv->deriv2_classes[6][10][34] = int_stack + 1138886;
 Libderiv->deriv2_classes[7][5][34] = int_stack + 1140734;
 Libderiv->deriv2_classes[7][6][34] = int_stack + 1141490;
 Libderiv->deriv2_classes[7][7][34] = int_stack + 1142498;
 Libderiv->deriv2_classes[7][8][34] = int_stack + 1143794;
 Libderiv->deriv2_classes[7][9][34] = int_stack + 1145414;
 Libderiv->deriv2_classes[7][10][34] = int_stack + 1147394;
 Libderiv->deriv2_classes[8][5][34] = int_stack + 1149770;
 Libderiv->deriv2_classes[8][6][34] = int_stack + 1150715;
 Libderiv->deriv2_classes[8][7][34] = int_stack + 1151975;
 Libderiv->deriv2_classes[8][8][34] = int_stack + 1153595;
 Libderiv->deriv2_classes[8][9][34] = int_stack + 1155620;
 Libderiv->deriv2_classes[8][10][34] = int_stack + 1158095;
 Libderiv->deriv2_classes[9][5][34] = int_stack + 1161065;
 Libderiv->deriv2_classes[9][6][34] = int_stack + 1162220;
 Libderiv->deriv2_classes[9][7][34] = int_stack + 1163760;
 Libderiv->deriv2_classes[9][8][34] = int_stack + 1165740;
 Libderiv->deriv2_classes[9][9][34] = int_stack + 1168215;
 Libderiv->deriv2_classes[9][10][34] = int_stack + 1171240;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 1174870;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 1175311;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 1175899;
 Libderiv->deriv2_classes[5][8][33] = int_stack + 1176655;
 Libderiv->deriv2_classes[5][9][33] = int_stack + 1177600;
 Libderiv->deriv2_classes[5][10][33] = int_stack + 1178755;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 1180141;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 1180729;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 1181513;
 Libderiv->deriv2_classes[6][8][33] = int_stack + 1182521;
 Libderiv->deriv2_classes[6][9][33] = int_stack + 1183781;
 Libderiv->deriv2_classes[6][10][33] = int_stack + 1185321;
 Libderiv->deriv2_classes[7][5][33] = int_stack + 1187169;
 Libderiv->deriv2_classes[7][6][33] = int_stack + 1187925;
 Libderiv->deriv2_classes[7][7][33] = int_stack + 1188933;
 Libderiv->deriv2_classes[7][8][33] = int_stack + 1190229;
 Libderiv->deriv2_classes[7][9][33] = int_stack + 1191849;
 Libderiv->deriv2_classes[7][10][33] = int_stack + 1193829;
 Libderiv->deriv2_classes[8][5][33] = int_stack + 1196205;
 Libderiv->deriv2_classes[8][6][33] = int_stack + 1197150;
 Libderiv->deriv2_classes[8][7][33] = int_stack + 1198410;
 Libderiv->deriv2_classes[8][8][33] = int_stack + 1200030;
 Libderiv->deriv2_classes[8][9][33] = int_stack + 1202055;
 Libderiv->deriv2_classes[8][10][33] = int_stack + 1204530;
 Libderiv->deriv2_classes[9][5][33] = int_stack + 1207500;
 Libderiv->deriv2_classes[9][6][33] = int_stack + 1208655;
 Libderiv->deriv2_classes[9][7][33] = int_stack + 1210195;
 Libderiv->deriv2_classes[9][8][33] = int_stack + 1212175;
 Libderiv->deriv2_classes[9][9][33] = int_stack + 1214650;
 Libderiv->deriv2_classes[9][10][33] = int_stack + 1217675;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 1221305;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 1221746;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 1222334;
 Libderiv->deriv2_classes[5][8][32] = int_stack + 1223090;
 Libderiv->deriv2_classes[5][9][32] = int_stack + 1224035;
 Libderiv->deriv2_classes[5][10][32] = int_stack + 1225190;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 1226576;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 1227164;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 1227948;
 Libderiv->deriv2_classes[6][8][32] = int_stack + 1228956;
 Libderiv->deriv2_classes[6][9][32] = int_stack + 1230216;
 Libderiv->deriv2_classes[6][10][32] = int_stack + 1231756;
 Libderiv->deriv2_classes[7][5][32] = int_stack + 1233604;
 Libderiv->deriv2_classes[7][6][32] = int_stack + 1234360;
 Libderiv->deriv2_classes[7][7][32] = int_stack + 1235368;
 Libderiv->deriv2_classes[7][8][32] = int_stack + 1236664;
 Libderiv->deriv2_classes[7][9][32] = int_stack + 1238284;
 Libderiv->deriv2_classes[7][10][32] = int_stack + 1240264;
 Libderiv->deriv2_classes[8][5][32] = int_stack + 1242640;
 Libderiv->deriv2_classes[8][6][32] = int_stack + 1243585;
 Libderiv->deriv2_classes[8][7][32] = int_stack + 1244845;
 Libderiv->deriv2_classes[8][8][32] = int_stack + 1246465;
 Libderiv->deriv2_classes[8][9][32] = int_stack + 1248490;
 Libderiv->deriv2_classes[8][10][32] = int_stack + 1250965;
 Libderiv->deriv2_classes[9][5][32] = int_stack + 1253935;
 Libderiv->deriv2_classes[9][6][32] = int_stack + 1255090;
 Libderiv->deriv2_classes[9][7][32] = int_stack + 1256630;
 Libderiv->deriv2_classes[9][8][32] = int_stack + 1258610;
 Libderiv->deriv2_classes[9][9][32] = int_stack + 1261085;
 Libderiv->deriv2_classes[9][10][32] = int_stack + 1264110;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 1267740;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 1268181;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 1268769;
 Libderiv->deriv2_classes[5][8][31] = int_stack + 1269525;
 Libderiv->deriv2_classes[5][9][31] = int_stack + 1270470;
 Libderiv->deriv2_classes[5][10][31] = int_stack + 1271625;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 1273011;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 1273599;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 1274383;
 Libderiv->deriv2_classes[6][8][31] = int_stack + 1275391;
 Libderiv->deriv2_classes[6][9][31] = int_stack + 1276651;
 Libderiv->deriv2_classes[6][10][31] = int_stack + 1278191;
 Libderiv->deriv2_classes[7][5][31] = int_stack + 1280039;
 Libderiv->deriv2_classes[7][6][31] = int_stack + 1280795;
 Libderiv->deriv2_classes[7][7][31] = int_stack + 1281803;
 Libderiv->deriv2_classes[7][8][31] = int_stack + 1283099;
 Libderiv->deriv2_classes[7][9][31] = int_stack + 1284719;
 Libderiv->deriv2_classes[7][10][31] = int_stack + 1286699;
 Libderiv->deriv2_classes[8][5][31] = int_stack + 1289075;
 Libderiv->deriv2_classes[8][6][31] = int_stack + 1290020;
 Libderiv->deriv2_classes[8][7][31] = int_stack + 1291280;
 Libderiv->deriv2_classes[8][8][31] = int_stack + 1292900;
 Libderiv->deriv2_classes[8][9][31] = int_stack + 1294925;
 Libderiv->deriv2_classes[8][10][31] = int_stack + 1297400;
 Libderiv->deriv2_classes[9][5][31] = int_stack + 1300370;
 Libderiv->deriv2_classes[9][6][31] = int_stack + 1301525;
 Libderiv->deriv2_classes[9][7][31] = int_stack + 1303065;
 Libderiv->deriv2_classes[9][8][31] = int_stack + 1305045;
 Libderiv->deriv2_classes[9][9][31] = int_stack + 1307520;
 Libderiv->deriv2_classes[9][10][31] = int_stack + 1310545;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 1314175;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 1314616;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 1315204;
 Libderiv->deriv2_classes[5][8][30] = int_stack + 1315960;
 Libderiv->deriv2_classes[5][9][30] = int_stack + 1316905;
 Libderiv->deriv2_classes[5][10][30] = int_stack + 1318060;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 1319446;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 1320034;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 1320818;
 Libderiv->deriv2_classes[6][8][30] = int_stack + 1321826;
 Libderiv->deriv2_classes[6][9][30] = int_stack + 1323086;
 Libderiv->deriv2_classes[6][10][30] = int_stack + 1324626;
 Libderiv->deriv2_classes[7][5][30] = int_stack + 1326474;
 Libderiv->deriv2_classes[7][6][30] = int_stack + 1327230;
 Libderiv->deriv2_classes[7][7][30] = int_stack + 1328238;
 Libderiv->deriv2_classes[7][8][30] = int_stack + 1329534;
 Libderiv->deriv2_classes[7][9][30] = int_stack + 1331154;
 Libderiv->deriv2_classes[7][10][30] = int_stack + 1333134;
 Libderiv->deriv2_classes[8][5][30] = int_stack + 1335510;
 Libderiv->deriv2_classes[8][6][30] = int_stack + 1336455;
 Libderiv->deriv2_classes[8][7][30] = int_stack + 1337715;
 Libderiv->deriv2_classes[8][8][30] = int_stack + 1339335;
 Libderiv->deriv2_classes[8][9][30] = int_stack + 1341360;
 Libderiv->deriv2_classes[8][10][30] = int_stack + 1343835;
 Libderiv->deriv_classes[9][5][2] = int_stack + 1346805;
 Libderiv->deriv2_classes[9][5][30] = int_stack + 1347960;
 Libderiv->deriv_classes[9][6][2] = int_stack + 1349115;
 Libderiv->deriv2_classes[9][6][30] = int_stack + 1350655;
 Libderiv->deriv_classes[9][7][2] = int_stack + 1352195;
 Libderiv->deriv2_classes[9][7][30] = int_stack + 1354175;
 Libderiv->deriv_classes[9][8][2] = int_stack + 1356155;
 Libderiv->deriv2_classes[9][8][30] = int_stack + 1358630;
 Libderiv->deriv_classes[9][9][2] = int_stack + 1361105;
 Libderiv->deriv2_classes[9][9][30] = int_stack + 1364130;
 Libderiv->deriv2_classes[9][10][30] = int_stack + 1367155;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 1370785;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 1371226;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 1371814;
 Libderiv->deriv2_classes[5][8][26] = int_stack + 1372570;
 Libderiv->deriv2_classes[5][9][26] = int_stack + 1373515;
 Libderiv->deriv2_classes[5][10][26] = int_stack + 1374670;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 1376056;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 1376644;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 1377428;
 Libderiv->deriv2_classes[6][8][26] = int_stack + 1378436;
 Libderiv->deriv2_classes[6][9][26] = int_stack + 1379696;
 Libderiv->deriv2_classes[6][10][26] = int_stack + 1381236;
 Libderiv->deriv2_classes[7][5][26] = int_stack + 1383084;
 Libderiv->deriv2_classes[7][6][26] = int_stack + 1383840;
 Libderiv->deriv2_classes[7][7][26] = int_stack + 1384848;
 Libderiv->deriv2_classes[7][8][26] = int_stack + 1386144;
 Libderiv->deriv2_classes[7][9][26] = int_stack + 1387764;
 Libderiv->deriv2_classes[7][10][26] = int_stack + 1389744;
 Libderiv->deriv2_classes[8][5][26] = int_stack + 1392120;
 Libderiv->deriv2_classes[8][6][26] = int_stack + 1393065;
 Libderiv->deriv2_classes[8][7][26] = int_stack + 1394325;
 Libderiv->deriv2_classes[8][8][26] = int_stack + 1395945;
 Libderiv->deriv2_classes[8][9][26] = int_stack + 1397970;
 Libderiv->deriv2_classes[8][10][26] = int_stack + 1400445;
 Libderiv->deriv2_classes[9][5][26] = int_stack + 1403415;
 Libderiv->deriv2_classes[9][6][26] = int_stack + 1404570;
 Libderiv->deriv2_classes[9][7][26] = int_stack + 1406110;
 Libderiv->deriv2_classes[9][8][26] = int_stack + 1408090;
 Libderiv->deriv2_classes[9][9][26] = int_stack + 1410565;
 Libderiv->deriv2_classes[9][10][26] = int_stack + 1413590;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 1417220;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 1417661;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 1418249;
 Libderiv->deriv2_classes[5][8][23] = int_stack + 1419005;
 Libderiv->deriv2_classes[5][9][23] = int_stack + 1419950;
 Libderiv->deriv2_classes[5][10][23] = int_stack + 1421105;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 1422491;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 1423079;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 1423863;
 Libderiv->deriv2_classes[6][8][23] = int_stack + 1424871;
 Libderiv->deriv2_classes[6][9][23] = int_stack + 1426131;
 Libderiv->deriv2_classes[6][10][23] = int_stack + 1427671;
 Libderiv->deriv2_classes[7][5][23] = int_stack + 1429519;
 Libderiv->deriv2_classes[7][6][23] = int_stack + 1430275;
 Libderiv->deriv2_classes[7][7][23] = int_stack + 1431283;
 Libderiv->deriv2_classes[7][8][23] = int_stack + 1432579;
 Libderiv->deriv2_classes[7][9][23] = int_stack + 1434199;
 Libderiv->deriv2_classes[7][10][23] = int_stack + 1436179;
 Libderiv->deriv2_classes[8][5][23] = int_stack + 1438555;
 Libderiv->deriv2_classes[8][6][23] = int_stack + 1439500;
 Libderiv->deriv2_classes[8][7][23] = int_stack + 1440760;
 Libderiv->deriv2_classes[8][8][23] = int_stack + 1442380;
 Libderiv->deriv2_classes[8][9][23] = int_stack + 1444405;
 Libderiv->deriv2_classes[8][10][23] = int_stack + 1446880;
 Libderiv->deriv2_classes[9][5][23] = int_stack + 1449850;
 Libderiv->deriv2_classes[9][6][23] = int_stack + 1451005;
 Libderiv->deriv2_classes[9][7][23] = int_stack + 1452545;
 Libderiv->deriv2_classes[9][8][23] = int_stack + 1454525;
 Libderiv->deriv2_classes[9][9][23] = int_stack + 1457000;
 Libderiv->deriv2_classes[9][10][23] = int_stack + 1460025;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 1463655;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 1464096;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 1464684;
 Libderiv->deriv2_classes[5][8][22] = int_stack + 1465440;
 Libderiv->deriv2_classes[5][9][22] = int_stack + 1466385;
 Libderiv->deriv2_classes[5][10][22] = int_stack + 1467540;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 1468926;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 1469514;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 1470298;
 Libderiv->deriv2_classes[6][8][22] = int_stack + 1471306;
 Libderiv->deriv2_classes[6][9][22] = int_stack + 1472566;
 Libderiv->deriv2_classes[6][10][22] = int_stack + 1474106;
 Libderiv->deriv2_classes[7][5][22] = int_stack + 1475954;
 Libderiv->deriv2_classes[7][6][22] = int_stack + 1476710;
 Libderiv->deriv2_classes[7][7][22] = int_stack + 1477718;
 Libderiv->deriv2_classes[7][8][22] = int_stack + 1479014;
 Libderiv->deriv2_classes[7][9][22] = int_stack + 1480634;
 Libderiv->deriv2_classes[7][10][22] = int_stack + 1482614;
 Libderiv->deriv2_classes[8][5][22] = int_stack + 1484990;
 Libderiv->deriv2_classes[8][6][22] = int_stack + 1485935;
 Libderiv->deriv2_classes[8][7][22] = int_stack + 1487195;
 Libderiv->deriv2_classes[8][8][22] = int_stack + 1488815;
 Libderiv->deriv2_classes[8][9][22] = int_stack + 1490840;
 Libderiv->deriv2_classes[8][10][22] = int_stack + 1493315;
 Libderiv->deriv2_classes[9][5][22] = int_stack + 1496285;
 Libderiv->deriv2_classes[9][6][22] = int_stack + 1497440;
 Libderiv->deriv2_classes[9][7][22] = int_stack + 1498980;
 Libderiv->deriv2_classes[9][8][22] = int_stack + 1500960;
 Libderiv->deriv2_classes[9][9][22] = int_stack + 1503435;
 Libderiv->deriv2_classes[9][10][22] = int_stack + 1506460;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 1510090;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 1510531;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 1511119;
 Libderiv->deriv2_classes[5][8][21] = int_stack + 1511875;
 Libderiv->deriv2_classes[5][9][21] = int_stack + 1512820;
 Libderiv->deriv2_classes[5][10][21] = int_stack + 1513975;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 1515361;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 1515949;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 1516733;
 Libderiv->deriv2_classes[6][8][21] = int_stack + 1517741;
 Libderiv->deriv2_classes[6][9][21] = int_stack + 1519001;
 Libderiv->deriv2_classes[6][10][21] = int_stack + 1520541;
 Libderiv->deriv2_classes[7][5][21] = int_stack + 1522389;
 Libderiv->deriv2_classes[7][6][21] = int_stack + 1523145;
 Libderiv->deriv2_classes[7][7][21] = int_stack + 1524153;
 Libderiv->deriv2_classes[7][8][21] = int_stack + 1525449;
 Libderiv->deriv2_classes[7][9][21] = int_stack + 1527069;
 Libderiv->deriv2_classes[7][10][21] = int_stack + 1529049;
 Libderiv->deriv2_classes[8][5][21] = int_stack + 1531425;
 Libderiv->deriv2_classes[8][6][21] = int_stack + 1532370;
 Libderiv->deriv2_classes[8][7][21] = int_stack + 1533630;
 Libderiv->deriv2_classes[8][8][21] = int_stack + 1535250;
 Libderiv->deriv2_classes[8][9][21] = int_stack + 1537275;
 Libderiv->deriv2_classes[8][10][21] = int_stack + 1539750;
 Libderiv->deriv2_classes[9][5][21] = int_stack + 1542720;
 Libderiv->deriv2_classes[9][6][21] = int_stack + 1543875;
 Libderiv->deriv2_classes[9][7][21] = int_stack + 1545415;
 Libderiv->deriv2_classes[9][8][21] = int_stack + 1547395;
 Libderiv->deriv2_classes[9][9][21] = int_stack + 1549870;
 Libderiv->deriv2_classes[9][10][21] = int_stack + 1552895;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 1556525;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 1556966;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 1557554;
 Libderiv->deriv2_classes[5][8][20] = int_stack + 1558310;
 Libderiv->deriv2_classes[5][9][20] = int_stack + 1559255;
 Libderiv->deriv2_classes[5][10][20] = int_stack + 1560410;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 1561796;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 1562384;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 1563168;
 Libderiv->deriv2_classes[6][8][20] = int_stack + 1564176;
 Libderiv->deriv2_classes[6][9][20] = int_stack + 1565436;
 Libderiv->deriv2_classes[6][10][20] = int_stack + 1566976;
 Libderiv->deriv2_classes[7][5][20] = int_stack + 1568824;
 Libderiv->deriv2_classes[7][6][20] = int_stack + 1569580;
 Libderiv->deriv2_classes[7][7][20] = int_stack + 1570588;
 Libderiv->deriv2_classes[7][8][20] = int_stack + 1571884;
 Libderiv->deriv2_classes[7][9][20] = int_stack + 1573504;
 Libderiv->deriv2_classes[7][10][20] = int_stack + 1575484;
 Libderiv->deriv2_classes[8][5][20] = int_stack + 1577860;
 Libderiv->deriv2_classes[8][6][20] = int_stack + 1578805;
 Libderiv->deriv2_classes[8][7][20] = int_stack + 1580065;
 Libderiv->deriv2_classes[8][8][20] = int_stack + 1581685;
 Libderiv->deriv2_classes[8][9][20] = int_stack + 1583710;
 Libderiv->deriv2_classes[8][10][20] = int_stack + 1586185;
 Libderiv->deriv2_classes[9][5][20] = int_stack + 1589155;
 Libderiv->deriv2_classes[9][6][20] = int_stack + 1590310;
 Libderiv->deriv2_classes[9][7][20] = int_stack + 1591850;
 Libderiv->deriv2_classes[9][8][20] = int_stack + 1593830;
 Libderiv->deriv2_classes[9][9][20] = int_stack + 1596305;
 Libderiv->deriv2_classes[9][10][20] = int_stack + 1599330;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 1602960;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 1603401;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 1603989;
 Libderiv->deriv2_classes[5][8][19] = int_stack + 1604745;
 Libderiv->deriv2_classes[5][9][19] = int_stack + 1605690;
 Libderiv->deriv2_classes[5][10][19] = int_stack + 1606845;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 1608231;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 1608819;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 1609603;
 Libderiv->deriv2_classes[6][8][19] = int_stack + 1610611;
 Libderiv->deriv2_classes[6][9][19] = int_stack + 1611871;
 Libderiv->deriv2_classes[6][10][19] = int_stack + 1613411;
 Libderiv->deriv2_classes[7][5][19] = int_stack + 1615259;
 Libderiv->deriv2_classes[7][6][19] = int_stack + 1616015;
 Libderiv->deriv2_classes[7][7][19] = int_stack + 1617023;
 Libderiv->deriv2_classes[7][8][19] = int_stack + 1618319;
 Libderiv->deriv2_classes[7][9][19] = int_stack + 1619939;
 Libderiv->deriv2_classes[7][10][19] = int_stack + 1621919;
 Libderiv->deriv2_classes[8][5][19] = int_stack + 1624295;
 Libderiv->deriv2_classes[8][6][19] = int_stack + 1625240;
 Libderiv->deriv2_classes[8][7][19] = int_stack + 1626500;
 Libderiv->deriv2_classes[8][8][19] = int_stack + 1628120;
 Libderiv->deriv2_classes[8][9][19] = int_stack + 1630145;
 Libderiv->deriv2_classes[8][10][19] = int_stack + 1632620;
 Libderiv->deriv2_classes[9][5][19] = int_stack + 1635590;
 Libderiv->deriv2_classes[9][6][19] = int_stack + 1636745;
 Libderiv->deriv2_classes[9][7][19] = int_stack + 1638285;
 Libderiv->deriv2_classes[9][8][19] = int_stack + 1640265;
 Libderiv->deriv2_classes[9][9][19] = int_stack + 1642740;
 Libderiv->deriv2_classes[9][10][19] = int_stack + 1645765;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 1649395;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 1649836;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 1650424;
 Libderiv->deriv2_classes[5][8][18] = int_stack + 1651180;
 Libderiv->deriv2_classes[5][9][18] = int_stack + 1652125;
 Libderiv->deriv2_classes[5][10][18] = int_stack + 1653280;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 1654666;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 1655254;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 1656038;
 Libderiv->deriv2_classes[6][8][18] = int_stack + 1657046;
 Libderiv->deriv2_classes[6][9][18] = int_stack + 1658306;
 Libderiv->deriv2_classes[6][10][18] = int_stack + 1659846;
 Libderiv->deriv2_classes[7][5][18] = int_stack + 1661694;
 Libderiv->deriv2_classes[7][6][18] = int_stack + 1662450;
 Libderiv->deriv2_classes[7][7][18] = int_stack + 1663458;
 Libderiv->deriv2_classes[7][8][18] = int_stack + 1664754;
 Libderiv->deriv2_classes[7][9][18] = int_stack + 1666374;
 Libderiv->deriv2_classes[7][10][18] = int_stack + 1668354;
 Libderiv->deriv2_classes[8][5][18] = int_stack + 1670730;
 Libderiv->deriv2_classes[8][6][18] = int_stack + 1671675;
 Libderiv->deriv2_classes[8][7][18] = int_stack + 1672935;
 Libderiv->deriv2_classes[8][8][18] = int_stack + 1674555;
 Libderiv->deriv2_classes[8][9][18] = int_stack + 1676580;
 Libderiv->deriv2_classes[8][10][18] = int_stack + 1679055;
 Libderiv->deriv_classes[9][5][1] = int_stack + 1682025;
 Libderiv->deriv2_classes[9][5][18] = int_stack + 1683180;
 Libderiv->deriv_classes[9][6][1] = int_stack + 1684335;
 Libderiv->deriv2_classes[9][6][18] = int_stack + 1685875;
 Libderiv->deriv_classes[9][7][1] = int_stack + 1687415;
 Libderiv->deriv2_classes[9][7][18] = int_stack + 1689395;
 Libderiv->deriv_classes[9][8][1] = int_stack + 1691375;
 Libderiv->deriv2_classes[9][8][18] = int_stack + 1693850;
 Libderiv->deriv_classes[9][9][1] = int_stack + 1696325;
 Libderiv->deriv2_classes[9][9][18] = int_stack + 1699350;
 Libderiv->deriv2_classes[9][10][18] = int_stack + 1702375;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 1706005;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 1706446;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 1707034;
 Libderiv->deriv2_classes[5][8][14] = int_stack + 1707790;
 Libderiv->deriv2_classes[5][9][14] = int_stack + 1708735;
 Libderiv->deriv2_classes[5][10][14] = int_stack + 1709890;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 1711276;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 1711864;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 1712648;
 Libderiv->deriv2_classes[6][8][14] = int_stack + 1713656;
 Libderiv->deriv2_classes[6][9][14] = int_stack + 1714916;
 Libderiv->deriv2_classes[6][10][14] = int_stack + 1716456;
 Libderiv->deriv2_classes[7][5][14] = int_stack + 1718304;
 Libderiv->deriv2_classes[7][6][14] = int_stack + 1719060;
 Libderiv->deriv2_classes[7][7][14] = int_stack + 1720068;
 Libderiv->deriv2_classes[7][8][14] = int_stack + 1721364;
 Libderiv->deriv2_classes[7][9][14] = int_stack + 1722984;
 Libderiv->deriv2_classes[7][10][14] = int_stack + 1724964;
 Libderiv->deriv2_classes[8][5][14] = int_stack + 1727340;
 Libderiv->deriv2_classes[8][6][14] = int_stack + 1728285;
 Libderiv->deriv2_classes[8][7][14] = int_stack + 1729545;
 Libderiv->deriv2_classes[8][8][14] = int_stack + 1731165;
 Libderiv->deriv2_classes[8][9][14] = int_stack + 1733190;
 Libderiv->deriv2_classes[8][10][14] = int_stack + 1735665;
 Libderiv->deriv2_classes[9][5][14] = int_stack + 1738635;
 Libderiv->deriv2_classes[9][6][14] = int_stack + 1739790;
 Libderiv->deriv2_classes[9][7][14] = int_stack + 1741330;
 Libderiv->deriv2_classes[9][8][14] = int_stack + 1743310;
 Libderiv->deriv2_classes[9][9][14] = int_stack + 1745785;
 Libderiv->deriv2_classes[9][10][14] = int_stack + 1748810;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 1752440;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 1752881;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 1753469;
 Libderiv->deriv2_classes[5][8][13] = int_stack + 1754225;
 Libderiv->deriv2_classes[5][9][13] = int_stack + 1755170;
 Libderiv->deriv2_classes[5][10][13] = int_stack + 1756325;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 1757711;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 1758299;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 1759083;
 Libderiv->deriv2_classes[6][8][13] = int_stack + 1760091;
 Libderiv->deriv2_classes[6][9][13] = int_stack + 1761351;
 Libderiv->deriv2_classes[6][10][13] = int_stack + 1762891;
 Libderiv->deriv2_classes[7][5][13] = int_stack + 1764739;
 Libderiv->deriv2_classes[7][6][13] = int_stack + 1765495;
 Libderiv->deriv2_classes[7][7][13] = int_stack + 1766503;
 Libderiv->deriv2_classes[7][8][13] = int_stack + 1767799;
 Libderiv->deriv2_classes[7][9][13] = int_stack + 1769419;
 Libderiv->deriv2_classes[7][10][13] = int_stack + 1771399;
 Libderiv->deriv2_classes[8][5][13] = int_stack + 1773775;
 Libderiv->deriv2_classes[8][6][13] = int_stack + 1774720;
 Libderiv->deriv2_classes[8][7][13] = int_stack + 1775980;
 Libderiv->deriv2_classes[8][8][13] = int_stack + 1777600;
 Libderiv->deriv2_classes[8][9][13] = int_stack + 1779625;
 Libderiv->deriv2_classes[8][10][13] = int_stack + 1782100;
 Libderiv->deriv2_classes[9][5][13] = int_stack + 1785070;
 Libderiv->deriv2_classes[9][6][13] = int_stack + 1786225;
 Libderiv->deriv2_classes[9][7][13] = int_stack + 1787765;
 Libderiv->deriv2_classes[9][8][13] = int_stack + 1789745;
 Libderiv->deriv2_classes[9][9][13] = int_stack + 1792220;
 Libderiv->deriv2_classes[9][10][13] = int_stack + 1795245;
 Libderiv->deriv_classes[5][5][11] = int_stack + 1798875;
 Libderiv->deriv_classes[5][6][11] = int_stack + 1799316;
 Libderiv->deriv_classes[5][7][11] = int_stack + 1799904;
 Libderiv->deriv_classes[5][8][11] = int_stack + 1800660;
 Libderiv->deriv_classes[5][9][11] = int_stack + 1801605;
 Libderiv->deriv_classes[5][10][11] = int_stack + 1802760;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 1804146;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 1804587;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 1805175;
 Libderiv->deriv2_classes[5][8][11] = int_stack + 1805931;
 Libderiv->deriv2_classes[5][9][11] = int_stack + 1806876;
 Libderiv->deriv2_classes[5][10][11] = int_stack + 1808031;
 Libderiv->deriv_classes[6][5][11] = int_stack + 1809417;
 Libderiv->deriv_classes[6][6][11] = int_stack + 1810005;
 Libderiv->deriv_classes[6][7][11] = int_stack + 1810789;
 Libderiv->deriv_classes[6][8][11] = int_stack + 1811797;
 Libderiv->deriv_classes[6][9][11] = int_stack + 1813057;
 Libderiv->deriv_classes[6][10][11] = int_stack + 1814597;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 1816445;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 1817033;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 1817817;
 Libderiv->deriv2_classes[6][8][11] = int_stack + 1818825;
 Libderiv->deriv2_classes[6][9][11] = int_stack + 1820085;
 Libderiv->deriv2_classes[6][10][11] = int_stack + 1821625;
 Libderiv->deriv_classes[7][5][11] = int_stack + 1823473;
 Libderiv->deriv_classes[7][6][11] = int_stack + 1824229;
 Libderiv->deriv_classes[7][7][11] = int_stack + 1825237;
 Libderiv->deriv_classes[7][8][11] = int_stack + 1826533;
 Libderiv->deriv_classes[7][9][11] = int_stack + 1828153;
 Libderiv->deriv_classes[7][10][11] = int_stack + 1830133;
 Libderiv->deriv2_classes[7][5][11] = int_stack + 1832509;
 Libderiv->deriv2_classes[7][6][11] = int_stack + 1833265;
 Libderiv->deriv2_classes[7][7][11] = int_stack + 1834273;
 Libderiv->deriv2_classes[7][8][11] = int_stack + 1835569;
 Libderiv->deriv2_classes[7][9][11] = int_stack + 1837189;
 Libderiv->deriv2_classes[7][10][11] = int_stack + 1839169;
 Libderiv->deriv_classes[8][5][11] = int_stack + 1841545;
 Libderiv->deriv_classes[8][6][11] = int_stack + 1842490;
 Libderiv->deriv_classes[8][7][11] = int_stack + 1843750;
 Libderiv->deriv_classes[8][8][11] = int_stack + 1845370;
 Libderiv->deriv_classes[8][9][11] = int_stack + 1847395;
 Libderiv->deriv_classes[8][10][11] = int_stack + 1849870;
 Libderiv->deriv2_classes[8][5][11] = int_stack + 1852840;
 Libderiv->deriv2_classes[8][6][11] = int_stack + 1853785;
 Libderiv->deriv2_classes[8][7][11] = int_stack + 1855045;
 Libderiv->deriv2_classes[8][8][11] = int_stack + 1856665;
 Libderiv->deriv2_classes[8][9][11] = int_stack + 1858690;
 Libderiv->deriv2_classes[8][10][11] = int_stack + 1861165;
 Libderiv->deriv2_classes[9][5][11] = int_stack + 1864135;
 Libderiv->deriv2_classes[9][6][11] = int_stack + 1865290;
 Libderiv->deriv2_classes[9][7][11] = int_stack + 1866830;
 Libderiv->deriv2_classes[9][8][11] = int_stack + 1868810;
 Libderiv->deriv2_classes[9][9][11] = int_stack + 1871285;
 Libderiv->deriv2_classes[9][10][11] = int_stack + 1874310;
 Libderiv->deriv_classes[5][5][10] = int_stack + 1877940;
 Libderiv->deriv_classes[5][6][10] = int_stack + 1878381;
 Libderiv->deriv_classes[5][7][10] = int_stack + 1878969;
 Libderiv->deriv_classes[5][8][10] = int_stack + 1879725;
 Libderiv->deriv_classes[5][9][10] = int_stack + 1880670;
 Libderiv->deriv_classes[5][10][10] = int_stack + 1881825;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 1883211;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 1883652;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 1884240;
 Libderiv->deriv2_classes[5][8][10] = int_stack + 1884996;
 Libderiv->deriv2_classes[5][9][10] = int_stack + 1885941;
 Libderiv->deriv2_classes[5][10][10] = int_stack + 1887096;
 Libderiv->deriv_classes[6][5][10] = int_stack + 1888482;
 Libderiv->deriv_classes[6][6][10] = int_stack + 1889070;
 Libderiv->deriv_classes[6][7][10] = int_stack + 1889854;
 Libderiv->deriv_classes[6][8][10] = int_stack + 1890862;
 Libderiv->deriv_classes[6][9][10] = int_stack + 1892122;
 Libderiv->deriv_classes[6][10][10] = int_stack + 1893662;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 1895510;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 1896098;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 1896882;
 Libderiv->deriv2_classes[6][8][10] = int_stack + 1897890;
 Libderiv->deriv2_classes[6][9][10] = int_stack + 1899150;
 Libderiv->deriv2_classes[6][10][10] = int_stack + 1900690;
 Libderiv->deriv_classes[7][5][10] = int_stack + 1902538;
 Libderiv->deriv_classes[7][6][10] = int_stack + 1903294;
 Libderiv->deriv_classes[7][7][10] = int_stack + 1904302;
 Libderiv->deriv_classes[7][8][10] = int_stack + 1905598;
 Libderiv->deriv_classes[7][9][10] = int_stack + 1907218;
 Libderiv->deriv_classes[7][10][10] = int_stack + 1909198;
 Libderiv->deriv2_classes[7][5][10] = int_stack + 1911574;
 Libderiv->deriv2_classes[7][6][10] = int_stack + 1912330;
 Libderiv->deriv2_classes[7][7][10] = int_stack + 1913338;
 Libderiv->deriv2_classes[7][8][10] = int_stack + 1914634;
 Libderiv->deriv2_classes[7][9][10] = int_stack + 1916254;
 Libderiv->deriv2_classes[7][10][10] = int_stack + 1918234;
 Libderiv->deriv_classes[8][5][10] = int_stack + 1920610;
 Libderiv->deriv_classes[8][6][10] = int_stack + 1921555;
 Libderiv->deriv_classes[8][7][10] = int_stack + 1922815;
 Libderiv->deriv_classes[8][8][10] = int_stack + 1924435;
 Libderiv->deriv_classes[8][9][10] = int_stack + 1926460;
 Libderiv->deriv_classes[8][10][10] = int_stack + 1928935;
 Libderiv->deriv2_classes[8][5][10] = int_stack + 1931905;
 Libderiv->deriv2_classes[8][6][10] = int_stack + 1932850;
 Libderiv->deriv2_classes[8][7][10] = int_stack + 1934110;
 Libderiv->deriv2_classes[8][8][10] = int_stack + 1935730;
 Libderiv->deriv2_classes[8][9][10] = int_stack + 1937755;
 Libderiv->deriv2_classes[8][10][10] = int_stack + 1940230;
 Libderiv->deriv2_classes[9][5][10] = int_stack + 1943200;
 Libderiv->deriv2_classes[9][6][10] = int_stack + 1944355;
 Libderiv->deriv2_classes[9][7][10] = int_stack + 1945895;
 Libderiv->deriv2_classes[9][8][10] = int_stack + 1947875;
 Libderiv->deriv2_classes[9][9][10] = int_stack + 1950350;
 Libderiv->deriv2_classes[9][10][10] = int_stack + 1953375;
 Libderiv->deriv_classes[5][5][9] = int_stack + 1957005;
 Libderiv->deriv_classes[5][6][9] = int_stack + 1957446;
 Libderiv->deriv_classes[5][7][9] = int_stack + 1958034;
 Libderiv->deriv_classes[5][8][9] = int_stack + 1958790;
 Libderiv->deriv_classes[5][9][9] = int_stack + 1959735;
 Libderiv->deriv_classes[5][10][9] = int_stack + 1960890;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 1962276;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 1962717;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 1963305;
 Libderiv->deriv2_classes[5][8][9] = int_stack + 1964061;
 Libderiv->deriv2_classes[5][9][9] = int_stack + 1965006;
 Libderiv->deriv2_classes[5][10][9] = int_stack + 1966161;
 Libderiv->deriv_classes[6][5][9] = int_stack + 1967547;
 Libderiv->deriv_classes[6][6][9] = int_stack + 1968135;
 Libderiv->deriv_classes[6][7][9] = int_stack + 1968919;
 Libderiv->deriv_classes[6][8][9] = int_stack + 1969927;
 Libderiv->deriv_classes[6][9][9] = int_stack + 1971187;
 Libderiv->deriv_classes[6][10][9] = int_stack + 1972727;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 1974575;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 1975163;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 1975947;
 Libderiv->deriv2_classes[6][8][9] = int_stack + 1976955;
 Libderiv->deriv2_classes[6][9][9] = int_stack + 1978215;
 Libderiv->deriv2_classes[6][10][9] = int_stack + 1979755;
 Libderiv->deriv_classes[7][5][9] = int_stack + 1981603;
 Libderiv->deriv_classes[7][6][9] = int_stack + 1982359;
 Libderiv->deriv_classes[7][7][9] = int_stack + 1983367;
 Libderiv->deriv_classes[7][8][9] = int_stack + 1984663;
 Libderiv->deriv_classes[7][9][9] = int_stack + 1986283;
 Libderiv->deriv_classes[7][10][9] = int_stack + 1988263;
 Libderiv->deriv2_classes[7][5][9] = int_stack + 1990639;
 Libderiv->deriv2_classes[7][6][9] = int_stack + 1991395;
 Libderiv->deriv2_classes[7][7][9] = int_stack + 1992403;
 Libderiv->deriv2_classes[7][8][9] = int_stack + 1993699;
 Libderiv->deriv2_classes[7][9][9] = int_stack + 1995319;
 Libderiv->deriv2_classes[7][10][9] = int_stack + 1997299;
 Libderiv->deriv_classes[8][5][9] = int_stack + 1999675;
 Libderiv->deriv_classes[8][6][9] = int_stack + 2000620;
 Libderiv->deriv_classes[8][7][9] = int_stack + 2001880;
 Libderiv->deriv_classes[8][8][9] = int_stack + 2003500;
 Libderiv->deriv_classes[8][9][9] = int_stack + 2005525;
 Libderiv->deriv_classes[8][10][9] = int_stack + 2008000;
 Libderiv->deriv2_classes[8][5][9] = int_stack + 2010970;
 Libderiv->deriv2_classes[8][6][9] = int_stack + 2011915;
 Libderiv->deriv2_classes[8][7][9] = int_stack + 2013175;
 Libderiv->deriv2_classes[8][8][9] = int_stack + 2014795;
 Libderiv->deriv2_classes[8][9][9] = int_stack + 2016820;
 Libderiv->deriv2_classes[8][10][9] = int_stack + 2019295;
 Libderiv->deriv2_classes[9][5][9] = int_stack + 2022265;
 Libderiv->deriv2_classes[9][6][9] = int_stack + 2023420;
 Libderiv->deriv2_classes[9][7][9] = int_stack + 2024960;
 Libderiv->deriv2_classes[9][8][9] = int_stack + 2026940;
 Libderiv->deriv2_classes[9][9][9] = int_stack + 2029415;
 Libderiv->deriv2_classes[9][10][9] = int_stack + 2032440;
 Libderiv->deriv_classes[5][5][8] = int_stack + 2036070;
 Libderiv->deriv_classes[5][6][8] = int_stack + 2036511;
 Libderiv->deriv_classes[5][7][8] = int_stack + 2037099;
 Libderiv->deriv_classes[5][8][8] = int_stack + 2037855;
 Libderiv->deriv_classes[5][9][8] = int_stack + 2038800;
 Libderiv->deriv_classes[5][10][8] = int_stack + 2039955;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 2041341;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 2041782;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 2042370;
 Libderiv->deriv2_classes[5][8][8] = int_stack + 2043126;
 Libderiv->deriv2_classes[5][9][8] = int_stack + 2044071;
 Libderiv->deriv2_classes[5][10][8] = int_stack + 2045226;
 Libderiv->deriv_classes[6][5][8] = int_stack + 2046612;
 Libderiv->deriv_classes[6][6][8] = int_stack + 2047200;
 Libderiv->deriv_classes[6][7][8] = int_stack + 2047984;
 Libderiv->deriv_classes[6][8][8] = int_stack + 2048992;
 Libderiv->deriv_classes[6][9][8] = int_stack + 2050252;
 Libderiv->deriv_classes[6][10][8] = int_stack + 2051792;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 2053640;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 2054228;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 2055012;
 Libderiv->deriv2_classes[6][8][8] = int_stack + 2056020;
 Libderiv->deriv2_classes[6][9][8] = int_stack + 2057280;
 Libderiv->deriv2_classes[6][10][8] = int_stack + 2058820;
 Libderiv->deriv_classes[7][5][8] = int_stack + 2060668;
 Libderiv->deriv_classes[7][6][8] = int_stack + 2061424;
 Libderiv->deriv_classes[7][7][8] = int_stack + 2062432;
 Libderiv->deriv_classes[7][8][8] = int_stack + 2063728;
 Libderiv->deriv_classes[7][9][8] = int_stack + 2065348;
 Libderiv->deriv_classes[7][10][8] = int_stack + 2067328;
 Libderiv->deriv2_classes[7][5][8] = int_stack + 2069704;
 Libderiv->deriv2_classes[7][6][8] = int_stack + 2070460;
 Libderiv->deriv2_classes[7][7][8] = int_stack + 2071468;
 Libderiv->deriv2_classes[7][8][8] = int_stack + 2072764;
 Libderiv->deriv2_classes[7][9][8] = int_stack + 2074384;
 Libderiv->deriv2_classes[7][10][8] = int_stack + 2076364;
 Libderiv->deriv_classes[8][5][8] = int_stack + 2078740;
 Libderiv->deriv_classes[8][6][8] = int_stack + 2079685;
 Libderiv->deriv_classes[8][7][8] = int_stack + 2080945;
 Libderiv->deriv_classes[8][8][8] = int_stack + 2082565;
 Libderiv->deriv_classes[8][9][8] = int_stack + 2084590;
 Libderiv->deriv_classes[8][10][8] = int_stack + 2087065;
 Libderiv->deriv2_classes[8][5][8] = int_stack + 2090035;
 Libderiv->deriv2_classes[8][6][8] = int_stack + 2090980;
 Libderiv->deriv2_classes[8][7][8] = int_stack + 2092240;
 Libderiv->deriv2_classes[8][8][8] = int_stack + 2093860;
 Libderiv->deriv2_classes[8][9][8] = int_stack + 2095885;
 Libderiv->deriv2_classes[8][10][8] = int_stack + 2098360;
 Libderiv->deriv2_classes[9][5][8] = int_stack + 2101330;
 Libderiv->deriv2_classes[9][6][8] = int_stack + 2102485;
 Libderiv->deriv2_classes[9][7][8] = int_stack + 2104025;
 Libderiv->deriv2_classes[9][8][8] = int_stack + 2106005;
 Libderiv->deriv2_classes[9][9][8] = int_stack + 2108480;
 Libderiv->deriv2_classes[9][10][8] = int_stack + 2111505;
 Libderiv->deriv_classes[5][5][7] = int_stack + 2115135;
 Libderiv->deriv_classes[5][6][7] = int_stack + 2115576;
 Libderiv->deriv_classes[5][7][7] = int_stack + 2116164;
 Libderiv->deriv_classes[5][8][7] = int_stack + 2116920;
 Libderiv->deriv_classes[5][9][7] = int_stack + 2117865;
 Libderiv->deriv_classes[5][10][7] = int_stack + 2119020;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 2120406;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 2120847;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 2121435;
 Libderiv->deriv2_classes[5][8][7] = int_stack + 2122191;
 Libderiv->deriv2_classes[5][9][7] = int_stack + 2123136;
 Libderiv->deriv2_classes[5][10][7] = int_stack + 2124291;
 Libderiv->deriv_classes[6][5][7] = int_stack + 2125677;
 Libderiv->deriv_classes[6][6][7] = int_stack + 2126265;
 Libderiv->deriv_classes[6][7][7] = int_stack + 2127049;
 Libderiv->deriv_classes[6][8][7] = int_stack + 2128057;
 Libderiv->deriv_classes[6][9][7] = int_stack + 2129317;
 Libderiv->deriv_classes[6][10][7] = int_stack + 2130857;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 2132705;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 2133293;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 2134077;
 Libderiv->deriv2_classes[6][8][7] = int_stack + 2135085;
 Libderiv->deriv2_classes[6][9][7] = int_stack + 2136345;
 Libderiv->deriv2_classes[6][10][7] = int_stack + 2137885;
 Libderiv->deriv_classes[7][5][7] = int_stack + 2139733;
 Libderiv->deriv_classes[7][6][7] = int_stack + 2140489;
 Libderiv->deriv_classes[7][7][7] = int_stack + 2141497;
 Libderiv->deriv_classes[7][8][7] = int_stack + 2142793;
 Libderiv->deriv_classes[7][9][7] = int_stack + 2144413;
 Libderiv->deriv_classes[7][10][7] = int_stack + 2146393;
 Libderiv->deriv2_classes[7][5][7] = int_stack + 2148769;
 Libderiv->deriv2_classes[7][6][7] = int_stack + 2149525;
 Libderiv->deriv2_classes[7][7][7] = int_stack + 2150533;
 Libderiv->deriv2_classes[7][8][7] = int_stack + 2151829;
 Libderiv->deriv2_classes[7][9][7] = int_stack + 2153449;
 Libderiv->deriv2_classes[7][10][7] = int_stack + 2155429;
 Libderiv->deriv_classes[8][5][7] = int_stack + 2157805;
 Libderiv->deriv_classes[8][6][7] = int_stack + 2158750;
 Libderiv->deriv_classes[8][7][7] = int_stack + 2160010;
 Libderiv->deriv_classes[8][8][7] = int_stack + 2161630;
 Libderiv->deriv_classes[8][9][7] = int_stack + 2163655;
 Libderiv->deriv_classes[8][10][7] = int_stack + 2166130;
 Libderiv->deriv2_classes[8][5][7] = int_stack + 2169100;
 Libderiv->deriv2_classes[8][6][7] = int_stack + 2170045;
 Libderiv->deriv2_classes[8][7][7] = int_stack + 2171305;
 Libderiv->deriv2_classes[8][8][7] = int_stack + 2172925;
 Libderiv->deriv2_classes[8][9][7] = int_stack + 2174950;
 Libderiv->deriv2_classes[8][10][7] = int_stack + 2177425;
 Libderiv->deriv2_classes[9][5][7] = int_stack + 2180395;
 Libderiv->deriv2_classes[9][6][7] = int_stack + 2181550;
 Libderiv->deriv2_classes[9][7][7] = int_stack + 2183090;
 Libderiv->deriv2_classes[9][8][7] = int_stack + 2185070;
 Libderiv->deriv2_classes[9][9][7] = int_stack + 2187545;
 Libderiv->deriv2_classes[9][10][7] = int_stack + 2190570;
 Libderiv->deriv_classes[5][5][6] = int_stack + 2194200;
 Libderiv->deriv_classes[5][6][6] = int_stack + 2194641;
 Libderiv->deriv_classes[5][7][6] = int_stack + 2195229;
 Libderiv->deriv_classes[5][8][6] = int_stack + 2195985;
 Libderiv->deriv_classes[5][9][6] = int_stack + 2196930;
 Libderiv->deriv_classes[5][10][6] = int_stack + 2198085;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 2199471;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 2199912;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 2200500;
 Libderiv->deriv2_classes[5][8][6] = int_stack + 2201256;
 Libderiv->deriv2_classes[5][9][6] = int_stack + 2202201;
 Libderiv->deriv2_classes[5][10][6] = int_stack + 2203356;
 Libderiv->deriv_classes[6][5][6] = int_stack + 2204742;
 Libderiv->deriv_classes[6][6][6] = int_stack + 2205330;
 Libderiv->deriv_classes[6][7][6] = int_stack + 2206114;
 Libderiv->deriv_classes[6][8][6] = int_stack + 2207122;
 Libderiv->deriv_classes[6][9][6] = int_stack + 2208382;
 Libderiv->deriv_classes[6][10][6] = int_stack + 2209922;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 2211770;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 2212358;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 2213142;
 Libderiv->deriv2_classes[6][8][6] = int_stack + 2214150;
 Libderiv->deriv2_classes[6][9][6] = int_stack + 2215410;
 Libderiv->deriv2_classes[6][10][6] = int_stack + 2216950;
 Libderiv->deriv_classes[7][5][6] = int_stack + 2218798;
 Libderiv->deriv_classes[7][6][6] = int_stack + 2219554;
 Libderiv->deriv_classes[7][7][6] = int_stack + 2220562;
 Libderiv->deriv_classes[7][8][6] = int_stack + 2221858;
 Libderiv->deriv_classes[7][9][6] = int_stack + 2223478;
 Libderiv->deriv_classes[7][10][6] = int_stack + 2225458;
 Libderiv->deriv2_classes[7][5][6] = int_stack + 2227834;
 Libderiv->deriv2_classes[7][6][6] = int_stack + 2228590;
 Libderiv->deriv2_classes[7][7][6] = int_stack + 2229598;
 Libderiv->deriv2_classes[7][8][6] = int_stack + 2230894;
 Libderiv->deriv2_classes[7][9][6] = int_stack + 2232514;
 Libderiv->deriv2_classes[7][10][6] = int_stack + 2234494;
 Libderiv->dvrr_classes[8][5] = int_stack + 2236870;
 Libderiv->deriv_classes[8][5][6] = int_stack + 2237815;
 Libderiv->dvrr_classes[8][6] = int_stack + 2238760;
 Libderiv->deriv_classes[8][6][6] = int_stack + 2240020;
 Libderiv->dvrr_classes[8][7] = int_stack + 2241280;
 Libderiv->deriv_classes[8][7][6] = int_stack + 2242900;
 Libderiv->dvrr_classes[8][8] = int_stack + 2244520;
 Libderiv->deriv_classes[8][8][6] = int_stack + 2246545;
 Libderiv->dvrr_classes[8][9] = int_stack + 2248570;
 Libderiv->deriv_classes[8][9][6] = int_stack + 2251045;
 Libderiv->deriv_classes[8][10][6] = int_stack + 2253520;
 Libderiv->deriv2_classes[8][5][6] = int_stack + 2256490;
 Libderiv->deriv2_classes[8][6][6] = int_stack + 2257435;
 Libderiv->deriv2_classes[8][7][6] = int_stack + 2258695;
 Libderiv->deriv2_classes[8][8][6] = int_stack + 2260315;
 Libderiv->deriv2_classes[8][9][6] = int_stack + 2262340;
 Libderiv->deriv2_classes[8][10][6] = int_stack + 2264815;
 Libderiv->deriv_classes[9][5][0] = int_stack + 2267785;
 Libderiv->deriv2_classes[9][5][6] = int_stack + 2268940;
 Libderiv->deriv_classes[9][6][0] = int_stack + 2270095;
 Libderiv->deriv2_classes[9][6][6] = int_stack + 2271635;
 Libderiv->deriv_classes[9][7][0] = int_stack + 2273175;
 Libderiv->deriv2_classes[9][7][6] = int_stack + 2275155;
 Libderiv->deriv_classes[9][8][0] = int_stack + 2277135;
 Libderiv->deriv2_classes[9][8][6] = int_stack + 2279610;
 Libderiv->deriv_classes[9][9][0] = int_stack + 2282085;
 Libderiv->deriv2_classes[9][9][6] = int_stack + 2285110;
 Libderiv->deriv2_classes[9][10][6] = int_stack + 2288135;
 Libderiv->deriv_classes[5][5][2] = int_stack + 2291765;
 Libderiv->deriv_classes[5][6][2] = int_stack + 2292206;
 Libderiv->deriv_classes[5][7][2] = int_stack + 2292794;
 Libderiv->deriv_classes[5][8][2] = int_stack + 2293550;
 Libderiv->deriv_classes[5][9][2] = int_stack + 2294495;
 Libderiv->deriv_classes[5][10][2] = int_stack + 2295650;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 2297036;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 2297477;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 2298065;
 Libderiv->deriv2_classes[5][8][2] = int_stack + 2298821;
 Libderiv->deriv2_classes[5][9][2] = int_stack + 2299766;
 Libderiv->deriv2_classes[5][10][2] = int_stack + 2300921;
 Libderiv->deriv_classes[6][5][2] = int_stack + 2302307;
 Libderiv->deriv_classes[6][6][2] = int_stack + 2302895;
 Libderiv->deriv_classes[6][7][2] = int_stack + 2303679;
 Libderiv->deriv_classes[6][8][2] = int_stack + 2304687;
 Libderiv->deriv_classes[6][9][2] = int_stack + 2305947;
 Libderiv->deriv_classes[6][10][2] = int_stack + 2307487;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 2309335;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 2309923;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 2310707;
 Libderiv->deriv2_classes[6][8][2] = int_stack + 2311715;
 Libderiv->deriv2_classes[6][9][2] = int_stack + 2312975;
 Libderiv->deriv2_classes[6][10][2] = int_stack + 2314515;
 Libderiv->deriv_classes[7][5][2] = int_stack + 2316363;
 Libderiv->deriv_classes[7][6][2] = int_stack + 2317119;
 Libderiv->deriv_classes[7][7][2] = int_stack + 2318127;
 Libderiv->deriv_classes[7][8][2] = int_stack + 2319423;
 Libderiv->deriv_classes[7][9][2] = int_stack + 2321043;
 Libderiv->deriv_classes[7][10][2] = int_stack + 2323023;
 Libderiv->deriv2_classes[7][5][2] = int_stack + 2325399;
 Libderiv->deriv2_classes[7][6][2] = int_stack + 2326155;
 Libderiv->deriv2_classes[7][7][2] = int_stack + 2327163;
 Libderiv->deriv2_classes[7][8][2] = int_stack + 2328459;
 Libderiv->deriv2_classes[7][9][2] = int_stack + 2330079;
 Libderiv->deriv2_classes[7][10][2] = int_stack + 2332059;
 Libderiv->deriv_classes[8][5][2] = int_stack + 2334435;
 Libderiv->deriv_classes[8][6][2] = int_stack + 2335380;
 Libderiv->deriv_classes[8][7][2] = int_stack + 2336640;
 Libderiv->deriv_classes[8][8][2] = int_stack + 2338260;
 Libderiv->deriv_classes[8][9][2] = int_stack + 2340285;
 Libderiv->deriv_classes[8][10][2] = int_stack + 2342760;
 Libderiv->deriv2_classes[8][5][2] = int_stack + 2345730;
 Libderiv->deriv2_classes[8][6][2] = int_stack + 2346675;
 Libderiv->deriv2_classes[8][7][2] = int_stack + 2347935;
 Libderiv->deriv2_classes[8][8][2] = int_stack + 2349555;
 Libderiv->deriv2_classes[8][9][2] = int_stack + 2351580;
 Libderiv->deriv2_classes[8][10][2] = int_stack + 2354055;
 Libderiv->deriv2_classes[9][5][2] = int_stack + 2357025;
 Libderiv->deriv2_classes[9][6][2] = int_stack + 2358180;
 Libderiv->deriv2_classes[9][7][2] = int_stack + 2359720;
 Libderiv->deriv2_classes[9][8][2] = int_stack + 2361700;
 Libderiv->deriv2_classes[9][9][2] = int_stack + 2364175;
 Libderiv->deriv2_classes[9][10][2] = int_stack + 2367200;
 Libderiv->deriv_classes[5][5][1] = int_stack + 2370830;
 Libderiv->deriv_classes[5][6][1] = int_stack + 2371271;
 Libderiv->deriv_classes[5][7][1] = int_stack + 2371859;
 Libderiv->deriv_classes[5][8][1] = int_stack + 2372615;
 Libderiv->deriv_classes[5][9][1] = int_stack + 2373560;
 Libderiv->deriv_classes[5][10][1] = int_stack + 2374715;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 2376101;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 2376542;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 2377130;
 Libderiv->deriv2_classes[5][8][1] = int_stack + 2377886;
 Libderiv->deriv2_classes[5][9][1] = int_stack + 2378831;
 Libderiv->deriv2_classes[5][10][1] = int_stack + 2379986;
 Libderiv->deriv_classes[6][5][1] = int_stack + 2381372;
 Libderiv->deriv_classes[6][6][1] = int_stack + 2381960;
 Libderiv->deriv_classes[6][7][1] = int_stack + 2382744;
 Libderiv->deriv_classes[6][8][1] = int_stack + 2383752;
 Libderiv->deriv_classes[6][9][1] = int_stack + 2385012;
 Libderiv->deriv_classes[6][10][1] = int_stack + 2386552;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 2388400;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 2388988;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 2389772;
 Libderiv->deriv2_classes[6][8][1] = int_stack + 2390780;
 Libderiv->deriv2_classes[6][9][1] = int_stack + 2392040;
 Libderiv->deriv2_classes[6][10][1] = int_stack + 2393580;
 Libderiv->deriv_classes[7][5][1] = int_stack + 2395428;
 Libderiv->deriv_classes[7][6][1] = int_stack + 2396184;
 Libderiv->deriv_classes[7][7][1] = int_stack + 2397192;
 Libderiv->deriv_classes[7][8][1] = int_stack + 2398488;
 Libderiv->deriv_classes[7][9][1] = int_stack + 2400108;
 Libderiv->deriv_classes[7][10][1] = int_stack + 2402088;
 Libderiv->deriv2_classes[7][5][1] = int_stack + 2404464;
 Libderiv->deriv2_classes[7][6][1] = int_stack + 2405220;
 Libderiv->deriv2_classes[7][7][1] = int_stack + 2406228;
 Libderiv->deriv2_classes[7][8][1] = int_stack + 2407524;
 Libderiv->deriv2_classes[7][9][1] = int_stack + 2409144;
 Libderiv->deriv2_classes[7][10][1] = int_stack + 2411124;
 Libderiv->deriv_classes[8][5][1] = int_stack + 2413500;
 Libderiv->deriv_classes[8][6][1] = int_stack + 2414445;
 Libderiv->deriv_classes[8][7][1] = int_stack + 2415705;
 Libderiv->deriv_classes[8][8][1] = int_stack + 2417325;
 Libderiv->deriv_classes[8][9][1] = int_stack + 2419350;
 Libderiv->deriv_classes[8][10][1] = int_stack + 2421825;
 Libderiv->deriv2_classes[8][5][1] = int_stack + 2424795;
 Libderiv->deriv2_classes[8][6][1] = int_stack + 2425740;
 Libderiv->deriv2_classes[8][7][1] = int_stack + 2427000;
 Libderiv->deriv2_classes[8][8][1] = int_stack + 2428620;
 Libderiv->deriv2_classes[8][9][1] = int_stack + 2430645;
 Libderiv->deriv2_classes[8][10][1] = int_stack + 2433120;
 Libderiv->deriv2_classes[9][5][1] = int_stack + 2436090;
 Libderiv->deriv2_classes[9][6][1] = int_stack + 2437245;
 Libderiv->deriv2_classes[9][7][1] = int_stack + 2438785;
 Libderiv->deriv2_classes[9][8][1] = int_stack + 2440765;
 Libderiv->deriv2_classes[9][9][1] = int_stack + 2443240;
 Libderiv->deriv2_classes[9][10][1] = int_stack + 2446265;
 Libderiv->dvrr_classes[5][5] = int_stack + 2449895;
 Libderiv->dvrr_classes[5][6] = int_stack + 2450336;
 Libderiv->dvrr_classes[5][7] = int_stack + 2450924;
 Libderiv->dvrr_classes[5][8] = int_stack + 2451680;
 Libderiv->dvrr_classes[5][9] = int_stack + 2452625;
 Libderiv->dvrr_classes[5][10] = int_stack + 2453780;
 Libderiv->deriv_classes[5][5][0] = int_stack + 2455166;
 Libderiv->deriv_classes[5][6][0] = int_stack + 2455607;
 Libderiv->deriv_classes[5][7][0] = int_stack + 2456195;
 Libderiv->deriv_classes[5][8][0] = int_stack + 2456951;
 Libderiv->deriv_classes[5][9][0] = int_stack + 2457896;
 Libderiv->deriv_classes[5][10][0] = int_stack + 2459051;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 2460437;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 2460878;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 2461466;
 Libderiv->deriv2_classes[5][8][0] = int_stack + 2462222;
 Libderiv->deriv2_classes[5][9][0] = int_stack + 2463167;
 Libderiv->deriv2_classes[5][10][0] = int_stack + 2464322;
 Libderiv->dvrr_classes[6][5] = int_stack + 2465708;
 Libderiv->dvrr_classes[6][6] = int_stack + 2466296;
 Libderiv->dvrr_classes[6][7] = int_stack + 2467080;
 Libderiv->dvrr_classes[6][8] = int_stack + 2468088;
 Libderiv->dvrr_classes[6][9] = int_stack + 2469348;
 Libderiv->dvrr_classes[6][10] = int_stack + 2470888;
 Libderiv->deriv_classes[6][5][0] = int_stack + 2472736;
 Libderiv->deriv_classes[6][6][0] = int_stack + 2473324;
 Libderiv->deriv_classes[6][7][0] = int_stack + 2474108;
 Libderiv->deriv_classes[6][8][0] = int_stack + 2475116;
 Libderiv->deriv_classes[6][9][0] = int_stack + 2476376;
 Libderiv->deriv_classes[6][10][0] = int_stack + 2477916;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 2479764;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 2480352;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 2481136;
 Libderiv->deriv2_classes[6][8][0] = int_stack + 2482144;
 Libderiv->deriv2_classes[6][9][0] = int_stack + 2483404;
 Libderiv->deriv2_classes[6][10][0] = int_stack + 2484944;
 Libderiv->dvrr_classes[7][5] = int_stack + 2486792;
 Libderiv->dvrr_classes[7][6] = int_stack + 2487548;
 Libderiv->dvrr_classes[7][7] = int_stack + 2488556;
 Libderiv->dvrr_classes[7][8] = int_stack + 2489852;
 Libderiv->dvrr_classes[7][9] = int_stack + 2491472;
 Libderiv->dvrr_classes[7][10] = int_stack + 2493452;
 Libderiv->deriv_classes[7][5][0] = int_stack + 2495828;
 Libderiv->deriv_classes[7][6][0] = int_stack + 2496584;
 Libderiv->deriv_classes[7][7][0] = int_stack + 2497592;
 Libderiv->deriv_classes[7][8][0] = int_stack + 2498888;
 Libderiv->deriv_classes[7][9][0] = int_stack + 2500508;
 Libderiv->deriv_classes[7][10][0] = int_stack + 2502488;
 Libderiv->deriv2_classes[7][5][0] = int_stack + 2504864;
 Libderiv->deriv2_classes[7][6][0] = int_stack + 2505620;
 Libderiv->deriv2_classes[7][7][0] = int_stack + 2506628;
 Libderiv->deriv2_classes[7][8][0] = int_stack + 2507924;
 Libderiv->deriv2_classes[7][9][0] = int_stack + 2509544;
 Libderiv->deriv2_classes[7][10][0] = int_stack + 2511524;
 Libderiv->deriv_classes[8][5][0] = int_stack + 2513900;
 Libderiv->deriv_classes[8][6][0] = int_stack + 2514845;
 Libderiv->deriv_classes[8][7][0] = int_stack + 2516105;
 Libderiv->deriv_classes[8][8][0] = int_stack + 2517725;
 Libderiv->deriv_classes[8][9][0] = int_stack + 2519750;
 Libderiv->deriv_classes[8][10][0] = int_stack + 2522225;
 Libderiv->deriv2_classes[8][5][0] = int_stack + 2525195;
 Libderiv->deriv2_classes[8][6][0] = int_stack + 2526140;
 Libderiv->deriv2_classes[8][7][0] = int_stack + 2527400;
 Libderiv->deriv2_classes[8][8][0] = int_stack + 2529020;
 Libderiv->deriv2_classes[8][9][0] = int_stack + 2531045;
 Libderiv->deriv2_classes[8][10][0] = int_stack + 2533520;
 Libderiv->deriv2_classes[9][5][0] = int_stack + 2536490;
 Libderiv->deriv2_classes[9][6][0] = int_stack + 2537645;
 Libderiv->deriv2_classes[9][7][0] = int_stack + 2539185;
 Libderiv->deriv2_classes[9][8][0] = int_stack + 2541165;
 Libderiv->deriv2_classes[9][9][0] = int_stack + 2543640;
 Libderiv->deriv2_classes[9][10][0] = int_stack + 2546665;
 memset(int_stack,0,20402360);

 Libderiv->dvrr_stack = int_stack + 16217439;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_hghh(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2550295,int_stack+2450336,int_stack+2449895,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2551618,int_stack+2450924,int_stack+2450336,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2553382,int_stack+2551618,int_stack+2550295,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2556028,int_stack+2451680,int_stack+2450924,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2558296,int_stack+2556028,int_stack+2551618,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2561824,int_stack+2558296,int_stack+2553382,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2566234,int_stack+2452625,int_stack+2451680,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2569069,int_stack+2566234,int_stack+2556028,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2573605,int_stack+2569069,int_stack+2558296,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2579485,int_stack+2573605,int_stack+2561824,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2586100,int_stack+1799316,int_stack+1798875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2449895,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2587423,int_stack+1799904,int_stack+1799316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2450336,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2589187,int_stack+2587423,int_stack+2586100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2550295,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2591833,int_stack+1800660,int_stack+1799904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2450924,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2594101,int_stack+2591833,int_stack+2587423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2551618,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2597629,int_stack+2594101,int_stack+2589187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2553382,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2602039,int_stack+1801605,int_stack+1800660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2451680,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2604874,int_stack+2602039,int_stack+2591833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2556028,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2609410,int_stack+2604874,int_stack+2594101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2558296,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2615290,int_stack+2609410,int_stack+2597629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2561824,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2621905,int_stack+1802760,int_stack+1801605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2452625,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2625370,int_stack+2621905,int_stack+2602039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2566234,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2631040,int_stack+2625370,int_stack+2604874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2569069,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2621905,int_stack+2631040,int_stack+2609410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2573605,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2630725,int_stack+2621905,int_stack+2615290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2579485,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2621905,int_stack+2466296,int_stack+2465708,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2623669,int_stack+2467080,int_stack+2466296,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2626021,int_stack+2623669,int_stack+2621905,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2639986,int_stack+2468088,int_stack+2467080,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2643010,int_stack+2639986,int_stack+2623669,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2647714,int_stack+2643010,int_stack+2626021,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2653594,int_stack+2469348,int_stack+2468088,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2657374,int_stack+2653594,int_stack+2639986,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2663422,int_stack+2657374,int_stack+2643010,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2671262,int_stack+2663422,int_stack+2647714,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2680082,int_stack+1810005,int_stack+1809417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465708,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2681846,int_stack+1810789,int_stack+1810005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2466296,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2684198,int_stack+2681846,int_stack+2680082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2621905,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2687726,int_stack+1811797,int_stack+1810789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2467080,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2690750,int_stack+2687726,int_stack+2681846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2623669,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2695454,int_stack+2690750,int_stack+2684198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2626021,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2701334,int_stack+1813057,int_stack+1811797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2468088,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2705114,int_stack+2701334,int_stack+2687726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2639986,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2711162,int_stack+2705114,int_stack+2690750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2643010,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2719002,int_stack+2711162,int_stack+2695454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2647714,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2727822,int_stack+1814597,int_stack+1813057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2469348,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2732442,int_stack+2727822,int_stack+2701334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653594,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2740002,int_stack+2732442,int_stack+2705114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2657374,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2727822,int_stack+2740002,int_stack+2711162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2663422,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2739582,int_stack+2727822,int_stack+2719002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2671262,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2751930,int_stack+2739582,int_stack+2630725,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2727822,int_stack+2487548,int_stack+2486792,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2730090,int_stack+2488556,int_stack+2487548,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2733114,int_stack+2730090,int_stack+2727822,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2779713,int_stack+2489852,int_stack+2488556,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2783601,int_stack+2779713,int_stack+2730090,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2789649,int_stack+2783601,int_stack+2733114,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2797209,int_stack+2491472,int_stack+2489852,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2802069,int_stack+2797209,int_stack+2779713,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2809845,int_stack+2802069,int_stack+2783601,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2819925,int_stack+2809845,int_stack+2789649,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2831265,int_stack+1824229,int_stack+1823473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2486792,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2833533,int_stack+1825237,int_stack+1824229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2487548,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2836557,int_stack+2833533,int_stack+2831265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2727822,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2841093,int_stack+1826533,int_stack+1825237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2488556,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2844981,int_stack+2841093,int_stack+2833533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2730090,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2851029,int_stack+2844981,int_stack+2836557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2733114,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2858589,int_stack+1828153,int_stack+1826533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2489852,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2863449,int_stack+2858589,int_stack+2841093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2779713,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2871225,int_stack+2863449,int_stack+2844981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2783601,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2881305,int_stack+2871225,int_stack+2851029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2789649,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2892645,int_stack+1830133,int_stack+1828153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2491472,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2898585,int_stack+2892645,int_stack+2858589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2797209,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2908305,int_stack+2898585,int_stack+2863449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2802069,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2892645,int_stack+2908305,int_stack+2871225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2809845,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2907765,int_stack+2892645,int_stack+2881305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2819925,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2923641,int_stack+2907765,int_stack+2739582,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2960685,int_stack+2923641,int_stack+2751930,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2892645,int_stack+2238760,int_stack+2236870,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2895480,int_stack+2241280,int_stack+2238760,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2899260,int_stack+2895480,int_stack+2892645,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3016251,int_stack+2244520,int_stack+2241280,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3021111,int_stack+3016251,int_stack+2895480,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3028671,int_stack+3021111,int_stack+2899260,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3038121,int_stack+2248570,int_stack+2244520,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3044196,int_stack+3038121,int_stack+3016251,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3053916,int_stack+3044196,int_stack+3021111,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3066516,int_stack+3053916,int_stack+3028671,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2904930,int_stack+1842490,int_stack+1841545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2236870,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3080691,int_stack+1843750,int_stack+1842490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2238760,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3084471,int_stack+3080691,int_stack+2904930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2892645,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3090141,int_stack+1845370,int_stack+1843750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2241280,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3095001,int_stack+3090141,int_stack+3080691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2895480,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3102561,int_stack+3095001,int_stack+3084471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2899260,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3112011,int_stack+1847395,int_stack+1845370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2244520,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3118086,int_stack+3112011,int_stack+3090141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3016251,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3127806,int_stack+3118086,int_stack+3095001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3021111,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3140406,int_stack+3127806,int_stack+3102561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3028671,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3154581,int_stack+1849870,int_stack+1847395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2248570,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3162006,int_stack+3154581,int_stack+3112011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3038121,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3174156,int_stack+3162006,int_stack+3118086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3044196,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3154581,int_stack+3174156,int_stack+3127806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3053916,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3173481,int_stack+3154581,int_stack+3140406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3066516,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3193326,int_stack+3173481,int_stack+2907765,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3240954,int_stack+3193326,int_stack+2923641,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3315042,int_stack+3240954,int_stack+2960685,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3154581,int_stack+1054335,int_stack+1050870,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3158046,int_stack+1058955,int_stack+1054335,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3162666,int_stack+3158046,int_stack+3154581,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3407652,int_stack+1064895,int_stack+1058955,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3413592,int_stack+3407652,int_stack+3158046,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3422832,int_stack+3413592,int_stack+3162666,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3434382,int_stack+18150,int_stack+1064895,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3441807,int_stack+3434382,int_stack+3407652,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3453687,int_stack+3441807,int_stack+3413592,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3469087,int_stack+3453687,int_stack+3422832,55);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3169596,int_stack+770130,int_stack+767820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050870,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3486412,int_stack+773210,int_stack+770130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1054335,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3491032,int_stack+3486412,int_stack+3169596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3154581,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3497962,int_stack+777170,int_stack+773210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058955,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3503902,int_stack+3497962,int_stack+3486412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3158046,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3513142,int_stack+3503902,int_stack+3491032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3162666,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3524692,int_stack+782120,int_stack+777170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1064895,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3532117,int_stack+3524692,int_stack+3497962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3407652,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3543997,int_stack+3532117,int_stack+3503902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3413592,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3559397,int_stack+3543997,int_stack+3513142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3422832,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3576722,int_stack+0,int_stack+782120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18150,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3585797,int_stack+3576722,int_stack+3524692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3434382,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3600647,int_stack+3585797,int_stack+3532117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3441807,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3576722,int_stack+3600647,int_stack+3543997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3453687,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3599822,int_stack+3576722,int_stack+3559397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3469087,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+3624077,int_stack+3599822,int_stack+3173481,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+3683612,int_stack+3624077,int_stack+3193326,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+3778868,int_stack+3683612,int_stack+3240954,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3576722,int_stack+1878381,int_stack+1877940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2449895, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3578045,int_stack+1878969,int_stack+1878381, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2450336, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3579809,int_stack+3578045,int_stack+3576722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2550295, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3582455,int_stack+1879725,int_stack+1878969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2450924, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3584723,int_stack+3582455,int_stack+3578045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2551618, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3588251,int_stack+3584723,int_stack+3579809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2553382, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3592661,int_stack+1880670,int_stack+1879725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2451680, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3595496,int_stack+3592661,int_stack+3582455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2556028, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3600032,int_stack+3595496,int_stack+3584723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2558296, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3605912,int_stack+3600032,int_stack+3588251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2561824, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3612527,int_stack+1881825,int_stack+1880670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2452625, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3615992,int_stack+3612527,int_stack+3592661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2566234, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3621662,int_stack+3615992,int_stack+3595496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2569069, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3612527,int_stack+3621662,int_stack+3600032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2573605, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3621347,int_stack+3612527,int_stack+3605912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2579485, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3612527,int_stack+1889070,int_stack+1888482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465708, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3614291,int_stack+1889854,int_stack+1889070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2466296, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3616643,int_stack+3614291,int_stack+3612527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2621905, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3630608,int_stack+1890862,int_stack+1889854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2467080, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3633632,int_stack+3630608,int_stack+3614291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2623669, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3638336,int_stack+3633632,int_stack+3616643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2626021, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3644216,int_stack+1892122,int_stack+1890862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2468088, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3647996,int_stack+3644216,int_stack+3630608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2639986, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3654044,int_stack+3647996,int_stack+3633632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2643010, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3661884,int_stack+3654044,int_stack+3638336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2647714, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3670704,int_stack+1893662,int_stack+1892122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2469348, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3675324,int_stack+3670704,int_stack+3644216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653594, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3682884,int_stack+3675324,int_stack+3647996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2657374, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3670704,int_stack+3682884,int_stack+3654044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2663422, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3682464,int_stack+3670704,int_stack+3661884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2671262, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3694812,int_stack+3682464,int_stack+3621347,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3670704,int_stack+1903294,int_stack+1902538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2486792, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3672972,int_stack+1904302,int_stack+1903294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2487548, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3675996,int_stack+3672972,int_stack+3670704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2727822, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3722595,int_stack+1905598,int_stack+1904302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2488556, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3726483,int_stack+3722595,int_stack+3672972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2730090, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3732531,int_stack+3726483,int_stack+3675996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2733114, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3740091,int_stack+1907218,int_stack+1905598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2489852, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3744951,int_stack+3740091,int_stack+3722595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2779713, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3752727,int_stack+3744951,int_stack+3726483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2783601, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3762807,int_stack+3752727,int_stack+3732531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2789649, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3902348,int_stack+1909198,int_stack+1907218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2491472, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3908288,int_stack+3902348,int_stack+3740091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2797209, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3918008,int_stack+3908288,int_stack+3744951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2802069, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3902348,int_stack+3918008,int_stack+3752727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2809845, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3917468,int_stack+3902348,int_stack+3762807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2819925, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3933344,int_stack+3917468,int_stack+3682464,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3970388,int_stack+3933344,int_stack+3694812,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3902348,int_stack+1921555,int_stack+1920610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2236870, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3905183,int_stack+1922815,int_stack+1921555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2238760, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3908963,int_stack+3905183,int_stack+3902348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2892645, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4025954,int_stack+1924435,int_stack+1922815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2241280, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4030814,int_stack+4025954,int_stack+3905183, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2895480, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4038374,int_stack+4030814,int_stack+3908963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2899260, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4047824,int_stack+1926460,int_stack+1924435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2244520, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4053899,int_stack+4047824,int_stack+4025954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3016251, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4063619,int_stack+4053899,int_stack+4030814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3021111, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4076219,int_stack+4063619,int_stack+4038374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3028671, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4090394,int_stack+1928935,int_stack+1926460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2248570, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4097819,int_stack+4090394,int_stack+4047824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3038121, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4109969,int_stack+4097819,int_stack+4053899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3044196, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4090394,int_stack+4109969,int_stack+4063619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3053916, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4109294,int_stack+4090394,int_stack+4076219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3066516, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+4129139,int_stack+4109294,int_stack+3917468,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4176767,int_stack+4129139,int_stack+3933344,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4250855,int_stack+4176767,int_stack+3970388,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4090394,int_stack+826740,int_stack+824430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050870, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4093859,int_stack+829820,int_stack+826740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1054335, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4098479,int_stack+4093859,int_stack+4090394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3154581, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4343465,int_stack+833780,int_stack+829820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058955, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4349405,int_stack+4343465,int_stack+4093859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3158046, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4358645,int_stack+4349405,int_stack+4098479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3162666, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4370195,int_stack+838730,int_stack+833780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1064895, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4377620,int_stack+4370195,int_stack+4343465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3407652, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4389500,int_stack+4377620,int_stack+4349405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3413592, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4404900,int_stack+4389500,int_stack+4358645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3422832, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4422225,int_stack+3630,int_stack+838730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18150, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4431300,int_stack+4422225,int_stack+4370195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3434382, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4446150,int_stack+4431300,int_stack+4377620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3441807, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4422225,int_stack+4446150,int_stack+4389500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3453687, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4445325,int_stack+4422225,int_stack+4404900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3469087, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+4469580,int_stack+4445325,int_stack+4109294,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+4529115,int_stack+4469580,int_stack+4129139,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+4624371,int_stack+4529115,int_stack+4176767,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4422225,int_stack+1957446,int_stack+1957005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2449895, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4423548,int_stack+1958034,int_stack+1957446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2450336, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4425312,int_stack+4423548,int_stack+4422225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2550295, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4427958,int_stack+1958790,int_stack+1958034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2450924, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4430226,int_stack+4427958,int_stack+4423548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2551618, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4433754,int_stack+4430226,int_stack+4425312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2553382, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3914633,int_stack+1959735,int_stack+1958790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2451680, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4438164,int_stack+3914633,int_stack+4427958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2556028, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4442700,int_stack+4438164,int_stack+4430226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2558296, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4448580,int_stack+4442700,int_stack+4433754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2561824, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4455195,int_stack+1960890,int_stack+1959735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2452625, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4458660,int_stack+4455195,int_stack+3914633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2566234, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4464330,int_stack+4458660,int_stack+4438164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2569069, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4455195,int_stack+4464330,int_stack+4442700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2573605, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4464015,int_stack+4455195,int_stack+4448580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2579485, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4455195,int_stack+1968135,int_stack+1967547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465708, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4456959,int_stack+1968919,int_stack+1968135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2466296, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4459311,int_stack+4456959,int_stack+4455195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2621905, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4473276,int_stack+1969927,int_stack+1968919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2467080, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4476300,int_stack+4473276,int_stack+4456959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2623669, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4481004,int_stack+4476300,int_stack+4459311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2626021, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4486884,int_stack+1971187,int_stack+1969927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2468088, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4490664,int_stack+4486884,int_stack+4473276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2639986, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4496712,int_stack+4490664,int_stack+4476300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2643010, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4504552,int_stack+4496712,int_stack+4481004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2647714, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4513372,int_stack+1972727,int_stack+1971187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2469348, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4517992,int_stack+4513372,int_stack+4486884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653594, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4525552,int_stack+4517992,int_stack+4490664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2657374, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4513372,int_stack+4525552,int_stack+4496712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2663422, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4525132,int_stack+4513372,int_stack+4504552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2671262, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4537480,int_stack+4525132,int_stack+4464015,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4513372,int_stack+1982359,int_stack+1981603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2486792, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4515640,int_stack+1983367,int_stack+1982359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2487548, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4518664,int_stack+4515640,int_stack+4513372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2727822, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4565263,int_stack+1984663,int_stack+1983367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2488556, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4569151,int_stack+4565263,int_stack+4515640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2730090, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4575199,int_stack+4569151,int_stack+4518664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2733114, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4582759,int_stack+1986283,int_stack+1984663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2489852, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4587619,int_stack+4582759,int_stack+4565263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2779713, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4595395,int_stack+4587619,int_stack+4569151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2783601, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4605475,int_stack+4595395,int_stack+4575199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2789649, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4616815,int_stack+1988263,int_stack+1986283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2491472, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4747851,int_stack+4616815,int_stack+4582759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2797209, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4757571,int_stack+4747851,int_stack+4587619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2802069, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4770531,int_stack+4757571,int_stack+4595395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2809845, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4747851,int_stack+4770531,int_stack+4605475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2819925, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+4763727,int_stack+4747851,int_stack+4525132,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+4800771,int_stack+4763727,int_stack+4537480,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4616815,int_stack+2000620,int_stack+1999675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2236870, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4619650,int_stack+2001880,int_stack+2000620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2238760, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+4619650,int_stack+4616815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2892645, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4856337,int_stack+2003500,int_stack+2001880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2241280, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4861197,int_stack+4856337,int_stack+4619650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2895480, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4868757,int_stack+4861197,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2899260, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4878207,int_stack+2005525,int_stack+2003500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2244520, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4884282,int_stack+4878207,int_stack+4856337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3016251, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4894002,int_stack+4884282,int_stack+4861197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3021111, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4906602,int_stack+4894002,int_stack+4868757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3028671, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4920777,int_stack+2008000,int_stack+2005525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2248570, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4928202,int_stack+4920777,int_stack+4878207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3038121, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4940352,int_stack+4928202,int_stack+4884282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3044196, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4920777,int_stack+4940352,int_stack+4894002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3053916, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4939677,int_stack+4920777,int_stack+4906602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3066516, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+4959522,int_stack+4939677,int_stack+4747851,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5007150,int_stack+4959522,int_stack+4763727,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+5081238,int_stack+5007150,int_stack+4800771,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4920777,int_stack+883350,int_stack+881040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050870, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4924242,int_stack+886430,int_stack+883350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1054335, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4928862,int_stack+4924242,int_stack+4920777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3154581, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5173848,int_stack+890390,int_stack+886430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058955, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5179788,int_stack+5173848,int_stack+4924242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3158046, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5189028,int_stack+5179788,int_stack+4928862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3162666, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5200578,int_stack+895340,int_stack+890390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1064895, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5208003,int_stack+5200578,int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3407652, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5219883,int_stack+5208003,int_stack+5179788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3413592, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5235283,int_stack+5219883,int_stack+5189028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3422832, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5252608,int_stack+7260,int_stack+895340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18150, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5261683,int_stack+5252608,int_stack+5200578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3434382, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5276533,int_stack+5261683,int_stack+5208003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3441807, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5252608,int_stack+5276533,int_stack+5219883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3453687, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5275708,int_stack+5252608,int_stack+5235283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3469087, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5299963,int_stack+5275708,int_stack+4939677,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+5359498,int_stack+5299963,int_stack+4959522,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+5454754,int_stack+5359498,int_stack+5007150,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5252608,int_stack+2036511,int_stack+2036070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2449895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5253931,int_stack+2037099,int_stack+2036511, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2450336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5255695,int_stack+5253931,int_stack+5252608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2550295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5258341,int_stack+2037855,int_stack+2037099, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2450924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5260609,int_stack+5258341,int_stack+5253931, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2551618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5264137,int_stack+5260609,int_stack+5255695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2553382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5268547,int_stack+2038800,int_stack+2037855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2451680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5271382,int_stack+5268547,int_stack+5258341, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2556028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5275918,int_stack+5271382,int_stack+5260609, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2558296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5281798,int_stack+5275918,int_stack+5264137, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2561824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5288413,int_stack+2039955,int_stack+2038800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2452625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5291878,int_stack+5288413,int_stack+5268547, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2566234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5297548,int_stack+5291878,int_stack+5271382, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2569069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5288413,int_stack+5297548,int_stack+5275918, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2573605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5297233,int_stack+5288413,int_stack+5281798, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2579485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5288413,int_stack+2047200,int_stack+2046612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5290177,int_stack+2047984,int_stack+2047200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2466296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5292529,int_stack+5290177,int_stack+5288413, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2621905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5306494,int_stack+2048992,int_stack+2047984, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2467080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5309518,int_stack+5306494,int_stack+5290177, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2623669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5314222,int_stack+5309518,int_stack+5292529, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2626021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5320102,int_stack+2050252,int_stack+2048992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2468088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5323882,int_stack+5320102,int_stack+5306494, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2639986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5329930,int_stack+5323882,int_stack+5309518, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2643010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5337770,int_stack+5329930,int_stack+5314222, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2647714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5346590,int_stack+2051792,int_stack+2050252, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2469348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5351210,int_stack+5346590,int_stack+5320102, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5358770,int_stack+5351210,int_stack+5323882, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2657374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5346590,int_stack+5358770,int_stack+5329930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2663422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5358350,int_stack+5346590,int_stack+5337770, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2671262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5370698,int_stack+5358350,int_stack+5297233,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5346590,int_stack+2061424,int_stack+2060668, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2486792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5348858,int_stack+2062432,int_stack+2061424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2487548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5351882,int_stack+5348858,int_stack+5346590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2727822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5398481,int_stack+2063728,int_stack+2062432, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2488556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5402369,int_stack+5398481,int_stack+5348858, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2730090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5408417,int_stack+5402369,int_stack+5351882, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2733114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5415977,int_stack+2065348,int_stack+2063728, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2489852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5420837,int_stack+5415977,int_stack+5398481, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2779713, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5428613,int_stack+5420837,int_stack+5402369, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2783601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5438693,int_stack+5428613,int_stack+5408417, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2789649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5578234,int_stack+2067328,int_stack+2065348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2491472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5584174,int_stack+5578234,int_stack+5415977, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2797209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5593894,int_stack+5584174,int_stack+5420837, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2802069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+5593894,int_stack+5428613, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2809845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5593354,int_stack+5578234,int_stack+5438693, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2819925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+5609230,int_stack+5593354,int_stack+5358350,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+5646274,int_stack+5609230,int_stack+5370698,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5578234,int_stack+2079685,int_stack+2078740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2236870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5581069,int_stack+2080945,int_stack+2079685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2238760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5584849,int_stack+5581069,int_stack+5578234, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2892645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5670,int_stack+2082565,int_stack+2080945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2241280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5701840,int_stack+5670,int_stack+5581069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2895480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5709400,int_stack+5701840,int_stack+5584849, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2899260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5718850,int_stack+2084590,int_stack+2082565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2244520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5724925,int_stack+5718850,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3016251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5734645,int_stack+5724925,int_stack+5701840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3021111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5747245,int_stack+5734645,int_stack+5709400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3028671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5761420,int_stack+2087065,int_stack+2084590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2248570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5768845,int_stack+5761420,int_stack+5718850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3038121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5780995,int_stack+5768845,int_stack+5724925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3044196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5761420,int_stack+5780995,int_stack+5734645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3053916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5780320,int_stack+5761420,int_stack+5747245, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3066516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5800165,int_stack+5780320,int_stack+5593354,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5847793,int_stack+5800165,int_stack+5609230,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+5921881,int_stack+5847793,int_stack+5646274,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5761420,int_stack+939960,int_stack+937650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5764885,int_stack+943040,int_stack+939960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1054335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5769505,int_stack+5764885,int_stack+5761420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3154581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6014491,int_stack+947000,int_stack+943040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6020431,int_stack+6014491,int_stack+5764885, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3158046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6029671,int_stack+6020431,int_stack+5769505, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3162666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6041221,int_stack+951950,int_stack+947000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1064895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6048646,int_stack+6041221,int_stack+6014491, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3407652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6060526,int_stack+6048646,int_stack+6020431, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3413592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6075926,int_stack+6060526,int_stack+6029671, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3422832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6093251,int_stack+10890,int_stack+951950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6102326,int_stack+6093251,int_stack+6041221, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3434382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6117176,int_stack+6102326,int_stack+6048646, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3441807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6093251,int_stack+6117176,int_stack+6060526, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3453687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6116351,int_stack+6093251,int_stack+6075926, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3469087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+6140606,int_stack+6116351,int_stack+5780320,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+6200141,int_stack+6140606,int_stack+5800165,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+6295397,int_stack+6200141,int_stack+5847793,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093251,int_stack+2115576,int_stack+2115135, 0.0, zero_stack, 1.0, int_stack+2449895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094574,int_stack+2116164,int_stack+2115576, 0.0, zero_stack, 1.0, int_stack+2450336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096338,int_stack+6094574,int_stack+6093251, 0.0, zero_stack, 1.0, int_stack+2550295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098984,int_stack+2116920,int_stack+2116164, 0.0, zero_stack, 1.0, int_stack+2450924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101252,int_stack+6098984,int_stack+6094574, 0.0, zero_stack, 1.0, int_stack+2551618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6104780,int_stack+6101252,int_stack+6096338, 0.0, zero_stack, 1.0, int_stack+2553382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5590519,int_stack+2117865,int_stack+2116920, 0.0, zero_stack, 1.0, int_stack+2451680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6109190,int_stack+5590519,int_stack+6098984, 0.0, zero_stack, 1.0, int_stack+2556028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6113726,int_stack+6109190,int_stack+6101252, 0.0, zero_stack, 1.0, int_stack+2558296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6119606,int_stack+6113726,int_stack+6104780, 0.0, zero_stack, 1.0, int_stack+2561824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6126221,int_stack+2119020,int_stack+2117865, 0.0, zero_stack, 1.0, int_stack+2452625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6129686,int_stack+6126221,int_stack+5590519, 0.0, zero_stack, 1.0, int_stack+2566234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6135356,int_stack+6129686,int_stack+6109190, 0.0, zero_stack, 1.0, int_stack+2569069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6126221,int_stack+6135356,int_stack+6113726, 0.0, zero_stack, 1.0, int_stack+2573605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6135041,int_stack+6126221,int_stack+6119606, 0.0, zero_stack, 1.0, int_stack+2579485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6126221,int_stack+2126265,int_stack+2125677, 0.0, zero_stack, 1.0, int_stack+2465708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6127985,int_stack+2127049,int_stack+2126265, 0.0, zero_stack, 1.0, int_stack+2466296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6130337,int_stack+6127985,int_stack+6126221, 0.0, zero_stack, 1.0, int_stack+2621905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6144302,int_stack+2128057,int_stack+2127049, 0.0, zero_stack, 1.0, int_stack+2467080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6147326,int_stack+6144302,int_stack+6127985, 0.0, zero_stack, 1.0, int_stack+2623669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6152030,int_stack+6147326,int_stack+6130337, 0.0, zero_stack, 1.0, int_stack+2626021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6157910,int_stack+2129317,int_stack+2128057, 0.0, zero_stack, 1.0, int_stack+2468088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6161690,int_stack+6157910,int_stack+6144302, 0.0, zero_stack, 1.0, int_stack+2639986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6167738,int_stack+6161690,int_stack+6147326, 0.0, zero_stack, 1.0, int_stack+2643010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6175578,int_stack+6167738,int_stack+6152030, 0.0, zero_stack, 1.0, int_stack+2647714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6184398,int_stack+2130857,int_stack+2129317, 0.0, zero_stack, 1.0, int_stack+2469348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6189018,int_stack+6184398,int_stack+6157910, 0.0, zero_stack, 1.0, int_stack+2653594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6196578,int_stack+6189018,int_stack+6161690, 0.0, zero_stack, 1.0, int_stack+2657374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6184398,int_stack+6196578,int_stack+6167738, 0.0, zero_stack, 1.0, int_stack+2663422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6196158,int_stack+6184398,int_stack+6175578, 0.0, zero_stack, 1.0, int_stack+2671262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+6208506,int_stack+6196158,int_stack+6135041,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6184398,int_stack+2140489,int_stack+2139733, 0.0, zero_stack, 1.0, int_stack+2486792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6186666,int_stack+2141497,int_stack+2140489, 0.0, zero_stack, 1.0, int_stack+2487548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6189690,int_stack+6186666,int_stack+6184398, 0.0, zero_stack, 1.0, int_stack+2727822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6236289,int_stack+2142793,int_stack+2141497, 0.0, zero_stack, 1.0, int_stack+2488556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6240177,int_stack+6236289,int_stack+6186666, 0.0, zero_stack, 1.0, int_stack+2730090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6246225,int_stack+6240177,int_stack+6189690, 0.0, zero_stack, 1.0, int_stack+2733114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6253785,int_stack+2144413,int_stack+2142793, 0.0, zero_stack, 1.0, int_stack+2489852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6258645,int_stack+6253785,int_stack+6236289, 0.0, zero_stack, 1.0, int_stack+2779713, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6266421,int_stack+6258645,int_stack+6240177, 0.0, zero_stack, 1.0, int_stack+2783601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6276501,int_stack+6266421,int_stack+6246225, 0.0, zero_stack, 1.0, int_stack+2789649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6287841,int_stack+2146393,int_stack+2144413, 0.0, zero_stack, 1.0, int_stack+2491472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6418877,int_stack+6287841,int_stack+6253785, 0.0, zero_stack, 1.0, int_stack+2797209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6428597,int_stack+6418877,int_stack+6258645, 0.0, zero_stack, 1.0, int_stack+2802069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6441557,int_stack+6428597,int_stack+6266421, 0.0, zero_stack, 1.0, int_stack+2809845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6418877,int_stack+6441557,int_stack+6276501, 0.0, zero_stack, 1.0, int_stack+2819925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+6434753,int_stack+6418877,int_stack+6196158,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+6471797,int_stack+6434753,int_stack+6208506,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6287841,int_stack+2158750,int_stack+2157805, 0.0, zero_stack, 1.0, int_stack+2236870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6290676,int_stack+2160010,int_stack+2158750, 0.0, zero_stack, 1.0, int_stack+2238760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6527363,int_stack+6290676,int_stack+6287841, 0.0, zero_stack, 1.0, int_stack+2892645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6533033,int_stack+2161630,int_stack+2160010, 0.0, zero_stack, 1.0, int_stack+2241280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6537893,int_stack+6533033,int_stack+6290676, 0.0, zero_stack, 1.0, int_stack+2895480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6545453,int_stack+6537893,int_stack+6527363, 0.0, zero_stack, 1.0, int_stack+2899260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6554903,int_stack+2163655,int_stack+2161630, 0.0, zero_stack, 1.0, int_stack+2244520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6560978,int_stack+6554903,int_stack+6533033, 0.0, zero_stack, 1.0, int_stack+3016251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6570698,int_stack+6560978,int_stack+6537893, 0.0, zero_stack, 1.0, int_stack+3021111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6583298,int_stack+6570698,int_stack+6545453, 0.0, zero_stack, 1.0, int_stack+3028671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6597473,int_stack+2166130,int_stack+2163655, 0.0, zero_stack, 1.0, int_stack+2248570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6604898,int_stack+6597473,int_stack+6554903, 0.0, zero_stack, 1.0, int_stack+3038121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6617048,int_stack+6604898,int_stack+6560978, 0.0, zero_stack, 1.0, int_stack+3044196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6597473,int_stack+6617048,int_stack+6570698, 0.0, zero_stack, 1.0, int_stack+3053916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6616373,int_stack+6597473,int_stack+6583298, 0.0, zero_stack, 1.0, int_stack+3066516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+6636218,int_stack+6616373,int_stack+6418877,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+6683846,int_stack+6636218,int_stack+6434753,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+6757934,int_stack+6683846,int_stack+6471797,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6597473,int_stack+996570,int_stack+994260, 0.0, zero_stack, 1.0, int_stack+1050870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6600938,int_stack+999650,int_stack+996570, 0.0, zero_stack, 1.0, int_stack+1054335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6605558,int_stack+6600938,int_stack+6597473, 0.0, zero_stack, 1.0, int_stack+3154581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6850544,int_stack+1003610,int_stack+999650, 0.0, zero_stack, 1.0, int_stack+1058955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6856484,int_stack+6850544,int_stack+6600938, 0.0, zero_stack, 1.0, int_stack+3158046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6865724,int_stack+6856484,int_stack+6605558, 0.0, zero_stack, 1.0, int_stack+3162666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6877274,int_stack+1008560,int_stack+1003610, 0.0, zero_stack, 1.0, int_stack+1064895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6884699,int_stack+6877274,int_stack+6850544, 0.0, zero_stack, 1.0, int_stack+3407652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6896579,int_stack+6884699,int_stack+6856484, 0.0, zero_stack, 1.0, int_stack+3413592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6911979,int_stack+6896579,int_stack+6865724, 0.0, zero_stack, 1.0, int_stack+3422832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6929304,int_stack+14520,int_stack+1008560, 0.0, zero_stack, 1.0, int_stack+18150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6938379,int_stack+6929304,int_stack+6877274, 0.0, zero_stack, 1.0, int_stack+3434382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6953229,int_stack+6938379,int_stack+6884699, 0.0, zero_stack, 1.0, int_stack+3441807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6929304,int_stack+6953229,int_stack+6896579, 0.0, zero_stack, 1.0, int_stack+3453687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6952404,int_stack+6929304,int_stack+6911979, 0.0, zero_stack, 1.0, int_stack+3469087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+6976659,int_stack+6952404,int_stack+6616373,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+7036194,int_stack+6976659,int_stack+6636218,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+7131450,int_stack+7036194,int_stack+6683846,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6929304,int_stack+2194641,int_stack+2194200, 1.0, int_stack+2449895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6930627,int_stack+2195229,int_stack+2194641, 1.0, int_stack+2450336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6932391,int_stack+6930627,int_stack+6929304, 1.0, int_stack+2550295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6935037,int_stack+2195985,int_stack+2195229, 1.0, int_stack+2450924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6937305,int_stack+6935037,int_stack+6930627, 1.0, int_stack+2551618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6940833,int_stack+6937305,int_stack+6932391, 1.0, int_stack+2553382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2550295,int_stack+2196930,int_stack+2195985, 1.0, int_stack+2451680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6945243,int_stack+2550295,int_stack+6935037, 1.0, int_stack+2556028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6949779,int_stack+6945243,int_stack+6937305, 1.0, int_stack+2558296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2553130,int_stack+6949779,int_stack+6940833, 1.0, int_stack+2561824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2559745,int_stack+2198085,int_stack+2196930, 1.0, int_stack+2452625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6955659,int_stack+2559745,int_stack+2550295, 1.0, int_stack+2566234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6961329,int_stack+6955659,int_stack+6945243, 1.0, int_stack+2569069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6968889,int_stack+6961329,int_stack+6949779, 1.0, int_stack+2573605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6955659,int_stack+6968889,int_stack+2553130, 1.0, int_stack+2579485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6964920,int_stack+2205330,int_stack+2204742, 1.0, int_stack+2465708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6966684,int_stack+2206114,int_stack+2205330, 1.0, int_stack+2466296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6969036,int_stack+6966684,int_stack+6964920, 1.0, int_stack+2621905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6972564,int_stack+2207122,int_stack+2206114, 1.0, int_stack+2467080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6975588,int_stack+6972564,int_stack+6966684, 1.0, int_stack+2623669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6980292,int_stack+6975588,int_stack+6969036, 1.0, int_stack+2626021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2621905,int_stack+2208382,int_stack+2207122, 1.0, int_stack+2468088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6986172,int_stack+2621905,int_stack+6972564, 1.0, int_stack+2639986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6992220,int_stack+6986172,int_stack+6975588, 1.0, int_stack+2643010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7000060,int_stack+6992220,int_stack+6980292, 1.0, int_stack+2647714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2639986,int_stack+2209922,int_stack+2208382, 1.0, int_stack+2469348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2644606,int_stack+2639986,int_stack+2621905, 1.0, int_stack+2653594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7008880,int_stack+2644606,int_stack+6986172, 1.0, int_stack+2657374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2639986,int_stack+7008880,int_stack+6992220, 1.0, int_stack+2663422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7008880,int_stack+2639986,int_stack+7000060, 1.0, int_stack+2671262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7021228,int_stack+7008880,int_stack+6955659,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2639986,int_stack+2219554,int_stack+2218798, 1.0, int_stack+2486792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2642254,int_stack+2220562,int_stack+2219554, 1.0, int_stack+2487548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2645278,int_stack+2642254,int_stack+2639986, 1.0, int_stack+2727822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7049011,int_stack+2221858,int_stack+2220562, 1.0, int_stack+2488556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7052899,int_stack+7049011,int_stack+2642254, 1.0, int_stack+2730090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7058947,int_stack+7052899,int_stack+2645278, 1.0, int_stack+2733114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2727822,int_stack+2223478,int_stack+2221858, 1.0, int_stack+2489852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7066507,int_stack+2727822,int_stack+7049011, 1.0, int_stack+2779713, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7074283,int_stack+7066507,int_stack+7052899, 1.0, int_stack+2783601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7084363,int_stack+7074283,int_stack+7058947, 1.0, int_stack+2789649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2779713,int_stack+2225458,int_stack+2223478, 1.0, int_stack+2491472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2785653,int_stack+2779713,int_stack+2727822, 1.0, int_stack+2797209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7095703,int_stack+2785653,int_stack+7066507, 1.0, int_stack+2802069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2779713,int_stack+7095703,int_stack+7074283, 1.0, int_stack+2809845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7095703,int_stack+2779713,int_stack+7084363, 1.0, int_stack+2819925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7254930,int_stack+7095703,int_stack+7008880,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7291974,int_stack+7254930,int_stack+7021228,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2779713,int_stack+2240020,int_stack+2237815, 1.0, int_stack+2236870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2649814,int_stack+2242900,int_stack+2240020, 1.0, int_stack+2238760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2782548,int_stack+2649814,int_stack+2779713, 1.0, int_stack+2892645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2788218,int_stack+2246545,int_stack+2242900, 1.0, int_stack+2241280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7111579,int_stack+2788218,int_stack+2649814, 1.0, int_stack+2895480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7119139,int_stack+7111579,int_stack+2782548, 1.0, int_stack+2899260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2892645,int_stack+2251045,int_stack+2246545, 1.0, int_stack+2244520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7347540,int_stack+2892645,int_stack+2788218, 1.0, int_stack+3016251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7357260,int_stack+7347540,int_stack+7111579, 1.0, int_stack+3021111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7369860,int_stack+7357260,int_stack+7119139, 1.0, int_stack+3028671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3016251,int_stack+2253520,int_stack+2251045, 1.0, int_stack+2248570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3023676,int_stack+3016251,int_stack+2892645, 1.0, int_stack+3038121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7384035,int_stack+3023676,int_stack+7347540, 1.0, int_stack+3044196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3016251,int_stack+7384035,int_stack+7357260, 1.0, int_stack+3053916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7384035,int_stack+3016251,int_stack+7369860, 1.0, int_stack+3066516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7403880,int_stack+7384035,int_stack+7095703,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7451508,int_stack+7403880,int_stack+7254930,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+7525596,int_stack+7451508,int_stack+7291974,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3016251,int_stack+1055875,int_stack+1052025, 1.0, int_stack+1050870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3019716,int_stack+1060935,int_stack+1055875, 1.0, int_stack+1054335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3024336,int_stack+3019716,int_stack+3016251, 1.0, int_stack+3154581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3031266,int_stack+1067370,int_stack+1060935, 1.0, int_stack+1058955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7618206,int_stack+3031266,int_stack+3019716, 1.0, int_stack+3158046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7627446,int_stack+7618206,int_stack+3024336, 1.0, int_stack+3162666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3154581,int_stack+1072320,int_stack+1067370, 1.0, int_stack+1064895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7638996,int_stack+3154581,int_stack+3031266, 1.0, int_stack+3407652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7650876,int_stack+7638996,int_stack+7618206, 1.0, int_stack+3413592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7666276,int_stack+7650876,int_stack+7627446, 1.0, int_stack+3422832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3407652,int_stack+21175,int_stack+1072320, 1.0, int_stack+18150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3416727,int_stack+3407652,int_stack+3154581, 1.0, int_stack+3434382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7683601,int_stack+3416727,int_stack+7638996, 1.0, int_stack+3441807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3407652,int_stack+7683601,int_stack+7650876, 1.0, int_stack+3453687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3430752,int_stack+3407652,int_stack+7666276, 1.0, int_stack+3469087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+7683601,int_stack+3430752,int_stack+7384035,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+7743136,int_stack+7683601,int_stack+7403880,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+7838392,int_stack+7743136,int_stack+7451508,441);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+7683601,int_stack+2453780,int_stack+2452625,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7687066,int_stack+7683601,int_stack+2566234,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7692736,int_stack+7687066,int_stack+2569069,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7683601,int_stack+7692736,int_stack+2573605,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7692421,int_stack+7683601,int_stack+2579485,21);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+7683601,int_stack+2470888,int_stack+2469348,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7701682,int_stack+7683601,int_stack+2653594,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7709242,int_stack+7701682,int_stack+2657374,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7719322,int_stack+7709242,int_stack+2663422,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7701682,int_stack+7719322,int_stack+2671262,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+7714030,int_stack+7701682,int_stack+7692421,441);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+7741813,int_stack+2493452,int_stack+2491472,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7747753,int_stack+7741813,int_stack+2797209,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7757473,int_stack+7747753,int_stack+2802069,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7741813,int_stack+7757473,int_stack+2809845,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7756933,int_stack+7741813,int_stack+2819925,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7772809,int_stack+7756933,int_stack+7701682,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3407652,int_stack+7772809,int_stack+7714030,441);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+7741813,int_stack+32065,int_stack+2248570,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7809853,int_stack+7741813,int_stack+3038121,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7822003,int_stack+7809853,int_stack+3044196,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2653594,int_stack+7822003,int_stack+3053916,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7809853,int_stack+2653594,int_stack+3066516,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7961872,int_stack+7809853,int_stack+7756933,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+8009500,int_stack+7961872,int_stack+7772809,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+8083588,int_stack+8009500,int_stack+3407652,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2653594,int_stack+2292206,int_stack+2291765,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2654917,int_stack+2292794,int_stack+2292206,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2656681,int_stack+2654917,int_stack+2653594,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2659327,int_stack+2293550,int_stack+2292794,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2661595,int_stack+2659327,int_stack+2654917,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2665123,int_stack+2661595,int_stack+2656681,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2669533,int_stack+2294495,int_stack+2293550,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2672368,int_stack+2669533,int_stack+2659327,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7829698,int_stack+2672368,int_stack+2661595,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7741813,int_stack+7829698,int_stack+2665123,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+7748428,int_stack+2295650,int_stack+2294495,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7683601,int_stack+7748428,int_stack+2669533,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7748428,int_stack+7683601,int_stack+2672368,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7683601,int_stack+7748428,int_stack+7829698,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+3463218,int_stack+7683601,int_stack+7741813,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7683601,int_stack+2302895,int_stack+2302307,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7685365,int_stack+2303679,int_stack+2302895,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7687717,int_stack+7685365,int_stack+7683601,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7748428,int_stack+2304687,int_stack+2303679,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7751452,int_stack+7748428,int_stack+7685365,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3472479,int_stack+7751452,int_stack+7687717,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3478359,int_stack+2305947,int_stack+2304687,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3162006,int_stack+3478359,int_stack+7748428,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3037206,int_stack+3162006,int_stack+7751452,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3045046,int_stack+3037206,int_stack+3472479,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3053866,int_stack+2307487,int_stack+2305947,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3058486,int_stack+3053866,int_stack+3478359,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3066046,int_stack+3058486,int_stack+3162006,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3053866,int_stack+3066046,int_stack+3037206,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+3065626,int_stack+3053866,int_stack+3045046,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2793078,int_stack+3065626,int_stack+3463218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7692421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3053866,int_stack+2317119,int_stack+2316363,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3056134,int_stack+2318127,int_stack+2317119,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3059158,int_stack+3056134,int_stack+3053866,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3482139,int_stack+2319423,int_stack+2318127,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2898720,int_stack+3482139,int_stack+3056134,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2820861,int_stack+2898720,int_stack+3059158,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2732682,int_stack+2321043,int_stack+2319423,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2486792,int_stack+2732682,int_stack+3482139,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2559745,int_stack+2486792,int_stack+2898720,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2569825,int_stack+2559745,int_stack+2820861,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2465708,int_stack+2323023,int_stack+2321043,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+10530,int_stack+2465708,int_stack+2732682,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8176198,int_stack+10530,int_stack+2486792,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+8189158,int_stack+8176198,int_stack+2559745,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8204278,int_stack+8189158,int_stack+2569825,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+8220154,int_stack+8204278,int_stack+3065626, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7701682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+8257198,int_stack+8220154,int_stack+2793078, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7714030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+8176198,int_stack+2335380,int_stack+2334435,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8179033,int_stack+2336640,int_stack+2335380,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+8182813,int_stack+8179033,int_stack+8176198,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+8188483,int_stack+2338260,int_stack+2336640,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8193343,int_stack+8188483,int_stack+8179033,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+10530,int_stack+8193343,int_stack+8182813,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2465708,int_stack+2340285,int_stack+2338260,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8312764,int_stack+2465708,int_stack+8188483,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8322484,int_stack+8312764,int_stack+8193343,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+8335084,int_stack+8322484,int_stack+10530,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8349259,int_stack+2342760,int_stack+2340285,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+8356684,int_stack+8349259,int_stack+2465708,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8368834,int_stack+8356684,int_stack+8312764,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+8349259,int_stack+8368834,int_stack+8322484,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8368159,int_stack+8349259,int_stack+8335084,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+8388004,int_stack+8368159,int_stack+8204278, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7756933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+8435632,int_stack+8388004,int_stack+8220154, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7772809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+8509720,int_stack+8435632,int_stack+8257198, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3407652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+8349259,int_stack+1349115,int_stack+1346805,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8352724,int_stack+1352195,int_stack+1349115,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+8357344,int_stack+8352724,int_stack+8349259,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+8602330,int_stack+1356155,int_stack+1352195,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8608270,int_stack+8602330,int_stack+8352724,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+8617510,int_stack+8608270,int_stack+8357344,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+8629060,int_stack+1361105,int_stack+1356155,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8636485,int_stack+8629060,int_stack+8602330,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8648365,int_stack+8636485,int_stack+8608270,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+8663765,int_stack+8648365,int_stack+8617510,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8681090,int_stack+24805,int_stack+1361105,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+8690165,int_stack+8681090,int_stack+8629060,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8705015,int_stack+8690165,int_stack+8636485,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+8681090,int_stack+8705015,int_stack+8648365,55);
 /*--- compute (m0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8704190,int_stack+8681090,int_stack+8663765,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+8728445,int_stack+8704190,int_stack+8368159, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7809853, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+8787980,int_stack+8728445,int_stack+8388004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+8883236,int_stack+8787980,int_stack+8435632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8009500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+8681090,int_stack+2371271,int_stack+2370830,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8682413,int_stack+2371859,int_stack+2371271,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+8684177,int_stack+8682413,int_stack+8681090,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+8686823,int_stack+2372615,int_stack+2371859,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8689091,int_stack+8686823,int_stack+8682413,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+8692619,int_stack+8689091,int_stack+8684177,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+8697029,int_stack+2373560,int_stack+2372615,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8699864,int_stack+8697029,int_stack+8686823,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8704400,int_stack+8699864,int_stack+8689091,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+8710280,int_stack+8704400,int_stack+8692619,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8716895,int_stack+2374715,int_stack+2373560,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+8720360,int_stack+8716895,int_stack+8697029,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8726030,int_stack+8720360,int_stack+8699864,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+8716895,int_stack+8726030,int_stack+8704400,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8725715,int_stack+8716895,int_stack+8710280,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+8716895,int_stack+2381960,int_stack+2381372,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8718659,int_stack+2382744,int_stack+2381960,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+8721011,int_stack+8718659,int_stack+8716895,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+8734976,int_stack+2383752,int_stack+2382744,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8738000,int_stack+8734976,int_stack+8718659,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+8742704,int_stack+8738000,int_stack+8721011,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+8748584,int_stack+2385012,int_stack+2383752,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8752364,int_stack+8748584,int_stack+8734976,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8758412,int_stack+8752364,int_stack+8738000,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+8766252,int_stack+8758412,int_stack+8742704,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8775072,int_stack+2386552,int_stack+2385012,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+8779692,int_stack+8775072,int_stack+8748584,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8787252,int_stack+8779692,int_stack+8752364,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+8775072,int_stack+8787252,int_stack+8758412,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8786832,int_stack+8775072,int_stack+8766252,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+8799180,int_stack+8786832,int_stack+8725715, 0.0, zero_stack, 1.0, int_stack+7692421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+8775072,int_stack+2396184,int_stack+2395428,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8777340,int_stack+2397192,int_stack+2396184,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+8780364,int_stack+8777340,int_stack+8775072,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+8826963,int_stack+2398488,int_stack+2397192,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8830851,int_stack+8826963,int_stack+8777340,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+8836899,int_stack+8830851,int_stack+8780364,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+8844459,int_stack+2400108,int_stack+2398488,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8849319,int_stack+8844459,int_stack+8826963,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8857095,int_stack+8849319,int_stack+8830851,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+8867175,int_stack+8857095,int_stack+8836899,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+19980,int_stack+2402088,int_stack+2400108,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+9006716,int_stack+19980,int_stack+8844459,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+9016436,int_stack+9006716,int_stack+8849319,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+9029396,int_stack+9016436,int_stack+8857095,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+9006716,int_stack+9029396,int_stack+8867175,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+9022592,int_stack+9006716,int_stack+8786832, 0.0, zero_stack, 1.0, int_stack+7701682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+9059636,int_stack+9022592,int_stack+8799180, 0.0, zero_stack, 1.0, int_stack+7714030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+19980,int_stack+2414445,int_stack+2413500,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+22815,int_stack+2415705,int_stack+2414445,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9115202,int_stack+22815,int_stack+19980,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2625685,int_stack+2417325,int_stack+2415705,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9120872,int_stack+2625685,int_stack+22815,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+9128432,int_stack+9120872,int_stack+9115202,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9137882,int_stack+2419350,int_stack+2417325,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+9143957,int_stack+9137882,int_stack+2625685,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+9153677,int_stack+9143957,int_stack+9120872,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+9166277,int_stack+9153677,int_stack+9128432,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+9180452,int_stack+2421825,int_stack+2419350,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+9187877,int_stack+9180452,int_stack+9137882,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+9200027,int_stack+9187877,int_stack+9143957,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+9180452,int_stack+9200027,int_stack+9153677,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+9199352,int_stack+9180452,int_stack+9166277,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+9219197,int_stack+9199352,int_stack+9006716, 0.0, zero_stack, 1.0, int_stack+7756933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+9266825,int_stack+9219197,int_stack+9022592, 0.0, zero_stack, 1.0, int_stack+7772809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+9340913,int_stack+9266825,int_stack+9059636, 0.0, zero_stack, 1.0, int_stack+3407652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+9180452,int_stack+1684335,int_stack+1682025,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9183917,int_stack+1687415,int_stack+1684335,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9188537,int_stack+9183917,int_stack+9180452,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9433523,int_stack+1691375,int_stack+1687415,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9439463,int_stack+9433523,int_stack+9183917,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+9448703,int_stack+9439463,int_stack+9188537,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9460253,int_stack+1696325,int_stack+1691375,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+9467678,int_stack+9460253,int_stack+9433523,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+9479558,int_stack+9467678,int_stack+9439463,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+9494958,int_stack+9479558,int_stack+9448703,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+9512283,int_stack+28435,int_stack+1696325,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+9521358,int_stack+9512283,int_stack+9460253,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+9536208,int_stack+9521358,int_stack+9467678,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+9512283,int_stack+9536208,int_stack+9479558,55);
 /*--- compute (m0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+9535383,int_stack+9512283,int_stack+9494958,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+9559638,int_stack+9535383,int_stack+9199352, 0.0, zero_stack, 1.0, int_stack+7809853, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+9619173,int_stack+9559638,int_stack+9219197, 0.0, zero_stack, 1.0, int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+9714429,int_stack+9619173,int_stack+9266825, 0.0, zero_stack, 1.0, int_stack+8009500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+9512283,int_stack+2455607,int_stack+2455166,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9513606,int_stack+2456195,int_stack+2455607,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9515370,int_stack+9513606,int_stack+9512283,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9518016,int_stack+2456951,int_stack+2456195,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9520284,int_stack+9518016,int_stack+9513606,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+9523812,int_stack+9520284,int_stack+9515370,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9528222,int_stack+2457896,int_stack+2456951,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+9531057,int_stack+9528222,int_stack+9518016,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+9535593,int_stack+9531057,int_stack+9520284,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+9541473,int_stack+9535593,int_stack+9523812,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+9548088,int_stack+2459051,int_stack+2457896,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+9551553,int_stack+9548088,int_stack+9528222,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+9557223,int_stack+9551553,int_stack+9531057,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+9548088,int_stack+9557223,int_stack+9535593,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+9556908,int_stack+9548088,int_stack+9541473,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+9548088,int_stack+2473324,int_stack+2472736,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9549852,int_stack+2474108,int_stack+2473324,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9552204,int_stack+9549852,int_stack+9548088,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9566169,int_stack+2475116,int_stack+2474108,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9569193,int_stack+9566169,int_stack+9549852,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+9573897,int_stack+9569193,int_stack+9552204,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9579777,int_stack+2476376,int_stack+2475116,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+9583557,int_stack+9579777,int_stack+9566169,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+9589605,int_stack+9583557,int_stack+9569193,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+9597445,int_stack+9589605,int_stack+9573897,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+9606265,int_stack+2477916,int_stack+2476376,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+9610885,int_stack+9606265,int_stack+9579777,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+9618445,int_stack+9610885,int_stack+9583557,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+9606265,int_stack+9618445,int_stack+9589605,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+9618025,int_stack+9606265,int_stack+9597445,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+9630373,int_stack+9618025,int_stack+9556908, 1.0, int_stack+7692421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+9606265,int_stack+2496584,int_stack+2495828,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9608533,int_stack+2497592,int_stack+2496584,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9611557,int_stack+9608533,int_stack+9606265,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9658156,int_stack+2498888,int_stack+2497592,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9662044,int_stack+9658156,int_stack+9608533,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+9668092,int_stack+9662044,int_stack+9611557,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9675652,int_stack+2500508,int_stack+2498888,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+9680512,int_stack+9675652,int_stack+9658156,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+9688288,int_stack+9680512,int_stack+9662044,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+9698368,int_stack+9688288,int_stack+9668092,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+26595,int_stack+2502488,int_stack+2500508,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7691245,int_stack+26595,int_stack+9675652,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+9837909,int_stack+7691245,int_stack+9680512,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+9850869,int_stack+9837909,int_stack+9688288,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+9865989,int_stack+9850869,int_stack+9698368,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+9881865,int_stack+9865989,int_stack+9618025, 1.0, int_stack+7701682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+9918909,int_stack+9881865,int_stack+9630373, 1.0, int_stack+7714030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+9837909,int_stack+2514845,int_stack+2513900,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9840744,int_stack+2516105,int_stack+2514845,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9844524,int_stack+9840744,int_stack+9837909,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9850194,int_stack+2517725,int_stack+2516105,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9855054,int_stack+9850194,int_stack+9840744,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7691245,int_stack+9855054,int_stack+9844524,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7700695,int_stack+2519750,int_stack+2517725,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7706770,int_stack+7700695,int_stack+9850194,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7716490,int_stack+7706770,int_stack+9855054,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+9974475,int_stack+7716490,int_stack+7691245,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+7729090,int_stack+2522225,int_stack+2519750,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+9988650,int_stack+7729090,int_stack+7700695,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+10000800,int_stack+9988650,int_stack+7706770,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+10017000,int_stack+10000800,int_stack+7716490,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+9988650,int_stack+10017000,int_stack+9974475,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+10008495,int_stack+9988650,int_stack+9865989, 1.0, int_stack+7756933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+10056123,int_stack+10008495,int_stack+9881865, 1.0, int_stack+7772809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+10130211,int_stack+10056123,int_stack+9918909, 1.0, int_stack+3407652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3407652,int_stack+2270095,int_stack+2267785,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3411117,int_stack+2273175,int_stack+2270095,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3415737,int_stack+3411117,int_stack+3407652,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3422667,int_stack+2277135,int_stack+2273175,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3428607,int_stack+3422667,int_stack+3411117,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3437847,int_stack+3428607,int_stack+3415737,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3449397,int_stack+2282085,int_stack+2277135,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7729090,int_stack+3449397,int_stack+3422667,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7756156,int_stack+7729090,int_stack+3428607,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7771556,int_stack+7756156,int_stack+3437847,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+7788881,int_stack+35035,int_stack+2282085,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+10222821,int_stack+7788881,int_stack+3449397,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7788881,int_stack+10222821,int_stack+7729090,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+10222821,int_stack+7788881,int_stack+7756156,55);
 /*--- compute (m0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+10245921,int_stack+10222821,int_stack+7771556,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+10270176,int_stack+10245921,int_stack+9988650, 1.0, int_stack+7809853, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+10329711,int_stack+10270176,int_stack+10008495, 1.0, int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+10424967,int_stack+10329711,int_stack+10056123, 1.0, int_stack+8009500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7961872,int_stack+39106,int_stack+38665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1798875,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7963195,int_stack+39694,int_stack+39106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1799316,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7964959,int_stack+7963195,int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2586100,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7967605,int_stack+40450,int_stack+39694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1799904,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7969873,int_stack+7967605,int_stack+7963195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2587423,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7973401,int_stack+7969873,int_stack+7964959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2589187,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7961872,int_stack+41395,int_stack+40450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1800660,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7977811,int_stack+7961872,int_stack+7967605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2591833,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7982347,int_stack+7977811,int_stack+7969873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2594101,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7964707,int_stack+7982347,int_stack+7973401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2597629,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7971322,int_stack+42550,int_stack+41395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1801605,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7988227,int_stack+7971322,int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2602039,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7993897,int_stack+7988227,int_stack+7977811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2604874,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7971322,int_stack+7993897,int_stack+7982347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2609410,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7980142,int_stack+7971322,int_stack+7964707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2615290,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7961872,int_stack+44524,int_stack+43936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1809417,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7963636,int_stack+45308,int_stack+44524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1810005,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7965988,int_stack+7963636,int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2680082,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7969516,int_stack+46316,int_stack+45308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1810789,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7972540,int_stack+7969516,int_stack+7963636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2681846,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7989403,int_stack+7972540,int_stack+7965988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2684198,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7961872,int_stack+47576,int_stack+46316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1811797,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7995283,int_stack+7961872,int_stack+7969516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2687726,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8001331,int_stack+7995283,int_stack+7972540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2690750,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7965652,int_stack+8001331,int_stack+7989403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2695454,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7989403,int_stack+49116,int_stack+47576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1813057,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8009171,int_stack+7989403,int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2701334,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016731,int_stack+8009171,int_stack+7995283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2705114,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7989403,int_stack+8016731,int_stack+8001331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2711162,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8001163,int_stack+7989403,int_stack+7965652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2719002,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+8013511,int_stack+8001163,int_stack+7980142,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7961872,int_stack+51720,int_stack+50964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1823473,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7964140,int_stack+52728,int_stack+51720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1824229,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7967164,int_stack+7964140,int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2831265,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7971700,int_stack+54024,int_stack+52728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1825237,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7975588,int_stack+7971700,int_stack+7964140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2833533,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7981636,int_stack+7975588,int_stack+7967164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2836557,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7961872,int_stack+55644,int_stack+54024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1826533,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7989196,int_stack+7961872,int_stack+7971700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2841093,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8041294,int_stack+7989196,int_stack+7975588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2844981,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7966732,int_stack+8041294,int_stack+7981636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2851029,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7978072,int_stack+57624,int_stack+55644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1828153,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8051374,int_stack+7978072,int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2858589,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8061094,int_stack+8051374,int_stack+7989196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2863449,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7978072,int_stack+8061094,int_stack+8041294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2871225,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8041294,int_stack+7978072,int_stack+7966732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2881305,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7961872,int_stack+8041294,int_stack+8001163,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+10222821,int_stack+7961872,int_stack+8013511,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8057170,int_stack+60945,int_stack+60000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1841545,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8060005,int_stack+62205,int_stack+60945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1842490,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8063785,int_stack+8060005,int_stack+8057170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2904930,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8069455,int_stack+63825,int_stack+62205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1843750,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8074315,int_stack+8069455,int_stack+8060005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3080691,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7998916,int_stack+8074315,int_stack+8063785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3084471,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8057170,int_stack+65850,int_stack+63825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1845370,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8008366,int_stack+8057170,int_stack+8069455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3090141,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8018086,int_stack+8008366,int_stack+8074315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3095001,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8063245,int_stack+8018086,int_stack+7998916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3102561,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7998916,int_stack+68325,int_stack+65850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1847395,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10278387,int_stack+7998916,int_stack+8057170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3112011,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10290537,int_stack+10278387,int_stack+8008366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3118086,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7998916,int_stack+10290537,int_stack+8018086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3127806,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10278387,int_stack+7998916,int_stack+8063245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3140406,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+10298232,int_stack+10278387,int_stack+8041294,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+7998916,int_stack+10298232,int_stack+7961872,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+10548447,int_stack+7998916,int_stack+10222821,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10222821,int_stack+72450,int_stack+71295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+767820,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10226286,int_stack+73990,int_stack+72450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+770130,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10230906,int_stack+10226286,int_stack+10222821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3169596,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10237836,int_stack+75970,int_stack+73990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+773210,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10243776,int_stack+10237836,int_stack+10226286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3486412,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10253016,int_stack+10243776,int_stack+10230906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3491032,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10222821,int_stack+78445,int_stack+75970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+777170,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10264566,int_stack+10222821,int_stack+10237836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3497962,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7961872,int_stack+10264566,int_stack+10243776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3503902,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10230246,int_stack+7961872,int_stack+10253016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3513142,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10247571,int_stack+81470,int_stack+78445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+782120,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7977272,int_stack+10247571,int_stack+10222821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3524692,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10345860,int_stack+7977272,int_stack+10264566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3532117,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10247571,int_stack+10345860,int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3543997,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7961872,int_stack+10247571,int_stack+10230246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3559397,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+10345860,int_stack+7961872,int_stack+10278387,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+10641057,int_stack+10345860,int_stack+10298232,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+10222821,int_stack+10641057,int_stack+7998916,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10641057,int_stack+85541,int_stack+85100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798875, 1.0, int_stack+1877940,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10642380,int_stack+86129,int_stack+85541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1799316, 1.0, int_stack+1878381,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10644144,int_stack+10642380,int_stack+10641057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2586100, 1.0, int_stack+3576722,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10646790,int_stack+86885,int_stack+86129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1799904, 1.0, int_stack+1878969,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10649058,int_stack+10646790,int_stack+10642380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2587423, 1.0, int_stack+3578045,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10652586,int_stack+10649058,int_stack+10644144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2589187, 1.0, int_stack+3579809,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10641057,int_stack+87830,int_stack+86885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800660, 1.0, int_stack+1879725,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10656996,int_stack+10641057,int_stack+10646790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2591833, 1.0, int_stack+3582455,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10661532,int_stack+10656996,int_stack+10649058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2594101, 1.0, int_stack+3584723,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10643892,int_stack+10661532,int_stack+10652586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2597629, 1.0, int_stack+3588251,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10650507,int_stack+88985,int_stack+87830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1801605, 1.0, int_stack+1880670,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10667412,int_stack+10650507,int_stack+10641057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2602039, 1.0, int_stack+3592661,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10673082,int_stack+10667412,int_stack+10656996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2604874, 1.0, int_stack+3595496,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10650507,int_stack+10673082,int_stack+10661532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2609410, 1.0, int_stack+3600032,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10659327,int_stack+10650507,int_stack+10643892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2615290, 1.0, int_stack+3605912,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10641057,int_stack+90959,int_stack+90371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1809417, 1.0, int_stack+1888482,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10642821,int_stack+91743,int_stack+90959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1810005, 1.0, int_stack+1889070,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10645173,int_stack+10642821,int_stack+10641057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2680082, 1.0, int_stack+3612527,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10648701,int_stack+92751,int_stack+91743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1810789, 1.0, int_stack+1889854,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10651725,int_stack+10648701,int_stack+10642821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2681846, 1.0, int_stack+3614291,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10668588,int_stack+10651725,int_stack+10645173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2684198, 1.0, int_stack+3616643,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10641057,int_stack+94011,int_stack+92751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1811797, 1.0, int_stack+1890862,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10674468,int_stack+10641057,int_stack+10648701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2687726, 1.0, int_stack+3630608,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10680516,int_stack+10674468,int_stack+10651725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2690750, 1.0, int_stack+3633632,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10644837,int_stack+10680516,int_stack+10668588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2695454, 1.0, int_stack+3638336,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10668588,int_stack+95551,int_stack+94011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1813057, 1.0, int_stack+1892122,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10688356,int_stack+10668588,int_stack+10641057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2701334, 1.0, int_stack+3644216,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10695916,int_stack+10688356,int_stack+10674468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2705114, 1.0, int_stack+3647996,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10668588,int_stack+10695916,int_stack+10680516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2711162, 1.0, int_stack+3654044,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10680348,int_stack+10668588,int_stack+10644837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2719002, 1.0, int_stack+3661884,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+10692696,int_stack+10680348,int_stack+10659327,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10641057,int_stack+98155,int_stack+97399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1823473, 1.0, int_stack+1902538,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10643325,int_stack+99163,int_stack+98155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1824229, 1.0, int_stack+1903294,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10646349,int_stack+10643325,int_stack+10641057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2831265, 1.0, int_stack+3670704,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10650885,int_stack+100459,int_stack+99163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1825237, 1.0, int_stack+1904302,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10654773,int_stack+10650885,int_stack+10643325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2833533, 1.0, int_stack+3672972,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10660821,int_stack+10654773,int_stack+10646349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2836557, 1.0, int_stack+3675996,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10641057,int_stack+102079,int_stack+100459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1826533, 1.0, int_stack+1905598,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10668381,int_stack+10641057,int_stack+10650885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2841093, 1.0, int_stack+3722595,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10720479,int_stack+10668381,int_stack+10654773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2844981, 1.0, int_stack+3726483,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10645917,int_stack+10720479,int_stack+10660821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2851029, 1.0, int_stack+3732531,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10657257,int_stack+104059,int_stack+102079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1828153, 1.0, int_stack+1907218,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7961872,int_stack+10657257,int_stack+10641057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2858589, 1.0, int_stack+3740091,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7971592,int_stack+7961872,int_stack+10668381, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2863449, 1.0, int_stack+3744951,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10657257,int_stack+7971592,int_stack+10720479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2871225, 1.0, int_stack+3752727,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10720479,int_stack+10657257,int_stack+10645917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2881305, 1.0, int_stack+3762807,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7961872,int_stack+10720479,int_stack+10680348,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7998916,int_stack+7961872,int_stack+10692696,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8054482,int_stack+107380,int_stack+106435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1841545, 1.0, int_stack+1920610,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8057317,int_stack+108640,int_stack+107380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1842490, 1.0, int_stack+1921555,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8061097,int_stack+8057317,int_stack+8054482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2904930, 1.0, int_stack+3902348,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8066767,int_stack+110260,int_stack+108640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1843750, 1.0, int_stack+1922815,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8071627,int_stack+8066767,int_stack+8057317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3080691, 1.0, int_stack+3905183,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10641057,int_stack+8071627,int_stack+8061097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3084471, 1.0, int_stack+3908963,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8054482,int_stack+112285,int_stack+110260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1845370, 1.0, int_stack+1924435,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10650507,int_stack+8054482,int_stack+8066767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3090141, 1.0, int_stack+4025954,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10660227,int_stack+10650507,int_stack+8071627, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3095001, 1.0, int_stack+4030814,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8060557,int_stack+10660227,int_stack+10641057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3102561, 1.0, int_stack+4038374,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10641057,int_stack+114760,int_stack+112285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1847395, 1.0, int_stack+1926460,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10672827,int_stack+10641057,int_stack+8054482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3112011, 1.0, int_stack+4047824,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10684977,int_stack+10672827,int_stack+10650507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3118086, 1.0, int_stack+4053899,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10641057,int_stack+10684977,int_stack+10660227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3127806, 1.0, int_stack+4063619,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10659957,int_stack+10641057,int_stack+8060557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3140406, 1.0, int_stack+4076219,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+10346301,int_stack+10659957,int_stack+10720479,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+26595,int_stack+10346301,int_stack+7961872,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+10679802,int_stack+26595,int_stack+7998916,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7961872,int_stack+118885,int_stack+117730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+767820, 1.0, int_stack+824430,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7965337,int_stack+120425,int_stack+118885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+770130, 1.0, int_stack+826740,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7969957,int_stack+7965337,int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3169596, 1.0, int_stack+4090394,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7976887,int_stack+122405,int_stack+120425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+773210, 1.0, int_stack+829820,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7982827,int_stack+7976887,int_stack+7965337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3486412, 1.0, int_stack+4093859,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7992067,int_stack+7982827,int_stack+7969957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3491032, 1.0, int_stack+4098479,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7961872,int_stack+124880,int_stack+122405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777170, 1.0, int_stack+833780,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8003617,int_stack+7961872,int_stack+7976887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3497962, 1.0, int_stack+4343465,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8015497,int_stack+8003617,int_stack+7982827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3503902, 1.0, int_stack+4349405,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7969297,int_stack+8015497,int_stack+7992067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3513142, 1.0, int_stack+4358645,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7986622,int_stack+127905,int_stack+124880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782120, 1.0, int_stack+838730,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8030897,int_stack+7986622,int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3524692, 1.0, int_stack+4370195,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8045747,int_stack+8030897,int_stack+8003617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3532117, 1.0, int_stack+4377620,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7986622,int_stack+8045747,int_stack+8015497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3543997, 1.0, int_stack+4389500,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8009722,int_stack+7986622,int_stack+7969297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3559397, 1.0, int_stack+4404900,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+10772412,int_stack+8009722,int_stack+10659957,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+7961872,int_stack+10772412,int_stack+10346301,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+10772412,int_stack+7961872,int_stack+26595,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26595,int_stack+131976,int_stack+131535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1877940, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+27918,int_stack+132564,int_stack+131976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1878381, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29682,int_stack+27918,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3576722, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+32328,int_stack+133320,int_stack+132564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1878969, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+34596,int_stack+32328,int_stack+27918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3578045, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+38124,int_stack+34596,int_stack+29682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3579809, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+26595,int_stack+134265,int_stack+133320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1879725, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+42534,int_stack+26595,int_stack+32328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3582455, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+47070,int_stack+42534,int_stack+34596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3584723, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+29430,int_stack+47070,int_stack+38124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3588251, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+36045,int_stack+135420,int_stack+134265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1880670, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+52950,int_stack+36045,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3592661, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+58620,int_stack+52950,int_stack+42534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3595496, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+36045,int_stack+58620,int_stack+47070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3600032, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+44865,int_stack+36045,int_stack+29430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3605912, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26595,int_stack+137394,int_stack+136806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1888482, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+28359,int_stack+138178,int_stack+137394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1889070, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30711,int_stack+28359,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3612527, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+34239,int_stack+139186,int_stack+138178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1889854, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+37263,int_stack+34239,int_stack+28359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3614291, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+54126,int_stack+37263,int_stack+30711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3616643, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+26595,int_stack+140446,int_stack+139186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1890862, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+60006,int_stack+26595,int_stack+34239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3630608, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+66054,int_stack+60006,int_stack+37263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3633632, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+30375,int_stack+66054,int_stack+54126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3638336, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+54126,int_stack+141986,int_stack+140446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1892122, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+73894,int_stack+54126,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3644216, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+81454,int_stack+73894,int_stack+60006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3647996, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+54126,int_stack+81454,int_stack+66054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3654044, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+65886,int_stack+54126,int_stack+30375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3661884, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+78234,int_stack+65886,int_stack+44865,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26595,int_stack+144590,int_stack+143834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1902538, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+28863,int_stack+145598,int_stack+144590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1903294, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+31887,int_stack+28863,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3670704, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+36423,int_stack+146894,int_stack+145598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1904302, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+40311,int_stack+36423,int_stack+28863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3672972, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+46359,int_stack+40311,int_stack+31887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3675996, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+26595,int_stack+148514,int_stack+146894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1905598, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+53919,int_stack+26595,int_stack+36423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3722595, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+106017,int_stack+53919,int_stack+40311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3726483, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+31455,int_stack+106017,int_stack+46359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3732531, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+42795,int_stack+150494,int_stack+148514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1907218, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+116097,int_stack+42795,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3740091, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+125817,int_stack+116097,int_stack+53919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3744951, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+42795,int_stack+125817,int_stack+106017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3752727, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+106017,int_stack+42795,int_stack+31455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3762807, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+26595,int_stack+106017,int_stack+65886,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7961872,int_stack+26595,int_stack+78234,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+121893,int_stack+153815,int_stack+152870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1920610, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+124728,int_stack+155075,int_stack+153815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1921555, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+128508,int_stack+124728,int_stack+121893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3902348, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+134178,int_stack+156695,int_stack+155075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1922815, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+139038,int_stack+134178,int_stack+124728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3905183, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+146598,int_stack+139038,int_stack+128508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3908963, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+121893,int_stack+158720,int_stack+156695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1924435, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+63639,int_stack+121893,int_stack+134178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4025954, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+73359,int_stack+63639,int_stack+139038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4030814, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+127968,int_stack+73359,int_stack+146598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4038374, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+142143,int_stack+161195,int_stack+158720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1926460, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+149568,int_stack+142143,int_stack+121893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4047824, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+85959,int_stack+149568,int_stack+63639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4053899, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+142143,int_stack+85959,int_stack+73359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4063619, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+63639,int_stack+142143,int_stack+127968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4076219, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+8017438,int_stack+63639,int_stack+106017,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+83484,int_stack+8017438,int_stack+26595,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+10895892,int_stack+83484,int_stack+7961872,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7961872,int_stack+165320,int_stack+164165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+824430, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7965337,int_stack+166860,int_stack+165320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+826740, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7969957,int_stack+7965337,int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4090394, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7976887,int_stack+168840,int_stack+166860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+829820, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7982827,int_stack+7976887,int_stack+7965337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4093859, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7992067,int_stack+7982827,int_stack+7969957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4098479, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7961872,int_stack+171315,int_stack+168840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+833780, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8003617,int_stack+7961872,int_stack+7976887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4343465, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+26595,int_stack+8003617,int_stack+7982827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4349405, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7969297,int_stack+26595,int_stack+7992067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4358645, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7986622,int_stack+174340,int_stack+171315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+838730, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+41995,int_stack+7986622,int_stack+7961872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4370195, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+157572,int_stack+41995,int_stack+8003617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4377620, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7986622,int_stack+157572,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4389500, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+26595,int_stack+7986622,int_stack+7969297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4404900, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+10346301,int_stack+26595,int_stack+63639,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+10988502,int_stack+10346301,int_stack+8017438,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+11083758,int_stack+10988502,int_stack+83484,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10988502,int_stack+178411,int_stack+177970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798875, 0.0, zero_stack, 1.0, int_stack+1957005,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10989825,int_stack+178999,int_stack+178411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1799316, 0.0, zero_stack, 1.0, int_stack+1957446,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10991589,int_stack+10989825,int_stack+10988502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2586100, 0.0, zero_stack, 1.0, int_stack+4422225,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10994235,int_stack+179755,int_stack+178999, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1799904, 0.0, zero_stack, 1.0, int_stack+1958034,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10996503,int_stack+10994235,int_stack+10989825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2587423, 0.0, zero_stack, 1.0, int_stack+4423548,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11000031,int_stack+10996503,int_stack+10991589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2589187, 0.0, zero_stack, 1.0, int_stack+4425312,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10988502,int_stack+180700,int_stack+179755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800660, 0.0, zero_stack, 1.0, int_stack+1958790,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11004441,int_stack+10988502,int_stack+10994235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2591833, 0.0, zero_stack, 1.0, int_stack+4427958,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11008977,int_stack+11004441,int_stack+10996503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2594101, 0.0, zero_stack, 1.0, int_stack+4430226,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10991337,int_stack+11008977,int_stack+11000031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2597629, 0.0, zero_stack, 1.0, int_stack+4433754,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10997952,int_stack+181855,int_stack+180700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1801605, 0.0, zero_stack, 1.0, int_stack+1959735,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11014857,int_stack+10997952,int_stack+10988502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2602039, 0.0, zero_stack, 1.0, int_stack+3914633,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11020527,int_stack+11014857,int_stack+11004441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2604874, 0.0, zero_stack, 1.0, int_stack+4438164,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10997952,int_stack+11020527,int_stack+11008977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2609410, 0.0, zero_stack, 1.0, int_stack+4442700,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11006772,int_stack+10997952,int_stack+10991337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2615290, 0.0, zero_stack, 1.0, int_stack+4448580,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10988502,int_stack+183829,int_stack+183241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1809417, 0.0, zero_stack, 1.0, int_stack+1967547,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10990266,int_stack+184613,int_stack+183829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1810005, 0.0, zero_stack, 1.0, int_stack+1968135,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10992618,int_stack+10990266,int_stack+10988502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2680082, 0.0, zero_stack, 1.0, int_stack+4455195,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10996146,int_stack+185621,int_stack+184613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1810789, 0.0, zero_stack, 1.0, int_stack+1968919,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10999170,int_stack+10996146,int_stack+10990266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2681846, 0.0, zero_stack, 1.0, int_stack+4456959,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11016033,int_stack+10999170,int_stack+10992618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2684198, 0.0, zero_stack, 1.0, int_stack+4459311,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10988502,int_stack+186881,int_stack+185621, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1811797, 0.0, zero_stack, 1.0, int_stack+1969927,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11021913,int_stack+10988502,int_stack+10996146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2687726, 0.0, zero_stack, 1.0, int_stack+4473276,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11027961,int_stack+11021913,int_stack+10999170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2690750, 0.0, zero_stack, 1.0, int_stack+4476300,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10992282,int_stack+11027961,int_stack+11016033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2695454, 0.0, zero_stack, 1.0, int_stack+4481004,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11016033,int_stack+188421,int_stack+186881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1813057, 0.0, zero_stack, 1.0, int_stack+1971187,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11035801,int_stack+11016033,int_stack+10988502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2701334, 0.0, zero_stack, 1.0, int_stack+4486884,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11043361,int_stack+11035801,int_stack+11021913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2705114, 0.0, zero_stack, 1.0, int_stack+4490664,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11016033,int_stack+11043361,int_stack+11027961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2711162, 0.0, zero_stack, 1.0, int_stack+4496712,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11027793,int_stack+11016033,int_stack+10992282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2719002, 0.0, zero_stack, 1.0, int_stack+4504552,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+11040141,int_stack+11027793,int_stack+11006772,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10988502,int_stack+191025,int_stack+190269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1823473, 0.0, zero_stack, 1.0, int_stack+1981603,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10990770,int_stack+192033,int_stack+191025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1824229, 0.0, zero_stack, 1.0, int_stack+1982359,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10993794,int_stack+10990770,int_stack+10988502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2831265, 0.0, zero_stack, 1.0, int_stack+4513372,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10998330,int_stack+193329,int_stack+192033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1825237, 0.0, zero_stack, 1.0, int_stack+1983367,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11002218,int_stack+10998330,int_stack+10990770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2833533, 0.0, zero_stack, 1.0, int_stack+4515640,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11008266,int_stack+11002218,int_stack+10993794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2836557, 0.0, zero_stack, 1.0, int_stack+4518664,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10988502,int_stack+194949,int_stack+193329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1826533, 0.0, zero_stack, 1.0, int_stack+1984663,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11015826,int_stack+10988502,int_stack+10998330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2841093, 0.0, zero_stack, 1.0, int_stack+4565263,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11067924,int_stack+11015826,int_stack+11002218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2844981, 0.0, zero_stack, 1.0, int_stack+4569151,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10993362,int_stack+11067924,int_stack+11008266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2851029, 0.0, zero_stack, 1.0, int_stack+4575199,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11004702,int_stack+196929,int_stack+194949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1828153, 0.0, zero_stack, 1.0, int_stack+1986283,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10346301,int_stack+11004702,int_stack+10988502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2858589, 0.0, zero_stack, 1.0, int_stack+4582759,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10356021,int_stack+10346301,int_stack+11015826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2863449, 0.0, zero_stack, 1.0, int_stack+4587619,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11004702,int_stack+10356021,int_stack+11067924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2871225, 0.0, zero_stack, 1.0, int_stack+4595395,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10346301,int_stack+11004702,int_stack+10993362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2881305, 0.0, zero_stack, 1.0, int_stack+4605475,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+10362177,int_stack+10346301,int_stack+11027793,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+26595,int_stack+10362177,int_stack+11040141,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10399221,int_stack+200250,int_stack+199305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1841545, 0.0, zero_stack, 1.0, int_stack+1999675,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10402056,int_stack+201510,int_stack+200250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1842490, 0.0, zero_stack, 1.0, int_stack+2000620,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10405836,int_stack+10402056,int_stack+10399221, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2904930, 0.0, zero_stack, 1.0, int_stack+4616815,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10411506,int_stack+203130,int_stack+201510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1843750, 0.0, zero_stack, 1.0, int_stack+2001880,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10416366,int_stack+10411506,int_stack+10402056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3080691, 0.0, zero_stack, 1.0, int_stack+4619650,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10988502,int_stack+10416366,int_stack+10405836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3084471, 0.0, zero_stack, 1.0, int_stack+0,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10399221,int_stack+205155,int_stack+203130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1845370, 0.0, zero_stack, 1.0, int_stack+2003500,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10997952,int_stack+10399221,int_stack+10411506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3090141, 0.0, zero_stack, 1.0, int_stack+4856337,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11007672,int_stack+10997952,int_stack+10416366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3095001, 0.0, zero_stack, 1.0, int_stack+4861197,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10405296,int_stack+11007672,int_stack+10988502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3102561, 0.0, zero_stack, 1.0, int_stack+4868757,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10988502,int_stack+207630,int_stack+205155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1847395, 0.0, zero_stack, 1.0, int_stack+2005525,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11020272,int_stack+10988502,int_stack+10399221, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3112011, 0.0, zero_stack, 1.0, int_stack+4878207,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11032422,int_stack+11020272,int_stack+10997952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3118086, 0.0, zero_stack, 1.0, int_stack+4884282,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10988502,int_stack+11032422,int_stack+11007672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3127806, 0.0, zero_stack, 1.0, int_stack+4894002,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11007402,int_stack+10988502,int_stack+10405296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3140406, 0.0, zero_stack, 1.0, int_stack+4906602,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+11027247,int_stack+11007402,int_stack+10346301,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+82161,int_stack+11027247,int_stack+10362177,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+7961872,int_stack+82161,int_stack+26595,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26595,int_stack+211755,int_stack+210600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+767820, 0.0, zero_stack, 1.0, int_stack+881040,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30060,int_stack+213295,int_stack+211755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+770130, 0.0, zero_stack, 1.0, int_stack+883350,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+34680,int_stack+30060,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3169596, 0.0, zero_stack, 1.0, int_stack+4920777,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+41610,int_stack+215275,int_stack+213295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+773210, 0.0, zero_stack, 1.0, int_stack+886430,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+47550,int_stack+41610,int_stack+30060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3486412, 0.0, zero_stack, 1.0, int_stack+4924242,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+56790,int_stack+47550,int_stack+34680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3491032, 0.0, zero_stack, 1.0, int_stack+4928862,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+26595,int_stack+217750,int_stack+215275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777170, 0.0, zero_stack, 1.0, int_stack+890390,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+68340,int_stack+26595,int_stack+41610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3497962, 0.0, zero_stack, 1.0, int_stack+5173848,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10346301,int_stack+68340,int_stack+47550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3503902, 0.0, zero_stack, 1.0, int_stack+5179788,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+34020,int_stack+10346301,int_stack+56790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3513142, 0.0, zero_stack, 1.0, int_stack+5189028,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+51345,int_stack+220775,int_stack+217750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782120, 0.0, zero_stack, 1.0, int_stack+895340,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10361701,int_stack+51345,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3524692, 0.0, zero_stack, 1.0, int_stack+5200578,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10376551,int_stack+10361701,int_stack+68340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3532117, 0.0, zero_stack, 1.0, int_stack+5208003,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+51345,int_stack+10376551,int_stack+10346301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3543997, 0.0, zero_stack, 1.0, int_stack+5219883,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10346301,int_stack+51345,int_stack+34020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3559397, 0.0, zero_stack, 1.0, int_stack+5235283,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+156249,int_stack+10346301,int_stack+11007402,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+11207238,int_stack+156249,int_stack+11027247,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+11302494,int_stack+11207238,int_stack+82161,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11207238,int_stack+224846,int_stack+224405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1877940, 1.0, int_stack+1957005, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11208561,int_stack+225434,int_stack+224846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1878381, 1.0, int_stack+1957446, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11210325,int_stack+11208561,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3576722, 1.0, int_stack+4422225, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11212971,int_stack+226190,int_stack+225434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1878969, 1.0, int_stack+1958034, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11215239,int_stack+11212971,int_stack+11208561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3578045, 1.0, int_stack+4423548, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11218767,int_stack+11215239,int_stack+11210325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3579809, 1.0, int_stack+4425312, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11207238,int_stack+227135,int_stack+226190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879725, 1.0, int_stack+1958790, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11223177,int_stack+11207238,int_stack+11212971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3582455, 1.0, int_stack+4427958, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11227713,int_stack+11223177,int_stack+11215239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3584723, 1.0, int_stack+4430226, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11210073,int_stack+11227713,int_stack+11218767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3588251, 1.0, int_stack+4433754, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11216688,int_stack+228290,int_stack+227135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1880670, 1.0, int_stack+1959735, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11233593,int_stack+11216688,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3592661, 1.0, int_stack+3914633, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11239263,int_stack+11233593,int_stack+11223177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3595496, 1.0, int_stack+4438164, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11216688,int_stack+11239263,int_stack+11227713, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3600032, 1.0, int_stack+4442700, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11225508,int_stack+11216688,int_stack+11210073, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3605912, 1.0, int_stack+4448580, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11207238,int_stack+230264,int_stack+229676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1888482, 1.0, int_stack+1967547, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11209002,int_stack+231048,int_stack+230264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1889070, 1.0, int_stack+1968135, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11211354,int_stack+11209002,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3612527, 1.0, int_stack+4455195, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11214882,int_stack+232056,int_stack+231048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1889854, 1.0, int_stack+1968919, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11217906,int_stack+11214882,int_stack+11209002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3614291, 1.0, int_stack+4456959, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11234769,int_stack+11217906,int_stack+11211354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3616643, 1.0, int_stack+4459311, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11207238,int_stack+233316,int_stack+232056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890862, 1.0, int_stack+1969927, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11240649,int_stack+11207238,int_stack+11214882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3630608, 1.0, int_stack+4473276, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11246697,int_stack+11240649,int_stack+11217906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3633632, 1.0, int_stack+4476300, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11211018,int_stack+11246697,int_stack+11234769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3638336, 1.0, int_stack+4481004, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11234769,int_stack+234856,int_stack+233316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1892122, 1.0, int_stack+1971187, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11254537,int_stack+11234769,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3644216, 1.0, int_stack+4486884, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11262097,int_stack+11254537,int_stack+11240649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3647996, 1.0, int_stack+4490664, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11234769,int_stack+11262097,int_stack+11246697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3654044, 1.0, int_stack+4496712, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11246529,int_stack+11234769,int_stack+11211018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3661884, 1.0, int_stack+4504552, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+11258877,int_stack+11246529,int_stack+11225508,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11207238,int_stack+237460,int_stack+236704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1902538, 1.0, int_stack+1981603, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11209506,int_stack+238468,int_stack+237460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1903294, 1.0, int_stack+1982359, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11212530,int_stack+11209506,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3670704, 1.0, int_stack+4513372, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11217066,int_stack+239764,int_stack+238468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1904302, 1.0, int_stack+1983367, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11220954,int_stack+11217066,int_stack+11209506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3672972, 1.0, int_stack+4515640, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11227002,int_stack+11220954,int_stack+11212530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3675996, 1.0, int_stack+4518664, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11207238,int_stack+241384,int_stack+239764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1905598, 1.0, int_stack+1984663, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11234562,int_stack+11207238,int_stack+11217066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3722595, 1.0, int_stack+4565263, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11286660,int_stack+11234562,int_stack+11220954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3726483, 1.0, int_stack+4569151, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11212098,int_stack+11286660,int_stack+11227002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3732531, 1.0, int_stack+4575199, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11223438,int_stack+243364,int_stack+241384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1907218, 1.0, int_stack+1986283, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10346301,int_stack+11223438,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3740091, 1.0, int_stack+4582759, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10356021,int_stack+10346301,int_stack+11234562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3744951, 1.0, int_stack+4587619, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11223438,int_stack+10356021,int_stack+11286660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3752727, 1.0, int_stack+4595395, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10346301,int_stack+11223438,int_stack+11212098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3762807, 1.0, int_stack+4605475, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+10362177,int_stack+10346301,int_stack+11246529,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+26595,int_stack+10362177,int_stack+11258877,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10399221,int_stack+246685,int_stack+245740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1920610, 1.0, int_stack+1999675, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10402056,int_stack+247945,int_stack+246685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921555, 1.0, int_stack+2000620, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10405836,int_stack+10402056,int_stack+10399221, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3902348, 1.0, int_stack+4616815, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10411506,int_stack+249565,int_stack+247945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1922815, 1.0, int_stack+2001880, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10416366,int_stack+10411506,int_stack+10402056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3905183, 1.0, int_stack+4619650, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11207238,int_stack+10416366,int_stack+10405836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3908963, 1.0, int_stack+0, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10399221,int_stack+251590,int_stack+249565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1924435, 1.0, int_stack+2003500, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11216688,int_stack+10399221,int_stack+10411506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4025954, 1.0, int_stack+4856337, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11226408,int_stack+11216688,int_stack+10416366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4030814, 1.0, int_stack+4861197, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10405296,int_stack+11226408,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4038374, 1.0, int_stack+4868757, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11207238,int_stack+254065,int_stack+251590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1926460, 1.0, int_stack+2005525, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11239008,int_stack+11207238,int_stack+10399221, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4047824, 1.0, int_stack+4878207, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11251158,int_stack+11239008,int_stack+11216688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4053899, 1.0, int_stack+4884282, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11207238,int_stack+11251158,int_stack+11226408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4063619, 1.0, int_stack+4894002, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11226138,int_stack+11207238,int_stack+10405296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4076219, 1.0, int_stack+4906602, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+11245983,int_stack+11226138,int_stack+10346301,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+82161,int_stack+11245983,int_stack+10362177,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+156249,int_stack+82161,int_stack+26595,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26595,int_stack+258190,int_stack+257035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+824430, 1.0, int_stack+881040, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30060,int_stack+259730,int_stack+258190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+826740, 1.0, int_stack+883350, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+34680,int_stack+30060,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4090394, 1.0, int_stack+4920777, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+41610,int_stack+261710,int_stack+259730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829820, 1.0, int_stack+886430, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+47550,int_stack+41610,int_stack+30060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4093859, 1.0, int_stack+4924242, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+56790,int_stack+47550,int_stack+34680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4098479, 1.0, int_stack+4928862, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+26595,int_stack+264185,int_stack+261710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+833780, 1.0, int_stack+890390, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+68340,int_stack+26595,int_stack+41610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4343465, 1.0, int_stack+5173848, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10346301,int_stack+68340,int_stack+47550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4349405, 1.0, int_stack+5179788, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+34020,int_stack+10346301,int_stack+56790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4358645, 1.0, int_stack+5189028, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+51345,int_stack+267210,int_stack+264185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+838730, 1.0, int_stack+895340, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10361701,int_stack+51345,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4370195, 1.0, int_stack+5200578, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10376551,int_stack+10361701,int_stack+68340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4377620, 1.0, int_stack+5208003, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+51345,int_stack+10376551,int_stack+10346301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4389500, 1.0, int_stack+5219883, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10346301,int_stack+51345,int_stack+34020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4404900, 1.0, int_stack+5235283, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+10988502,int_stack+10346301,int_stack+11226138,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+11425974,int_stack+10988502,int_stack+11245983,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+11521230,int_stack+11425974,int_stack+82161,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11425974,int_stack+271281,int_stack+270840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1957005, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11427297,int_stack+271869,int_stack+271281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1957446, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11429061,int_stack+11427297,int_stack+11425974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4422225, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11431707,int_stack+272625,int_stack+271869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1958034, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11433975,int_stack+11431707,int_stack+11427297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4423548, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11437503,int_stack+11433975,int_stack+11429061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4425312, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11425974,int_stack+273570,int_stack+272625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1958790, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11441913,int_stack+11425974,int_stack+11431707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4427958, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11446449,int_stack+11441913,int_stack+11433975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4430226, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11428809,int_stack+11446449,int_stack+11437503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4433754, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11435424,int_stack+274725,int_stack+273570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1959735, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11452329,int_stack+11435424,int_stack+11425974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3914633, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11457999,int_stack+11452329,int_stack+11441913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4438164, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11435424,int_stack+11457999,int_stack+11446449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4442700, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11444244,int_stack+11435424,int_stack+11428809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4448580, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11425974,int_stack+276699,int_stack+276111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1967547, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11427738,int_stack+277483,int_stack+276699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1968135, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11430090,int_stack+11427738,int_stack+11425974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4455195, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11433618,int_stack+278491,int_stack+277483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1968919, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11436642,int_stack+11433618,int_stack+11427738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4456959, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11453505,int_stack+11436642,int_stack+11430090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4459311, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11425974,int_stack+279751,int_stack+278491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1969927, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11459385,int_stack+11425974,int_stack+11433618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4473276, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11465433,int_stack+11459385,int_stack+11436642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4476300, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11429754,int_stack+11465433,int_stack+11453505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4481004, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11453505,int_stack+281291,int_stack+279751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1971187, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11473273,int_stack+11453505,int_stack+11425974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4486884, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11480833,int_stack+11473273,int_stack+11459385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4490664, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11453505,int_stack+11480833,int_stack+11465433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4496712, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11465265,int_stack+11453505,int_stack+11429754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4504552, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+11477613,int_stack+11465265,int_stack+11444244,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11425974,int_stack+283895,int_stack+283139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1981603, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11428242,int_stack+284903,int_stack+283895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1982359, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11431266,int_stack+11428242,int_stack+11425974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4513372, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11435802,int_stack+286199,int_stack+284903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1983367, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11439690,int_stack+11435802,int_stack+11428242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4515640, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11445738,int_stack+11439690,int_stack+11431266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4518664, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11425974,int_stack+287819,int_stack+286199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1984663, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11453298,int_stack+11425974,int_stack+11435802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4565263, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11505396,int_stack+11453298,int_stack+11439690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4569151, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11430834,int_stack+11505396,int_stack+11445738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4575199, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11442174,int_stack+289799,int_stack+287819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1986283, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10988502,int_stack+11442174,int_stack+11425974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4582759, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10998222,int_stack+10988502,int_stack+11453298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4587619, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11442174,int_stack+10998222,int_stack+11505396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4595395, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10988502,int_stack+11442174,int_stack+11430834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4605475, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+11004378,int_stack+10988502,int_stack+11465265,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+10346301,int_stack+11004378,int_stack+11477613,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11041422,int_stack+293120,int_stack+292175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1999675, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11044257,int_stack+294380,int_stack+293120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2000620, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11048037,int_stack+11044257,int_stack+11041422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4616815, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11053707,int_stack+296000,int_stack+294380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2001880, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11058567,int_stack+11053707,int_stack+11044257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4619650, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11066127,int_stack+11058567,int_stack+11048037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11041422,int_stack+298025,int_stack+296000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2003500, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11425974,int_stack+11041422,int_stack+11053707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4856337, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11435694,int_stack+11425974,int_stack+11058567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4861197, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11047497,int_stack+11435694,int_stack+11066127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4868757, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11061672,int_stack+300500,int_stack+298025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2005525, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11069097,int_stack+11061672,int_stack+11041422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4878207, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11448294,int_stack+11069097,int_stack+11425974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4884282, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11061672,int_stack+11448294,int_stack+11435694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4894002, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11425974,int_stack+11061672,int_stack+11047497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4906602, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+11445819,int_stack+11425974,int_stack+10988502,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+26595,int_stack+11445819,int_stack+11004378,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+10988502,int_stack+26595,int_stack+10346301,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10346301,int_stack+304625,int_stack+303470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+881040, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10349766,int_stack+306165,int_stack+304625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+883350, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10354386,int_stack+10349766,int_stack+10346301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4920777, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10361316,int_stack+308145,int_stack+306165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+886430, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10367256,int_stack+10361316,int_stack+10349766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4924242, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10376496,int_stack+10367256,int_stack+10354386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4928862, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10346301,int_stack+310620,int_stack+308145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+890390, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10388046,int_stack+10346301,int_stack+10361316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10399926,int_stack+10388046,int_stack+10367256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5179788, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10353726,int_stack+10399926,int_stack+10376496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5189028, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10371051,int_stack+313645,int_stack+310620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+895340, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11493447,int_stack+10371051,int_stack+10346301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5200578, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+100683,int_stack+11493447,int_stack+10388046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5208003, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11493447,int_stack+100683,int_stack+10399926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5219883, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+100683,int_stack+11493447,int_stack+10353726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5235283, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+10346301,int_stack+100683,int_stack+11425974,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+11207238,int_stack+10346301,int_stack+11445819,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+11644710,int_stack+11207238,int_stack+26595,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26595,int_stack+317716,int_stack+317275, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2036070,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+27918,int_stack+318304,int_stack+317716, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1799316, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2036511,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+27918,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2586100, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5252608,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+29682,int_stack+319060,int_stack+318304, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1799904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2037099,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31950,int_stack+29682,int_stack+27918, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2587423, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5253931,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+35478,int_stack+31950,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2589187, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5255695,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+26595,int_stack+320005,int_stack+319060, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800660, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2037855,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+39888,int_stack+26595,int_stack+29682, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2591833, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5258341,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+44424,int_stack+39888,int_stack+31950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2594101, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5260609,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+50304,int_stack+44424,int_stack+35478, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2597629, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5264137,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+29430,int_stack+321160,int_stack+320005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1801605, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2038800,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+32895,int_stack+29430,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2602039, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5268547,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+56919,int_stack+32895,int_stack+39888, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2604874, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5271382,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+26595,int_stack+56919,int_stack+44424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2609410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5275918,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+56919,int_stack+26595,int_stack+50304, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2615290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5281798,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26595,int_stack+323134,int_stack+322546, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1809417, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2046612,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+28359,int_stack+323918,int_stack+323134, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1810005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2047200,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30711,int_stack+28359,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2680082, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5288413,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+34239,int_stack+324926,int_stack+323918, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1810789, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2047984,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+37263,int_stack+34239,int_stack+28359, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2681846, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5290177,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+41967,int_stack+37263,int_stack+30711, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2684198, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5292529,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+26595,int_stack+326186,int_stack+324926, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1811797, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2048992,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+47847,int_stack+26595,int_stack+34239, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2687726, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5306494,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+66180,int_stack+47847,int_stack+37263, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2690750, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5309518,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+30375,int_stack+66180,int_stack+41967, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2695454, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5314222,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+39195,int_stack+327726,int_stack+326186, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1813057, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2050252,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+74020,int_stack+39195,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2701334, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5320102,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+81580,int_stack+74020,int_stack+47847, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2705114, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5323882,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+39195,int_stack+81580,int_stack+66180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2711162, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5329930,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+66180,int_stack+39195,int_stack+30375, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2719002, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5337770,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+78528,int_stack+66180,int_stack+56919,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+106311,int_stack+330330,int_stack+329574, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1823473, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2060668,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+108579,int_stack+331338,int_stack+330330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1824229, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2061424,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+111603,int_stack+108579,int_stack+106311, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2831265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5346590,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+116139,int_stack+332634,int_stack+331338, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1825237, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2062432,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+120027,int_stack+116139,int_stack+108579, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2833533, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5348858,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+126075,int_stack+120027,int_stack+111603, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2836557, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5351882,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+106311,int_stack+334254,int_stack+332634, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1826533, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2063728,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+133635,int_stack+106311,int_stack+116139, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2841093, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5398481,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+141411,int_stack+133635,int_stack+120027, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2844981, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5402369,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+111171,int_stack+141411,int_stack+126075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2851029, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5408417,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+122511,int_stack+336234,int_stack+334254, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1828153, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2065348,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+26595,int_stack+122511,int_stack+106311, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2858589, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5415977,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+36315,int_stack+26595,int_stack+133635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2863449, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5420837,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+122511,int_stack+36315,int_stack+141411, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2871225, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5428613,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+26595,int_stack+122511,int_stack+111171, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2881305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5438693,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+106311,int_stack+26595,int_stack+66180,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+11207238,int_stack+106311,int_stack+78528,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+42471,int_stack+339555,int_stack+338610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1841545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2078740,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+45306,int_stack+340815,int_stack+339555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1842490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2079685,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+49086,int_stack+45306,int_stack+42471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2904930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5578234,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+54756,int_stack+342435,int_stack+340815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1843750, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2080945,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+59616,int_stack+54756,int_stack+45306, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3080691, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5581069,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+67176,int_stack+59616,int_stack+49086, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3084471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5584849,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+42471,int_stack+344460,int_stack+342435, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1845370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2082565,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+76626,int_stack+42471,int_stack+54756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3090141, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5670,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+86346,int_stack+76626,int_stack+59616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3095001, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5701840,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+48546,int_stack+86346,int_stack+67176, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3102561, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5709400,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+62721,int_stack+346935,int_stack+344460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1847395, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2084590,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+143355,int_stack+62721,int_stack+42471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3112011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5718850,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11262804,int_stack+143355,int_stack+76626, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3118086, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5724925,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+62721,int_stack+11262804,int_stack+86346, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3127806, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5734645,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11262804,int_stack+62721,int_stack+48546, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3140406, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5747245,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+42471,int_stack+11262804,int_stack+26595,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+10346301,int_stack+42471,int_stack+106311,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+11425974,int_stack+10346301,int_stack+11207238,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11207238,int_stack+351060,int_stack+349905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+767820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+937650,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11210703,int_stack+352600,int_stack+351060, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+770130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+939960,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11215323,int_stack+11210703,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3169596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5761420,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11222253,int_stack+354580,int_stack+352600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+773210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+943040,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11228193,int_stack+11222253,int_stack+11210703, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3486412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5764885,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11237433,int_stack+11228193,int_stack+11215323, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3491032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5769505,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11207238,int_stack+357055,int_stack+354580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+947000,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11248983,int_stack+11207238,int_stack+11222253, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3497962, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6014491,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+26595,int_stack+11248983,int_stack+11228193, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3503902, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6020431,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11214663,int_stack+26595,int_stack+11237433, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3513142, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6029671,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11231988,int_stack+360080,int_stack+357055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+951950,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11282649,int_stack+11231988,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3524692, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6041221,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+90099,int_stack+11282649,int_stack+11248983, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3532117, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6048646,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11231988,int_stack+90099,int_stack+26595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3543997, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6060526,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+90099,int_stack+11231988,int_stack+11214663, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3559397, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6075926,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+248859,int_stack+90099,int_stack+11262804,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+11207238,int_stack+248859,int_stack+42471,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+26595,int_stack+11207238,int_stack+10346301,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10346301,int_stack+364151,int_stack+363710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1877940, 0.0, zero_stack, 1.0, int_stack+2036070, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10347624,int_stack+364739,int_stack+364151, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1878381, 0.0, zero_stack, 1.0, int_stack+2036511, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+10347624,int_stack+10346301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3576722, 0.0, zero_stack, 1.0, int_stack+5252608, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10349388,int_stack+365495,int_stack+364739, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1878969, 0.0, zero_stack, 1.0, int_stack+2037099, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10351656,int_stack+10349388,int_stack+10347624, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3578045, 0.0, zero_stack, 1.0, int_stack+5253931, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10355184,int_stack+10351656,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3579809, 0.0, zero_stack, 1.0, int_stack+5255695, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10346301,int_stack+366440,int_stack+365495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879725, 0.0, zero_stack, 1.0, int_stack+2037855, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10359594,int_stack+10346301,int_stack+10349388, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3582455, 0.0, zero_stack, 1.0, int_stack+5258341, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10364130,int_stack+10359594,int_stack+10351656, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3584723, 0.0, zero_stack, 1.0, int_stack+5260609, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10370010,int_stack+10364130,int_stack+10355184, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3588251, 0.0, zero_stack, 1.0, int_stack+5264137, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10349136,int_stack+367595,int_stack+366440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1880670, 0.0, zero_stack, 1.0, int_stack+2038800, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10352601,int_stack+10349136,int_stack+10346301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3592661, 0.0, zero_stack, 1.0, int_stack+5268547, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10376625,int_stack+10352601,int_stack+10359594, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3595496, 0.0, zero_stack, 1.0, int_stack+5271382, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10346301,int_stack+10376625,int_stack+10364130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3600032, 0.0, zero_stack, 1.0, int_stack+5275918, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10376625,int_stack+10346301,int_stack+10370010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3605912, 0.0, zero_stack, 1.0, int_stack+5281798, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10346301,int_stack+369569,int_stack+368981, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1888482, 0.0, zero_stack, 1.0, int_stack+2046612, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10348065,int_stack+370353,int_stack+369569, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1889070, 0.0, zero_stack, 1.0, int_stack+2047200, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10350417,int_stack+10348065,int_stack+10346301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3612527, 0.0, zero_stack, 1.0, int_stack+5288413, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10353945,int_stack+371361,int_stack+370353, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1889854, 0.0, zero_stack, 1.0, int_stack+2047984, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10356969,int_stack+10353945,int_stack+10348065, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3614291, 0.0, zero_stack, 1.0, int_stack+5290177, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10361673,int_stack+10356969,int_stack+10350417, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3616643, 0.0, zero_stack, 1.0, int_stack+5292529, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10346301,int_stack+372621,int_stack+371361, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890862, 0.0, zero_stack, 1.0, int_stack+2048992, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10367553,int_stack+10346301,int_stack+10353945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3630608, 0.0, zero_stack, 1.0, int_stack+5306494, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10385886,int_stack+10367553,int_stack+10356969, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3633632, 0.0, zero_stack, 1.0, int_stack+5309518, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10350081,int_stack+10385886,int_stack+10361673, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3638336, 0.0, zero_stack, 1.0, int_stack+5314222, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10358901,int_stack+374161,int_stack+372621, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1892122, 0.0, zero_stack, 1.0, int_stack+2050252, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10393726,int_stack+10358901,int_stack+10346301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3644216, 0.0, zero_stack, 1.0, int_stack+5320102, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10401286,int_stack+10393726,int_stack+10367553, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3647996, 0.0, zero_stack, 1.0, int_stack+5323882, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10358901,int_stack+10401286,int_stack+10385886, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3654044, 0.0, zero_stack, 1.0, int_stack+5329930, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10385886,int_stack+10358901,int_stack+10350081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3661884, 0.0, zero_stack, 1.0, int_stack+5337770, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+10346301,int_stack+10385886,int_stack+10376625,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10398234,int_stack+376765,int_stack+376009, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1902538, 0.0, zero_stack, 1.0, int_stack+2060668, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10400502,int_stack+377773,int_stack+376765, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1903294, 0.0, zero_stack, 1.0, int_stack+2061424, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10403526,int_stack+10400502,int_stack+10398234, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3670704, 0.0, zero_stack, 1.0, int_stack+5346590, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10408062,int_stack+379069,int_stack+377773, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1904302, 0.0, zero_stack, 1.0, int_stack+2062432, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10411950,int_stack+10408062,int_stack+10400502, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3672972, 0.0, zero_stack, 1.0, int_stack+5348858, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10374084,int_stack+10411950,int_stack+10403526, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3675996, 0.0, zero_stack, 1.0, int_stack+5351882, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10398234,int_stack+380689,int_stack+379069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1905598, 0.0, zero_stack, 1.0, int_stack+2063728, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11207238,int_stack+10398234,int_stack+10408062, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3722595, 0.0, zero_stack, 1.0, int_stack+5398481, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11215014,int_stack+11207238,int_stack+10411950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3726483, 0.0, zero_stack, 1.0, int_stack+5402369, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10403094,int_stack+11215014,int_stack+10374084, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3732531, 0.0, zero_stack, 1.0, int_stack+5408417, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10374084,int_stack+382669,int_stack+380689, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1907218, 0.0, zero_stack, 1.0, int_stack+2065348, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10414434,int_stack+10374084,int_stack+10398234, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3740091, 0.0, zero_stack, 1.0, int_stack+5415977, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11225094,int_stack+10414434,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3744951, 0.0, zero_stack, 1.0, int_stack+5420837, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11238054,int_stack+11225094,int_stack+11215014, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3752727, 0.0, zero_stack, 1.0, int_stack+5428613, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11207238,int_stack+11238054,int_stack+10403094, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3762807, 0.0, zero_stack, 1.0, int_stack+5438693, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+11223114,int_stack+11207238,int_stack+10385886,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+248859,int_stack+11223114,int_stack+10346301,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10346301,int_stack+385990,int_stack+385045, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1920610, 0.0, zero_stack, 1.0, int_stack+2078740, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10349136,int_stack+387250,int_stack+385990, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921555, 0.0, zero_stack, 1.0, int_stack+2079685, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10352916,int_stack+10349136,int_stack+10346301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3902348, 0.0, zero_stack, 1.0, int_stack+5578234, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10358586,int_stack+388870,int_stack+387250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1922815, 0.0, zero_stack, 1.0, int_stack+2080945, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10363446,int_stack+10358586,int_stack+10349136, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3905183, 0.0, zero_stack, 1.0, int_stack+5581069, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10371006,int_stack+10363446,int_stack+10352916, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3908963, 0.0, zero_stack, 1.0, int_stack+5584849, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10346301,int_stack+390895,int_stack+388870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1924435, 0.0, zero_stack, 1.0, int_stack+2082565, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10380456,int_stack+10346301,int_stack+10358586, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4025954, 0.0, zero_stack, 1.0, int_stack+5670, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10390176,int_stack+10380456,int_stack+10363446, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4030814, 0.0, zero_stack, 1.0, int_stack+5701840, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10352376,int_stack+10390176,int_stack+10371006, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4038374, 0.0, zero_stack, 1.0, int_stack+5709400, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10366551,int_stack+393370,int_stack+390895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1926460, 0.0, zero_stack, 1.0, int_stack+2084590, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10402776,int_stack+10366551,int_stack+10346301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4047824, 0.0, zero_stack, 1.0, int_stack+5718850, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11260158,int_stack+10402776,int_stack+10380456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4053899, 0.0, zero_stack, 1.0, int_stack+5724925, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10402776,int_stack+11260158,int_stack+10390176, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4063619, 0.0, zero_stack, 1.0, int_stack+5734645, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11260158,int_stack+10402776,int_stack+10352376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4076219, 0.0, zero_stack, 1.0, int_stack+5747245, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+10346301,int_stack+11260158,int_stack+11207238,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+304425,int_stack+10346301,int_stack+11223114,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+11768190,int_stack+304425,int_stack+248859,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+248859,int_stack+397495,int_stack+396340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+824430, 0.0, zero_stack, 1.0, int_stack+937650, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+252324,int_stack+399035,int_stack+397495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+826740, 0.0, zero_stack, 1.0, int_stack+939960, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+256944,int_stack+252324,int_stack+248859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4090394, 0.0, zero_stack, 1.0, int_stack+5761420, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+263874,int_stack+401015,int_stack+399035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829820, 0.0, zero_stack, 1.0, int_stack+943040, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+269814,int_stack+263874,int_stack+252324, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4093859, 0.0, zero_stack, 1.0, int_stack+5764885, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+279054,int_stack+269814,int_stack+256944, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4098479, 0.0, zero_stack, 1.0, int_stack+5769505, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+248859,int_stack+403490,int_stack+401015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+833780, 0.0, zero_stack, 1.0, int_stack+947000, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+290604,int_stack+248859,int_stack+263874, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4343465, 0.0, zero_stack, 1.0, int_stack+6014491, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11207238,int_stack+290604,int_stack+269814, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4349405, 0.0, zero_stack, 1.0, int_stack+6020431, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+256284,int_stack+11207238,int_stack+279054, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4358645, 0.0, zero_stack, 1.0, int_stack+6029671, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+273609,int_stack+406515,int_stack+403490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+838730, 0.0, zero_stack, 1.0, int_stack+951950, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11222638,int_stack+273609,int_stack+248859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4370195, 0.0, zero_stack, 1.0, int_stack+6041221, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11237488,int_stack+11222638,int_stack+290604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4377620, 0.0, zero_stack, 1.0, int_stack+6048646, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+273609,int_stack+11237488,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4389500, 0.0, zero_stack, 1.0, int_stack+6060526, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11207238,int_stack+273609,int_stack+256284, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4404900, 0.0, zero_stack, 1.0, int_stack+6075926, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+11860800,int_stack+11207238,int_stack+11260158,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+11207238,int_stack+11860800,int_stack+10346301,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+11860800,int_stack+11207238,int_stack+304425,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11207238,int_stack+410586,int_stack+410145, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1957005, 1.0, int_stack+2036070, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11208561,int_stack+411174,int_stack+410586, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1957446, 1.0, int_stack+2036511, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+11208561,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4422225, 1.0, int_stack+5252608, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11210325,int_stack+411930,int_stack+411174, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1958034, 1.0, int_stack+2037099, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11212593,int_stack+11210325,int_stack+11208561, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4423548, 1.0, int_stack+5253931, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11216121,int_stack+11212593,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4425312, 1.0, int_stack+5255695, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11207238,int_stack+412875,int_stack+411930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1958790, 1.0, int_stack+2037855, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11220531,int_stack+11207238,int_stack+11210325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4427958, 1.0, int_stack+5258341, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11225067,int_stack+11220531,int_stack+11212593, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4430226, 1.0, int_stack+5260609, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11230947,int_stack+11225067,int_stack+11216121, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4433754, 1.0, int_stack+5264137, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11210073,int_stack+414030,int_stack+412875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1959735, 1.0, int_stack+2038800, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11213538,int_stack+11210073,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3914633, 1.0, int_stack+5268547, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11237562,int_stack+11213538,int_stack+11220531, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4438164, 1.0, int_stack+5271382, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11207238,int_stack+11237562,int_stack+11225067, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4442700, 1.0, int_stack+5275918, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11237562,int_stack+11207238,int_stack+11230947, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4448580, 1.0, int_stack+5281798, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11207238,int_stack+416004,int_stack+415416, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1967547, 1.0, int_stack+2046612, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11209002,int_stack+416788,int_stack+416004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1968135, 1.0, int_stack+2047200, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11211354,int_stack+11209002,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4455195, 1.0, int_stack+5288413, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11214882,int_stack+417796,int_stack+416788, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1968919, 1.0, int_stack+2047984, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11217906,int_stack+11214882,int_stack+11209002, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4456959, 1.0, int_stack+5290177, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11222610,int_stack+11217906,int_stack+11211354, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4459311, 1.0, int_stack+5292529, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11207238,int_stack+419056,int_stack+417796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1969927, 1.0, int_stack+2048992, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11228490,int_stack+11207238,int_stack+11214882, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4473276, 1.0, int_stack+5306494, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11246823,int_stack+11228490,int_stack+11217906, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4476300, 1.0, int_stack+5309518, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11211018,int_stack+11246823,int_stack+11222610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4481004, 1.0, int_stack+5314222, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11219838,int_stack+420596,int_stack+419056, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1971187, 1.0, int_stack+2050252, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11254663,int_stack+11219838,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4486884, 1.0, int_stack+5320102, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11262223,int_stack+11254663,int_stack+11228490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4490664, 1.0, int_stack+5323882, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11219838,int_stack+11262223,int_stack+11246823, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4496712, 1.0, int_stack+5329930, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11246823,int_stack+11219838,int_stack+11211018, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4504552, 1.0, int_stack+5337770, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+11259171,int_stack+11246823,int_stack+11237562,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11286954,int_stack+423200,int_stack+422444, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1981603, 1.0, int_stack+2060668, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11289222,int_stack+424208,int_stack+423200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1982359, 1.0, int_stack+2061424, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11292246,int_stack+11289222,int_stack+11286954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4513372, 1.0, int_stack+5346590, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11296782,int_stack+425504,int_stack+424208, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1983367, 1.0, int_stack+2062432, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11207238,int_stack+11296782,int_stack+11289222, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4515640, 1.0, int_stack+5348858, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11213286,int_stack+11207238,int_stack+11292246, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4518664, 1.0, int_stack+5351882, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11286954,int_stack+427124,int_stack+425504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1984663, 1.0, int_stack+2063728, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11220846,int_stack+11286954,int_stack+11296782, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4565263, 1.0, int_stack+5398481, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11291814,int_stack+11220846,int_stack+11207238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4569151, 1.0, int_stack+5402369, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11228622,int_stack+11291814,int_stack+11213286, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4575199, 1.0, int_stack+5408417, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11207238,int_stack+429104,int_stack+427124, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1986283, 1.0, int_stack+2065348, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10346301,int_stack+11207238,int_stack+11286954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4582759, 1.0, int_stack+5415977, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11207238,int_stack+10346301,int_stack+11220846, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4587619, 1.0, int_stack+5420837, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10346301,int_stack+11207238,int_stack+11291814, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4595395, 1.0, int_stack+5428613, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11207238,int_stack+10346301,int_stack+11228622, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4605475, 1.0, int_stack+5438693, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+10346301,int_stack+11207238,int_stack+11246823,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+248859,int_stack+10346301,int_stack+11259171,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10383345,int_stack+432425,int_stack+431480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1999675, 1.0, int_stack+2078740, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10386180,int_stack+433685,int_stack+432425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2000620, 1.0, int_stack+2079685, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10389960,int_stack+10386180,int_stack+10383345, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4616815, 1.0, int_stack+5578234, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10395630,int_stack+435305,int_stack+433685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2001880, 1.0, int_stack+2080945, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10400490,int_stack+10395630,int_stack+10386180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4619650, 1.0, int_stack+5581069, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10408050,int_stack+10400490,int_stack+10389960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+5584849, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10383345,int_stack+437330,int_stack+435305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2003500, 1.0, int_stack+2082565, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11223114,int_stack+10383345,int_stack+10395630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4856337, 1.0, int_stack+5670, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11232834,int_stack+11223114,int_stack+10400490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4861197, 1.0, int_stack+5701840, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10389420,int_stack+11232834,int_stack+10408050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4868757, 1.0, int_stack+5709400, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10403595,int_stack+439805,int_stack+437330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2005525, 1.0, int_stack+2084590, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10411020,int_stack+10403595,int_stack+10383345, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4878207, 1.0, int_stack+5718850, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11245434,int_stack+10411020,int_stack+11223114, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4884282, 1.0, int_stack+5724925, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10403595,int_stack+11245434,int_stack+11232834, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4894002, 1.0, int_stack+5734645, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11223114,int_stack+10403595,int_stack+10389420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4906602, 1.0, int_stack+5747245, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+11242959,int_stack+11223114,int_stack+11207238,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+304425,int_stack+11242959,int_stack+10346301,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+11984280,int_stack+304425,int_stack+248859,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+248859,int_stack+443930,int_stack+442775, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+881040, 1.0, int_stack+937650, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+252324,int_stack+445470,int_stack+443930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+883350, 1.0, int_stack+939960, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+256944,int_stack+252324,int_stack+248859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4920777, 1.0, int_stack+5761420, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+263874,int_stack+447450,int_stack+445470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+886430, 1.0, int_stack+943040, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+269814,int_stack+263874,int_stack+252324, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4924242, 1.0, int_stack+5764885, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+279054,int_stack+269814,int_stack+256944, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4928862, 1.0, int_stack+5769505, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+248859,int_stack+449925,int_stack+447450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+890390, 1.0, int_stack+947000, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+290604,int_stack+248859,int_stack+263874, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5173848, 1.0, int_stack+6014491, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10346301,int_stack+290604,int_stack+269814, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5179788, 1.0, int_stack+6020431, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+256284,int_stack+10346301,int_stack+279054, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5189028, 1.0, int_stack+6029671, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+273609,int_stack+452950,int_stack+449925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+895340, 1.0, int_stack+951950, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10361701,int_stack+273609,int_stack+248859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5200578, 1.0, int_stack+6041221, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10376551,int_stack+10361701,int_stack+290604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5208003, 1.0, int_stack+6048646, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+273609,int_stack+10376551,int_stack+10346301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5219883, 1.0, int_stack+6060526, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10346301,int_stack+273609,int_stack+256284, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5235283, 1.0, int_stack+6075926, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+378513,int_stack+10346301,int_stack+11223114,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+12076890,int_stack+378513,int_stack+11242959,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+12172146,int_stack+12076890,int_stack+304425,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12076890,int_stack+457021,int_stack+456580, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2036070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12078213,int_stack+457609,int_stack+457021, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2036511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+12078213,int_stack+12076890, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5252608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12079977,int_stack+458365,int_stack+457609, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2037099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12082245,int_stack+12079977,int_stack+12078213, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5253931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12085773,int_stack+12082245,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5255695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12076890,int_stack+459310,int_stack+458365, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2037855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12090183,int_stack+12076890,int_stack+12079977, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5258341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12094719,int_stack+12090183,int_stack+12082245, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5260609, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12100599,int_stack+12094719,int_stack+12085773, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5264137, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12079725,int_stack+460465,int_stack+459310, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2038800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12083190,int_stack+12079725,int_stack+12076890, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5268547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12107214,int_stack+12083190,int_stack+12090183, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5271382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12076890,int_stack+12107214,int_stack+12094719, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5275918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12107214,int_stack+12076890,int_stack+12100599, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5281798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12076890,int_stack+462439,int_stack+461851, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2046612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12078654,int_stack+463223,int_stack+462439, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2047200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12081006,int_stack+12078654,int_stack+12076890, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5288413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12084534,int_stack+464231,int_stack+463223, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2047984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12087558,int_stack+12084534,int_stack+12078654, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5290177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12092262,int_stack+12087558,int_stack+12081006, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5292529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12076890,int_stack+465491,int_stack+464231, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2048992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12098142,int_stack+12076890,int_stack+12084534, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5306494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12116475,int_stack+12098142,int_stack+12087558, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5309518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12080670,int_stack+12116475,int_stack+12092262, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5314222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12089490,int_stack+467031,int_stack+465491, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2050252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12124315,int_stack+12089490,int_stack+12076890, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5320102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12131875,int_stack+12124315,int_stack+12098142, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5323882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12089490,int_stack+12131875,int_stack+12116475, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5329930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12116475,int_stack+12089490,int_stack+12080670, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5337770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+12128823,int_stack+12116475,int_stack+12107214,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12156606,int_stack+469635,int_stack+468879, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2060668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12158874,int_stack+470643,int_stack+469635, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2061424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12161898,int_stack+12158874,int_stack+12156606, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5346590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12166434,int_stack+471939,int_stack+470643, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2062432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12076890,int_stack+12166434,int_stack+12158874, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5348858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12082938,int_stack+12076890,int_stack+12161898, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5351882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12156606,int_stack+473559,int_stack+471939, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2063728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12090498,int_stack+12156606,int_stack+12166434, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5398481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12161466,int_stack+12090498,int_stack+12076890, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5402369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12098274,int_stack+12161466,int_stack+12082938, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5408417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12076890,int_stack+475539,int_stack+473559, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2065348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10346301,int_stack+12076890,int_stack+12156606, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5415977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12076890,int_stack+10346301,int_stack+12090498, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5420837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10346301,int_stack+12076890,int_stack+12161466, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5428613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12076890,int_stack+10346301,int_stack+12098274, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5438693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+10346301,int_stack+12076890,int_stack+12116475,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+248859,int_stack+10346301,int_stack+12128823,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10383345,int_stack+478860,int_stack+477915, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2078740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10386180,int_stack+480120,int_stack+478860, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2079685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10389960,int_stack+10386180,int_stack+10383345, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5578234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10395630,int_stack+481740,int_stack+480120, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2080945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10400490,int_stack+10395630,int_stack+10386180, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5581069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10408050,int_stack+10400490,int_stack+10389960, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5584849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10383345,int_stack+483765,int_stack+481740, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2082565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12092766,int_stack+10383345,int_stack+10395630, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12102486,int_stack+12092766,int_stack+10400490, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5701840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10389420,int_stack+12102486,int_stack+10408050, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5709400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10403595,int_stack+486240,int_stack+483765, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2084590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10411020,int_stack+10403595,int_stack+10383345, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5718850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12115086,int_stack+10411020,int_stack+12092766, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5724925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10403595,int_stack+12115086,int_stack+12102486, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5734645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12092766,int_stack+10403595,int_stack+10389420, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5747245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+12112611,int_stack+12092766,int_stack+12076890,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+304425,int_stack+12112611,int_stack+10346301,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+378513,int_stack+304425,int_stack+248859,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+248859,int_stack+490365,int_stack+489210, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+937650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+252324,int_stack+491905,int_stack+490365, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+939960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+256944,int_stack+252324,int_stack+248859, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5761420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+263874,int_stack+493885,int_stack+491905, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+943040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+269814,int_stack+263874,int_stack+252324, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5764885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+279054,int_stack+269814,int_stack+256944, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+5769505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+248859,int_stack+496360,int_stack+493885, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+947000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+290604,int_stack+248859,int_stack+263874, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6014491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10346301,int_stack+290604,int_stack+269814, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6020431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+256284,int_stack+10346301,int_stack+279054, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6029671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+273609,int_stack+499385,int_stack+496360, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+951950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10361701,int_stack+273609,int_stack+248859, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6041221, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10376551,int_stack+10361701,int_stack+290604, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6048646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+273609,int_stack+10376551,int_stack+10346301, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6060526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10346301,int_stack+273609,int_stack+256284, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6075926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+11207238,int_stack+10346301,int_stack+12092766,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+12295626,int_stack+11207238,int_stack+12112611,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+12390882,int_stack+12295626,int_stack+304425,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12295626,int_stack+503456,int_stack+503015, 0.0, zero_stack, 1.0, int_stack+1798875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2115135,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12296949,int_stack+504044,int_stack+503456, 0.0, zero_stack, 1.0, int_stack+1799316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2115576,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+12296949,int_stack+12295626, 0.0, zero_stack, 1.0, int_stack+2586100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6093251,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12298713,int_stack+504800,int_stack+504044, 0.0, zero_stack, 1.0, int_stack+1799904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2116164,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12300981,int_stack+12298713,int_stack+12296949, 0.0, zero_stack, 1.0, int_stack+2587423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6094574,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12304509,int_stack+12300981,int_stack+11081112, 0.0, zero_stack, 1.0, int_stack+2589187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6096338,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12295626,int_stack+505745,int_stack+504800, 0.0, zero_stack, 1.0, int_stack+1800660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2116920,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12308919,int_stack+12295626,int_stack+12298713, 0.0, zero_stack, 1.0, int_stack+2591833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6098984,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12313455,int_stack+12308919,int_stack+12300981, 0.0, zero_stack, 1.0, int_stack+2594101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6101252,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12319335,int_stack+12313455,int_stack+12304509, 0.0, zero_stack, 1.0, int_stack+2597629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6104780,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12298461,int_stack+506900,int_stack+505745, 0.0, zero_stack, 1.0, int_stack+1801605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2117865,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12301926,int_stack+12298461,int_stack+12295626, 0.0, zero_stack, 1.0, int_stack+2602039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5590519,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12325950,int_stack+12301926,int_stack+12308919, 0.0, zero_stack, 1.0, int_stack+2604874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6109190,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12295626,int_stack+12325950,int_stack+12313455, 0.0, zero_stack, 1.0, int_stack+2609410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6113726,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12325950,int_stack+12295626,int_stack+12319335, 0.0, zero_stack, 1.0, int_stack+2615290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6119606,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12295626,int_stack+508874,int_stack+508286, 0.0, zero_stack, 1.0, int_stack+1809417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2125677,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12297390,int_stack+509658,int_stack+508874, 0.0, zero_stack, 1.0, int_stack+1810005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2126265,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12299742,int_stack+12297390,int_stack+12295626, 0.0, zero_stack, 1.0, int_stack+2680082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6126221,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12303270,int_stack+510666,int_stack+509658, 0.0, zero_stack, 1.0, int_stack+1810789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2127049,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12306294,int_stack+12303270,int_stack+12297390, 0.0, zero_stack, 1.0, int_stack+2681846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6127985,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12310998,int_stack+12306294,int_stack+12299742, 0.0, zero_stack, 1.0, int_stack+2684198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6130337,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12295626,int_stack+511926,int_stack+510666, 0.0, zero_stack, 1.0, int_stack+1811797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2128057,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12316878,int_stack+12295626,int_stack+12303270, 0.0, zero_stack, 1.0, int_stack+2687726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6144302,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12335211,int_stack+12316878,int_stack+12306294, 0.0, zero_stack, 1.0, int_stack+2690750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6147326,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12299406,int_stack+12335211,int_stack+12310998, 0.0, zero_stack, 1.0, int_stack+2695454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6152030,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12308226,int_stack+513466,int_stack+511926, 0.0, zero_stack, 1.0, int_stack+1813057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2129317,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12343051,int_stack+12308226,int_stack+12295626, 0.0, zero_stack, 1.0, int_stack+2701334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6157910,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12350611,int_stack+12343051,int_stack+12316878, 0.0, zero_stack, 1.0, int_stack+2705114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6161690,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12308226,int_stack+12350611,int_stack+12335211, 0.0, zero_stack, 1.0, int_stack+2711162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6167738,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12335211,int_stack+12308226,int_stack+12299406, 0.0, zero_stack, 1.0, int_stack+2719002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6175578,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+12347559,int_stack+12335211,int_stack+12325950,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12375342,int_stack+516070,int_stack+515314, 0.0, zero_stack, 1.0, int_stack+1823473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2139733,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12377610,int_stack+517078,int_stack+516070, 0.0, zero_stack, 1.0, int_stack+1824229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2140489,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12380634,int_stack+12377610,int_stack+12375342, 0.0, zero_stack, 1.0, int_stack+2831265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6184398,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12385170,int_stack+518374,int_stack+517078, 0.0, zero_stack, 1.0, int_stack+1825237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2141497,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12295626,int_stack+12385170,int_stack+12377610, 0.0, zero_stack, 1.0, int_stack+2833533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6186666,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12301674,int_stack+12295626,int_stack+12380634, 0.0, zero_stack, 1.0, int_stack+2836557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6189690,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12375342,int_stack+519994,int_stack+518374, 0.0, zero_stack, 1.0, int_stack+1826533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2142793,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12309234,int_stack+12375342,int_stack+12385170, 0.0, zero_stack, 1.0, int_stack+2841093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6236289,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12380202,int_stack+12309234,int_stack+12295626, 0.0, zero_stack, 1.0, int_stack+2844981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6240177,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12317010,int_stack+12380202,int_stack+12301674, 0.0, zero_stack, 1.0, int_stack+2851029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6246225,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12295626,int_stack+521974,int_stack+519994, 0.0, zero_stack, 1.0, int_stack+1828153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2144413,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11207238,int_stack+12295626,int_stack+12375342, 0.0, zero_stack, 1.0, int_stack+2858589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6253785,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12295626,int_stack+11207238,int_stack+12309234, 0.0, zero_stack, 1.0, int_stack+2863449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6258645,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11207238,int_stack+12295626,int_stack+12380202, 0.0, zero_stack, 1.0, int_stack+2871225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6266421,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12295626,int_stack+11207238,int_stack+12317010, 0.0, zero_stack, 1.0, int_stack+2881305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6276501,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+11207238,int_stack+12295626,int_stack+12335211,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+11244282,int_stack+11207238,int_stack+12347559,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12311502,int_stack+525295,int_stack+524350, 0.0, zero_stack, 1.0, int_stack+1841545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2157805,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12314337,int_stack+526555,int_stack+525295, 0.0, zero_stack, 1.0, int_stack+1842490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2158750,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12318117,int_stack+12314337,int_stack+12311502, 0.0, zero_stack, 1.0, int_stack+2904930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6287841,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12323787,int_stack+528175,int_stack+526555, 0.0, zero_stack, 1.0, int_stack+1843750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2160010,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12328647,int_stack+12323787,int_stack+12314337, 0.0, zero_stack, 1.0, int_stack+3080691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6290676,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12336207,int_stack+12328647,int_stack+12318117, 0.0, zero_stack, 1.0, int_stack+3084471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6527363,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12311502,int_stack+530200,int_stack+528175, 0.0, zero_stack, 1.0, int_stack+1845370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2161630,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12345657,int_stack+12311502,int_stack+12323787, 0.0, zero_stack, 1.0, int_stack+3090141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6533033,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12355377,int_stack+12345657,int_stack+12328647, 0.0, zero_stack, 1.0, int_stack+3095001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6537893,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12317577,int_stack+12355377,int_stack+12336207, 0.0, zero_stack, 1.0, int_stack+3102561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6545453,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12331752,int_stack+532675,int_stack+530200, 0.0, zero_stack, 1.0, int_stack+1847395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2163655,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12367977,int_stack+12331752,int_stack+12311502, 0.0, zero_stack, 1.0, int_stack+3112011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6554903,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10346301,int_stack+12367977,int_stack+12345657, 0.0, zero_stack, 1.0, int_stack+3118086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6560978,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12367977,int_stack+10346301,int_stack+12355377, 0.0, zero_stack, 1.0, int_stack+3127806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6570698,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10346301,int_stack+12367977,int_stack+12317577, 0.0, zero_stack, 1.0, int_stack+3140406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6583298,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+10366146,int_stack+10346301,int_stack+12295626,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+12295626,int_stack+10366146,int_stack+11207238,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+248859,int_stack+12295626,int_stack+11244282,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11207238,int_stack+536800,int_stack+535645, 0.0, zero_stack, 1.0, int_stack+767820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994260,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11210703,int_stack+538340,int_stack+536800, 0.0, zero_stack, 1.0, int_stack+770130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+996570,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11215323,int_stack+11210703,int_stack+11207238, 0.0, zero_stack, 1.0, int_stack+3169596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6597473,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11222253,int_stack+540320,int_stack+538340, 0.0, zero_stack, 1.0, int_stack+773210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999650,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11228193,int_stack+11222253,int_stack+11210703, 0.0, zero_stack, 1.0, int_stack+3486412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6600938,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11237433,int_stack+11228193,int_stack+11215323, 0.0, zero_stack, 1.0, int_stack+3491032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6605558,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11207238,int_stack+542795,int_stack+540320, 0.0, zero_stack, 1.0, int_stack+777170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003610,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11248983,int_stack+11207238,int_stack+11222253, 0.0, zero_stack, 1.0, int_stack+3497962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6850544,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11260863,int_stack+11248983,int_stack+11228193, 0.0, zero_stack, 1.0, int_stack+3503902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6856484,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11214663,int_stack+11260863,int_stack+11237433, 0.0, zero_stack, 1.0, int_stack+3513142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6865724,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11231988,int_stack+545820,int_stack+542795, 0.0, zero_stack, 1.0, int_stack+782120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1008560,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11276263,int_stack+11231988,int_stack+11207238, 0.0, zero_stack, 1.0, int_stack+3524692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6877274,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12369714,int_stack+11276263,int_stack+11248983, 0.0, zero_stack, 1.0, int_stack+3532117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6884699,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11276263,int_stack+12369714,int_stack+11260863, 0.0, zero_stack, 1.0, int_stack+3543997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6896579,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11231988,int_stack+11276263,int_stack+11214663, 0.0, zero_stack, 1.0, int_stack+3559397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6911979,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+12076890,int_stack+11231988,int_stack+10346301,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+11207238,int_stack+12076890,int_stack+10366146,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+12514362,int_stack+11207238,int_stack+12295626,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12295626,int_stack+549891,int_stack+549450, 0.0, zero_stack, 1.0, int_stack+1877940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2115135, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12296949,int_stack+550479,int_stack+549891, 0.0, zero_stack, 1.0, int_stack+1878381, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2115576, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+12296949,int_stack+12295626, 0.0, zero_stack, 1.0, int_stack+3576722, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6093251, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12298713,int_stack+551235,int_stack+550479, 0.0, zero_stack, 1.0, int_stack+1878969, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2116164, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12300981,int_stack+12298713,int_stack+12296949, 0.0, zero_stack, 1.0, int_stack+3578045, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6094574, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12304509,int_stack+12300981,int_stack+11081112, 0.0, zero_stack, 1.0, int_stack+3579809, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6096338, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12295626,int_stack+552180,int_stack+551235, 0.0, zero_stack, 1.0, int_stack+1879725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2116920, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12308919,int_stack+12295626,int_stack+12298713, 0.0, zero_stack, 1.0, int_stack+3582455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6098984, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12313455,int_stack+12308919,int_stack+12300981, 0.0, zero_stack, 1.0, int_stack+3584723, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6101252, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12319335,int_stack+12313455,int_stack+12304509, 0.0, zero_stack, 1.0, int_stack+3588251, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6104780, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12298461,int_stack+553335,int_stack+552180, 0.0, zero_stack, 1.0, int_stack+1880670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2117865, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12301926,int_stack+12298461,int_stack+12295626, 0.0, zero_stack, 1.0, int_stack+3592661, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5590519, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12325950,int_stack+12301926,int_stack+12308919, 0.0, zero_stack, 1.0, int_stack+3595496, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6109190, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12295626,int_stack+12325950,int_stack+12313455, 0.0, zero_stack, 1.0, int_stack+3600032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6113726, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12325950,int_stack+12295626,int_stack+12319335, 0.0, zero_stack, 1.0, int_stack+3605912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6119606, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12295626,int_stack+555309,int_stack+554721, 0.0, zero_stack, 1.0, int_stack+1888482, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2125677, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12297390,int_stack+556093,int_stack+555309, 0.0, zero_stack, 1.0, int_stack+1889070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2126265, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12299742,int_stack+12297390,int_stack+12295626, 0.0, zero_stack, 1.0, int_stack+3612527, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6126221, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12303270,int_stack+557101,int_stack+556093, 0.0, zero_stack, 1.0, int_stack+1889854, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2127049, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12306294,int_stack+12303270,int_stack+12297390, 0.0, zero_stack, 1.0, int_stack+3614291, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6127985, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12310998,int_stack+12306294,int_stack+12299742, 0.0, zero_stack, 1.0, int_stack+3616643, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6130337, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12295626,int_stack+558361,int_stack+557101, 0.0, zero_stack, 1.0, int_stack+1890862, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2128057, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12316878,int_stack+12295626,int_stack+12303270, 0.0, zero_stack, 1.0, int_stack+3630608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6144302, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12335211,int_stack+12316878,int_stack+12306294, 0.0, zero_stack, 1.0, int_stack+3633632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6147326, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12299406,int_stack+12335211,int_stack+12310998, 0.0, zero_stack, 1.0, int_stack+3638336, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6152030, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12308226,int_stack+559901,int_stack+558361, 0.0, zero_stack, 1.0, int_stack+1892122, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2129317, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12343051,int_stack+12308226,int_stack+12295626, 0.0, zero_stack, 1.0, int_stack+3644216, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6157910, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12350611,int_stack+12343051,int_stack+12316878, 0.0, zero_stack, 1.0, int_stack+3647996, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6161690, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12308226,int_stack+12350611,int_stack+12335211, 0.0, zero_stack, 1.0, int_stack+3654044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6167738, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12335211,int_stack+12308226,int_stack+12299406, 0.0, zero_stack, 1.0, int_stack+3661884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6175578, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+12347559,int_stack+12335211,int_stack+12325950,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12375342,int_stack+562505,int_stack+561749, 0.0, zero_stack, 1.0, int_stack+1902538, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2139733, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12377610,int_stack+563513,int_stack+562505, 0.0, zero_stack, 1.0, int_stack+1903294, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2140489, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12380634,int_stack+12377610,int_stack+12375342, 0.0, zero_stack, 1.0, int_stack+3670704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6184398, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12385170,int_stack+564809,int_stack+563513, 0.0, zero_stack, 1.0, int_stack+1904302, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2141497, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12295626,int_stack+12385170,int_stack+12377610, 0.0, zero_stack, 1.0, int_stack+3672972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6186666, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12301674,int_stack+12295626,int_stack+12380634, 0.0, zero_stack, 1.0, int_stack+3675996, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6189690, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12375342,int_stack+566429,int_stack+564809, 0.0, zero_stack, 1.0, int_stack+1905598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2142793, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12309234,int_stack+12375342,int_stack+12385170, 0.0, zero_stack, 1.0, int_stack+3722595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6236289, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12380202,int_stack+12309234,int_stack+12295626, 0.0, zero_stack, 1.0, int_stack+3726483, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6240177, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12317010,int_stack+12380202,int_stack+12301674, 0.0, zero_stack, 1.0, int_stack+3732531, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6246225, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12295626,int_stack+568409,int_stack+566429, 0.0, zero_stack, 1.0, int_stack+1907218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2144413, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11207238,int_stack+12295626,int_stack+12375342, 0.0, zero_stack, 1.0, int_stack+3740091, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6253785, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12295626,int_stack+11207238,int_stack+12309234, 0.0, zero_stack, 1.0, int_stack+3744951, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6258645, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11207238,int_stack+12295626,int_stack+12380202, 0.0, zero_stack, 1.0, int_stack+3752727, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6266421, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12295626,int_stack+11207238,int_stack+12317010, 0.0, zero_stack, 1.0, int_stack+3762807, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6276501, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+12295626,int_stack+12335211,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+11207238,int_stack+341469,int_stack+12347559,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11262804,int_stack+571730,int_stack+570785, 0.0, zero_stack, 1.0, int_stack+1920610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2157805, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11265639,int_stack+572990,int_stack+571730, 0.0, zero_stack, 1.0, int_stack+1921555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2158750, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11269419,int_stack+11265639,int_stack+11262804, 0.0, zero_stack, 1.0, int_stack+3902348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6287841, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11275089,int_stack+574610,int_stack+572990, 0.0, zero_stack, 1.0, int_stack+1922815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2160010, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11279949,int_stack+11275089,int_stack+11265639, 0.0, zero_stack, 1.0, int_stack+3905183, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6290676, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11287509,int_stack+11279949,int_stack+11269419, 0.0, zero_stack, 1.0, int_stack+3908963, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6527363, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11262804,int_stack+576635,int_stack+574610, 0.0, zero_stack, 1.0, int_stack+1924435, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2161630, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12311502,int_stack+11262804,int_stack+11275089, 0.0, zero_stack, 1.0, int_stack+4025954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6533033, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12321222,int_stack+12311502,int_stack+11279949, 0.0, zero_stack, 1.0, int_stack+4030814, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6537893, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11268879,int_stack+12321222,int_stack+11287509, 0.0, zero_stack, 1.0, int_stack+4038374, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6545453, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11283054,int_stack+579110,int_stack+576635, 0.0, zero_stack, 1.0, int_stack+1926460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2163655, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12333822,int_stack+11283054,int_stack+11262804, 0.0, zero_stack, 1.0, int_stack+4047824, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6554903, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11283054,int_stack+12333822,int_stack+12311502, 0.0, zero_stack, 1.0, int_stack+4053899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6560978, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12333822,int_stack+11283054,int_stack+12321222, 0.0, zero_stack, 1.0, int_stack+4063619, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6570698, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12311502,int_stack+12333822,int_stack+11268879, 0.0, zero_stack, 1.0, int_stack+4076219, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6583298, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+12331347,int_stack+12311502,int_stack+12295626,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+12076890,int_stack+12331347,int_stack+341469,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+471123,int_stack+12076890,int_stack+11207238,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11207238,int_stack+583235,int_stack+582080, 0.0, zero_stack, 1.0, int_stack+824430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+994260, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11210703,int_stack+584775,int_stack+583235, 0.0, zero_stack, 1.0, int_stack+826740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+996570, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11215323,int_stack+11210703,int_stack+11207238, 0.0, zero_stack, 1.0, int_stack+4090394, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6597473, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11222253,int_stack+586755,int_stack+584775, 0.0, zero_stack, 1.0, int_stack+829820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999650, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11228193,int_stack+11222253,int_stack+11210703, 0.0, zero_stack, 1.0, int_stack+4093859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6600938, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11237433,int_stack+11228193,int_stack+11215323, 0.0, zero_stack, 1.0, int_stack+4098479, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6605558, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11207238,int_stack+589230,int_stack+586755, 0.0, zero_stack, 1.0, int_stack+833780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003610, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11248983,int_stack+11207238,int_stack+11222253, 0.0, zero_stack, 1.0, int_stack+4343465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6850544, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11260863,int_stack+11248983,int_stack+11228193, 0.0, zero_stack, 1.0, int_stack+4349405, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6856484, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11214663,int_stack+11260863,int_stack+11237433, 0.0, zero_stack, 1.0, int_stack+4358645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6865724, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11231988,int_stack+592255,int_stack+589230, 0.0, zero_stack, 1.0, int_stack+838730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1008560, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11276263,int_stack+11231988,int_stack+11207238, 0.0, zero_stack, 1.0, int_stack+4370195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6877274, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+341469,int_stack+11276263,int_stack+11248983, 0.0, zero_stack, 1.0, int_stack+4377620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6884699, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11276263,int_stack+341469,int_stack+11260863, 0.0, zero_stack, 1.0, int_stack+4389500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6896579, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+11276263,int_stack+11214663, 0.0, zero_stack, 1.0, int_stack+4404900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6911979, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+11207238,int_stack+341469,int_stack+12311502,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+12637842,int_stack+11207238,int_stack+12331347,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+12733098,int_stack+12637842,int_stack+12076890,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12076890,int_stack+596326,int_stack+595885, 0.0, zero_stack, 1.0, int_stack+1957005, 0.0, zero_stack, 1.0, int_stack+2115135, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12078213,int_stack+596914,int_stack+596326, 0.0, zero_stack, 1.0, int_stack+1957446, 0.0, zero_stack, 1.0, int_stack+2115576, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+12078213,int_stack+12076890, 0.0, zero_stack, 1.0, int_stack+4422225, 0.0, zero_stack, 1.0, int_stack+6093251, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12079977,int_stack+597670,int_stack+596914, 0.0, zero_stack, 1.0, int_stack+1958034, 0.0, zero_stack, 1.0, int_stack+2116164, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12082245,int_stack+12079977,int_stack+12078213, 0.0, zero_stack, 1.0, int_stack+4423548, 0.0, zero_stack, 1.0, int_stack+6094574, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12085773,int_stack+12082245,int_stack+11081112, 0.0, zero_stack, 1.0, int_stack+4425312, 0.0, zero_stack, 1.0, int_stack+6096338, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12076890,int_stack+598615,int_stack+597670, 0.0, zero_stack, 1.0, int_stack+1958790, 0.0, zero_stack, 1.0, int_stack+2116920, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12090183,int_stack+12076890,int_stack+12079977, 0.0, zero_stack, 1.0, int_stack+4427958, 0.0, zero_stack, 1.0, int_stack+6098984, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12094719,int_stack+12090183,int_stack+12082245, 0.0, zero_stack, 1.0, int_stack+4430226, 0.0, zero_stack, 1.0, int_stack+6101252, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12100599,int_stack+12094719,int_stack+12085773, 0.0, zero_stack, 1.0, int_stack+4433754, 0.0, zero_stack, 1.0, int_stack+6104780, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12079725,int_stack+599770,int_stack+598615, 0.0, zero_stack, 1.0, int_stack+1959735, 0.0, zero_stack, 1.0, int_stack+2117865, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12083190,int_stack+12079725,int_stack+12076890, 0.0, zero_stack, 1.0, int_stack+3914633, 0.0, zero_stack, 1.0, int_stack+5590519, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12107214,int_stack+12083190,int_stack+12090183, 0.0, zero_stack, 1.0, int_stack+4438164, 0.0, zero_stack, 1.0, int_stack+6109190, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12076890,int_stack+12107214,int_stack+12094719, 0.0, zero_stack, 1.0, int_stack+4442700, 0.0, zero_stack, 1.0, int_stack+6113726, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12107214,int_stack+12076890,int_stack+12100599, 0.0, zero_stack, 1.0, int_stack+4448580, 0.0, zero_stack, 1.0, int_stack+6119606, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12076890,int_stack+601744,int_stack+601156, 0.0, zero_stack, 1.0, int_stack+1967547, 0.0, zero_stack, 1.0, int_stack+2125677, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12078654,int_stack+602528,int_stack+601744, 0.0, zero_stack, 1.0, int_stack+1968135, 0.0, zero_stack, 1.0, int_stack+2126265, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12081006,int_stack+12078654,int_stack+12076890, 0.0, zero_stack, 1.0, int_stack+4455195, 0.0, zero_stack, 1.0, int_stack+6126221, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12084534,int_stack+603536,int_stack+602528, 0.0, zero_stack, 1.0, int_stack+1968919, 0.0, zero_stack, 1.0, int_stack+2127049, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12087558,int_stack+12084534,int_stack+12078654, 0.0, zero_stack, 1.0, int_stack+4456959, 0.0, zero_stack, 1.0, int_stack+6127985, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12092262,int_stack+12087558,int_stack+12081006, 0.0, zero_stack, 1.0, int_stack+4459311, 0.0, zero_stack, 1.0, int_stack+6130337, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12076890,int_stack+604796,int_stack+603536, 0.0, zero_stack, 1.0, int_stack+1969927, 0.0, zero_stack, 1.0, int_stack+2128057, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12098142,int_stack+12076890,int_stack+12084534, 0.0, zero_stack, 1.0, int_stack+4473276, 0.0, zero_stack, 1.0, int_stack+6144302, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12116475,int_stack+12098142,int_stack+12087558, 0.0, zero_stack, 1.0, int_stack+4476300, 0.0, zero_stack, 1.0, int_stack+6147326, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12080670,int_stack+12116475,int_stack+12092262, 0.0, zero_stack, 1.0, int_stack+4481004, 0.0, zero_stack, 1.0, int_stack+6152030, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12089490,int_stack+606336,int_stack+604796, 0.0, zero_stack, 1.0, int_stack+1971187, 0.0, zero_stack, 1.0, int_stack+2129317, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12124315,int_stack+12089490,int_stack+12076890, 0.0, zero_stack, 1.0, int_stack+4486884, 0.0, zero_stack, 1.0, int_stack+6157910, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12131875,int_stack+12124315,int_stack+12098142, 0.0, zero_stack, 1.0, int_stack+4490664, 0.0, zero_stack, 1.0, int_stack+6161690, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12089490,int_stack+12131875,int_stack+12116475, 0.0, zero_stack, 1.0, int_stack+4496712, 0.0, zero_stack, 1.0, int_stack+6167738, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12116475,int_stack+12089490,int_stack+12080670, 0.0, zero_stack, 1.0, int_stack+4504552, 0.0, zero_stack, 1.0, int_stack+6175578, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+12128823,int_stack+12116475,int_stack+12107214,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12156606,int_stack+608940,int_stack+608184, 0.0, zero_stack, 1.0, int_stack+1981603, 0.0, zero_stack, 1.0, int_stack+2139733, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12158874,int_stack+609948,int_stack+608940, 0.0, zero_stack, 1.0, int_stack+1982359, 0.0, zero_stack, 1.0, int_stack+2140489, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12161898,int_stack+12158874,int_stack+12156606, 0.0, zero_stack, 1.0, int_stack+4513372, 0.0, zero_stack, 1.0, int_stack+6184398, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12166434,int_stack+611244,int_stack+609948, 0.0, zero_stack, 1.0, int_stack+1983367, 0.0, zero_stack, 1.0, int_stack+2141497, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12076890,int_stack+12166434,int_stack+12158874, 0.0, zero_stack, 1.0, int_stack+4515640, 0.0, zero_stack, 1.0, int_stack+6186666, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12082938,int_stack+12076890,int_stack+12161898, 0.0, zero_stack, 1.0, int_stack+4518664, 0.0, zero_stack, 1.0, int_stack+6189690, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12156606,int_stack+612864,int_stack+611244, 0.0, zero_stack, 1.0, int_stack+1984663, 0.0, zero_stack, 1.0, int_stack+2142793, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12090498,int_stack+12156606,int_stack+12166434, 0.0, zero_stack, 1.0, int_stack+4565263, 0.0, zero_stack, 1.0, int_stack+6236289, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12161466,int_stack+12090498,int_stack+12076890, 0.0, zero_stack, 1.0, int_stack+4569151, 0.0, zero_stack, 1.0, int_stack+6240177, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12098274,int_stack+12161466,int_stack+12082938, 0.0, zero_stack, 1.0, int_stack+4575199, 0.0, zero_stack, 1.0, int_stack+6246225, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12076890,int_stack+614844,int_stack+612864, 0.0, zero_stack, 1.0, int_stack+1986283, 0.0, zero_stack, 1.0, int_stack+2144413, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12637842,int_stack+12076890,int_stack+12156606, 0.0, zero_stack, 1.0, int_stack+4582759, 0.0, zero_stack, 1.0, int_stack+6253785, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12076890,int_stack+12637842,int_stack+12090498, 0.0, zero_stack, 1.0, int_stack+4587619, 0.0, zero_stack, 1.0, int_stack+6258645, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12637842,int_stack+12076890,int_stack+12161466, 0.0, zero_stack, 1.0, int_stack+4595395, 0.0, zero_stack, 1.0, int_stack+6266421, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12076890,int_stack+12637842,int_stack+12098274, 0.0, zero_stack, 1.0, int_stack+4605475, 0.0, zero_stack, 1.0, int_stack+6276501, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+12076890,int_stack+12116475,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+12637842,int_stack+341469,int_stack+12128823,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12693408,int_stack+618165,int_stack+617220, 0.0, zero_stack, 1.0, int_stack+1999675, 0.0, zero_stack, 1.0, int_stack+2157805, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12696243,int_stack+619425,int_stack+618165, 0.0, zero_stack, 1.0, int_stack+2000620, 0.0, zero_stack, 1.0, int_stack+2158750, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12700023,int_stack+12696243,int_stack+12693408, 0.0, zero_stack, 1.0, int_stack+4616815, 0.0, zero_stack, 1.0, int_stack+6287841, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12705693,int_stack+621045,int_stack+619425, 0.0, zero_stack, 1.0, int_stack+2001880, 0.0, zero_stack, 1.0, int_stack+2160010, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12710553,int_stack+12705693,int_stack+12696243, 0.0, zero_stack, 1.0, int_stack+4619650, 0.0, zero_stack, 1.0, int_stack+6290676, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12718113,int_stack+12710553,int_stack+12700023, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+6527363, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12693408,int_stack+623070,int_stack+621045, 0.0, zero_stack, 1.0, int_stack+2003500, 0.0, zero_stack, 1.0, int_stack+2161630, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12092766,int_stack+12693408,int_stack+12705693, 0.0, zero_stack, 1.0, int_stack+4856337, 0.0, zero_stack, 1.0, int_stack+6533033, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12102486,int_stack+12092766,int_stack+12710553, 0.0, zero_stack, 1.0, int_stack+4861197, 0.0, zero_stack, 1.0, int_stack+6537893, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12699483,int_stack+12102486,int_stack+12718113, 0.0, zero_stack, 1.0, int_stack+4868757, 0.0, zero_stack, 1.0, int_stack+6545453, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12713658,int_stack+625545,int_stack+623070, 0.0, zero_stack, 1.0, int_stack+2005525, 0.0, zero_stack, 1.0, int_stack+2163655, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12115086,int_stack+12713658,int_stack+12693408, 0.0, zero_stack, 1.0, int_stack+4878207, 0.0, zero_stack, 1.0, int_stack+6554903, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12713658,int_stack+12115086,int_stack+12092766, 0.0, zero_stack, 1.0, int_stack+4884282, 0.0, zero_stack, 1.0, int_stack+6560978, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12115086,int_stack+12713658,int_stack+12102486, 0.0, zero_stack, 1.0, int_stack+4894002, 0.0, zero_stack, 1.0, int_stack+6570698, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12092766,int_stack+12115086,int_stack+12699483, 0.0, zero_stack, 1.0, int_stack+4906602, 0.0, zero_stack, 1.0, int_stack+6583298, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+12112611,int_stack+12092766,int_stack+12076890,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+11207238,int_stack+12112611,int_stack+341469,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+12295626,int_stack+11207238,int_stack+12637842,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12637842,int_stack+629670,int_stack+628515, 0.0, zero_stack, 1.0, int_stack+881040, 0.0, zero_stack, 1.0, int_stack+994260, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12641307,int_stack+631210,int_stack+629670, 0.0, zero_stack, 1.0, int_stack+883350, 0.0, zero_stack, 1.0, int_stack+996570, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12645927,int_stack+12641307,int_stack+12637842, 0.0, zero_stack, 1.0, int_stack+4920777, 0.0, zero_stack, 1.0, int_stack+6597473, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12652857,int_stack+633190,int_stack+631210, 0.0, zero_stack, 1.0, int_stack+886430, 0.0, zero_stack, 1.0, int_stack+999650, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12658797,int_stack+12652857,int_stack+12641307, 0.0, zero_stack, 1.0, int_stack+4924242, 0.0, zero_stack, 1.0, int_stack+6600938, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12668037,int_stack+12658797,int_stack+12645927, 0.0, zero_stack, 1.0, int_stack+4928862, 0.0, zero_stack, 1.0, int_stack+6605558, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12637842,int_stack+635665,int_stack+633190, 0.0, zero_stack, 1.0, int_stack+890390, 0.0, zero_stack, 1.0, int_stack+1003610, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12679587,int_stack+12637842,int_stack+12652857, 0.0, zero_stack, 1.0, int_stack+5173848, 0.0, zero_stack, 1.0, int_stack+6850544, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12691467,int_stack+12679587,int_stack+12658797, 0.0, zero_stack, 1.0, int_stack+5179788, 0.0, zero_stack, 1.0, int_stack+6856484, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12645267,int_stack+12691467,int_stack+12668037, 0.0, zero_stack, 1.0, int_stack+5189028, 0.0, zero_stack, 1.0, int_stack+6865724, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12662592,int_stack+638690,int_stack+635665, 0.0, zero_stack, 1.0, int_stack+895340, 0.0, zero_stack, 1.0, int_stack+1008560, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12706867,int_stack+12662592,int_stack+12637842, 0.0, zero_stack, 1.0, int_stack+5200578, 0.0, zero_stack, 1.0, int_stack+6877274, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+341469,int_stack+12706867,int_stack+12679587, 0.0, zero_stack, 1.0, int_stack+5208003, 0.0, zero_stack, 1.0, int_stack+6884699, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12706867,int_stack+341469,int_stack+12691467, 0.0, zero_stack, 1.0, int_stack+5219883, 0.0, zero_stack, 1.0, int_stack+6896579, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+12706867,int_stack+12645267, 0.0, zero_stack, 1.0, int_stack+5235283, 0.0, zero_stack, 1.0, int_stack+6911979, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+12637842,int_stack+341469,int_stack+12092766,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+12856578,int_stack+12637842,int_stack+12112611,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+12951834,int_stack+12856578,int_stack+11207238,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11207238,int_stack+642761,int_stack+642320, 0.0, zero_stack, 1.0, int_stack+2036070, 1.0, int_stack+2115135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11208561,int_stack+643349,int_stack+642761, 0.0, zero_stack, 1.0, int_stack+2036511, 1.0, int_stack+2115576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+11208561,int_stack+11207238, 0.0, zero_stack, 1.0, int_stack+5252608, 1.0, int_stack+6093251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11210325,int_stack+644105,int_stack+643349, 0.0, zero_stack, 1.0, int_stack+2037099, 1.0, int_stack+2116164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11212593,int_stack+11210325,int_stack+11208561, 0.0, zero_stack, 1.0, int_stack+5253931, 1.0, int_stack+6094574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11216121,int_stack+11212593,int_stack+11081112, 0.0, zero_stack, 1.0, int_stack+5255695, 1.0, int_stack+6096338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11207238,int_stack+645050,int_stack+644105, 0.0, zero_stack, 1.0, int_stack+2037855, 1.0, int_stack+2116920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11220531,int_stack+11207238,int_stack+11210325, 0.0, zero_stack, 1.0, int_stack+5258341, 1.0, int_stack+6098984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11225067,int_stack+11220531,int_stack+11212593, 0.0, zero_stack, 1.0, int_stack+5260609, 1.0, int_stack+6101252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11230947,int_stack+11225067,int_stack+11216121, 0.0, zero_stack, 1.0, int_stack+5264137, 1.0, int_stack+6104780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11210073,int_stack+646205,int_stack+645050, 0.0, zero_stack, 1.0, int_stack+2038800, 1.0, int_stack+2117865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11213538,int_stack+11210073,int_stack+11207238, 0.0, zero_stack, 1.0, int_stack+5268547, 1.0, int_stack+5590519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11237562,int_stack+11213538,int_stack+11220531, 0.0, zero_stack, 1.0, int_stack+5271382, 1.0, int_stack+6109190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11207238,int_stack+11237562,int_stack+11225067, 0.0, zero_stack, 1.0, int_stack+5275918, 1.0, int_stack+6113726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11237562,int_stack+11207238,int_stack+11230947, 0.0, zero_stack, 1.0, int_stack+5281798, 1.0, int_stack+6119606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11207238,int_stack+648179,int_stack+647591, 0.0, zero_stack, 1.0, int_stack+2046612, 1.0, int_stack+2125677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11209002,int_stack+648963,int_stack+648179, 0.0, zero_stack, 1.0, int_stack+2047200, 1.0, int_stack+2126265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11211354,int_stack+11209002,int_stack+11207238, 0.0, zero_stack, 1.0, int_stack+5288413, 1.0, int_stack+6126221, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11214882,int_stack+649971,int_stack+648963, 0.0, zero_stack, 1.0, int_stack+2047984, 1.0, int_stack+2127049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11217906,int_stack+11214882,int_stack+11209002, 0.0, zero_stack, 1.0, int_stack+5290177, 1.0, int_stack+6127985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11222610,int_stack+11217906,int_stack+11211354, 0.0, zero_stack, 1.0, int_stack+5292529, 1.0, int_stack+6130337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11207238,int_stack+651231,int_stack+649971, 0.0, zero_stack, 1.0, int_stack+2048992, 1.0, int_stack+2128057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11228490,int_stack+11207238,int_stack+11214882, 0.0, zero_stack, 1.0, int_stack+5306494, 1.0, int_stack+6144302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11246823,int_stack+11228490,int_stack+11217906, 0.0, zero_stack, 1.0, int_stack+5309518, 1.0, int_stack+6147326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11211018,int_stack+11246823,int_stack+11222610, 0.0, zero_stack, 1.0, int_stack+5314222, 1.0, int_stack+6152030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11219838,int_stack+652771,int_stack+651231, 0.0, zero_stack, 1.0, int_stack+2050252, 1.0, int_stack+2129317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11254663,int_stack+11219838,int_stack+11207238, 0.0, zero_stack, 1.0, int_stack+5320102, 1.0, int_stack+6157910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11262223,int_stack+11254663,int_stack+11228490, 0.0, zero_stack, 1.0, int_stack+5323882, 1.0, int_stack+6161690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11219838,int_stack+11262223,int_stack+11246823, 0.0, zero_stack, 1.0, int_stack+5329930, 1.0, int_stack+6167738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11246823,int_stack+11219838,int_stack+11211018, 0.0, zero_stack, 1.0, int_stack+5337770, 1.0, int_stack+6175578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+11259171,int_stack+11246823,int_stack+11237562,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11286954,int_stack+655375,int_stack+654619, 0.0, zero_stack, 1.0, int_stack+2060668, 1.0, int_stack+2139733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11289222,int_stack+656383,int_stack+655375, 0.0, zero_stack, 1.0, int_stack+2061424, 1.0, int_stack+2140489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11292246,int_stack+11289222,int_stack+11286954, 0.0, zero_stack, 1.0, int_stack+5346590, 1.0, int_stack+6184398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11296782,int_stack+657679,int_stack+656383, 0.0, zero_stack, 1.0, int_stack+2062432, 1.0, int_stack+2141497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11207238,int_stack+11296782,int_stack+11289222, 0.0, zero_stack, 1.0, int_stack+5348858, 1.0, int_stack+6186666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11213286,int_stack+11207238,int_stack+11292246, 0.0, zero_stack, 1.0, int_stack+5351882, 1.0, int_stack+6189690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11286954,int_stack+659299,int_stack+657679, 0.0, zero_stack, 1.0, int_stack+2063728, 1.0, int_stack+2142793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11220846,int_stack+11286954,int_stack+11296782, 0.0, zero_stack, 1.0, int_stack+5398481, 1.0, int_stack+6236289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11291814,int_stack+11220846,int_stack+11207238, 0.0, zero_stack, 1.0, int_stack+5402369, 1.0, int_stack+6240177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+11228622,int_stack+11291814,int_stack+11213286, 0.0, zero_stack, 1.0, int_stack+5408417, 1.0, int_stack+6246225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+11207238,int_stack+661279,int_stack+659299, 0.0, zero_stack, 1.0, int_stack+2065348, 1.0, int_stack+2144413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12856578,int_stack+11207238,int_stack+11286954, 0.0, zero_stack, 1.0, int_stack+5415977, 1.0, int_stack+6253785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11207238,int_stack+12856578,int_stack+11220846, 0.0, zero_stack, 1.0, int_stack+5420837, 1.0, int_stack+6258645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12856578,int_stack+11207238,int_stack+11291814, 0.0, zero_stack, 1.0, int_stack+5428613, 1.0, int_stack+6266421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11207238,int_stack+12856578,int_stack+11228622, 0.0, zero_stack, 1.0, int_stack+5438693, 1.0, int_stack+6276501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+11207238,int_stack+11246823,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+12856578,int_stack+341469,int_stack+11259171,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12912144,int_stack+664600,int_stack+663655, 0.0, zero_stack, 1.0, int_stack+2078740, 1.0, int_stack+2157805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12914979,int_stack+665860,int_stack+664600, 0.0, zero_stack, 1.0, int_stack+2079685, 1.0, int_stack+2158750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12918759,int_stack+12914979,int_stack+12912144, 0.0, zero_stack, 1.0, int_stack+5578234, 1.0, int_stack+6287841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12924429,int_stack+667480,int_stack+665860, 0.0, zero_stack, 1.0, int_stack+2080945, 1.0, int_stack+2160010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12929289,int_stack+12924429,int_stack+12914979, 0.0, zero_stack, 1.0, int_stack+5581069, 1.0, int_stack+6290676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12936849,int_stack+12929289,int_stack+12918759, 0.0, zero_stack, 1.0, int_stack+5584849, 1.0, int_stack+6527363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12912144,int_stack+669505,int_stack+667480, 0.0, zero_stack, 1.0, int_stack+2082565, 1.0, int_stack+2161630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11223114,int_stack+12912144,int_stack+12924429, 0.0, zero_stack, 1.0, int_stack+5670, 1.0, int_stack+6533033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11232834,int_stack+11223114,int_stack+12929289, 0.0, zero_stack, 1.0, int_stack+5701840, 1.0, int_stack+6537893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12918219,int_stack+11232834,int_stack+12936849, 0.0, zero_stack, 1.0, int_stack+5709400, 1.0, int_stack+6545453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12932394,int_stack+671980,int_stack+669505, 0.0, zero_stack, 1.0, int_stack+2084590, 1.0, int_stack+2163655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+11245434,int_stack+12932394,int_stack+12912144, 0.0, zero_stack, 1.0, int_stack+5718850, 1.0, int_stack+6554903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12932394,int_stack+11245434,int_stack+11223114, 0.0, zero_stack, 1.0, int_stack+5724925, 1.0, int_stack+6560978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+11245434,int_stack+12932394,int_stack+11232834, 0.0, zero_stack, 1.0, int_stack+5734645, 1.0, int_stack+6570698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+11223114,int_stack+11245434,int_stack+12918219, 0.0, zero_stack, 1.0, int_stack+5747245, 1.0, int_stack+6583298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+11242959,int_stack+11223114,int_stack+11207238,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+12637842,int_stack+11242959,int_stack+341469,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+12076890,int_stack+12637842,int_stack+12856578,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12856578,int_stack+676105,int_stack+674950, 0.0, zero_stack, 1.0, int_stack+937650, 1.0, int_stack+994260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12860043,int_stack+677645,int_stack+676105, 0.0, zero_stack, 1.0, int_stack+939960, 1.0, int_stack+996570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12864663,int_stack+12860043,int_stack+12856578, 0.0, zero_stack, 1.0, int_stack+5761420, 1.0, int_stack+6597473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12871593,int_stack+679625,int_stack+677645, 0.0, zero_stack, 1.0, int_stack+943040, 1.0, int_stack+999650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12877533,int_stack+12871593,int_stack+12860043, 0.0, zero_stack, 1.0, int_stack+5764885, 1.0, int_stack+6600938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12886773,int_stack+12877533,int_stack+12864663, 0.0, zero_stack, 1.0, int_stack+5769505, 1.0, int_stack+6605558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12856578,int_stack+682100,int_stack+679625, 0.0, zero_stack, 1.0, int_stack+947000, 1.0, int_stack+1003610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12898323,int_stack+12856578,int_stack+12871593, 0.0, zero_stack, 1.0, int_stack+6014491, 1.0, int_stack+6850544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12910203,int_stack+12898323,int_stack+12877533, 0.0, zero_stack, 1.0, int_stack+6020431, 1.0, int_stack+6856484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12864003,int_stack+12910203,int_stack+12886773, 0.0, zero_stack, 1.0, int_stack+6029671, 1.0, int_stack+6865724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12881328,int_stack+685125,int_stack+682100, 0.0, zero_stack, 1.0, int_stack+951950, 1.0, int_stack+1008560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12925603,int_stack+12881328,int_stack+12856578, 0.0, zero_stack, 1.0, int_stack+6041221, 1.0, int_stack+6877274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+341469,int_stack+12925603,int_stack+12898323, 0.0, zero_stack, 1.0, int_stack+6048646, 1.0, int_stack+6884699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12925603,int_stack+341469,int_stack+12910203, 0.0, zero_stack, 1.0, int_stack+6060526, 1.0, int_stack+6896579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+12925603,int_stack+12864003, 0.0, zero_stack, 1.0, int_stack+6075926, 1.0, int_stack+6911979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+12856578,int_stack+341469,int_stack+11223114,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+563733,int_stack+12856578,int_stack+11242959,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+13075314,int_stack+563733,int_stack+12637842,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12637842,int_stack+689196,int_stack+688755, 0.0, zero_stack, 2.0, int_stack+2115135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12639165,int_stack+689784,int_stack+689196, 0.0, zero_stack, 2.0, int_stack+2115576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+12639165,int_stack+12637842, 0.0, zero_stack, 2.0, int_stack+6093251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12640929,int_stack+690540,int_stack+689784, 0.0, zero_stack, 2.0, int_stack+2116164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12643197,int_stack+12640929,int_stack+12639165, 0.0, zero_stack, 2.0, int_stack+6094574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12646725,int_stack+12643197,int_stack+11081112, 0.0, zero_stack, 2.0, int_stack+6096338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12637842,int_stack+691485,int_stack+690540, 0.0, zero_stack, 2.0, int_stack+2116920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12651135,int_stack+12637842,int_stack+12640929, 0.0, zero_stack, 2.0, int_stack+6098984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12655671,int_stack+12651135,int_stack+12643197, 0.0, zero_stack, 2.0, int_stack+6101252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12661551,int_stack+12655671,int_stack+12646725, 0.0, zero_stack, 2.0, int_stack+6104780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12640677,int_stack+692640,int_stack+691485, 0.0, zero_stack, 2.0, int_stack+2117865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12644142,int_stack+12640677,int_stack+12637842, 0.0, zero_stack, 2.0, int_stack+5590519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12668166,int_stack+12644142,int_stack+12651135, 0.0, zero_stack, 2.0, int_stack+6109190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12637842,int_stack+12668166,int_stack+12655671, 0.0, zero_stack, 2.0, int_stack+6113726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12668166,int_stack+12637842,int_stack+12661551, 0.0, zero_stack, 2.0, int_stack+6119606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12637842,int_stack+694614,int_stack+694026, 0.0, zero_stack, 2.0, int_stack+2125677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12639606,int_stack+695398,int_stack+694614, 0.0, zero_stack, 2.0, int_stack+2126265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12641958,int_stack+12639606,int_stack+12637842, 0.0, zero_stack, 2.0, int_stack+6126221, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12645486,int_stack+696406,int_stack+695398, 0.0, zero_stack, 2.0, int_stack+2127049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12648510,int_stack+12645486,int_stack+12639606, 0.0, zero_stack, 2.0, int_stack+6127985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12653214,int_stack+12648510,int_stack+12641958, 0.0, zero_stack, 2.0, int_stack+6130337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12637842,int_stack+697666,int_stack+696406, 0.0, zero_stack, 2.0, int_stack+2128057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12659094,int_stack+12637842,int_stack+12645486, 0.0, zero_stack, 2.0, int_stack+6144302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12677427,int_stack+12659094,int_stack+12648510, 0.0, zero_stack, 2.0, int_stack+6147326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12641622,int_stack+12677427,int_stack+12653214, 0.0, zero_stack, 2.0, int_stack+6152030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12650442,int_stack+699206,int_stack+697666, 0.0, zero_stack, 2.0, int_stack+2129317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12685267,int_stack+12650442,int_stack+12637842, 0.0, zero_stack, 2.0, int_stack+6157910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12692827,int_stack+12685267,int_stack+12659094, 0.0, zero_stack, 2.0, int_stack+6161690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12650442,int_stack+12692827,int_stack+12677427, 0.0, zero_stack, 2.0, int_stack+6167738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12677427,int_stack+12650442,int_stack+12641622, 0.0, zero_stack, 2.0, int_stack+6175578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+12689775,int_stack+12677427,int_stack+12668166,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12717558,int_stack+701810,int_stack+701054, 0.0, zero_stack, 2.0, int_stack+2139733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12719826,int_stack+702818,int_stack+701810, 0.0, zero_stack, 2.0, int_stack+2140489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12722850,int_stack+12719826,int_stack+12717558, 0.0, zero_stack, 2.0, int_stack+6184398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12727386,int_stack+704114,int_stack+702818, 0.0, zero_stack, 2.0, int_stack+2141497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12637842,int_stack+12727386,int_stack+12719826, 0.0, zero_stack, 2.0, int_stack+6186666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12643890,int_stack+12637842,int_stack+12722850, 0.0, zero_stack, 2.0, int_stack+6189690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12717558,int_stack+705734,int_stack+704114, 0.0, zero_stack, 2.0, int_stack+2142793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12651450,int_stack+12717558,int_stack+12727386, 0.0, zero_stack, 2.0, int_stack+6236289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12722418,int_stack+12651450,int_stack+12637842, 0.0, zero_stack, 2.0, int_stack+6240177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12659226,int_stack+12722418,int_stack+12643890, 0.0, zero_stack, 2.0, int_stack+6246225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12637842,int_stack+707714,int_stack+705734, 0.0, zero_stack, 2.0, int_stack+2144413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+563733,int_stack+12637842,int_stack+12717558, 0.0, zero_stack, 2.0, int_stack+6253785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12637842,int_stack+563733,int_stack+12651450, 0.0, zero_stack, 2.0, int_stack+6258645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+563733,int_stack+12637842,int_stack+12722418, 0.0, zero_stack, 2.0, int_stack+6266421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12637842,int_stack+563733,int_stack+12659226, 0.0, zero_stack, 2.0, int_stack+6276501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+12637842,int_stack+12677427,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+563733,int_stack+341469,int_stack+12689775,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+619299,int_stack+711035,int_stack+710090, 0.0, zero_stack, 2.0, int_stack+2157805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+622134,int_stack+712295,int_stack+711035, 0.0, zero_stack, 2.0, int_stack+2158750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+625914,int_stack+622134,int_stack+619299, 0.0, zero_stack, 2.0, int_stack+6287841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+631584,int_stack+713915,int_stack+712295, 0.0, zero_stack, 2.0, int_stack+2160010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+636444,int_stack+631584,int_stack+622134, 0.0, zero_stack, 2.0, int_stack+6290676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+644004,int_stack+636444,int_stack+625914, 0.0, zero_stack, 2.0, int_stack+6527363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+619299,int_stack+715940,int_stack+713915, 0.0, zero_stack, 2.0, int_stack+2161630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+653454,int_stack+619299,int_stack+631584, 0.0, zero_stack, 2.0, int_stack+6533033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+663174,int_stack+653454,int_stack+636444, 0.0, zero_stack, 2.0, int_stack+6537893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+625374,int_stack+663174,int_stack+644004, 0.0, zero_stack, 2.0, int_stack+6545453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+639549,int_stack+718415,int_stack+715940, 0.0, zero_stack, 2.0, int_stack+2163655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+675774,int_stack+639549,int_stack+619299, 0.0, zero_stack, 2.0, int_stack+6554903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+687924,int_stack+675774,int_stack+653454, 0.0, zero_stack, 2.0, int_stack+6560978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+639549,int_stack+687924,int_stack+663174, 0.0, zero_stack, 2.0, int_stack+6570698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+658449,int_stack+639549,int_stack+625374, 0.0, zero_stack, 2.0, int_stack+6583298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+12653718,int_stack+658449,int_stack+12637842,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+12856578,int_stack+12653718,int_stack+341469,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+11207238,int_stack+12856578,int_stack+563733,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+563733,int_stack+722540,int_stack+721385, 0.0, zero_stack, 2.0, int_stack+994260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567198,int_stack+724080,int_stack+722540, 0.0, zero_stack, 2.0, int_stack+996570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+571818,int_stack+567198,int_stack+563733, 0.0, zero_stack, 2.0, int_stack+6597473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+578748,int_stack+726060,int_stack+724080, 0.0, zero_stack, 2.0, int_stack+999650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+584688,int_stack+578748,int_stack+567198, 0.0, zero_stack, 2.0, int_stack+6600938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+593928,int_stack+584688,int_stack+571818, 0.0, zero_stack, 2.0, int_stack+6605558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+563733,int_stack+728535,int_stack+726060, 0.0, zero_stack, 2.0, int_stack+1003610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+605478,int_stack+563733,int_stack+578748, 0.0, zero_stack, 2.0, int_stack+6850544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+617358,int_stack+605478,int_stack+584688, 0.0, zero_stack, 2.0, int_stack+6856484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+571158,int_stack+617358,int_stack+593928, 0.0, zero_stack, 2.0, int_stack+6865724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+588483,int_stack+731560,int_stack+728535, 0.0, zero_stack, 2.0, int_stack+1008560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+632758,int_stack+588483,int_stack+563733, 0.0, zero_stack, 2.0, int_stack+6877274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+341469,int_stack+632758,int_stack+605478, 0.0, zero_stack, 2.0, int_stack+6884699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+632758,int_stack+341469,int_stack+617358, 0.0, zero_stack, 2.0, int_stack+6896579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+632758,int_stack+571158, 0.0, zero_stack, 2.0, int_stack+6911979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+563733,int_stack+341469,int_stack+658449,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+623268,int_stack+563733,int_stack+12653718,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+13198794,int_stack+623268,int_stack+12856578,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12856578,int_stack+735631,int_stack+735190, 1.0, int_stack+1798875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2194200,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12857901,int_stack+736219,int_stack+735631, 1.0, int_stack+1799316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2194641,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+12857901,int_stack+12856578, 1.0, int_stack+2586100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6929304,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12859665,int_stack+736975,int_stack+736219, 1.0, int_stack+1799904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195229,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12861933,int_stack+12859665,int_stack+12857901, 1.0, int_stack+2587423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6930627,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12865461,int_stack+12861933,int_stack+11081112, 1.0, int_stack+2589187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6932391,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12856578,int_stack+737920,int_stack+736975, 1.0, int_stack+1800660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195985,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12869871,int_stack+12856578,int_stack+12859665, 1.0, int_stack+2591833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6935037,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12874407,int_stack+12869871,int_stack+12861933, 1.0, int_stack+2594101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6937305,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12880287,int_stack+12874407,int_stack+12865461, 1.0, int_stack+2597629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6940833,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12859413,int_stack+739075,int_stack+737920, 1.0, int_stack+1801605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2196930,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12862878,int_stack+12859413,int_stack+12856578, 1.0, int_stack+2602039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2550295,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12886902,int_stack+12862878,int_stack+12869871, 1.0, int_stack+2604874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6945243,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12856578,int_stack+12886902,int_stack+12874407, 1.0, int_stack+2609410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6949779,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12886902,int_stack+12856578,int_stack+12880287, 1.0, int_stack+2615290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2553130,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12856578,int_stack+741049,int_stack+740461, 1.0, int_stack+1809417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2204742,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12858342,int_stack+741833,int_stack+741049, 1.0, int_stack+1810005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2205330,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12860694,int_stack+12858342,int_stack+12856578, 1.0, int_stack+2680082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6964920,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12864222,int_stack+742841,int_stack+741833, 1.0, int_stack+1810789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2206114,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12867246,int_stack+12864222,int_stack+12858342, 1.0, int_stack+2681846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6966684,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12871950,int_stack+12867246,int_stack+12860694, 1.0, int_stack+2684198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6969036,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12856578,int_stack+744101,int_stack+742841, 1.0, int_stack+1811797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2207122,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12877830,int_stack+12856578,int_stack+12864222, 1.0, int_stack+2687726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6972564,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12896163,int_stack+12877830,int_stack+12867246, 1.0, int_stack+2690750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6975588,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12860358,int_stack+12896163,int_stack+12871950, 1.0, int_stack+2695454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6980292,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12869178,int_stack+745641,int_stack+744101, 1.0, int_stack+1813057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2208382,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12904003,int_stack+12869178,int_stack+12856578, 1.0, int_stack+2701334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2621905,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12911563,int_stack+12904003,int_stack+12877830, 1.0, int_stack+2705114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6986172,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12869178,int_stack+12911563,int_stack+12896163, 1.0, int_stack+2711162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6992220,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12896163,int_stack+12869178,int_stack+12860358, 1.0, int_stack+2719002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7000060,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+12908511,int_stack+12896163,int_stack+12886902,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12936294,int_stack+748245,int_stack+747489, 1.0, int_stack+1823473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2218798,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12938562,int_stack+749253,int_stack+748245, 1.0, int_stack+1824229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2219554,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12941586,int_stack+12938562,int_stack+12936294, 1.0, int_stack+2831265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2639986,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12946122,int_stack+750549,int_stack+749253, 1.0, int_stack+1825237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2220562,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12856578,int_stack+12946122,int_stack+12938562, 1.0, int_stack+2833533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2642254,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12862626,int_stack+12856578,int_stack+12941586, 1.0, int_stack+2836557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2645278,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12936294,int_stack+752169,int_stack+750549, 1.0, int_stack+1826533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2221858,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12870186,int_stack+12936294,int_stack+12946122, 1.0, int_stack+2841093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7049011,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12941154,int_stack+12870186,int_stack+12856578, 1.0, int_stack+2844981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7052899,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12877962,int_stack+12941154,int_stack+12862626, 1.0, int_stack+2851029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7058947,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12856578,int_stack+754149,int_stack+752169, 1.0, int_stack+1828153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2223478,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+563733,int_stack+12856578,int_stack+12936294, 1.0, int_stack+2858589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2727822,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12856578,int_stack+563733,int_stack+12870186, 1.0, int_stack+2863449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7066507,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+563733,int_stack+12856578,int_stack+12941154, 1.0, int_stack+2871225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7074283,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12856578,int_stack+563733,int_stack+12877962, 1.0, int_stack+2881305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7084363,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+12856578,int_stack+12896163,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+563733,int_stack+341469,int_stack+12908511,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+619299,int_stack+757470,int_stack+756525, 1.0, int_stack+1841545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2237815,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+622134,int_stack+758730,int_stack+757470, 1.0, int_stack+1842490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2240020,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+625914,int_stack+622134,int_stack+619299, 1.0, int_stack+2904930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2779713,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+631584,int_stack+760350,int_stack+758730, 1.0, int_stack+1843750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2242900,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+636444,int_stack+631584,int_stack+622134, 1.0, int_stack+3080691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2649814,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+644004,int_stack+636444,int_stack+625914, 1.0, int_stack+3084471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2782548,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+619299,int_stack+762375,int_stack+760350, 1.0, int_stack+1845370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2246545,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+653454,int_stack+619299,int_stack+631584, 1.0, int_stack+3090141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2788218,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+663174,int_stack+653454,int_stack+636444, 1.0, int_stack+3095001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7111579,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+625374,int_stack+663174,int_stack+644004, 1.0, int_stack+3102561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7119139,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+639549,int_stack+764850,int_stack+762375, 1.0, int_stack+1847395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2251045,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+675774,int_stack+639549,int_stack+619299, 1.0, int_stack+3112011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2892645,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+687924,int_stack+675774,int_stack+653454, 1.0, int_stack+3118086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7347540,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+639549,int_stack+687924,int_stack+663174, 1.0, int_stack+3127806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7357260,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+658449,int_stack+639549,int_stack+625374, 1.0, int_stack+3140406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7369860,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+678294,int_stack+658449,int_stack+12856578,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+12856578,int_stack+678294,int_stack+341469,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+12637842,int_stack+12856578,int_stack+563733,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+563733,int_stack+771670,int_stack+768975, 1.0, int_stack+767820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052025,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567198,int_stack+775190,int_stack+771670, 1.0, int_stack+770130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1055875,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+571818,int_stack+567198,int_stack+563733, 1.0, int_stack+3169596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3016251,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+578748,int_stack+779645,int_stack+775190, 1.0, int_stack+773210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060935,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+584688,int_stack+578748,int_stack+567198, 1.0, int_stack+3486412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3019716,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+593928,int_stack+584688,int_stack+571818, 1.0, int_stack+3491032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024336,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+563733,int_stack+785145,int_stack+779645, 1.0, int_stack+777170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1067370,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+605478,int_stack+563733,int_stack+578748, 1.0, int_stack+3497962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3031266,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+617358,int_stack+605478,int_stack+584688, 1.0, int_stack+3503902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7618206,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+571158,int_stack+617358,int_stack+593928, 1.0, int_stack+3513142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7627446,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+588483,int_stack+788170,int_stack+785145, 1.0, int_stack+782120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1072320,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+632758,int_stack+588483,int_stack+563733, 1.0, int_stack+3524692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3154581,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+341469,int_stack+632758,int_stack+605478, 1.0, int_stack+3532117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7638996,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+632758,int_stack+341469,int_stack+617358, 1.0, int_stack+3543997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7650876,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+632758,int_stack+571158, 1.0, int_stack+3559397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7666276,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+563733,int_stack+341469,int_stack+658449,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+13322274,int_stack+563733,int_stack+678294,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+563733,int_stack+13322274,int_stack+12856578,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12856578,int_stack+792241,int_stack+791800, 1.0, int_stack+1877940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2194200, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12857901,int_stack+792829,int_stack+792241, 1.0, int_stack+1878381, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2194641, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+12857901,int_stack+12856578, 1.0, int_stack+3576722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6929304, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12859665,int_stack+793585,int_stack+792829, 1.0, int_stack+1878969, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195229, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12861933,int_stack+12859665,int_stack+12857901, 1.0, int_stack+3578045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6930627, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12865461,int_stack+12861933,int_stack+11081112, 1.0, int_stack+3579809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6932391, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12856578,int_stack+794530,int_stack+793585, 1.0, int_stack+1879725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195985, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12869871,int_stack+12856578,int_stack+12859665, 1.0, int_stack+3582455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6935037, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12874407,int_stack+12869871,int_stack+12861933, 1.0, int_stack+3584723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6937305, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12880287,int_stack+12874407,int_stack+12865461, 1.0, int_stack+3588251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6940833, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12859413,int_stack+795685,int_stack+794530, 1.0, int_stack+1880670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2196930, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12862878,int_stack+12859413,int_stack+12856578, 1.0, int_stack+3592661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2550295, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12886902,int_stack+12862878,int_stack+12869871, 1.0, int_stack+3595496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6945243, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12856578,int_stack+12886902,int_stack+12874407, 1.0, int_stack+3600032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6949779, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12886902,int_stack+12856578,int_stack+12880287, 1.0, int_stack+3605912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2553130, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12856578,int_stack+797659,int_stack+797071, 1.0, int_stack+1888482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2204742, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12858342,int_stack+798443,int_stack+797659, 1.0, int_stack+1889070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2205330, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12860694,int_stack+12858342,int_stack+12856578, 1.0, int_stack+3612527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6964920, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12864222,int_stack+799451,int_stack+798443, 1.0, int_stack+1889854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2206114, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12867246,int_stack+12864222,int_stack+12858342, 1.0, int_stack+3614291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6966684, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12871950,int_stack+12867246,int_stack+12860694, 1.0, int_stack+3616643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6969036, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12856578,int_stack+800711,int_stack+799451, 1.0, int_stack+1890862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2207122, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12877830,int_stack+12856578,int_stack+12864222, 1.0, int_stack+3630608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6972564, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12896163,int_stack+12877830,int_stack+12867246, 1.0, int_stack+3633632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6975588, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12860358,int_stack+12896163,int_stack+12871950, 1.0, int_stack+3638336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6980292, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3630608,int_stack+802251,int_stack+800711, 1.0, int_stack+1892122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2208382, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3635228,int_stack+3630608,int_stack+12856578, 1.0, int_stack+3644216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2621905, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12904003,int_stack+3635228,int_stack+12877830, 1.0, int_stack+3647996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6986172, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3630608,int_stack+12904003,int_stack+12896163, 1.0, int_stack+3654044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6992220, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12896163,int_stack+3630608,int_stack+12860358, 1.0, int_stack+3661884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7000060, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3630608,int_stack+12896163,int_stack+12886902,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3658391,int_stack+804855,int_stack+804099, 1.0, int_stack+1902538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2218798, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3660659,int_stack+805863,int_stack+804855, 1.0, int_stack+1903294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2219554, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3663683,int_stack+3660659,int_stack+3658391, 1.0, int_stack+3670704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2639986, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3668219,int_stack+807159,int_stack+805863, 1.0, int_stack+1904302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2220562, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12908511,int_stack+3668219,int_stack+3660659, 1.0, int_stack+3672972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2642254, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12914559,int_stack+12908511,int_stack+3663683, 1.0, int_stack+3675996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2645278, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3658391,int_stack+808779,int_stack+807159, 1.0, int_stack+1905598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2221858, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3672107,int_stack+3658391,int_stack+3668219, 1.0, int_stack+3722595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7049011, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12922119,int_stack+3672107,int_stack+12908511, 1.0, int_stack+3726483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7052899, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12932199,int_stack+12922119,int_stack+12914559, 1.0, int_stack+3732531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7058947, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12908511,int_stack+810759,int_stack+808779, 1.0, int_stack+1907218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2223478, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3722595,int_stack+12908511,int_stack+3658391, 1.0, int_stack+3740091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2727822, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3658391,int_stack+3722595,int_stack+3672107, 1.0, int_stack+3744951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7066507, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3722595,int_stack+3658391,int_stack+12922119, 1.0, int_stack+3752727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7074283, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3658391,int_stack+3722595,int_stack+12932199, 1.0, int_stack+3762807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7084363, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+3658391,int_stack+12896163,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3722595,int_stack+341469,int_stack+3630608,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3630608,int_stack+814080,int_stack+813135, 1.0, int_stack+1920610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2237815, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3633443,int_stack+815340,int_stack+814080, 1.0, int_stack+1921555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2240020, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3637223,int_stack+3633443,int_stack+3630608, 1.0, int_stack+3902348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2779713, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3642893,int_stack+816960,int_stack+815340, 1.0, int_stack+1922815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2242900, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3647753,int_stack+3642893,int_stack+3633443, 1.0, int_stack+3905183, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2649814, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12856578,int_stack+3647753,int_stack+3637223, 1.0, int_stack+3908963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2782548, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3902348,int_stack+818985,int_stack+816960, 1.0, int_stack+1924435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2246545, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3630608,int_stack+3902348,int_stack+3642893, 1.0, int_stack+4025954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2788218, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12866028,int_stack+3630608,int_stack+3647753, 1.0, int_stack+4030814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7111579, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3640328,int_stack+12866028,int_stack+12856578, 1.0, int_stack+4038374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7119139, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12856578,int_stack+821460,int_stack+818985, 1.0, int_stack+1926460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2251045, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4025954,int_stack+12856578,int_stack+3902348, 1.0, int_stack+4047824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2892645, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+12878628,int_stack+4025954,int_stack+3630608, 1.0, int_stack+4053899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7347540, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4025954,int_stack+12878628,int_stack+12866028, 1.0, int_stack+4063619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7357260, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4044854,int_stack+4025954,int_stack+3640328, 1.0, int_stack+4076219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7369860, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+12856578,int_stack+4044854,int_stack+3658391,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+12856578,int_stack+341469,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+687213,int_stack+13322274,int_stack+3722595,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3722595,int_stack+828280,int_stack+825585, 1.0, int_stack+824430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052025, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3726060,int_stack+831800,int_stack+828280, 1.0, int_stack+826740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1055875, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3730680,int_stack+3726060,int_stack+3722595, 1.0, int_stack+4090394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3016251, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737610,int_stack+836255,int_stack+831800, 1.0, int_stack+829820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060935, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743550,int_stack+3737610,int_stack+3726060, 1.0, int_stack+4093859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3019716, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752790,int_stack+3743550,int_stack+3730680, 1.0, int_stack+4098479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024336, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3722595,int_stack+841755,int_stack+836255, 1.0, int_stack+833780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1067370, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3764340,int_stack+3722595,int_stack+3737610, 1.0, int_stack+4343465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3031266, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+341469,int_stack+3764340,int_stack+3743550, 1.0, int_stack+4349405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7618206, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3730020,int_stack+341469,int_stack+3752790, 1.0, int_stack+4358645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7627446, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4343465,int_stack+844780,int_stack+841755, 1.0, int_stack+838730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1072320, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4352540,int_stack+4343465,int_stack+3722595, 1.0, int_stack+4370195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3154581, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+356869,int_stack+4352540,int_stack+3764340, 1.0, int_stack+4377620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7638996, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4343465,int_stack+356869,int_stack+341469, 1.0, int_stack+4389500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7650876, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+4343465,int_stack+3730020, 1.0, int_stack+4404900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7666276, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+4343465,int_stack+341469,int_stack+4044854,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+3486027,int_stack+4343465,int_stack+12856578,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+13396362,int_stack+3486027,int_stack+13322274,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+848851,int_stack+848410, 1.0, int_stack+1957005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2194200, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+849439,int_stack+848851, 1.0, int_stack+1957446, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2194641, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274, 1.0, int_stack+4422225, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6929304, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+850195,int_stack+849439, 1.0, int_stack+1958034, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195229, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597, 1.0, int_stack+4423548, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6930627, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112, 1.0, int_stack+4425312, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6932391, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+851140,int_stack+850195, 1.0, int_stack+1958790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2195985, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361, 1.0, int_stack+4427958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6935037, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629, 1.0, int_stack+4430226, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6937305, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157, 1.0, int_stack+4433754, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6940833, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+852295,int_stack+851140, 1.0, int_stack+1959735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2196930, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274, 1.0, int_stack+3914633, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2550295, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567, 1.0, int_stack+4438164, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6945243, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103, 1.0, int_stack+4442700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6949779, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983, 1.0, int_stack+4448580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2553130, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+854269,int_stack+853681, 1.0, int_stack+1967547, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2204742, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+855053,int_stack+854269, 1.0, int_stack+1968135, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2205330, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274, 1.0, int_stack+4455195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6964920, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+856061,int_stack+855053, 1.0, int_stack+1968919, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2206114, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038, 1.0, int_stack+4456959, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6966684, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390, 1.0, int_stack+4459311, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6969036, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+857321,int_stack+856061, 1.0, int_stack+1969927, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2207122, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918, 1.0, int_stack+4473276, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6972564, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942, 1.0, int_stack+4476300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6975588, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646, 1.0, int_stack+4481004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6980292, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4473276,int_stack+858861,int_stack+857321, 1.0, int_stack+1971187, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2208382, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4477896,int_stack+4473276,int_stack+13322274, 1.0, int_stack+4486884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2621905, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13369699,int_stack+4477896,int_stack+13343526, 1.0, int_stack+4490664, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6986172, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4473276,int_stack+13369699,int_stack+13361859, 1.0, int_stack+4496712, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6992220, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+4473276,int_stack+13326054, 1.0, int_stack+4504552, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7000060, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4473276,int_stack+13361859,int_stack+13352598,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4501059,int_stack+861465,int_stack+860709, 1.0, int_stack+1981603, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2218798, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4503327,int_stack+862473,int_stack+861465, 1.0, int_stack+1982359, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2219554, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4506351,int_stack+4503327,int_stack+4501059, 1.0, int_stack+4513372, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2639986, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4510887,int_stack+863769,int_stack+862473, 1.0, int_stack+1983367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2220562, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13374207,int_stack+4510887,int_stack+4503327, 1.0, int_stack+4515640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2642254, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13380255,int_stack+13374207,int_stack+4506351, 1.0, int_stack+4518664, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2645278, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4501059,int_stack+865389,int_stack+863769, 1.0, int_stack+1984663, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2221858, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4514775,int_stack+4501059,int_stack+4510887, 1.0, int_stack+4565263, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7049011, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13322274,int_stack+4514775,int_stack+13374207, 1.0, int_stack+4569151, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7052899, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13332354,int_stack+13322274,int_stack+13380255, 1.0, int_stack+4575199, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7058947, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13374207,int_stack+867369,int_stack+865389, 1.0, int_stack+1986283, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2223478, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13380147,int_stack+13374207,int_stack+4501059, 1.0, int_stack+4582759, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2727822, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4501059,int_stack+13380147,int_stack+4514775, 1.0, int_stack+4587619, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7066507, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3902348,int_stack+4501059,int_stack+13322274, 1.0, int_stack+4595395, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7074283, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4501059,int_stack+3902348,int_stack+13332354, 1.0, int_stack+4605475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7084363, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+4501059,int_stack+13361859,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+13322274,int_stack+341469,int_stack+4473276,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4473276,int_stack+870690,int_stack+869745, 1.0, int_stack+1999675, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2237815, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4476111,int_stack+871950,int_stack+870690, 1.0, int_stack+2000620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2240020, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4479891,int_stack+4476111,int_stack+4473276, 1.0, int_stack+4616815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2779713, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4485561,int_stack+873570,int_stack+871950, 1.0, int_stack+2001880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2242900, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4490421,int_stack+4485561,int_stack+4476111, 1.0, int_stack+4619650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2649814, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3902348,int_stack+4490421,int_stack+4479891, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2782548, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4473276,int_stack+875595,int_stack+873570, 1.0, int_stack+2003500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2246545, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13377840,int_stack+4473276,int_stack+4485561, 1.0, int_stack+4856337, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2788218, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4565263,int_stack+13377840,int_stack+4490421, 1.0, int_stack+4861197, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7111579, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4479351,int_stack+4565263,int_stack+3902348, 1.0, int_stack+4868757, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7119139, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3902348,int_stack+878070,int_stack+875595, 1.0, int_stack+2005525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2251045, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4856337,int_stack+3902348,int_stack+4473276, 1.0, int_stack+4878207, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2892645, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4577863,int_stack+4856337,int_stack+13377840, 1.0, int_stack+4884282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7347540, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4856337,int_stack+4577863,int_stack+4565263, 1.0, int_stack+4894002, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7357260, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4565263,int_stack+4856337,int_stack+4479351, 1.0, int_stack+4906602, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7369860, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+4856337,int_stack+4565263,int_stack+4501059,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3486027,int_stack+4856337,int_stack+341469,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+12856578,int_stack+3486027,int_stack+13322274,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+884890,int_stack+882195, 1.0, int_stack+881040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052025, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13325739,int_stack+888410,int_stack+884890, 1.0, int_stack+883350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1055875, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13330359,int_stack+13325739,int_stack+13322274, 1.0, int_stack+4920777, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3016251, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13337289,int_stack+892865,int_stack+888410, 1.0, int_stack+886430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060935, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13343229,int_stack+13337289,int_stack+13325739, 1.0, int_stack+4924242, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3019716, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13352469,int_stack+13343229,int_stack+13330359, 1.0, int_stack+4928862, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024336, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+898365,int_stack+892865, 1.0, int_stack+890390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1067370, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13364019,int_stack+13322274,int_stack+13337289, 1.0, int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3031266, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13375899,int_stack+13364019,int_stack+13343229, 1.0, int_stack+5179788, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7618206, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13329699,int_stack+13375899,int_stack+13352469, 1.0, int_stack+5189028, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7627446, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5173848,int_stack+901390,int_stack+898365, 1.0, int_stack+895340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1072320, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5182923,int_stack+5173848,int_stack+13322274, 1.0, int_stack+5200578, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3154581, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+341469,int_stack+5182923,int_stack+13364019, 1.0, int_stack+5208003, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7638996, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5173848,int_stack+341469,int_stack+13375899, 1.0, int_stack+5219883, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7650876, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+5173848,int_stack+13329699, 1.0, int_stack+5235283, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7666276, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5173848,int_stack+341469,int_stack+4565263,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+4343465,int_stack+5173848,int_stack+4856337,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+779823,int_stack+4343465,int_stack+3486027,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3486027,int_stack+905461,int_stack+905020, 1.0, int_stack+2036070, 0.0, zero_stack, 1.0, int_stack+2194200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3487350,int_stack+906049,int_stack+905461, 1.0, int_stack+2036511, 0.0, zero_stack, 1.0, int_stack+2194641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+3487350,int_stack+3486027, 1.0, int_stack+5252608, 0.0, zero_stack, 1.0, int_stack+6929304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3489114,int_stack+906805,int_stack+906049, 1.0, int_stack+2037099, 0.0, zero_stack, 1.0, int_stack+2195229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3491382,int_stack+3489114,int_stack+3487350, 1.0, int_stack+5253931, 0.0, zero_stack, 1.0, int_stack+6930627, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3494910,int_stack+3491382,int_stack+11081112, 1.0, int_stack+5255695, 0.0, zero_stack, 1.0, int_stack+6932391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3486027,int_stack+907750,int_stack+906805, 1.0, int_stack+2037855, 0.0, zero_stack, 1.0, int_stack+2195985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3499320,int_stack+3486027,int_stack+3489114, 1.0, int_stack+5258341, 0.0, zero_stack, 1.0, int_stack+6935037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3503856,int_stack+3499320,int_stack+3491382, 1.0, int_stack+5260609, 0.0, zero_stack, 1.0, int_stack+6937305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3509736,int_stack+3503856,int_stack+3494910, 1.0, int_stack+5264137, 0.0, zero_stack, 1.0, int_stack+6940833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3488862,int_stack+908905,int_stack+907750, 1.0, int_stack+2038800, 0.0, zero_stack, 1.0, int_stack+2196930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+3488862,int_stack+3486027, 1.0, int_stack+5268547, 0.0, zero_stack, 1.0, int_stack+2550295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3486027,int_stack+0,int_stack+3499320, 1.0, int_stack+5271382, 0.0, zero_stack, 1.0, int_stack+6945243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3493587,int_stack+3486027,int_stack+3503856, 1.0, int_stack+5275918, 0.0, zero_stack, 1.0, int_stack+6949779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3516351,int_stack+3493587,int_stack+3509736, 1.0, int_stack+5281798, 0.0, zero_stack, 1.0, int_stack+2553130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3486027,int_stack+910879,int_stack+910291, 1.0, int_stack+2046612, 0.0, zero_stack, 1.0, int_stack+2204742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3487791,int_stack+911663,int_stack+910879, 1.0, int_stack+2047200, 0.0, zero_stack, 1.0, int_stack+2205330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3490143,int_stack+3487791,int_stack+3486027, 1.0, int_stack+5288413, 0.0, zero_stack, 1.0, int_stack+6964920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3493671,int_stack+912671,int_stack+911663, 1.0, int_stack+2047984, 0.0, zero_stack, 1.0, int_stack+2206114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3496695,int_stack+3493671,int_stack+3487791, 1.0, int_stack+5290177, 0.0, zero_stack, 1.0, int_stack+6966684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3501399,int_stack+3496695,int_stack+3490143, 1.0, int_stack+5292529, 0.0, zero_stack, 1.0, int_stack+6969036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3486027,int_stack+913931,int_stack+912671, 1.0, int_stack+2048992, 0.0, zero_stack, 1.0, int_stack+2207122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3507279,int_stack+3486027,int_stack+3493671, 1.0, int_stack+5306494, 0.0, zero_stack, 1.0, int_stack+6972564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3525612,int_stack+3507279,int_stack+3496695, 1.0, int_stack+5309518, 0.0, zero_stack, 1.0, int_stack+6975588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3489807,int_stack+3525612,int_stack+3501399, 1.0, int_stack+5314222, 0.0, zero_stack, 1.0, int_stack+6980292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5306494,int_stack+915471,int_stack+913931, 1.0, int_stack+2050252, 0.0, zero_stack, 1.0, int_stack+2208382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5311114,int_stack+5306494,int_stack+3486027, 1.0, int_stack+5320102, 0.0, zero_stack, 1.0, int_stack+2621905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3533452,int_stack+5311114,int_stack+3507279, 1.0, int_stack+5323882, 0.0, zero_stack, 1.0, int_stack+6986172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5306494,int_stack+3533452,int_stack+3525612, 1.0, int_stack+5329930, 0.0, zero_stack, 1.0, int_stack+6992220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3525612,int_stack+5306494,int_stack+3489807, 1.0, int_stack+5337770, 0.0, zero_stack, 1.0, int_stack+7000060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5306494,int_stack+3525612,int_stack+3516351,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5334277,int_stack+918075,int_stack+917319, 1.0, int_stack+2060668, 0.0, zero_stack, 1.0, int_stack+2218798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5336545,int_stack+919083,int_stack+918075, 1.0, int_stack+2061424, 0.0, zero_stack, 1.0, int_stack+2219554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5339569,int_stack+5336545,int_stack+5334277, 1.0, int_stack+5346590, 0.0, zero_stack, 1.0, int_stack+2639986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5344105,int_stack+920379,int_stack+919083, 1.0, int_stack+2062432, 0.0, zero_stack, 1.0, int_stack+2220562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3537960,int_stack+5344105,int_stack+5336545, 1.0, int_stack+5348858, 0.0, zero_stack, 1.0, int_stack+2642254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3544008,int_stack+3537960,int_stack+5339569, 1.0, int_stack+5351882, 0.0, zero_stack, 1.0, int_stack+2645278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5334277,int_stack+921999,int_stack+920379, 1.0, int_stack+2063728, 0.0, zero_stack, 1.0, int_stack+2221858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5347993,int_stack+5334277,int_stack+5344105, 1.0, int_stack+5398481, 0.0, zero_stack, 1.0, int_stack+7049011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3551568,int_stack+5347993,int_stack+3537960, 1.0, int_stack+5402369, 0.0, zero_stack, 1.0, int_stack+7052899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3561648,int_stack+3551568,int_stack+3544008, 1.0, int_stack+5408417, 0.0, zero_stack, 1.0, int_stack+7058947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3537960,int_stack+923979,int_stack+921999, 1.0, int_stack+2065348, 0.0, zero_stack, 1.0, int_stack+2223478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5398481,int_stack+3537960,int_stack+5334277, 1.0, int_stack+5415977, 0.0, zero_stack, 1.0, int_stack+2727822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5334277,int_stack+5398481,int_stack+5347993, 1.0, int_stack+5420837, 0.0, zero_stack, 1.0, int_stack+7066507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3902348,int_stack+5334277,int_stack+3551568, 1.0, int_stack+5428613, 0.0, zero_stack, 1.0, int_stack+7074283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5334277,int_stack+3902348,int_stack+3561648, 1.0, int_stack+5438693, 0.0, zero_stack, 1.0, int_stack+7084363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+5334277,int_stack+3525612,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+5398481,int_stack+341469,int_stack+5306494,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5306494,int_stack+927300,int_stack+926355, 1.0, int_stack+2078740, 0.0, zero_stack, 1.0, int_stack+2237815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5309329,int_stack+928560,int_stack+927300, 1.0, int_stack+2079685, 0.0, zero_stack, 1.0, int_stack+2240020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+5309329,int_stack+5306494, 1.0, int_stack+5578234, 0.0, zero_stack, 1.0, int_stack+2779713, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5313109,int_stack+930180,int_stack+928560, 1.0, int_stack+2080945, 0.0, zero_stack, 1.0, int_stack+2242900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5317969,int_stack+5313109,int_stack+5309329, 1.0, int_stack+5581069, 0.0, zero_stack, 1.0, int_stack+2649814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3902348,int_stack+5317969,int_stack+0, 1.0, int_stack+5584849, 0.0, zero_stack, 1.0, int_stack+2782548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5578234,int_stack+932205,int_stack+930180, 1.0, int_stack+2082565, 0.0, zero_stack, 1.0, int_stack+2246545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3486027,int_stack+5578234,int_stack+5313109, 1.0, int_stack+5670, 0.0, zero_stack, 1.0, int_stack+2788218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3495747,int_stack+3486027,int_stack+5317969, 1.0, int_stack+5701840, 0.0, zero_stack, 1.0, int_stack+7111579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5306494,int_stack+3495747,int_stack+3902348, 1.0, int_stack+5709400, 0.0, zero_stack, 1.0, int_stack+7119139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3902348,int_stack+934680,int_stack+932205, 1.0, int_stack+2084590, 0.0, zero_stack, 1.0, int_stack+2251045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5701840,int_stack+3902348,int_stack+5578234, 1.0, int_stack+5718850, 0.0, zero_stack, 1.0, int_stack+2892645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3508347,int_stack+5701840,int_stack+3486027, 1.0, int_stack+5724925, 0.0, zero_stack, 1.0, int_stack+7347540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5701840,int_stack+3508347,int_stack+3495747, 1.0, int_stack+5734645, 0.0, zero_stack, 1.0, int_stack+7357260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3486027,int_stack+5701840,int_stack+5306494, 1.0, int_stack+5747245, 0.0, zero_stack, 1.0, int_stack+7369860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5701840,int_stack+3486027,int_stack+5334277,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+5701840,int_stack+341469,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3505872,int_stack+13322274,int_stack+5398481,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5398481,int_stack+941500,int_stack+938805, 1.0, int_stack+937650, 0.0, zero_stack, 1.0, int_stack+1052025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5401946,int_stack+945020,int_stack+941500, 1.0, int_stack+939960, 0.0, zero_stack, 1.0, int_stack+1055875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5406566,int_stack+5401946,int_stack+5398481, 1.0, int_stack+5761420, 0.0, zero_stack, 1.0, int_stack+3016251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5413496,int_stack+949475,int_stack+945020, 1.0, int_stack+943040, 0.0, zero_stack, 1.0, int_stack+1060935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5419436,int_stack+5413496,int_stack+5401946, 1.0, int_stack+5764885, 0.0, zero_stack, 1.0, int_stack+3019716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5428676,int_stack+5419436,int_stack+5406566, 1.0, int_stack+5769505, 0.0, zero_stack, 1.0, int_stack+3024336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5398481,int_stack+954975,int_stack+949475, 1.0, int_stack+947000, 0.0, zero_stack, 1.0, int_stack+1067370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5440226,int_stack+5398481,int_stack+5413496, 1.0, int_stack+6014491, 0.0, zero_stack, 1.0, int_stack+3031266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+341469,int_stack+5440226,int_stack+5419436, 1.0, int_stack+6020431, 0.0, zero_stack, 1.0, int_stack+7618206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5405906,int_stack+341469,int_stack+5428676, 1.0, int_stack+6029671, 0.0, zero_stack, 1.0, int_stack+7627446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6014491,int_stack+958000,int_stack+954975, 1.0, int_stack+951950, 0.0, zero_stack, 1.0, int_stack+1072320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6023566,int_stack+6014491,int_stack+5398481, 1.0, int_stack+6041221, 0.0, zero_stack, 1.0, int_stack+3154581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+356869,int_stack+6023566,int_stack+5440226, 1.0, int_stack+6048646, 0.0, zero_stack, 1.0, int_stack+7638996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6014491,int_stack+356869,int_stack+341469, 1.0, int_stack+6060526, 0.0, zero_stack, 1.0, int_stack+7650876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+6014491,int_stack+5405906, 1.0, int_stack+6075926, 0.0, zero_stack, 1.0, int_stack+7666276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+6014491,int_stack+341469,int_stack+3486027,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+4343465,int_stack+6014491,int_stack+5701840,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+13519842,int_stack+4343465,int_stack+13322274,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+962071,int_stack+961630, 1.0, int_stack+2115135, 1.0, int_stack+2194200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+962659,int_stack+962071, 1.0, int_stack+2115576, 1.0, int_stack+2194641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274, 1.0, int_stack+6093251, 1.0, int_stack+6929304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+963415,int_stack+962659, 1.0, int_stack+2116164, 1.0, int_stack+2195229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597, 1.0, int_stack+6094574, 1.0, int_stack+6930627, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112, 1.0, int_stack+6096338, 1.0, int_stack+6932391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+964360,int_stack+963415, 1.0, int_stack+2116920, 1.0, int_stack+2195985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361, 1.0, int_stack+6098984, 1.0, int_stack+6935037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629, 1.0, int_stack+6101252, 1.0, int_stack+6937305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157, 1.0, int_stack+6104780, 1.0, int_stack+6940833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+965515,int_stack+964360, 1.0, int_stack+2117865, 1.0, int_stack+2196930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274, 1.0, int_stack+5590519, 1.0, int_stack+2550295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567, 1.0, int_stack+6109190, 1.0, int_stack+6945243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103, 1.0, int_stack+6113726, 1.0, int_stack+6949779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983, 1.0, int_stack+6119606, 1.0, int_stack+2553130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+967489,int_stack+966901, 1.0, int_stack+2125677, 1.0, int_stack+2204742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+968273,int_stack+967489, 1.0, int_stack+2126265, 1.0, int_stack+2205330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274, 1.0, int_stack+6126221, 1.0, int_stack+6964920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+969281,int_stack+968273, 1.0, int_stack+2127049, 1.0, int_stack+2206114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038, 1.0, int_stack+6127985, 1.0, int_stack+6966684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390, 1.0, int_stack+6130337, 1.0, int_stack+6969036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+970541,int_stack+969281, 1.0, int_stack+2128057, 1.0, int_stack+2207122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918, 1.0, int_stack+6144302, 1.0, int_stack+6972564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942, 1.0, int_stack+6147326, 1.0, int_stack+6975588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646, 1.0, int_stack+6152030, 1.0, int_stack+6980292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6144302,int_stack+972081,int_stack+970541, 1.0, int_stack+2129317, 1.0, int_stack+2208382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6148922,int_stack+6144302,int_stack+13322274, 1.0, int_stack+6157910, 1.0, int_stack+2621905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13369699,int_stack+6148922,int_stack+13343526, 1.0, int_stack+6161690, 1.0, int_stack+6986172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6144302,int_stack+13369699,int_stack+13361859, 1.0, int_stack+6167738, 1.0, int_stack+6992220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+6144302,int_stack+13326054, 1.0, int_stack+6175578, 1.0, int_stack+7000060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+6144302,int_stack+13361859,int_stack+13352598,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6172085,int_stack+974685,int_stack+973929, 1.0, int_stack+2139733, 1.0, int_stack+2218798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6174353,int_stack+975693,int_stack+974685, 1.0, int_stack+2140489, 1.0, int_stack+2219554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6177377,int_stack+6174353,int_stack+6172085, 1.0, int_stack+6184398, 1.0, int_stack+2639986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6181913,int_stack+976989,int_stack+975693, 1.0, int_stack+2141497, 1.0, int_stack+2220562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13374207,int_stack+6181913,int_stack+6174353, 1.0, int_stack+6186666, 1.0, int_stack+2642254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13380255,int_stack+13374207,int_stack+6177377, 1.0, int_stack+6189690, 1.0, int_stack+2645278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6172085,int_stack+978609,int_stack+976989, 1.0, int_stack+2142793, 1.0, int_stack+2221858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6185801,int_stack+6172085,int_stack+6181913, 1.0, int_stack+6236289, 1.0, int_stack+7049011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13322274,int_stack+6185801,int_stack+13374207, 1.0, int_stack+6240177, 1.0, int_stack+7052899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13332354,int_stack+13322274,int_stack+13380255, 1.0, int_stack+6246225, 1.0, int_stack+7058947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13374207,int_stack+980589,int_stack+978609, 1.0, int_stack+2144413, 1.0, int_stack+2223478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13380147,int_stack+13374207,int_stack+6172085, 1.0, int_stack+6253785, 1.0, int_stack+2727822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6172085,int_stack+13380147,int_stack+6185801, 1.0, int_stack+6258645, 1.0, int_stack+7066507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+6172085,int_stack+13322274, 1.0, int_stack+6266421, 1.0, int_stack+7074283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6172085,int_stack+5578234,int_stack+13332354, 1.0, int_stack+6276501, 1.0, int_stack+7084363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+6172085,int_stack+13361859,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+13322274,int_stack+341469,int_stack+6144302,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6144302,int_stack+983910,int_stack+982965, 1.0, int_stack+2157805, 1.0, int_stack+2237815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6147137,int_stack+985170,int_stack+983910, 1.0, int_stack+2158750, 1.0, int_stack+2240020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6150917,int_stack+6147137,int_stack+6144302, 1.0, int_stack+6287841, 1.0, int_stack+2779713, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6156587,int_stack+986790,int_stack+985170, 1.0, int_stack+2160010, 1.0, int_stack+2242900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6161447,int_stack+6156587,int_stack+6147137, 1.0, int_stack+6290676, 1.0, int_stack+2649814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5578234,int_stack+6161447,int_stack+6150917, 1.0, int_stack+6527363, 1.0, int_stack+2782548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6144302,int_stack+988815,int_stack+986790, 1.0, int_stack+2161630, 1.0, int_stack+2246545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13377840,int_stack+6144302,int_stack+6156587, 1.0, int_stack+6533033, 1.0, int_stack+2788218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6236289,int_stack+13377840,int_stack+6161447, 1.0, int_stack+6537893, 1.0, int_stack+7111579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6527363,int_stack+6236289,int_stack+5578234, 1.0, int_stack+6545453, 1.0, int_stack+7119139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5578234,int_stack+991290,int_stack+988815, 1.0, int_stack+2163655, 1.0, int_stack+2251045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6541538,int_stack+5578234,int_stack+6144302, 1.0, int_stack+6554903, 1.0, int_stack+2892645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6144302,int_stack+6541538,int_stack+13377840, 1.0, int_stack+6560978, 1.0, int_stack+7347540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6541538,int_stack+6144302,int_stack+6236289, 1.0, int_stack+6570698, 1.0, int_stack+7357260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3486027,int_stack+6541538,int_stack+6527363, 1.0, int_stack+6583298, 1.0, int_stack+7369860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+6527363,int_stack+3486027,int_stack+6172085,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4343465,int_stack+6527363,int_stack+341469,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+6014491,int_stack+4343465,int_stack+13322274,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+998110,int_stack+995415, 1.0, int_stack+994260, 1.0, int_stack+1052025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13325739,int_stack+1001630,int_stack+998110, 1.0, int_stack+996570, 1.0, int_stack+1055875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13330359,int_stack+13325739,int_stack+13322274, 1.0, int_stack+6597473, 1.0, int_stack+3016251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13337289,int_stack+1006085,int_stack+1001630, 1.0, int_stack+999650, 1.0, int_stack+1060935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13343229,int_stack+13337289,int_stack+13325739, 1.0, int_stack+6600938, 1.0, int_stack+3019716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13352469,int_stack+13343229,int_stack+13330359, 1.0, int_stack+6605558, 1.0, int_stack+3024336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1011585,int_stack+1006085, 1.0, int_stack+1003610, 1.0, int_stack+1067370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13364019,int_stack+13322274,int_stack+13337289, 1.0, int_stack+6850544, 1.0, int_stack+3031266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13375899,int_stack+13364019,int_stack+13343229, 1.0, int_stack+6856484, 1.0, int_stack+7618206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13329699,int_stack+13375899,int_stack+13352469, 1.0, int_stack+6865724, 1.0, int_stack+7627446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6850544,int_stack+1014610,int_stack+1011585, 1.0, int_stack+1008560, 1.0, int_stack+1072320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6859619,int_stack+6850544,int_stack+13322274, 1.0, int_stack+6877274, 1.0, int_stack+3154581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+341469,int_stack+6859619,int_stack+13364019, 1.0, int_stack+6884699, 1.0, int_stack+7638996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6850544,int_stack+341469,int_stack+13375899, 1.0, int_stack+6896579, 1.0, int_stack+7650876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+6850544,int_stack+13329699, 1.0, int_stack+6911979, 1.0, int_stack+7666276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+6850544,int_stack+341469,int_stack+3486027,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+5173848,int_stack+6850544,int_stack+6527363,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+13643322,int_stack+5173848,int_stack+4343465,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4343465,int_stack+1018681,int_stack+1018240, 2.0, int_stack+2194200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4344788,int_stack+1019269,int_stack+1018681, 2.0, int_stack+2194641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+4344788,int_stack+4343465, 2.0, int_stack+6929304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4346552,int_stack+1020025,int_stack+1019269, 2.0, int_stack+2195229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4348820,int_stack+4346552,int_stack+4344788, 2.0, int_stack+6930627, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4352348,int_stack+4348820,int_stack+11081112, 2.0, int_stack+6932391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4343465,int_stack+1020970,int_stack+1020025, 2.0, int_stack+2195985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4356758,int_stack+4343465,int_stack+4346552, 2.0, int_stack+6935037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4361294,int_stack+4356758,int_stack+4348820, 2.0, int_stack+6937305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4367174,int_stack+4361294,int_stack+4352348, 2.0, int_stack+6940833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4346300,int_stack+1022125,int_stack+1020970, 2.0, int_stack+2196930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4349765,int_stack+4346300,int_stack+4343465, 2.0, int_stack+2550295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4373789,int_stack+4349765,int_stack+4356758, 2.0, int_stack+6945243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4343465,int_stack+4373789,int_stack+4361294, 2.0, int_stack+6949779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4373789,int_stack+4343465,int_stack+4367174, 2.0, int_stack+2553130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4343465,int_stack+1024099,int_stack+1023511, 2.0, int_stack+2204742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4345229,int_stack+1024883,int_stack+1024099, 2.0, int_stack+2205330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4347581,int_stack+4345229,int_stack+4343465, 2.0, int_stack+6964920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4351109,int_stack+1025891,int_stack+1024883, 2.0, int_stack+2206114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4354133,int_stack+4351109,int_stack+4345229, 2.0, int_stack+6966684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4358837,int_stack+4354133,int_stack+4347581, 2.0, int_stack+6969036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6964920,int_stack+1027151,int_stack+1025891, 2.0, int_stack+2207122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4343465,int_stack+6964920,int_stack+4351109, 2.0, int_stack+6972564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4364717,int_stack+4343465,int_stack+4354133, 2.0, int_stack+6975588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6968700,int_stack+4364717,int_stack+4358837, 2.0, int_stack+6980292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6977520,int_stack+1028691,int_stack+1027151, 2.0, int_stack+2208382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4349513,int_stack+6977520,int_stack+6964920, 2.0, int_stack+2621905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4383050,int_stack+4349513,int_stack+4343465, 2.0, int_stack+6986172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4343465,int_stack+4383050,int_stack+4364717, 2.0, int_stack+6992220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4383050,int_stack+4343465,int_stack+6968700, 2.0, int_stack+7000060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4343465,int_stack+4383050,int_stack+4373789,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4371248,int_stack+1031295,int_stack+1030539, 2.0, int_stack+2218798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4373516,int_stack+1032303,int_stack+1031295, 2.0, int_stack+2219554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4376540,int_stack+4373516,int_stack+4371248, 2.0, int_stack+2639986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4395398,int_stack+1033599,int_stack+1032303, 2.0, int_stack+2220562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4399286,int_stack+4395398,int_stack+4373516, 2.0, int_stack+2642254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4405334,int_stack+4399286,int_stack+4376540, 2.0, int_stack+2645278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2639986,int_stack+1035219,int_stack+1033599, 2.0, int_stack+2221858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4371248,int_stack+2639986,int_stack+4395398, 2.0, int_stack+7049011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4412894,int_stack+4371248,int_stack+4399286, 2.0, int_stack+7052899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4422974,int_stack+4412894,int_stack+4405334, 2.0, int_stack+7058947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7049011,int_stack+1037199,int_stack+1035219, 2.0, int_stack+2223478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7054951,int_stack+7049011,int_stack+2639986, 2.0, int_stack+2727822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4395398,int_stack+7054951,int_stack+4371248, 2.0, int_stack+7066507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+4395398,int_stack+4412894, 2.0, int_stack+7074283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4395398,int_stack+5578234,int_stack+4422974, 2.0, int_stack+7084363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+4395398,int_stack+4383050,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+5173848,int_stack+341469,int_stack+4343465,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4343465,int_stack+1040520,int_stack+1039575, 2.0, int_stack+2237815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4346300,int_stack+1041780,int_stack+1040520, 2.0, int_stack+2240020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4350080,int_stack+4346300,int_stack+4343465, 2.0, int_stack+2779713, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4355750,int_stack+1043400,int_stack+1041780, 2.0, int_stack+2242900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4360610,int_stack+4355750,int_stack+4346300, 2.0, int_stack+2649814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2550295,int_stack+4360610,int_stack+4350080, 2.0, int_stack+2782548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2779713,int_stack+1045425,int_stack+1043400, 2.0, int_stack+2246545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4343465,int_stack+2779713,int_stack+4355750, 2.0, int_stack+2788218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4368170,int_stack+4343465,int_stack+4360610, 2.0, int_stack+7111579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2236870,int_stack+4368170,int_stack+2550295, 2.0, int_stack+7119139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2550295,int_stack+1047900,int_stack+1045425, 2.0, int_stack+2251045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7111579,int_stack+2550295,int_stack+2779713, 2.0, int_stack+2892645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4411274,int_stack+7111579,int_stack+4343465, 2.0, int_stack+7347540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4343465,int_stack+4411274,int_stack+4368170, 2.0, int_stack+7357260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3486027,int_stack+4343465,int_stack+2236870, 2.0, int_stack+7369860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+4343465,int_stack+3486027,int_stack+4395398,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+4343465,int_stack+341469,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+6850544,int_stack+13322274,int_stack+5173848,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5173848,int_stack+1057415,int_stack+1053180, 2.0, int_stack+1052025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5177313,int_stack+1062915,int_stack+1057415, 2.0, int_stack+1055875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5181933,int_stack+5177313,int_stack+5173848, 2.0, int_stack+3016251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5188863,int_stack+1069845,int_stack+1062915, 2.0, int_stack+1060935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5194803,int_stack+5188863,int_stack+5177313, 2.0, int_stack+3019716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5204043,int_stack+5194803,int_stack+5181933, 2.0, int_stack+3024336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3016251,int_stack+1075345,int_stack+1069845, 2.0, int_stack+1067370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5173848,int_stack+3016251,int_stack+5188863, 2.0, int_stack+3031266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5215593,int_stack+5173848,int_stack+5194803, 2.0, int_stack+7618206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5185728,int_stack+5215593,int_stack+5204043, 2.0, int_stack+7627446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7618206,int_stack+1078370,int_stack+1075345, 2.0, int_stack+1072320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5230993,int_stack+7618206,int_stack+3016251, 2.0, int_stack+3154581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3016251,int_stack+5230993,int_stack+5173848, 2.0, int_stack+7638996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5230993,int_stack+3016251,int_stack+5215593, 2.0, int_stack+7650876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5254093,int_stack+5230993,int_stack+5185728, 2.0, int_stack+7666276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+5173848,int_stack+5254093,int_stack+3486027,441);
 /*--- compute (kd|hh) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+903303,int_stack+5173848,int_stack+4343465,441);
 /*--- compute (if|hh) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+13766802,int_stack+903303,int_stack+13322274,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1082441,int_stack+1082000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2291765,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+1083029,int_stack+1082441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2292206,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653594,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+1083785,int_stack+1083029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2292794,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2654917,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2656681,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1084730,int_stack+1083785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2293550,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2659327,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2661595,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2665123,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+1085885,int_stack+1084730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2294495,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2669533,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2672368,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7829698,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7741813,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1087859,int_stack+1087271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2302307,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+1088643,int_stack+1087859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2302895,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7683601,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+1089651,int_stack+1088643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2303679,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7685365,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7687717,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1090911,int_stack+1089651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2304687,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7748428,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7751452,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3472479,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+1092451,int_stack+1090911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2305947,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3478359,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3162006,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3037206,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3045046,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2630725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+1095055,int_stack+1094299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2316363,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+1096063,int_stack+1095055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2317119,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3053866,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+1097359,int_stack+1096063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2318127,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3056134,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3059158,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+1098979,int_stack+1097359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2319423,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+903303,int_stack+13374207,int_stack+13384035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3482139,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+911079,int_stack+903303,int_stack+13387923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2898720,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+911079,int_stack+13350057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2820861,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+1100959,int_stack+1098979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2321043,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+921159,int_stack+13350057,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2732682,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+930879,int_stack+921159,int_stack+903303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2486792,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+930879,int_stack+911079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2559745,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+903303,int_stack+5578234,int_stack+13379067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2569825,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+903303,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2739582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+919179,int_stack+341469,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2751930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1104280,int_stack+1103335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2334435,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+1105540,int_stack+1104280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2335380,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8176198,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+1107160,int_stack+1105540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2336640,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8179033,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2550295,int_stack+13339419,int_stack+13328889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8182813,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1109185,int_stack+1107160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2338260,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13346979,int_stack+13322274,int_stack+13334559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8188483,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13356699,int_stack+13346979,int_stack+13339419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8193343,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13328349,int_stack+13356699,int_stack+2550295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10530,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2550295,int_stack+1111660,int_stack+1109185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2340285,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369299,int_stack+2550295,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465708,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+974745,int_stack+13369299,int_stack+13346979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8312764,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13369299,int_stack+974745,int_stack+13356699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8322484,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3486027,int_stack+13369299,int_stack+13328349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8335084,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+974745,int_stack+3486027,int_stack+903303, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2907765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+974745,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2923641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4343465,int_stack+13322274,int_stack+919179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2960685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1115785,int_stack+1114630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1346805,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1117325,int_stack+1115785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1349115,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8349259,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1119305,int_stack+1117325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1352195,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8352724,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+903303,int_stack+362424,int_stack+349554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8357344,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1121780,int_stack+1119305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1356155,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+914853,int_stack+341469,int_stack+356484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8602330,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+926733,int_stack+914853,int_stack+362424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8608270,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+926733,int_stack+903303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8617510,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+903303,int_stack+1124805,int_stack+1121780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1361105,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+942133,int_stack+903303,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8629060,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1022373,int_stack+942133,int_stack+914853, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8636485,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+942133,int_stack+1022373,int_stack+926733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8648365,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1022373,int_stack+942133,int_stack+348894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8663765,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+1046628,int_stack+1022373,int_stack+3486027, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3173481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+5173848,int_stack+1046628,int_stack+974745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3193326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+903303,int_stack+5173848,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3240954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1128876,int_stack+1128435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2291765, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+1129464,int_stack+1128876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2292206, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653594, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+1130220,int_stack+1129464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2292794, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2654917, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2656681, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1131165,int_stack+1130220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2293550, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2659327, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2661595, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2665123, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+1132320,int_stack+1131165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2294495, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2669533, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2672368, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7829698, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7741813, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1134294,int_stack+1133706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2302307, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+1135078,int_stack+1134294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2302895, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7683601, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+1136086,int_stack+1135078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2303679, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7685365, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7687717, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1137346,int_stack+1136086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2304687, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7748428, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7751452, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3472479, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+1138886,int_stack+1137346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2305947, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3478359, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3162006, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3037206, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3045046, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3621347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+1141490,int_stack+1140734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2316363, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+1142498,int_stack+1141490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2317119, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3053866, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+1143794,int_stack+1142498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2318127, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3056134, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3059158, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+1145414,int_stack+1143794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2319423, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5173848,int_stack+13374207,int_stack+13384035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3482139, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5181624,int_stack+5173848,int_stack+13387923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2898720, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+5181624,int_stack+13350057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2820861, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+1147394,int_stack+1145414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2321043, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5191704,int_stack+13350057,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2732682, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5201424,int_stack+5191704,int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2486792, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+5201424,int_stack+5181624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2559745, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5173848,int_stack+5578234,int_stack+13379067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2569825, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+5173848,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3682464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+5189724,int_stack+341469,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3694812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1150715,int_stack+1149770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2334435, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+1151975,int_stack+1150715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2335380, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8176198, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+1153595,int_stack+1151975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2336640, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8179033, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2550295,int_stack+13339419,int_stack+13328889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8182813, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1155620,int_stack+1153595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2338260, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13346979,int_stack+13322274,int_stack+13334559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8188483, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13356699,int_stack+13346979,int_stack+13339419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8193343, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13328349,int_stack+13356699,int_stack+2550295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10530, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2550295,int_stack+1158095,int_stack+1155620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2340285, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369299,int_stack+2550295,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465708, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5245290,int_stack+13369299,int_stack+13346979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8312764, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13369299,int_stack+5245290,int_stack+13356699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8322484, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3486027,int_stack+13369299,int_stack+13328349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8335084, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+5245290,int_stack+3486027,int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3917468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+5245290,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3933344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1026783,int_stack+13322274,int_stack+5189724, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3970388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1162220,int_stack+1161065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1346805, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1163760,int_stack+1162220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1349115, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8349259, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1165740,int_stack+1163760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1352195, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8352724, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5173848,int_stack+362424,int_stack+349554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8357344, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1168215,int_stack+1165740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1356155, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5185398,int_stack+341469,int_stack+356484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8602330, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5197278,int_stack+5185398,int_stack+362424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8608270, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+5197278,int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8617510, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5173848,int_stack+1171240,int_stack+1168215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1361105, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5212678,int_stack+5173848,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8629060, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1119393,int_stack+5212678,int_stack+5185398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8636485, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5212678,int_stack+1119393,int_stack+5197278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8648365, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1119393,int_stack+5212678,int_stack+348894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8663765, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+5173848,int_stack+1119393,int_stack+3486027, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4109294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+13890282,int_stack+5173848,int_stack+5245290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4129139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+13985538,int_stack+13890282,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4176767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1175311,int_stack+1174870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2291765, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+1175899,int_stack+1175311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2292206, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653594, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+1176655,int_stack+1175899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2292794, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2654917, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2656681, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1177600,int_stack+1176655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2293550, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2659327, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2661595, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2665123, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+1178755,int_stack+1177600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2294495, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2669533, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2672368, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7829698, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7741813, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1180729,int_stack+1180141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2302307, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+1181513,int_stack+1180729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2302895, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7683601, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+1182521,int_stack+1181513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2303679, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7685365, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7687717, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1183781,int_stack+1182521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2304687, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7748428, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7751452, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3472479, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+1185321,int_stack+1183781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2305947, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3478359, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3162006, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3037206, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3045046, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4464015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+1187925,int_stack+1187169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2316363, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+1188933,int_stack+1187925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2317119, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3053866, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+1190229,int_stack+1188933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2318127, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3056134, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3059158, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+1191849,int_stack+1190229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2319423, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13890282,int_stack+13374207,int_stack+13384035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3482139, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13898058,int_stack+13890282,int_stack+13387923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2898720, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+13898058,int_stack+13350057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2820861, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+1193829,int_stack+1191849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2321043, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13908138,int_stack+13350057,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2732682, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13917858,int_stack+13908138,int_stack+13890282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2486792, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+13917858,int_stack+13898058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2559745, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13890282,int_stack+5578234,int_stack+13379067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2569825, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+13890282,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4525132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+13906158,int_stack+341469,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4537480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1197150,int_stack+1196205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2334435, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+1198410,int_stack+1197150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2335380, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8176198, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+1200030,int_stack+1198410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2336640, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8179033, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2550295,int_stack+13339419,int_stack+13328889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8182813, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1202055,int_stack+1200030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2338260, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13346979,int_stack+13322274,int_stack+13334559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8188483, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13356699,int_stack+13346979,int_stack+13339419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8193343, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13328349,int_stack+13356699,int_stack+2550295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10530, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2550295,int_stack+1204530,int_stack+1202055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2340285, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369299,int_stack+2550295,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465708, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13961724,int_stack+13369299,int_stack+13346979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8312764, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13369299,int_stack+13961724,int_stack+13356699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8322484, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3486027,int_stack+13369299,int_stack+13328349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8335084, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+13322274,int_stack+3486027,int_stack+13890282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4747851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5173848,int_stack+13322274,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4763727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+14109018,int_stack+5173848,int_stack+13906158, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4800771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1208655,int_stack+1207500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1346805, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1210195,int_stack+1208655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1349115, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8349259, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1212175,int_stack+1210195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1352195, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8352724, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13890282,int_stack+362424,int_stack+349554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8357344, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1214650,int_stack+1212175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1356155, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13901832,int_stack+341469,int_stack+356484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8602330, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13913712,int_stack+13901832,int_stack+362424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8608270, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+13913712,int_stack+13890282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8617510, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13890282,int_stack+1217675,int_stack+1214650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1361105, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13929112,int_stack+13890282,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8629060, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13943962,int_stack+13929112,int_stack+13901832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8636485, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13890282,int_stack+13943962,int_stack+13913712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8648365, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13913382,int_stack+13890282,int_stack+348894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8663765, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+1119393,int_stack+13913382,int_stack+3486027, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4939677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+13890282,int_stack+1119393,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4959522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+14201628,int_stack+13890282,int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5007150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5173848,int_stack+1221746,int_stack+1221305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2291765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5175171,int_stack+1222334,int_stack+1221746, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2292206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+5175171,int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5176935,int_stack+1223090,int_stack+1222334, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2292794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5179203,int_stack+5176935,int_stack+5175171, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2654917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5182731,int_stack+5179203,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2656681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5173848,int_stack+1224035,int_stack+1223090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2293550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5187141,int_stack+5173848,int_stack+5176935, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2659327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5191677,int_stack+5187141,int_stack+5179203, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2661595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5197557,int_stack+5191677,int_stack+5182731, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2665123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5176683,int_stack+1225190,int_stack+1224035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2294495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5180148,int_stack+5176683,int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2669533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5204172,int_stack+5180148,int_stack+5187141, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2672368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5173848,int_stack+5204172,int_stack+5191677, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7829698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5204172,int_stack+5173848,int_stack+5197557, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7741813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5173848,int_stack+1227164,int_stack+1226576, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2302307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5175612,int_stack+1227948,int_stack+1227164, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2302895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5177964,int_stack+5175612,int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7683601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5181492,int_stack+1228956,int_stack+1227948, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2303679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5184516,int_stack+5181492,int_stack+5175612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7685365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5189220,int_stack+5184516,int_stack+5177964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7687717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5173848,int_stack+1230216,int_stack+1228956, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2304687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5195100,int_stack+5173848,int_stack+5181492, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7748428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5213433,int_stack+5195100,int_stack+5184516, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7751452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5177628,int_stack+5213433,int_stack+5189220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3472479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5186448,int_stack+1231756,int_stack+1230216, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2305947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5221273,int_stack+5186448,int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3478359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5228833,int_stack+5221273,int_stack+5195100, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3162006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5186448,int_stack+5228833,int_stack+5213433, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3037206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5213433,int_stack+5186448,int_stack+5177628, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3045046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+5225781,int_stack+5213433,int_stack+5204172, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5297233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5253564,int_stack+1234360,int_stack+1233604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2316363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5255832,int_stack+1235368,int_stack+1234360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2317119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5258856,int_stack+5255832,int_stack+5253564, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3053866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5263392,int_stack+1236664,int_stack+1235368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2318127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5267280,int_stack+5263392,int_stack+5255832, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3056134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5273328,int_stack+5267280,int_stack+5258856, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3059158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5253564,int_stack+1238284,int_stack+1236664, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2319423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5280888,int_stack+5253564,int_stack+5263392, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3482139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5173848,int_stack+5280888,int_stack+5267280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2898720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5258424,int_stack+5173848,int_stack+5273328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2820861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5269764,int_stack+1240264,int_stack+1238284, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2321043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5183928,int_stack+5269764,int_stack+5253564, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2732682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5193648,int_stack+5183928,int_stack+5280888, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2486792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+5193648,int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2559745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5173848,int_stack+5578234,int_stack+5258424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2569825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+5173848,int_stack+5213433, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5358350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+13890282,int_stack+341469,int_stack+5225781, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5370698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5578234,int_stack+1243585,int_stack+1242640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2334435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5581069,int_stack+1244845,int_stack+1243585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2335380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5584849,int_stack+5581069,int_stack+5578234, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8176198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5189724,int_stack+1246465,int_stack+1244845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2336640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5194584,int_stack+5189724,int_stack+5581069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8179033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2550295,int_stack+5194584,int_stack+5584849, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8182813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5578234,int_stack+1248490,int_stack+1246465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2338260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5202144,int_stack+5578234,int_stack+5189724, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8188483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5211864,int_stack+5202144,int_stack+5194584, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8193343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5224464,int_stack+5211864,int_stack+2550295, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2550295,int_stack+1250965,int_stack+1248490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2340285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5189724,int_stack+2550295,int_stack+5578234, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5238639,int_stack+5189724,int_stack+5202144, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8312764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5189724,int_stack+5238639,int_stack+5211864, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8322484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3486027,int_stack+5189724,int_stack+5224464, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8335084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+5189724,int_stack+3486027,int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5593354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+5189724,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5609230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1119393,int_stack+13322274,int_stack+13890282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5646274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13890282,int_stack+1255090,int_stack+1253935, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1346805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13893747,int_stack+1256630,int_stack+1255090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1349115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13898367,int_stack+13893747,int_stack+13890282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8349259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13905297,int_stack+1258610,int_stack+1256630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1352195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13911237,int_stack+13905297,int_stack+13893747, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8352724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13920477,int_stack+13911237,int_stack+13898367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8357344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13890282,int_stack+1261085,int_stack+1258610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1356155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13932027,int_stack+13890282,int_stack+13905297, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8602330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13943907,int_stack+13932027,int_stack+13911237, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8608270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13897707,int_stack+13943907,int_stack+13920477, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8617510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13915032,int_stack+1264110,int_stack+1261085, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1361105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13959307,int_stack+13915032,int_stack+13890282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8629060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+341469,int_stack+13959307,int_stack+13932027, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8636485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13959307,int_stack+341469,int_stack+13943907, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8648365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+13959307,int_stack+13897707, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8663765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+13890282,int_stack+341469,int_stack+3486027, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5780320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+14325108,int_stack+13890282,int_stack+5189724, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5800165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+14420364,int_stack+14325108,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5847793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1268181,int_stack+1267740, 0.0, zero_stack, 1.0, int_stack+2291765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+1268769,int_stack+1268181, 0.0, zero_stack, 1.0, int_stack+2292206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+2653594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+1269525,int_stack+1268769, 0.0, zero_stack, 1.0, int_stack+2292794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597, 0.0, zero_stack, 1.0, int_stack+2654917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112, 0.0, zero_stack, 1.0, int_stack+2656681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1270470,int_stack+1269525, 0.0, zero_stack, 1.0, int_stack+2293550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361, 0.0, zero_stack, 1.0, int_stack+2659327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629, 0.0, zero_stack, 1.0, int_stack+2661595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157, 0.0, zero_stack, 1.0, int_stack+2665123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+1271625,int_stack+1270470, 0.0, zero_stack, 1.0, int_stack+2294495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+2669533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567, 0.0, zero_stack, 1.0, int_stack+2672368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103, 0.0, zero_stack, 1.0, int_stack+7829698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983, 0.0, zero_stack, 1.0, int_stack+7741813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1273599,int_stack+1273011, 0.0, zero_stack, 1.0, int_stack+2302307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+1274383,int_stack+1273599, 0.0, zero_stack, 1.0, int_stack+2302895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+7683601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+1275391,int_stack+1274383, 0.0, zero_stack, 1.0, int_stack+2303679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038, 0.0, zero_stack, 1.0, int_stack+7685365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390, 0.0, zero_stack, 1.0, int_stack+7687717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1276651,int_stack+1275391, 0.0, zero_stack, 1.0, int_stack+2304687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918, 0.0, zero_stack, 1.0, int_stack+7748428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942, 0.0, zero_stack, 1.0, int_stack+7751452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646, 0.0, zero_stack, 1.0, int_stack+3472479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+1278191,int_stack+1276651, 0.0, zero_stack, 1.0, int_stack+2305947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+3478359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526, 0.0, zero_stack, 1.0, int_stack+3162006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859, 0.0, zero_stack, 1.0, int_stack+3037206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054, 0.0, zero_stack, 1.0, int_stack+3045046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6135041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+1280795,int_stack+1280039, 0.0, zero_stack, 1.0, int_stack+2316363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+1281803,int_stack+1280795, 0.0, zero_stack, 1.0, int_stack+2317119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207, 0.0, zero_stack, 1.0, int_stack+3053866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+1283099,int_stack+1281803, 0.0, zero_stack, 1.0, int_stack+2318127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475, 0.0, zero_stack, 1.0, int_stack+3056134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499, 0.0, zero_stack, 1.0, int_stack+3059158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+1284719,int_stack+1283099, 0.0, zero_stack, 1.0, int_stack+2319423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+14325108,int_stack+13374207,int_stack+13384035, 0.0, zero_stack, 1.0, int_stack+3482139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+14332884,int_stack+14325108,int_stack+13387923, 0.0, zero_stack, 1.0, int_stack+2898720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+14332884,int_stack+13350057, 0.0, zero_stack, 1.0, int_stack+2820861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+1286699,int_stack+1284719, 0.0, zero_stack, 1.0, int_stack+2321043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+14342964,int_stack+13350057,int_stack+13374207, 0.0, zero_stack, 1.0, int_stack+2732682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+14352684,int_stack+14342964,int_stack+14325108, 0.0, zero_stack, 1.0, int_stack+2486792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+14352684,int_stack+14332884, 0.0, zero_stack, 1.0, int_stack+2559745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+14325108,int_stack+5578234,int_stack+13379067, 0.0, zero_stack, 1.0, int_stack+2569825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+14325108,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6196158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+14340984,int_stack+341469,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6208506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1290020,int_stack+1289075, 0.0, zero_stack, 1.0, int_stack+2334435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+1291280,int_stack+1290020, 0.0, zero_stack, 1.0, int_stack+2335380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+8176198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+1292900,int_stack+1291280, 0.0, zero_stack, 1.0, int_stack+2336640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109, 0.0, zero_stack, 1.0, int_stack+8179033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2550295,int_stack+13339419,int_stack+13328889, 0.0, zero_stack, 1.0, int_stack+8182813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1294925,int_stack+1292900, 0.0, zero_stack, 1.0, int_stack+2338260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13346979,int_stack+13322274,int_stack+13334559, 0.0, zero_stack, 1.0, int_stack+8188483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13356699,int_stack+13346979,int_stack+13339419, 0.0, zero_stack, 1.0, int_stack+8193343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13328349,int_stack+13356699,int_stack+2550295, 0.0, zero_stack, 1.0, int_stack+10530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2550295,int_stack+1297400,int_stack+1294925, 0.0, zero_stack, 1.0, int_stack+2340285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369299,int_stack+2550295,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+2465708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+14396550,int_stack+13369299,int_stack+13346979, 0.0, zero_stack, 1.0, int_stack+8312764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13369299,int_stack+14396550,int_stack+13356699, 0.0, zero_stack, 1.0, int_stack+8322484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3486027,int_stack+13369299,int_stack+13328349, 0.0, zero_stack, 1.0, int_stack+8335084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+13322274,int_stack+3486027,int_stack+14325108, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6418877, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13890282,int_stack+13322274,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6434753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5173848,int_stack+13890282,int_stack+14340984, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6471797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1301525,int_stack+1300370, 0.0, zero_stack, 1.0, int_stack+1346805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1303065,int_stack+1301525, 0.0, zero_stack, 1.0, int_stack+1349115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 0.0, zero_stack, 1.0, int_stack+8349259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1305045,int_stack+1303065, 0.0, zero_stack, 1.0, int_stack+1352195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 0.0, zero_stack, 1.0, int_stack+8352724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+14325108,int_stack+362424,int_stack+349554, 0.0, zero_stack, 1.0, int_stack+8357344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1307520,int_stack+1305045, 0.0, zero_stack, 1.0, int_stack+1356155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+14336658,int_stack+341469,int_stack+356484, 0.0, zero_stack, 1.0, int_stack+8602330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+14348538,int_stack+14336658,int_stack+362424, 0.0, zero_stack, 1.0, int_stack+8608270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+14348538,int_stack+14325108, 0.0, zero_stack, 1.0, int_stack+8617510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+14325108,int_stack+1310545,int_stack+1307520, 0.0, zero_stack, 1.0, int_stack+1361105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+14363938,int_stack+14325108,int_stack+341469, 0.0, zero_stack, 1.0, int_stack+8629060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+14378788,int_stack+14363938,int_stack+14336658, 0.0, zero_stack, 1.0, int_stack+8636485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+14325108,int_stack+14378788,int_stack+14348538, 0.0, zero_stack, 1.0, int_stack+8648365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+14348208,int_stack+14325108,int_stack+348894, 0.0, zero_stack, 1.0, int_stack+8663765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+1212003,int_stack+14348208,int_stack+3486027, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6616373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+14325108,int_stack+1212003,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6636218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+14543844,int_stack+14325108,int_stack+13890282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6683846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13890282,int_stack+1314616,int_stack+1314175, 1.0, int_stack+2291765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13891605,int_stack+1315204,int_stack+1314616, 1.0, int_stack+2292206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13891605,int_stack+13890282, 1.0, int_stack+2653594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13893369,int_stack+1315960,int_stack+1315204, 1.0, int_stack+2292794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13895637,int_stack+13893369,int_stack+13891605, 1.0, int_stack+2654917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13899165,int_stack+13895637,int_stack+11081112, 1.0, int_stack+2656681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13890282,int_stack+1316905,int_stack+1315960, 1.0, int_stack+2293550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13903575,int_stack+13890282,int_stack+13893369, 1.0, int_stack+2659327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13908111,int_stack+13903575,int_stack+13895637, 1.0, int_stack+2661595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13913991,int_stack+13908111,int_stack+13899165, 1.0, int_stack+2665123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13893117,int_stack+1318060,int_stack+1316905, 1.0, int_stack+2294495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13896582,int_stack+13893117,int_stack+13890282, 1.0, int_stack+2669533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13920606,int_stack+13896582,int_stack+13903575, 1.0, int_stack+2672368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13890282,int_stack+13920606,int_stack+13908111, 1.0, int_stack+7829698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13920606,int_stack+13890282,int_stack+13913991, 1.0, int_stack+7741813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13890282,int_stack+1320034,int_stack+1319446, 1.0, int_stack+2302307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13892046,int_stack+1320818,int_stack+1320034, 1.0, int_stack+2302895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13894398,int_stack+13892046,int_stack+13890282, 1.0, int_stack+7683601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13897926,int_stack+1321826,int_stack+1320818, 1.0, int_stack+2303679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13900950,int_stack+13897926,int_stack+13892046, 1.0, int_stack+7685365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13905654,int_stack+13900950,int_stack+13894398, 1.0, int_stack+7687717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13890282,int_stack+1323086,int_stack+1321826, 1.0, int_stack+2304687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13911534,int_stack+13890282,int_stack+13897926, 1.0, int_stack+7748428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13929867,int_stack+13911534,int_stack+13900950, 1.0, int_stack+7751452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13894062,int_stack+13929867,int_stack+13905654, 1.0, int_stack+3472479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3472479,int_stack+1324626,int_stack+1323086, 1.0, int_stack+2305947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13902882,int_stack+3472479,int_stack+13890282, 1.0, int_stack+3478359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13937707,int_stack+13902882,int_stack+13911534, 1.0, int_stack+3162006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13902882,int_stack+13937707,int_stack+13929867, 1.0, int_stack+3037206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13929867,int_stack+13902882,int_stack+13894062, 1.0, int_stack+3045046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13942215,int_stack+13929867,int_stack+13920606, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6955659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13969998,int_stack+1327230,int_stack+1326474, 1.0, int_stack+2316363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13972266,int_stack+1328238,int_stack+1327230, 1.0, int_stack+2317119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13975290,int_stack+13972266,int_stack+13969998, 1.0, int_stack+3053866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13979826,int_stack+1329534,int_stack+1328238, 1.0, int_stack+2318127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13890282,int_stack+13979826,int_stack+13972266, 1.0, int_stack+3056134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13896330,int_stack+13890282,int_stack+13975290, 1.0, int_stack+3059158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13969998,int_stack+1331154,int_stack+1329534, 1.0, int_stack+2319423, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13903890,int_stack+13969998,int_stack+13979826, 1.0, int_stack+3482139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13974858,int_stack+13903890,int_stack+13890282, 1.0, int_stack+2898720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13911666,int_stack+13974858,int_stack+13896330, 1.0, int_stack+2820861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2820861,int_stack+1333134,int_stack+1331154, 1.0, int_stack+2321043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2826801,int_stack+2820861,int_stack+13969998, 1.0, int_stack+2732682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2836521,int_stack+2826801,int_stack+13903890, 1.0, int_stack+2486792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+2836521,int_stack+13974858, 1.0, int_stack+2559745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2820861,int_stack+5578234,int_stack+13911666, 1.0, int_stack+2569825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+2820861,int_stack+13929867, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7008880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2836737,int_stack+341469,int_stack+13942215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7021228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5578234,int_stack+1336455,int_stack+1335510, 1.0, int_stack+2334435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5581069,int_stack+1337715,int_stack+1336455, 1.0, int_stack+2335380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5584849,int_stack+5581069,int_stack+5578234, 1.0, int_stack+8176198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2486792,int_stack+1339335,int_stack+1337715, 1.0, int_stack+2336640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2892303,int_stack+2486792,int_stack+5581069, 1.0, int_stack+8179033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13890282,int_stack+2892303,int_stack+5584849, 1.0, int_stack+8182813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8176198,int_stack+1341360,int_stack+1339335, 1.0, int_stack+2338260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5578234,int_stack+8176198,int_stack+2486792, 1.0, int_stack+8188483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13899732,int_stack+5578234,int_stack+2892303, 1.0, int_stack+8193343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2892303,int_stack+13899732,int_stack+13890282, 1.0, int_stack+10530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13890282,int_stack+1343835,int_stack+1341360, 1.0, int_stack+2340285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8182273,int_stack+13890282,int_stack+8176198, 1.0, int_stack+2465708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13912332,int_stack+8182273,int_stack+5578234, 1.0, int_stack+8312764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8176198,int_stack+13912332,int_stack+13899732, 1.0, int_stack+8322484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8312764,int_stack+8176198,int_stack+2892303, 1.0, int_stack+8335084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+13890282,int_stack+8312764,int_stack+2820861, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7095703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+13890282,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7254930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+14325108,int_stack+13322274,int_stack+2836737, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7291974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1350655,int_stack+1347960, 1.0, int_stack+1346805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1354175,int_stack+1350655, 1.0, int_stack+1349115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 1.0, int_stack+8349259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1358630,int_stack+1354175, 1.0, int_stack+1352195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 1.0, int_stack+8352724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2820861,int_stack+362424,int_stack+349554, 1.0, int_stack+8357344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1364130,int_stack+1358630, 1.0, int_stack+1356155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2832411,int_stack+341469,int_stack+356484, 1.0, int_stack+8602330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2844291,int_stack+2832411,int_stack+362424, 1.0, int_stack+8608270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+2844291,int_stack+2820861, 1.0, int_stack+8617510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2820861,int_stack+1367155,int_stack+1364130, 1.0, int_stack+1361105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8602330,int_stack+2820861,int_stack+341469, 1.0, int_stack+8629060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2859691,int_stack+8602330,int_stack+2832411, 1.0, int_stack+8636485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8602330,int_stack+2859691,int_stack+2844291, 1.0, int_stack+8648365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8625430,int_stack+8602330,int_stack+348894, 1.0, int_stack+8663765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+2820861,int_stack+8625430,int_stack+8312764, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7384035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+1212003,int_stack+2820861,int_stack+13890282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7403880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+14667324,int_stack+1212003,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7451508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1371226,int_stack+1370785,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+1371814,int_stack+1371226,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+1372570,int_stack+1371814,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1373515,int_stack+1372570,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+1374670,int_stack+1373515,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1376644,int_stack+1376056,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+1377428,int_stack+1376644,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+1378436,int_stack+1377428,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1379696,int_stack+1378436,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+1381236,int_stack+1379696,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3463218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+1383840,int_stack+1383084,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+1384848,int_stack+1383840,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+1386144,int_stack+1384848,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+1387764,int_stack+1386144,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1212003,int_stack+13374207,int_stack+13384035,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1219779,int_stack+1212003,int_stack+13387923,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+1219779,int_stack+13350057,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+1389744,int_stack+1387764,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1229859,int_stack+13350057,int_stack+13374207,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1239579,int_stack+1229859,int_stack+1212003,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+1239579,int_stack+1219779,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1212003,int_stack+5578234,int_stack+13379067,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+1212003,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3065626, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1227879,int_stack+341469,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2793078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1393065,int_stack+1392120,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+1394325,int_stack+1393065,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+1395945,int_stack+1394325,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13346979,int_stack+13339419,int_stack+13328889,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1397970,int_stack+1395945,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13356429,int_stack+13322274,int_stack+13334559,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+13366149,int_stack+13356429,int_stack+13339419,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13328349,int_stack+13366149,int_stack+13346979,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13342524,int_stack+1400445,int_stack+1397970,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13378749,int_stack+13342524,int_stack+13322274,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1283445,int_stack+13378749,int_stack+13356429,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+13342524,int_stack+1283445,int_stack+13366149,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1283445,int_stack+13342524,int_stack+13328349,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1303290,int_stack+1283445,int_stack+1212003, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+8204278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+1303290,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+8220154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+13890282,int_stack+13322274,int_stack+1227879, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+8257198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1404570,int_stack+1403415,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1406110,int_stack+1404570,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1408090,int_stack+1406110,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1212003,int_stack+362424,int_stack+349554,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1410565,int_stack+1408090,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1223553,int_stack+341469,int_stack+356484,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1235433,int_stack+1223553,int_stack+362424,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+1235433,int_stack+1212003,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1212003,int_stack+1413590,int_stack+1410565,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1250833,int_stack+1212003,int_stack+341469,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1350918,int_stack+1250833,int_stack+1223553,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1250833,int_stack+1350918,int_stack+1235433,55);
 /*--- compute (m0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1350918,int_stack+1250833,int_stack+348894,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+1212003,int_stack+1350918,int_stack+1283445, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+8368159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+2639986,int_stack+1212003,int_stack+1303290, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+8388004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+1212003,int_stack+2639986,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+8435632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1417661,int_stack+1417220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2370830,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+1418249,int_stack+1417661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371271,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8681090,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+1419005,int_stack+1418249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371859,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8682413,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8684177,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1419950,int_stack+1419005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2372615,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8686823,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8689091,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8692619,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+1421105,int_stack+1419950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2373560,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8697029,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8699864,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8704400,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8710280,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1423079,int_stack+1422491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2381372,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+1423863,int_stack+1423079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2381960,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8716895,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+1424871,int_stack+1423863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2382744,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8718659,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8721011,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1426131,int_stack+1424871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2383752,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8734976,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8738000,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8742704,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+1427671,int_stack+1426131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2385012,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8748584,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8752364,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8758412,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8766252,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 0.0, zero_stack, 1.0, int_stack+2630725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+1430275,int_stack+1429519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2395428,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+1431283,int_stack+1430275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2396184,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8775072,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+1432579,int_stack+1431283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2397192,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8777340,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8780364,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+1434199,int_stack+1432579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2398488,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2639986,int_stack+13374207,int_stack+13384035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8826963,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2647762,int_stack+2639986,int_stack+13387923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8830851,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+2647762,int_stack+13350057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8836899,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+1436179,int_stack+1434199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2400108,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2657842,int_stack+13350057,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8844459,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2667562,int_stack+2657842,int_stack+2639986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8849319,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+2667562,int_stack+2647762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8857095,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2639986,int_stack+5578234,int_stack+13379067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8867175,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+2639986,int_stack+13361859, 0.0, zero_stack, 1.0, int_stack+2739582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2655862,int_stack+341469,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+2751930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1439500,int_stack+1438555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2413500,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+1440760,int_stack+1439500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2414445,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19980,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+1442380,int_stack+1440760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2415705,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22815,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13346979,int_stack+13339419,int_stack+13328889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9115202,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1444405,int_stack+1442380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2417325,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13356429,int_stack+13322274,int_stack+13334559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2625685,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13366149,int_stack+13356429,int_stack+13339419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9120872,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13328349,int_stack+13366149,int_stack+13346979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9128432,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13342524,int_stack+1446880,int_stack+1444405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2419350,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13378749,int_stack+13342524,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9137882,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2711428,int_stack+13378749,int_stack+13356429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9143957,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13342524,int_stack+2711428,int_stack+13366149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9153677,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2711428,int_stack+13342524,int_stack+13328349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9166277,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+13322274,int_stack+2711428,int_stack+2639986, 0.0, zero_stack, 1.0, int_stack+2907765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1335483,int_stack+13322274,int_stack+341469, 0.0, zero_stack, 1.0, int_stack+2923641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3077974,int_stack+1335483,int_stack+2655862, 0.0, zero_stack, 1.0, int_stack+2960685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1451005,int_stack+1449850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1682025,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1452545,int_stack+1451005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1684335,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9180452,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1454525,int_stack+1452545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1687415,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9183917,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2639986,int_stack+362424,int_stack+349554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9188537,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1457000,int_stack+1454525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1691375,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2651536,int_stack+341469,int_stack+356484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9433523,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2663416,int_stack+2651536,int_stack+362424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9439463,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+2663416,int_stack+2639986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9448703,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2639986,int_stack+1460025,int_stack+1457000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1696325,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2678816,int_stack+2639986,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9460253,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13369902,int_stack+2678816,int_stack+2651536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9467678,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2678816,int_stack+13369902,int_stack+2663416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9479558,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13369902,int_stack+2678816,int_stack+348894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9494958,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+2639986,int_stack+13369902,int_stack+2711428, 0.0, zero_stack, 1.0, int_stack+3173481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+14790804,int_stack+2639986,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+3193326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+14886060,int_stack+14790804,int_stack+1335483, 0.0, zero_stack, 1.0, int_stack+3240954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1335483,int_stack+1464096,int_stack+1463655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2370830, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1336806,int_stack+1464684,int_stack+1464096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371271, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+1336806,int_stack+1335483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8681090, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1338570,int_stack+1465440,int_stack+1464684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371859, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1340838,int_stack+1338570,int_stack+1336806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8682413, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1344366,int_stack+1340838,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8684177, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1335483,int_stack+1466385,int_stack+1465440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2372615, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1348776,int_stack+1335483,int_stack+1338570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8686823, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1353312,int_stack+1348776,int_stack+1340838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8689091, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1359192,int_stack+1353312,int_stack+1344366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8692619, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1338318,int_stack+1467540,int_stack+1466385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2373560, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1341783,int_stack+1338318,int_stack+1335483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8697029, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1365807,int_stack+1341783,int_stack+1348776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8699864, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1335483,int_stack+1365807,int_stack+1353312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8704400, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1365807,int_stack+1335483,int_stack+1359192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8710280, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1335483,int_stack+1469514,int_stack+1468926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2381372, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1337247,int_stack+1470298,int_stack+1469514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2381960, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1339599,int_stack+1337247,int_stack+1335483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8716895, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1343127,int_stack+1471306,int_stack+1470298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2382744, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1346151,int_stack+1343127,int_stack+1337247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8718659, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1350855,int_stack+1346151,int_stack+1339599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8721011, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1335483,int_stack+1472566,int_stack+1471306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2383752, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1356735,int_stack+1335483,int_stack+1343127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8734976, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1375068,int_stack+1356735,int_stack+1346151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8738000, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1339263,int_stack+1375068,int_stack+1350855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8742704, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1348083,int_stack+1474106,int_stack+1472566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2385012, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1382908,int_stack+1348083,int_stack+1335483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8748584, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1390468,int_stack+1382908,int_stack+1356735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8752364, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1348083,int_stack+1390468,int_stack+1375068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8758412, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1375068,int_stack+1348083,int_stack+1339263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8766252, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1387416,int_stack+1375068,int_stack+1365807, 0.0, zero_stack, 1.0, int_stack+3621347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1415199,int_stack+1476710,int_stack+1475954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2395428, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1417467,int_stack+1477718,int_stack+1476710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2396184, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1420491,int_stack+1417467,int_stack+1415199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8775072, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1425027,int_stack+1479014,int_stack+1477718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2397192, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1428915,int_stack+1425027,int_stack+1417467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8777340, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1434963,int_stack+1428915,int_stack+1420491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8780364, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1415199,int_stack+1480634,int_stack+1479014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2398488, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1442523,int_stack+1415199,int_stack+1425027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8826963, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1450299,int_stack+1442523,int_stack+1428915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8830851, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1420059,int_stack+1450299,int_stack+1434963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8836899, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1431399,int_stack+1482614,int_stack+1480634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2400108, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1460379,int_stack+1431399,int_stack+1415199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8844459, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1470099,int_stack+1460379,int_stack+1442523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8849319, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+1470099,int_stack+1450299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8857095, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1431399,int_stack+5578234,int_stack+1420059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8867175, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+1431399,int_stack+1375068, 0.0, zero_stack, 1.0, int_stack+3682464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+14790804,int_stack+341469,int_stack+1387416, 0.0, zero_stack, 1.0, int_stack+3694812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5578234,int_stack+1485935,int_stack+1484990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2413500, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5581069,int_stack+1487195,int_stack+1485935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2414445, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5584849,int_stack+5581069,int_stack+5578234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19980, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1447275,int_stack+1488815,int_stack+1487195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2415705, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1452135,int_stack+1447275,int_stack+5581069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22815, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1459695,int_stack+1452135,int_stack+5584849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9115202, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5578234,int_stack+1490840,int_stack+1488815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2417325, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1469145,int_stack+5578234,int_stack+1447275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2625685, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1335483,int_stack+1469145,int_stack+1452135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9120872, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1348083,int_stack+1335483,int_stack+1459695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9128432, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1447275,int_stack+1493315,int_stack+1490840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2419350, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1454700,int_stack+1447275,int_stack+5578234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9137882, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1478865,int_stack+1454700,int_stack+1469145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9143957, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1447275,int_stack+1478865,int_stack+1335483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9153677, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1466175,int_stack+1447275,int_stack+1348083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9166277, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1335483,int_stack+1466175,int_stack+1431399, 0.0, zero_stack, 1.0, int_stack+3917468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+1335483,int_stack+341469, 0.0, zero_stack, 1.0, int_stack+3933344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2639986,int_stack+13322274,int_stack+14790804, 0.0, zero_stack, 1.0, int_stack+3970388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+14790804,int_stack+1497440,int_stack+1496285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1682025, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14794269,int_stack+1498980,int_stack+1497440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1684335, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+14798889,int_stack+14794269,int_stack+14790804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9180452, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+14805819,int_stack+1500960,int_stack+1498980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1687415, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+14811759,int_stack+14805819,int_stack+14794269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9183917, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+14820999,int_stack+14811759,int_stack+14798889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9188537, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+14790804,int_stack+1503435,int_stack+1500960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1691375, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+14832549,int_stack+14790804,int_stack+14805819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9433523, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+14844429,int_stack+14832549,int_stack+14811759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9439463, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+14798229,int_stack+14844429,int_stack+14820999, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9448703, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+14815554,int_stack+1506460,int_stack+1503435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1696325, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+14859829,int_stack+14815554,int_stack+14790804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9460253, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+341469,int_stack+14859829,int_stack+14832549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9467678, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+14859829,int_stack+341469,int_stack+14844429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9479558, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+14859829,int_stack+14798229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9494958, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+14790804,int_stack+341469,int_stack+1466175, 0.0, zero_stack, 1.0, int_stack+4109294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+1383111,int_stack+14790804,int_stack+1335483, 0.0, zero_stack, 1.0, int_stack+4129139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+15009540,int_stack+1383111,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+4176767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1510531,int_stack+1510090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2370830, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+1511119,int_stack+1510531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371271, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8681090, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+1511875,int_stack+1511119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371859, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8682413, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8684177, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1512820,int_stack+1511875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2372615, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8686823, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8689091, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8692619, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+1513975,int_stack+1512820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2373560, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8697029, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8699864, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8704400, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8710280, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1515949,int_stack+1515361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2381372, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+1516733,int_stack+1515949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2381960, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8716895, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+1517741,int_stack+1516733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2382744, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8718659, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8721011, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1519001,int_stack+1517741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2383752, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8734976, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8738000, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8742704, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+1520541,int_stack+1519001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2385012, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8748584, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8752364, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8758412, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8766252, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 0.0, zero_stack, 1.0, int_stack+4464015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+1523145,int_stack+1522389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2395428, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+1524153,int_stack+1523145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2396184, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8775072, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+1525449,int_stack+1524153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2397192, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8777340, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8780364, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+1527069,int_stack+1525449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2398488, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1335483,int_stack+13374207,int_stack+13384035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8826963, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1343259,int_stack+1335483,int_stack+13387923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8830851, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+1343259,int_stack+13350057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8836899, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+1529049,int_stack+1527069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2400108, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1353339,int_stack+13350057,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8844459, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1363059,int_stack+1353339,int_stack+1335483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8849319, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+1363059,int_stack+1343259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8857095, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1335483,int_stack+5578234,int_stack+13379067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8867175, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+1335483,int_stack+13361859, 0.0, zero_stack, 1.0, int_stack+4525132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1351359,int_stack+341469,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+4537480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1532370,int_stack+1531425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2413500, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+1533630,int_stack+1532370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2414445, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19980, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+1535250,int_stack+1533630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2415705, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22815, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13346979,int_stack+13339419,int_stack+13328889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9115202, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1537275,int_stack+1535250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2417325, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13356429,int_stack+13322274,int_stack+13334559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2625685, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13366149,int_stack+13356429,int_stack+13339419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9120872, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13328349,int_stack+13366149,int_stack+13346979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9128432, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13342524,int_stack+1539750,int_stack+1537275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2419350, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13378749,int_stack+13342524,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9137882, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1406925,int_stack+13378749,int_stack+13356429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9143957, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13342524,int_stack+1406925,int_stack+13366149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9153677, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1406925,int_stack+13342524,int_stack+13328349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9166277, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1426770,int_stack+1406925,int_stack+1335483, 0.0, zero_stack, 1.0, int_stack+4747851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+1426770,int_stack+341469, 0.0, zero_stack, 1.0, int_stack+4763727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+14790804,int_stack+13322274,int_stack+1351359, 0.0, zero_stack, 1.0, int_stack+4800771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1543875,int_stack+1542720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1682025, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1545415,int_stack+1543875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1684335, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9180452, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1547395,int_stack+1545415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1687415, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9183917, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1335483,int_stack+362424,int_stack+349554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9188537, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1549870,int_stack+1547395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1691375, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1347033,int_stack+341469,int_stack+356484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9433523, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1358913,int_stack+1347033,int_stack+362424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9439463, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+1358913,int_stack+1335483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9448703, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1335483,int_stack+1552895,int_stack+1549870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1696325, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1374313,int_stack+1335483,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9460253, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1474398,int_stack+1374313,int_stack+1347033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9467678, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1374313,int_stack+1474398,int_stack+1358913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9479558, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1474398,int_stack+1374313,int_stack+348894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9494958, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+1335483,int_stack+1474398,int_stack+1406925, 0.0, zero_stack, 1.0, int_stack+4939677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+15133020,int_stack+1335483,int_stack+1426770, 0.0, zero_stack, 1.0, int_stack+4959522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+1335483,int_stack+15133020,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+5007150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1556966,int_stack+1556525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2370830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+1557554,int_stack+1556966, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8681090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+1558310,int_stack+1557554, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2371859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8682413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8684177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1559255,int_stack+1558310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2372615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8686823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8689091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8692619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+1560410,int_stack+1559255, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2373560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8697029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8699864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8704400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8710280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1562384,int_stack+1561796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2381372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+1563168,int_stack+1562384, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2381960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8716895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+1564176,int_stack+1563168, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2382744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8718659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8721011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1565436,int_stack+1564176, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2383752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8734976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8738000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8742704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+1566976,int_stack+1565436, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2385012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8748584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8752364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8758412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8766252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 0.0, zero_stack, 1.0, int_stack+5297233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+1569580,int_stack+1568824, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2395428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+1570588,int_stack+1569580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2396184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8775072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+1571884,int_stack+1570588, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2397192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8777340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8780364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+1573504,int_stack+1571884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2398488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15133020,int_stack+13374207,int_stack+13384035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8826963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+15140796,int_stack+15133020,int_stack+13387923, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8830851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+15140796,int_stack+13350057, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8836899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+1575484,int_stack+1573504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2400108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+15150876,int_stack+13350057,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8844459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+15160596,int_stack+15150876,int_stack+15133020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8849319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+15160596,int_stack+15140796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8857095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+15133020,int_stack+5578234,int_stack+13379067, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8867175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+15133020,int_stack+13361859, 0.0, zero_stack, 1.0, int_stack+5358350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+15148896,int_stack+341469,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+5370698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1578805,int_stack+1577860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2413500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+1580065,int_stack+1578805, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2414445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+1581685,int_stack+1580065, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2415705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13346979,int_stack+13339419,int_stack+13328889, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9115202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1583710,int_stack+1581685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2417325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13356429,int_stack+13322274,int_stack+13334559, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2625685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13366149,int_stack+13356429,int_stack+13339419, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9120872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13328349,int_stack+13366149,int_stack+13346979, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9128432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13342524,int_stack+1586185,int_stack+1583710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2419350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13378749,int_stack+13342524,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9137882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+15204462,int_stack+13378749,int_stack+13356429, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9143957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13342524,int_stack+15204462,int_stack+13366149, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9153677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+15204462,int_stack+13342524,int_stack+13328349, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9166277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+13322274,int_stack+15204462,int_stack+15133020, 0.0, zero_stack, 1.0, int_stack+5593354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1458963,int_stack+13322274,int_stack+341469, 0.0, zero_stack, 1.0, int_stack+5609230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+15224307,int_stack+1458963,int_stack+15148896, 0.0, zero_stack, 1.0, int_stack+5646274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1590310,int_stack+1589155, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1682025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1591850,int_stack+1590310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1684335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9180452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1593830,int_stack+1591850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1687415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9183917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15133020,int_stack+362424,int_stack+349554, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9188537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1596305,int_stack+1593830, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1691375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15144570,int_stack+341469,int_stack+356484, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9433523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+15156450,int_stack+15144570,int_stack+362424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9439463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+15156450,int_stack+15133020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9448703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15133020,int_stack+1599330,int_stack+1596305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1696325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+15171850,int_stack+15133020,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9460253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13369902,int_stack+15171850,int_stack+15144570, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9467678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+15171850,int_stack+13369902,int_stack+15156450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9479558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13369902,int_stack+15171850,int_stack+348894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9494958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+15133020,int_stack+13369902,int_stack+15204462, 0.0, zero_stack, 1.0, int_stack+5780320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+15316917,int_stack+15133020,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+5800165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+15412173,int_stack+15316917,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+5847793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+1603401,int_stack+1602960, 0.0, zero_stack, 1.0, int_stack+2370830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1460286,int_stack+1603989,int_stack+1603401, 0.0, zero_stack, 1.0, int_stack+2371271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+1460286,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+8681090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1462050,int_stack+1604745,int_stack+1603989, 0.0, zero_stack, 1.0, int_stack+2371859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1464318,int_stack+1462050,int_stack+1460286, 0.0, zero_stack, 1.0, int_stack+8682413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1467846,int_stack+1464318,int_stack+11081112, 0.0, zero_stack, 1.0, int_stack+8684177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+1605690,int_stack+1604745, 0.0, zero_stack, 1.0, int_stack+2372615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1472256,int_stack+1458963,int_stack+1462050, 0.0, zero_stack, 1.0, int_stack+8686823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1476792,int_stack+1472256,int_stack+1464318, 0.0, zero_stack, 1.0, int_stack+8689091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1482672,int_stack+1476792,int_stack+1467846, 0.0, zero_stack, 1.0, int_stack+8692619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1461798,int_stack+1606845,int_stack+1605690, 0.0, zero_stack, 1.0, int_stack+2373560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1465263,int_stack+1461798,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+8697029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1489287,int_stack+1465263,int_stack+1472256, 0.0, zero_stack, 1.0, int_stack+8699864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1458963,int_stack+1489287,int_stack+1476792, 0.0, zero_stack, 1.0, int_stack+8704400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1489287,int_stack+1458963,int_stack+1482672, 0.0, zero_stack, 1.0, int_stack+8710280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+1608819,int_stack+1608231, 0.0, zero_stack, 1.0, int_stack+2381372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1460727,int_stack+1609603,int_stack+1608819, 0.0, zero_stack, 1.0, int_stack+2381960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1463079,int_stack+1460727,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+8716895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1466607,int_stack+1610611,int_stack+1609603, 0.0, zero_stack, 1.0, int_stack+2382744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1469631,int_stack+1466607,int_stack+1460727, 0.0, zero_stack, 1.0, int_stack+8718659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1474335,int_stack+1469631,int_stack+1463079, 0.0, zero_stack, 1.0, int_stack+8721011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+1611871,int_stack+1610611, 0.0, zero_stack, 1.0, int_stack+2383752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1480215,int_stack+1458963,int_stack+1466607, 0.0, zero_stack, 1.0, int_stack+8734976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1498548,int_stack+1480215,int_stack+1469631, 0.0, zero_stack, 1.0, int_stack+8738000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1462743,int_stack+1498548,int_stack+1474335, 0.0, zero_stack, 1.0, int_stack+8742704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1471563,int_stack+1613411,int_stack+1611871, 0.0, zero_stack, 1.0, int_stack+2385012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1506388,int_stack+1471563,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+8748584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1513948,int_stack+1506388,int_stack+1480215, 0.0, zero_stack, 1.0, int_stack+8752364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1471563,int_stack+1513948,int_stack+1498548, 0.0, zero_stack, 1.0, int_stack+8758412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1498548,int_stack+1471563,int_stack+1462743, 0.0, zero_stack, 1.0, int_stack+8766252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1510896,int_stack+1498548,int_stack+1489287, 0.0, zero_stack, 1.0, int_stack+6135041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1538679,int_stack+1616015,int_stack+1615259, 0.0, zero_stack, 1.0, int_stack+2395428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1540947,int_stack+1617023,int_stack+1616015, 0.0, zero_stack, 1.0, int_stack+2396184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1543971,int_stack+1540947,int_stack+1538679, 0.0, zero_stack, 1.0, int_stack+8775072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1548507,int_stack+1618319,int_stack+1617023, 0.0, zero_stack, 1.0, int_stack+2397192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1552395,int_stack+1548507,int_stack+1540947, 0.0, zero_stack, 1.0, int_stack+8777340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1558443,int_stack+1552395,int_stack+1543971, 0.0, zero_stack, 1.0, int_stack+8780364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1538679,int_stack+1619939,int_stack+1618319, 0.0, zero_stack, 1.0, int_stack+2398488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1566003,int_stack+1538679,int_stack+1548507, 0.0, zero_stack, 1.0, int_stack+8826963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1573779,int_stack+1566003,int_stack+1552395, 0.0, zero_stack, 1.0, int_stack+8830851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1543539,int_stack+1573779,int_stack+1558443, 0.0, zero_stack, 1.0, int_stack+8836899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1554879,int_stack+1621919,int_stack+1619939, 0.0, zero_stack, 1.0, int_stack+2400108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1583859,int_stack+1554879,int_stack+1538679, 0.0, zero_stack, 1.0, int_stack+8844459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1593579,int_stack+1583859,int_stack+1566003, 0.0, zero_stack, 1.0, int_stack+8849319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+1593579,int_stack+1573779, 0.0, zero_stack, 1.0, int_stack+8857095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1554879,int_stack+5578234,int_stack+1543539, 0.0, zero_stack, 1.0, int_stack+8867175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+1554879,int_stack+1498548, 0.0, zero_stack, 1.0, int_stack+6196158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+15316917,int_stack+341469,int_stack+1510896, 0.0, zero_stack, 1.0, int_stack+6208506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5578234,int_stack+1625240,int_stack+1624295, 0.0, zero_stack, 1.0, int_stack+2413500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5581069,int_stack+1626500,int_stack+1625240, 0.0, zero_stack, 1.0, int_stack+2414445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5584849,int_stack+5581069,int_stack+5578234, 0.0, zero_stack, 1.0, int_stack+19980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1570755,int_stack+1628120,int_stack+1626500, 0.0, zero_stack, 1.0, int_stack+2415705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1575615,int_stack+1570755,int_stack+5581069, 0.0, zero_stack, 1.0, int_stack+22815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1583175,int_stack+1575615,int_stack+5584849, 0.0, zero_stack, 1.0, int_stack+9115202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5578234,int_stack+1630145,int_stack+1628120, 0.0, zero_stack, 1.0, int_stack+2417325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1592625,int_stack+5578234,int_stack+1570755, 0.0, zero_stack, 1.0, int_stack+2625685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1602345,int_stack+1592625,int_stack+1575615, 0.0, zero_stack, 1.0, int_stack+9120872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1614945,int_stack+1602345,int_stack+1583175, 0.0, zero_stack, 1.0, int_stack+9128432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1570755,int_stack+1632620,int_stack+1630145, 0.0, zero_stack, 1.0, int_stack+2419350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1578180,int_stack+1570755,int_stack+5578234, 0.0, zero_stack, 1.0, int_stack+9137882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1458963,int_stack+1578180,int_stack+1592625, 0.0, zero_stack, 1.0, int_stack+9143957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1570755,int_stack+1458963,int_stack+1602345, 0.0, zero_stack, 1.0, int_stack+9153677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1458963,int_stack+1570755,int_stack+1614945, 0.0, zero_stack, 1.0, int_stack+9166277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1570755,int_stack+1458963,int_stack+1554879, 0.0, zero_stack, 1.0, int_stack+6418877, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+1570755,int_stack+341469, 0.0, zero_stack, 1.0, int_stack+6434753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+15535653,int_stack+13322274,int_stack+15316917, 0.0, zero_stack, 1.0, int_stack+6471797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15316917,int_stack+1636745,int_stack+1635590, 0.0, zero_stack, 1.0, int_stack+1682025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15320382,int_stack+1638285,int_stack+1636745, 0.0, zero_stack, 1.0, int_stack+1684335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15325002,int_stack+15320382,int_stack+15316917, 0.0, zero_stack, 1.0, int_stack+9180452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15331932,int_stack+1640265,int_stack+1638285, 0.0, zero_stack, 1.0, int_stack+1687415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15337872,int_stack+15331932,int_stack+15320382, 0.0, zero_stack, 1.0, int_stack+9183917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15347112,int_stack+15337872,int_stack+15325002, 0.0, zero_stack, 1.0, int_stack+9188537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+15316917,int_stack+1642740,int_stack+1640265, 0.0, zero_stack, 1.0, int_stack+1691375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15358662,int_stack+15316917,int_stack+15331932, 0.0, zero_stack, 1.0, int_stack+9433523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+15370542,int_stack+15358662,int_stack+15337872, 0.0, zero_stack, 1.0, int_stack+9439463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+15324342,int_stack+15370542,int_stack+15347112, 0.0, zero_stack, 1.0, int_stack+9448703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15341667,int_stack+1645765,int_stack+1642740, 0.0, zero_stack, 1.0, int_stack+1696325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+15385942,int_stack+15341667,int_stack+15316917, 0.0, zero_stack, 1.0, int_stack+9460253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+341469,int_stack+15385942,int_stack+15358662, 0.0, zero_stack, 1.0, int_stack+9467678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+15385942,int_stack+341469,int_stack+15370542, 0.0, zero_stack, 1.0, int_stack+9479558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+15385942,int_stack+15324342, 0.0, zero_stack, 1.0, int_stack+9494958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+15316917,int_stack+341469,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+6616373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+1458963,int_stack+15316917,int_stack+1570755, 0.0, zero_stack, 1.0, int_stack+6636218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+15628263,int_stack+1458963,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+6683846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1649836,int_stack+1649395, 1.0, int_stack+2370830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+1650424,int_stack+1649836, 1.0, int_stack+2371271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274, 1.0, int_stack+8681090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+1651180,int_stack+1650424, 1.0, int_stack+2371859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597, 1.0, int_stack+8682413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112, 1.0, int_stack+8684177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1652125,int_stack+1651180, 1.0, int_stack+2372615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361, 1.0, int_stack+8686823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629, 1.0, int_stack+8689091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157, 1.0, int_stack+8692619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+1653280,int_stack+1652125, 1.0, int_stack+2373560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274, 1.0, int_stack+8697029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567, 1.0, int_stack+8699864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103, 1.0, int_stack+8704400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983, 1.0, int_stack+8710280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1655254,int_stack+1654666, 1.0, int_stack+2381372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+1656038,int_stack+1655254, 1.0, int_stack+2381960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274, 1.0, int_stack+8716895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+1657046,int_stack+1656038, 1.0, int_stack+2382744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038, 1.0, int_stack+8718659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390, 1.0, int_stack+8721011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1658306,int_stack+1657046, 1.0, int_stack+2383752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918, 1.0, int_stack+8734976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942, 1.0, int_stack+8738000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646, 1.0, int_stack+8742704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8734976,int_stack+1659846,int_stack+1658306, 1.0, int_stack+2385012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8739596,int_stack+8734976,int_stack+13322274, 1.0, int_stack+8748584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13369699,int_stack+8739596,int_stack+13343526, 1.0, int_stack+8752364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8734976,int_stack+13369699,int_stack+13361859, 1.0, int_stack+8758412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+8734976,int_stack+13326054, 1.0, int_stack+8766252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+8734976,int_stack+13361859,int_stack+13352598, 0.0, zero_stack, 1.0, int_stack+6955659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8762759,int_stack+1662450,int_stack+1661694, 1.0, int_stack+2395428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8765027,int_stack+1663458,int_stack+1662450, 1.0, int_stack+2396184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8768051,int_stack+8765027,int_stack+8762759, 1.0, int_stack+8775072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8772587,int_stack+1664754,int_stack+1663458, 1.0, int_stack+2397192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13374207,int_stack+8772587,int_stack+8765027, 1.0, int_stack+8777340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13380255,int_stack+13374207,int_stack+8768051, 1.0, int_stack+8780364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8762759,int_stack+1666374,int_stack+1664754, 1.0, int_stack+2398488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8776475,int_stack+8762759,int_stack+8772587, 1.0, int_stack+8826963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13322274,int_stack+8776475,int_stack+13374207, 1.0, int_stack+8830851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13332354,int_stack+13322274,int_stack+13380255, 1.0, int_stack+8836899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13374207,int_stack+1668354,int_stack+1666374, 1.0, int_stack+2400108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13380147,int_stack+13374207,int_stack+8762759, 1.0, int_stack+8844459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8762759,int_stack+13380147,int_stack+8776475, 1.0, int_stack+8849319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+8762759,int_stack+13322274, 1.0, int_stack+8857095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8762759,int_stack+5578234,int_stack+13332354, 1.0, int_stack+8867175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+8762759,int_stack+13361859, 0.0, zero_stack, 1.0, int_stack+7008880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+13322274,int_stack+341469,int_stack+8734976, 0.0, zero_stack, 1.0, int_stack+7021228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8734976,int_stack+1671675,int_stack+1670730, 1.0, int_stack+2413500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8737811,int_stack+1672935,int_stack+1671675, 1.0, int_stack+2414445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8741591,int_stack+8737811,int_stack+8734976, 1.0, int_stack+19980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8747261,int_stack+1674555,int_stack+1672935, 1.0, int_stack+2415705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8752121,int_stack+8747261,int_stack+8737811, 1.0, int_stack+22815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5578234,int_stack+8752121,int_stack+8741591, 1.0, int_stack+9115202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8734976,int_stack+1676580,int_stack+1674555, 1.0, int_stack+2417325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13377840,int_stack+8734976,int_stack+8747261, 1.0, int_stack+2625685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8826963,int_stack+13377840,int_stack+8752121, 1.0, int_stack+9120872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8741051,int_stack+8826963,int_stack+5578234, 1.0, int_stack+9128432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5578234,int_stack+1679055,int_stack+1676580, 1.0, int_stack+2419350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9115202,int_stack+5578234,int_stack+8734976, 1.0, int_stack+9137882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+9127352,int_stack+9115202,int_stack+13377840, 1.0, int_stack+9143957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8839563,int_stack+9127352,int_stack+8826963, 1.0, int_stack+9153677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+9115202,int_stack+8839563,int_stack+8741051, 1.0, int_stack+9166277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+8826963,int_stack+9115202,int_stack+8762759, 0.0, zero_stack, 1.0, int_stack+7095703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1458963,int_stack+8826963,int_stack+341469, 0.0, zero_stack, 1.0, int_stack+7254930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1533051,int_stack+1458963,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+7291974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1685875,int_stack+1683180, 1.0, int_stack+1682025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13325739,int_stack+1689395,int_stack+1685875, 1.0, int_stack+1684335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13330359,int_stack+13325739,int_stack+13322274, 1.0, int_stack+9180452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13337289,int_stack+1693850,int_stack+1689395, 1.0, int_stack+1687415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13343229,int_stack+13337289,int_stack+13325739, 1.0, int_stack+9183917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13352469,int_stack+13343229,int_stack+13330359, 1.0, int_stack+9188537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1699350,int_stack+1693850, 1.0, int_stack+1691375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13364019,int_stack+13322274,int_stack+13337289, 1.0, int_stack+9433523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13375899,int_stack+13364019,int_stack+13343229, 1.0, int_stack+9439463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13329699,int_stack+13375899,int_stack+13352469, 1.0, int_stack+9448703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+9433523,int_stack+1702375,int_stack+1699350, 1.0, int_stack+1696325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9442598,int_stack+9433523,int_stack+13322274, 1.0, int_stack+9460253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+341469,int_stack+9442598,int_stack+13364019, 1.0, int_stack+9467678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+9433523,int_stack+341469,int_stack+13375899, 1.0, int_stack+9479558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+9433523,int_stack+13329699, 1.0, int_stack+9494958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+9433523,int_stack+341469,int_stack+9115202, 0.0, zero_stack, 1.0, int_stack+7384035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+15316917,int_stack+9433523,int_stack+8826963, 0.0, zero_stack, 1.0, int_stack+7403880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+15751743,int_stack+15316917,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+7451508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+1706446,int_stack+1706005,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1460286,int_stack+1707034,int_stack+1706446,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+1460286,int_stack+1458963,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1462050,int_stack+1707790,int_stack+1707034,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1464318,int_stack+1462050,int_stack+1460286,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1467846,int_stack+1464318,int_stack+11081112,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+1708735,int_stack+1707790,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1472256,int_stack+1458963,int_stack+1462050,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1476792,int_stack+1472256,int_stack+1464318,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1482672,int_stack+1476792,int_stack+1467846,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1461798,int_stack+1709890,int_stack+1708735,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1465263,int_stack+1461798,int_stack+1458963,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1489287,int_stack+1465263,int_stack+1472256,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1458963,int_stack+1489287,int_stack+1476792,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1489287,int_stack+1458963,int_stack+1482672,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+1711864,int_stack+1711276,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1460727,int_stack+1712648,int_stack+1711864,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1463079,int_stack+1460727,int_stack+1458963,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1466607,int_stack+1713656,int_stack+1712648,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1469631,int_stack+1466607,int_stack+1460727,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1474335,int_stack+1469631,int_stack+1463079,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+1714916,int_stack+1713656,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1480215,int_stack+1458963,int_stack+1466607,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1498548,int_stack+1480215,int_stack+1469631,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1462743,int_stack+1498548,int_stack+1474335,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1471563,int_stack+1716456,int_stack+1714916,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1506388,int_stack+1471563,int_stack+1458963,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1513948,int_stack+1506388,int_stack+1480215,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1471563,int_stack+1513948,int_stack+1498548,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1498548,int_stack+1471563,int_stack+1462743,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1458963,int_stack+1498548,int_stack+1489287, 0.0, zero_stack, 1.0, int_stack+3463218, 1.0, int_stack+8725715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1510896,int_stack+1719060,int_stack+1718304,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1513164,int_stack+1720068,int_stack+1719060,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1516188,int_stack+1513164,int_stack+1510896,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1520724,int_stack+1721364,int_stack+1720068,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1524612,int_stack+1520724,int_stack+1513164,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1486746,int_stack+1524612,int_stack+1516188,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1510896,int_stack+1722984,int_stack+1721364,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+15316917,int_stack+1510896,int_stack+1520724,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+15324693,int_stack+15316917,int_stack+1524612,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1515756,int_stack+15324693,int_stack+1486746,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1486746,int_stack+1724964,int_stack+1722984,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+15334773,int_stack+1486746,int_stack+1510896,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+15344493,int_stack+15334773,int_stack+15316917,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+15344493,int_stack+15324693,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+15316917,int_stack+5578234,int_stack+1515756,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+15316917,int_stack+1498548, 0.0, zero_stack, 1.0, int_stack+3065626, 1.0, int_stack+8786832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+15332793,int_stack+341469,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+2793078, 1.0, int_stack+8799180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+1728285,int_stack+1727340,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1461798,int_stack+1729545,int_stack+1728285,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1465578,int_stack+1461798,int_stack+1458963,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1471248,int_stack+1731165,int_stack+1729545,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1476108,int_stack+1471248,int_stack+1461798,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1483668,int_stack+1476108,int_stack+1465578,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+1733190,int_stack+1731165,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1493118,int_stack+1458963,int_stack+1471248,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1502838,int_stack+1493118,int_stack+1476108,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1465038,int_stack+1502838,int_stack+1483668,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1479213,int_stack+1735665,int_stack+1733190,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1515438,int_stack+1479213,int_stack+1458963,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+15388359,int_stack+1515438,int_stack+1493118,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1479213,int_stack+15388359,int_stack+1502838,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+15388359,int_stack+1479213,int_stack+1465038,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1458963,int_stack+15388359,int_stack+15316917, 0.0, zero_stack, 1.0, int_stack+8204278, 1.0, int_stack+9006716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+1458963,int_stack+341469, 0.0, zero_stack, 1.0, int_stack+8220154, 1.0, int_stack+9022592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1625661,int_stack+13322274,int_stack+15332793, 0.0, zero_stack, 1.0, int_stack+8257198, 1.0, int_stack+9059636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1739790,int_stack+1738635,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1741330,int_stack+1739790,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1743310,int_stack+1741330,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+15316917,int_stack+362424,int_stack+349554,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1745785,int_stack+1743310,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+15328467,int_stack+341469,int_stack+356484,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+15340347,int_stack+15328467,int_stack+362424,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+15340347,int_stack+15316917,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+15316917,int_stack+1748810,int_stack+1745785,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+15355747,int_stack+15316917,int_stack+341469,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1506591,int_stack+15355747,int_stack+15328467,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+15355747,int_stack+1506591,int_stack+15340347,55);
 /*--- compute (m0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1506591,int_stack+15355747,int_stack+348894,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+15316917,int_stack+1506591,int_stack+15388359, 0.0, zero_stack, 1.0, int_stack+8368159, 1.0, int_stack+9199352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+8602330,int_stack+15316917,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+8388004, 1.0, int_stack+9219197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+15875223,int_stack+8602330,int_stack+13322274, 0.0, zero_stack, 1.0, int_stack+8435632, 1.0, int_stack+9266825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1752881,int_stack+1752440,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+1753469,int_stack+1752881,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+1754225,int_stack+1753469,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1755170,int_stack+1754225,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+1756325,int_stack+1755170,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1758299,int_stack+1757711,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+1759083,int_stack+1758299,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+1760091,int_stack+1759083,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1761351,int_stack+1760091,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+1762891,int_stack+1761351,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 0.0, zero_stack, 2.0, int_stack+8725715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+1765495,int_stack+1764739,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+1766503,int_stack+1765495,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+1767799,int_stack+1766503,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+1769419,int_stack+1767799,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8602330,int_stack+13374207,int_stack+13384035,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8610106,int_stack+8602330,int_stack+13387923,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+8610106,int_stack+13350057,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+1771399,int_stack+1769419,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+8620186,int_stack+13350057,int_stack+13374207,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8629906,int_stack+8620186,int_stack+8602330,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+8629906,int_stack+8610106,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8602330,int_stack+5578234,int_stack+13379067,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+8602330,int_stack+13361859, 0.0, zero_stack, 2.0, int_stack+8786832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+8618206,int_stack+341469,int_stack+13322274, 0.0, zero_stack, 2.0, int_stack+8799180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1774720,int_stack+1773775,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+1775980,int_stack+1774720,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+1777600,int_stack+1775980,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13346979,int_stack+13339419,int_stack+13328889,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1779625,int_stack+1777600,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13356429,int_stack+13322274,int_stack+13334559,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+13366149,int_stack+13356429,int_stack+13339419,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13328349,int_stack+13366149,int_stack+13346979,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13342524,int_stack+1782100,int_stack+1779625,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13378749,int_stack+13342524,int_stack+13322274,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8673772,int_stack+13378749,int_stack+13356429,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+13342524,int_stack+8673772,int_stack+13366149,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8673772,int_stack+13342524,int_stack+13328349,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+13322274,int_stack+8673772,int_stack+8602330, 0.0, zero_stack, 2.0, int_stack+9006716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1458963,int_stack+13322274,int_stack+341469, 0.0, zero_stack, 2.0, int_stack+9022592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+15316917,int_stack+1458963,int_stack+8618206, 0.0, zero_stack, 2.0, int_stack+9059636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1786225,int_stack+1785070,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1787765,int_stack+1786225,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1789745,int_stack+1787765,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+8602330,int_stack+362424,int_stack+349554,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1792220,int_stack+1789745,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8613880,int_stack+341469,int_stack+356484,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8625760,int_stack+8613880,int_stack+362424,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+8625760,int_stack+8602330,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8602330,int_stack+1795245,int_stack+1792220,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+8641160,int_stack+8602330,int_stack+341469,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8693617,int_stack+8641160,int_stack+8613880,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+8641160,int_stack+8693617,int_stack+8625760,55);
 /*--- compute (m0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8693617,int_stack+8641160,int_stack+348894,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+8602330,int_stack+8693617,int_stack+8673772, 0.0, zero_stack, 2.0, int_stack+9199352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+15998703,int_stack+8602330,int_stack+13322274, 0.0, zero_stack, 2.0, int_stack+9219197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+16093959,int_stack+15998703,int_stack+1458963, 0.0, zero_stack, 2.0, int_stack+9266825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+1804587,int_stack+1804146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2455166,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1460286,int_stack+1805175,int_stack+1804587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2455607,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+1460286,int_stack+1458963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9512283,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1462050,int_stack+1805931,int_stack+1805175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2456195,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1464318,int_stack+1462050,int_stack+1460286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9513606,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1467846,int_stack+1464318,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9515370,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+1806876,int_stack+1805931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2456951,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1472256,int_stack+1458963,int_stack+1462050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9518016,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1476792,int_stack+1472256,int_stack+1464318, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9520284,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1482672,int_stack+1476792,int_stack+1467846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9523812,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1461798,int_stack+1808031,int_stack+1806876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2457896,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1465263,int_stack+1461798,int_stack+1458963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9528222,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1489287,int_stack+1465263,int_stack+1472256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9531057,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1458963,int_stack+1489287,int_stack+1476792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9535593,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1489287,int_stack+1458963,int_stack+1482672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9541473,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+1817033,int_stack+1816445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2472736,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1460727,int_stack+1817817,int_stack+1817033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2473324,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1463079,int_stack+1460727,int_stack+1458963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9548088,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1466607,int_stack+1818825,int_stack+1817817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2474108,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1469631,int_stack+1466607,int_stack+1460727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9549852,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1474335,int_stack+1469631,int_stack+1463079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9552204,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+1820085,int_stack+1818825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2475116,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1480215,int_stack+1458963,int_stack+1466607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9566169,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1498548,int_stack+1480215,int_stack+1469631, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9569193,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1462743,int_stack+1498548,int_stack+1474335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9573897,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1471563,int_stack+1821625,int_stack+1820085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2476376,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1506388,int_stack+1471563,int_stack+1458963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9579777,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1513948,int_stack+1506388,int_stack+1480215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9583557,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1471563,int_stack+1513948,int_stack+1498548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9589605,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1498548,int_stack+1471563,int_stack+1462743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9597445,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1458963,int_stack+1498548,int_stack+1489287, 1.0, int_stack+2630725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1510896,int_stack+1833265,int_stack+1832509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2495828,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1513164,int_stack+1834273,int_stack+1833265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2496584,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1516188,int_stack+1513164,int_stack+1510896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9606265,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1520724,int_stack+1835569,int_stack+1834273, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2497592,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1524612,int_stack+1520724,int_stack+1513164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9608533,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1486746,int_stack+1524612,int_stack+1516188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9611557,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1510896,int_stack+1837189,int_stack+1835569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2498888,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15998703,int_stack+1510896,int_stack+1520724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9658156,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+16006479,int_stack+15998703,int_stack+1524612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9662044,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1515756,int_stack+16006479,int_stack+1486746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9668092,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1486746,int_stack+1839169,int_stack+1837189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2500508,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+16016559,int_stack+1486746,int_stack+1510896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9675652,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+16026279,int_stack+16016559,int_stack+15998703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9680512,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+16026279,int_stack+16006479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9688288,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+15998703,int_stack+5578234,int_stack+1515756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9698368,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+15998703,int_stack+1498548, 1.0, int_stack+2739582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+16014579,int_stack+341469,int_stack+1458963, 1.0, int_stack+2751930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+1853785,int_stack+1852840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2513900,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1461798,int_stack+1855045,int_stack+1853785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2514845,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1465578,int_stack+1461798,int_stack+1458963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9837909,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1471248,int_stack+1856665,int_stack+1855045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2516105,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1476108,int_stack+1471248,int_stack+1461798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9840744,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1483668,int_stack+1476108,int_stack+1465578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9844524,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+1858690,int_stack+1856665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2517725,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1493118,int_stack+1458963,int_stack+1471248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9850194,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1502838,int_stack+1493118,int_stack+1476108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9855054,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1465038,int_stack+1502838,int_stack+1483668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7691245,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1479213,int_stack+1861165,int_stack+1858690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2519750,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1515438,int_stack+1479213,int_stack+1458963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7700695,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+16070145,int_stack+1515438,int_stack+1493118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7706770,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1479213,int_stack+16070145,int_stack+1502838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7716490,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+16070145,int_stack+1479213,int_stack+1465038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9974475,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1458963,int_stack+16070145,int_stack+15998703, 1.0, int_stack+2907765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+1458963,int_stack+341469, 1.0, int_stack+2923641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+8602330,int_stack+13322274,int_stack+16014579, 1.0, int_stack+2960685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1865290,int_stack+1864135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2267785,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1866830,int_stack+1865290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2270095,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3407652,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1868810,int_stack+1866830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2273175,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3411117,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15998703,int_stack+362424,int_stack+349554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3415737,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1871285,int_stack+1868810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2277135,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+16010253,int_stack+341469,int_stack+356484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3422667,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+16022133,int_stack+16010253,int_stack+362424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3428607,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+16022133,int_stack+15998703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3437847,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15998703,int_stack+1874310,int_stack+1871285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2282085,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+16037533,int_stack+15998703,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3449397,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1506591,int_stack+16037533,int_stack+16010253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7729090,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+16037533,int_stack+1506591,int_stack+16022133, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7756156,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1506591,int_stack+16037533,int_stack+348894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7771556,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+15998703,int_stack+1506591,int_stack+16070145, 1.0, int_stack+3173481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+1718271,int_stack+15998703,int_stack+1458963, 1.0, int_stack+3193326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+2820861,int_stack+1718271,int_stack+13322274, 1.0, int_stack+3240954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1883652,int_stack+1883211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2455166, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+1884240,int_stack+1883652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2455607, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9512283, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+1884996,int_stack+1884240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2456195, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9513606, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9515370, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1885941,int_stack+1884996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2456951, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9518016, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9520284, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9523812, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+1887096,int_stack+1885941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2457896, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9528222, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9531057, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9535593, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9541473, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1896098,int_stack+1895510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2472736, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+1896882,int_stack+1896098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2473324, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9548088, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+1897890,int_stack+1896882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2474108, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9549852, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9552204, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1899150,int_stack+1897890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2475116, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9566169, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9569193, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9573897, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+1900690,int_stack+1899150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2476376, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9579777, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9583557, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9589605, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9597445, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 1.0, int_stack+3621347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+1912330,int_stack+1911574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2495828, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+1913338,int_stack+1912330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2496584, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9606265, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+1914634,int_stack+1913338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2497592, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9608533, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9611557, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+1916254,int_stack+1914634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2498888, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1718271,int_stack+13374207,int_stack+13384035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9658156, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1726047,int_stack+1718271,int_stack+13387923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9662044, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+1726047,int_stack+13350057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9668092, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+1918234,int_stack+1916254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2500508, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1736127,int_stack+13350057,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9675652, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1745847,int_stack+1736127,int_stack+1718271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9680512, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+1745847,int_stack+1726047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9688288, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1718271,int_stack+5578234,int_stack+13379067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9698368, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+1718271,int_stack+13361859, 1.0, int_stack+3682464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1734147,int_stack+341469,int_stack+13322274, 1.0, int_stack+3694812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1932850,int_stack+1931905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2513900, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+1934110,int_stack+1932850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2514845, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9837909, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+1935730,int_stack+1934110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2516105, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9840744, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13346979,int_stack+13339419,int_stack+13328889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9844524, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1937755,int_stack+1935730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2517725, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13356429,int_stack+13322274,int_stack+13334559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9850194, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13366149,int_stack+13356429,int_stack+13339419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9855054, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13328349,int_stack+13366149,int_stack+13346979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7691245, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13342524,int_stack+1940230,int_stack+1937755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2519750, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13378749,int_stack+13342524,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7700695, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1789713,int_stack+13378749,int_stack+13356429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7706770, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13342524,int_stack+1789713,int_stack+13366149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7716490, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1789713,int_stack+13342524,int_stack+13328349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9974475, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1809558,int_stack+1789713,int_stack+1718271, 1.0, int_stack+3917468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+1809558,int_stack+341469, 1.0, int_stack+3933344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+15998703,int_stack+13322274,int_stack+1734147, 1.0, int_stack+3970388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+1944355,int_stack+1943200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2267785, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+1945895,int_stack+1944355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2270095, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3407652, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+1947875,int_stack+1945895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2273175, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3411117, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1718271,int_stack+362424,int_stack+349554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3415737, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+1950350,int_stack+1947875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2277135, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1729821,int_stack+341469,int_stack+356484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3422667, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1741701,int_stack+1729821,int_stack+362424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3428607, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+1741701,int_stack+1718271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3437847, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1718271,int_stack+1953375,int_stack+1950350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2282085, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1757101,int_stack+1718271,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3449397, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1857186,int_stack+1757101,int_stack+1729821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7729090, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1757101,int_stack+1857186,int_stack+1741701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7756156, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1857186,int_stack+1757101,int_stack+348894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7771556, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+1881441,int_stack+1857186,int_stack+1789713, 1.0, int_stack+4109294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+2944341,int_stack+1881441,int_stack+1809558, 1.0, int_stack+4129139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+1718271,int_stack+2944341,int_stack+13322274, 1.0, int_stack+4176767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1962717,int_stack+1962276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2455166, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+1963305,int_stack+1962717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2455607, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9512283, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+1964061,int_stack+1963305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2456195, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9513606, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9515370, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1965006,int_stack+1964061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2456951, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9518016, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9520284, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9523812, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+1966161,int_stack+1965006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2457896, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9528222, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9531057, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9535593, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9541473, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+1975163,int_stack+1974575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2472736, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+1975947,int_stack+1975163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2473324, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9548088, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+1976955,int_stack+1975947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2474108, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9549852, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9552204, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+1978215,int_stack+1976955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2475116, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9566169, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9569193, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9573897, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+1979755,int_stack+1978215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2476376, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9579777, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9583557, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9589605, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9597445, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 1.0, int_stack+4464015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+1991395,int_stack+1990639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2495828, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+1992403,int_stack+1991395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2496584, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9606265, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+1993699,int_stack+1992403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2497592, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9608533, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9611557, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+1995319,int_stack+1993699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2498888, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2944341,int_stack+13374207,int_stack+13384035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9658156, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2952117,int_stack+2944341,int_stack+13387923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9662044, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+2952117,int_stack+13350057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9668092, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+1997299,int_stack+1995319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2500508, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2962197,int_stack+13350057,int_stack+13374207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9675652, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2971917,int_stack+2962197,int_stack+2944341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9680512, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+2971917,int_stack+2952117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9688288, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2944341,int_stack+5578234,int_stack+13379067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9698368, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+2944341,int_stack+13361859, 1.0, int_stack+4525132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2960217,int_stack+341469,int_stack+13322274, 1.0, int_stack+4537480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+2011915,int_stack+2010970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2513900, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+2013175,int_stack+2011915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2514845, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9837909, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+2014795,int_stack+2013175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2516105, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9840744, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13346979,int_stack+13339419,int_stack+13328889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9844524, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+2016820,int_stack+2014795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2517725, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13356429,int_stack+13322274,int_stack+13334559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9850194, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13366149,int_stack+13356429,int_stack+13339419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9855054, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+13328349,int_stack+13366149,int_stack+13346979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7691245, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13342524,int_stack+2019295,int_stack+2016820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2519750, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13378749,int_stack+13342524,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7700695, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3015783,int_stack+13378749,int_stack+13356429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7706770, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13342524,int_stack+3015783,int_stack+13366149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7716490, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3015783,int_stack+13342524,int_stack+13328349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9974475, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+13322274,int_stack+3015783,int_stack+2944341, 1.0, int_stack+4747851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1458963,int_stack+13322274,int_stack+341469, 1.0, int_stack+4763727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1841751,int_stack+1458963,int_stack+2960217, 1.0, int_stack+4800771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+2023420,int_stack+2022265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2267785, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+2024960,int_stack+2023420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2270095, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3407652, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+2026940,int_stack+2024960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2273175, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3411117, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4747851,int_stack+362424,int_stack+349554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3415737, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+2029415,int_stack+2026940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2277135, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4759401,int_stack+341469,int_stack+356484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3422667, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4771281,int_stack+4759401,int_stack+362424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3428607, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+4771281,int_stack+4747851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3437847, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4747851,int_stack+2032440,int_stack+2029415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2282085, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4786681,int_stack+4747851,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3449397, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4801531,int_stack+4786681,int_stack+4759401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7729090, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4747851,int_stack+4801531,int_stack+4771281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7756156, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4770951,int_stack+4747851,int_stack+348894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7771556, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4795206,int_stack+4770951,int_stack+3015783, 1.0, int_stack+4939677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+4854741,int_stack+4795206,int_stack+13322274, 1.0, int_stack+4959522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+4436075,int_stack+4854741,int_stack+1458963, 1.0, int_stack+5007150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+2041782,int_stack+2041341, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2455166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1460286,int_stack+2042370,int_stack+2041782, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2455607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+1460286,int_stack+1458963, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9512283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1462050,int_stack+2043126,int_stack+2042370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2456195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1464318,int_stack+1462050,int_stack+1460286, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9513606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1467846,int_stack+1464318,int_stack+11081112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9515370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+2044071,int_stack+2043126, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2456951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1472256,int_stack+1458963,int_stack+1462050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9518016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1476792,int_stack+1472256,int_stack+1464318, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9520284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1482672,int_stack+1476792,int_stack+1467846, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9523812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1461798,int_stack+2045226,int_stack+2044071, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2457896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1465263,int_stack+1461798,int_stack+1458963, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9528222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1489287,int_stack+1465263,int_stack+1472256, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9531057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1458963,int_stack+1489287,int_stack+1476792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9535593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1489287,int_stack+1458963,int_stack+1482672, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9541473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+2054228,int_stack+2053640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2472736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1460727,int_stack+2055012,int_stack+2054228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2473324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1463079,int_stack+1460727,int_stack+1458963, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9548088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1466607,int_stack+2056020,int_stack+2055012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2474108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1469631,int_stack+1466607,int_stack+1460727, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9549852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1474335,int_stack+1469631,int_stack+1463079, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9552204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+2057280,int_stack+2056020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2475116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1480215,int_stack+1458963,int_stack+1466607, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9566169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1498548,int_stack+1480215,int_stack+1469631, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9569193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1462743,int_stack+1498548,int_stack+1474335, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9573897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1471563,int_stack+2058820,int_stack+2057280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2476376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1506388,int_stack+1471563,int_stack+1458963, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9579777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1513948,int_stack+1506388,int_stack+1480215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9583557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1471563,int_stack+1513948,int_stack+1498548, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9589605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1498548,int_stack+1471563,int_stack+1462743, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9597445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1458963,int_stack+1498548,int_stack+1489287, 1.0, int_stack+5297233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1510896,int_stack+2070460,int_stack+2069704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2495828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1513164,int_stack+2071468,int_stack+2070460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2496584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1516188,int_stack+1513164,int_stack+1510896, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9606265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1520724,int_stack+2072764,int_stack+2071468, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2497592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1524612,int_stack+1520724,int_stack+1513164, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9608533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1486746,int_stack+1524612,int_stack+1516188, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9611557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1510896,int_stack+2074384,int_stack+2072764, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2498888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13322274,int_stack+1510896,int_stack+1520724, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9658156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13330050,int_stack+13322274,int_stack+1524612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9662044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1515756,int_stack+13330050,int_stack+1486746, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9668092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1486746,int_stack+2076364,int_stack+2074384, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2500508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13340130,int_stack+1486746,int_stack+1510896, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9675652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13349850,int_stack+13340130,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9680512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5578234,int_stack+13349850,int_stack+13330050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9688288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13322274,int_stack+5578234,int_stack+1515756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9698368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+13322274,int_stack+1498548, 1.0, int_stack+5358350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+13338150,int_stack+341469,int_stack+1458963, 1.0, int_stack+5370698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+2090980,int_stack+2090035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2513900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1461798,int_stack+2092240,int_stack+2090980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2514845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1465578,int_stack+1461798,int_stack+1458963, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9837909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1471248,int_stack+2093860,int_stack+2092240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2516105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1476108,int_stack+1471248,int_stack+1461798, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9840744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1483668,int_stack+1476108,int_stack+1465578, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9844524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+2095885,int_stack+2093860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2517725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1493118,int_stack+1458963,int_stack+1471248, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9850194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1502838,int_stack+1493118,int_stack+1476108, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9855054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1465038,int_stack+1502838,int_stack+1483668, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7691245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1479213,int_stack+2098360,int_stack+2095885, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2519750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1515438,int_stack+1479213,int_stack+1458963, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7700695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4747851,int_stack+1515438,int_stack+1493118, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7706770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1479213,int_stack+4747851,int_stack+1502838, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7716490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4747851,int_stack+1479213,int_stack+1465038, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9974475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4767696,int_stack+4747851,int_stack+13322274, 1.0, int_stack+5593354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1458963,int_stack+4767696,int_stack+341469, 1.0, int_stack+5609230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4815324,int_stack+1458963,int_stack+13338150, 1.0, int_stack+5646274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+2102485,int_stack+2101330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2267785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+2104025,int_stack+2102485, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2270095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3407652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+2106005,int_stack+2104025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2273175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3411117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13322274,int_stack+362424,int_stack+349554, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3415737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+2108480,int_stack+2106005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2277135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13333824,int_stack+341469,int_stack+356484, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3422667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13345704,int_stack+13333824,int_stack+362424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3428607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+13345704,int_stack+13322274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3437847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13322274,int_stack+2111505,int_stack+2108480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2282085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13361104,int_stack+13322274,int_stack+341469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3449397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13375954,int_stack+13361104,int_stack+13333824, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7729090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13375954,int_stack+13345704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7756156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13345374,int_stack+13322274,int_stack+348894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7771556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4907934,int_stack+13345374,int_stack+4747851, 1.0, int_stack+5780320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+4967469,int_stack+4907934,int_stack+4767696, 1.0, int_stack+5800165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+5578234,int_stack+4967469,int_stack+1458963, 1.0, int_stack+5847793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+2120847,int_stack+2120406, 0.0, zero_stack, 1.0, int_stack+2455166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1460286,int_stack+2121435,int_stack+2120847, 0.0, zero_stack, 1.0, int_stack+2455607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+1460286,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+9512283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1462050,int_stack+2122191,int_stack+2121435, 0.0, zero_stack, 1.0, int_stack+2456195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1464318,int_stack+1462050,int_stack+1460286, 0.0, zero_stack, 1.0, int_stack+9513606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1467846,int_stack+1464318,int_stack+11081112, 0.0, zero_stack, 1.0, int_stack+9515370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+2123136,int_stack+2122191, 0.0, zero_stack, 1.0, int_stack+2456951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1472256,int_stack+1458963,int_stack+1462050, 0.0, zero_stack, 1.0, int_stack+9518016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1476792,int_stack+1472256,int_stack+1464318, 0.0, zero_stack, 1.0, int_stack+9520284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1482672,int_stack+1476792,int_stack+1467846, 0.0, zero_stack, 1.0, int_stack+9523812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1461798,int_stack+2124291,int_stack+2123136, 0.0, zero_stack, 1.0, int_stack+2457896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1465263,int_stack+1461798,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+9528222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1489287,int_stack+1465263,int_stack+1472256, 0.0, zero_stack, 1.0, int_stack+9531057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1458963,int_stack+1489287,int_stack+1476792, 0.0, zero_stack, 1.0, int_stack+9535593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1489287,int_stack+1458963,int_stack+1482672, 0.0, zero_stack, 1.0, int_stack+9541473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+2133293,int_stack+2132705, 0.0, zero_stack, 1.0, int_stack+2472736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1460727,int_stack+2134077,int_stack+2133293, 0.0, zero_stack, 1.0, int_stack+2473324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1463079,int_stack+1460727,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+9548088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1466607,int_stack+2135085,int_stack+2134077, 0.0, zero_stack, 1.0, int_stack+2474108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1469631,int_stack+1466607,int_stack+1460727, 0.0, zero_stack, 1.0, int_stack+9549852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1474335,int_stack+1469631,int_stack+1463079, 0.0, zero_stack, 1.0, int_stack+9552204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+2136345,int_stack+2135085, 0.0, zero_stack, 1.0, int_stack+2475116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1480215,int_stack+1458963,int_stack+1466607, 0.0, zero_stack, 1.0, int_stack+9566169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1498548,int_stack+1480215,int_stack+1469631, 0.0, zero_stack, 1.0, int_stack+9569193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1462743,int_stack+1498548,int_stack+1474335, 0.0, zero_stack, 1.0, int_stack+9573897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1471563,int_stack+2137885,int_stack+2136345, 0.0, zero_stack, 1.0, int_stack+2476376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1506388,int_stack+1471563,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+9579777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1513948,int_stack+1506388,int_stack+1480215, 0.0, zero_stack, 1.0, int_stack+9583557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1471563,int_stack+1513948,int_stack+1498548, 0.0, zero_stack, 1.0, int_stack+9589605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1498548,int_stack+1471563,int_stack+1462743, 0.0, zero_stack, 1.0, int_stack+9597445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1458963,int_stack+1498548,int_stack+1489287, 1.0, int_stack+6135041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1510896,int_stack+2149525,int_stack+2148769, 0.0, zero_stack, 1.0, int_stack+2495828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1513164,int_stack+2150533,int_stack+2149525, 0.0, zero_stack, 1.0, int_stack+2496584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1516188,int_stack+1513164,int_stack+1510896, 0.0, zero_stack, 1.0, int_stack+9606265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1520724,int_stack+2151829,int_stack+2150533, 0.0, zero_stack, 1.0, int_stack+2497592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1524612,int_stack+1520724,int_stack+1513164, 0.0, zero_stack, 1.0, int_stack+9608533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1486746,int_stack+1524612,int_stack+1516188, 0.0, zero_stack, 1.0, int_stack+9611557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1510896,int_stack+2153449,int_stack+2151829, 0.0, zero_stack, 1.0, int_stack+2498888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4907934,int_stack+1510896,int_stack+1520724, 0.0, zero_stack, 1.0, int_stack+9658156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4915710,int_stack+4907934,int_stack+1524612, 0.0, zero_stack, 1.0, int_stack+9662044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1515756,int_stack+4915710,int_stack+1486746, 0.0, zero_stack, 1.0, int_stack+9668092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1486746,int_stack+2155429,int_stack+2153449, 0.0, zero_stack, 1.0, int_stack+2500508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4925790,int_stack+1486746,int_stack+1510896, 0.0, zero_stack, 1.0, int_stack+9675652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4935510,int_stack+4925790,int_stack+4907934, 0.0, zero_stack, 1.0, int_stack+9680512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4948470,int_stack+4935510,int_stack+4915710, 0.0, zero_stack, 1.0, int_stack+9688288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4907934,int_stack+4948470,int_stack+1515756, 0.0, zero_stack, 1.0, int_stack+9698368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+4907934,int_stack+1498548, 1.0, int_stack+6196158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+4923810,int_stack+341469,int_stack+1458963, 1.0, int_stack+6208506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+2170045,int_stack+2169100, 0.0, zero_stack, 1.0, int_stack+2513900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1461798,int_stack+2171305,int_stack+2170045, 0.0, zero_stack, 1.0, int_stack+2514845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1465578,int_stack+1461798,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+9837909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1471248,int_stack+2172925,int_stack+2171305, 0.0, zero_stack, 1.0, int_stack+2516105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1476108,int_stack+1471248,int_stack+1461798, 0.0, zero_stack, 1.0, int_stack+9840744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1483668,int_stack+1476108,int_stack+1465578, 0.0, zero_stack, 1.0, int_stack+9844524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+2174950,int_stack+2172925, 0.0, zero_stack, 1.0, int_stack+2517725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1493118,int_stack+1458963,int_stack+1471248, 0.0, zero_stack, 1.0, int_stack+9850194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1502838,int_stack+1493118,int_stack+1476108, 0.0, zero_stack, 1.0, int_stack+9855054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1465038,int_stack+1502838,int_stack+1483668, 0.0, zero_stack, 1.0, int_stack+7691245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1479213,int_stack+2177425,int_stack+2174950, 0.0, zero_stack, 1.0, int_stack+2519750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1515438,int_stack+1479213,int_stack+1458963, 0.0, zero_stack, 1.0, int_stack+7700695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4979376,int_stack+1515438,int_stack+1493118, 0.0, zero_stack, 1.0, int_stack+7706770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1479213,int_stack+4979376,int_stack+1502838, 0.0, zero_stack, 1.0, int_stack+7716490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4979376,int_stack+1479213,int_stack+1465038, 0.0, zero_stack, 1.0, int_stack+9974475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4999221,int_stack+4979376,int_stack+4907934, 1.0, int_stack+6418877, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1458963,int_stack+4999221,int_stack+341469, 1.0, int_stack+6434753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5701714,int_stack+1458963,int_stack+4923810, 1.0, int_stack+6471797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+2181550,int_stack+2180395, 0.0, zero_stack, 1.0, int_stack+2267785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+2183090,int_stack+2181550, 0.0, zero_stack, 1.0, int_stack+2270095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469, 0.0, zero_stack, 1.0, int_stack+3407652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+2185070,int_stack+2183090, 0.0, zero_stack, 1.0, int_stack+2273175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934, 0.0, zero_stack, 1.0, int_stack+3411117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6418877,int_stack+362424,int_stack+349554, 0.0, zero_stack, 1.0, int_stack+3415737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+2187545,int_stack+2185070, 0.0, zero_stack, 1.0, int_stack+2277135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6430427,int_stack+341469,int_stack+356484, 0.0, zero_stack, 1.0, int_stack+3422667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6442307,int_stack+6430427,int_stack+362424, 0.0, zero_stack, 1.0, int_stack+3428607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+6442307,int_stack+6418877, 0.0, zero_stack, 1.0, int_stack+3437847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6418877,int_stack+2190570,int_stack+2187545, 0.0, zero_stack, 1.0, int_stack+2282085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6457707,int_stack+6418877,int_stack+341469, 0.0, zero_stack, 1.0, int_stack+3449397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6472557,int_stack+6457707,int_stack+6430427, 0.0, zero_stack, 1.0, int_stack+7729090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6418877,int_stack+6472557,int_stack+6442307, 0.0, zero_stack, 1.0, int_stack+7756156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6441977,int_stack+6418877,int_stack+348894, 0.0, zero_stack, 1.0, int_stack+7771556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+6466232,int_stack+6441977,int_stack+4979376, 1.0, int_stack+6616373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+6525767,int_stack+6466232,int_stack+4999221, 1.0, int_stack+6636218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+4907934,int_stack+6525767,int_stack+1458963, 1.0, int_stack+6683846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+2199912,int_stack+2199471, 1.0, int_stack+2455166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1460286,int_stack+2200500,int_stack+2199912, 1.0, int_stack+2455607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+1460286,int_stack+1458963, 1.0, int_stack+9512283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1462050,int_stack+2201256,int_stack+2200500, 1.0, int_stack+2456195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1464318,int_stack+1462050,int_stack+1460286, 1.0, int_stack+9513606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1467846,int_stack+1464318,int_stack+11081112, 1.0, int_stack+9515370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+2202201,int_stack+2201256, 1.0, int_stack+2456951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1472256,int_stack+1458963,int_stack+1462050, 1.0, int_stack+9518016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1476792,int_stack+1472256,int_stack+1464318, 1.0, int_stack+9520284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1482672,int_stack+1476792,int_stack+1467846, 1.0, int_stack+9523812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1461798,int_stack+2203356,int_stack+2202201, 1.0, int_stack+2457896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1465263,int_stack+1461798,int_stack+1458963, 1.0, int_stack+9528222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1489287,int_stack+1465263,int_stack+1472256, 1.0, int_stack+9531057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1458963,int_stack+1489287,int_stack+1476792, 1.0, int_stack+9535593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1489287,int_stack+1458963,int_stack+1482672, 1.0, int_stack+9541473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+2212358,int_stack+2211770, 1.0, int_stack+2472736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1460727,int_stack+2213142,int_stack+2212358, 1.0, int_stack+2473324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1463079,int_stack+1460727,int_stack+1458963, 1.0, int_stack+9548088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1466607,int_stack+2214150,int_stack+2213142, 1.0, int_stack+2474108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1469631,int_stack+1466607,int_stack+1460727, 1.0, int_stack+9549852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1474335,int_stack+1469631,int_stack+1463079, 1.0, int_stack+9552204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+2215410,int_stack+2214150, 1.0, int_stack+2475116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1480215,int_stack+1458963,int_stack+1466607, 1.0, int_stack+9566169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1498548,int_stack+1480215,int_stack+1469631, 1.0, int_stack+9569193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1462743,int_stack+1498548,int_stack+1474335, 1.0, int_stack+9573897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+9566169,int_stack+2216950,int_stack+2215410, 1.0, int_stack+2476376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9570789,int_stack+9566169,int_stack+1458963, 1.0, int_stack+9579777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1506388,int_stack+9570789,int_stack+1480215, 1.0, int_stack+9583557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+9566169,int_stack+1506388,int_stack+1498548, 1.0, int_stack+9589605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1498548,int_stack+9566169,int_stack+1462743, 1.0, int_stack+9597445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+9566169,int_stack+1498548,int_stack+1489287, 1.0, int_stack+6955659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9593952,int_stack+2228590,int_stack+2227834, 1.0, int_stack+2495828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9596220,int_stack+2229598,int_stack+2228590, 1.0, int_stack+2496584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9599244,int_stack+9596220,int_stack+9593952, 1.0, int_stack+9606265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9603780,int_stack+2230894,int_stack+2229598, 1.0, int_stack+2497592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1510896,int_stack+9603780,int_stack+9596220, 1.0, int_stack+9608533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1516944,int_stack+1510896,int_stack+9599244, 1.0, int_stack+9611557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9593952,int_stack+2232514,int_stack+2230894, 1.0, int_stack+2498888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9607668,int_stack+9593952,int_stack+9603780, 1.0, int_stack+9658156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1458963,int_stack+9607668,int_stack+1510896, 1.0, int_stack+9662044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1469043,int_stack+1458963,int_stack+1516944, 1.0, int_stack+9668092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1510896,int_stack+2234494,int_stack+2232514, 1.0, int_stack+2500508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1516836,int_stack+1510896,int_stack+9593952, 1.0, int_stack+9675652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+9593952,int_stack+1516836,int_stack+9607668, 1.0, int_stack+9680512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1510896,int_stack+9593952,int_stack+1458963, 1.0, int_stack+9688288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+9593952,int_stack+1510896,int_stack+1469043, 1.0, int_stack+9698368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+9593952,int_stack+1498548, 1.0, int_stack+7008880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1458963,int_stack+341469,int_stack+9566169, 1.0, int_stack+7021228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9566169,int_stack+2257435,int_stack+2256490, 1.0, int_stack+2513900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9569004,int_stack+2258695,int_stack+2257435, 1.0, int_stack+2514845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9572784,int_stack+9569004,int_stack+9566169, 1.0, int_stack+9837909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9578454,int_stack+2260315,int_stack+2258695, 1.0, int_stack+2516105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9583314,int_stack+9578454,int_stack+9569004, 1.0, int_stack+9840744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1514529,int_stack+9583314,int_stack+9572784, 1.0, int_stack+9844524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9837909,int_stack+2262340,int_stack+2260315, 1.0, int_stack+2517725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9566169,int_stack+9837909,int_stack+9578454, 1.0, int_stack+9850194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+9658156,int_stack+9566169,int_stack+9583314, 1.0, int_stack+9855054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+9843984,int_stack+9658156,int_stack+1514529, 1.0, int_stack+7691245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1514529,int_stack+2264815,int_stack+2262340, 1.0, int_stack+2519750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9575889,int_stack+1514529,int_stack+9837909, 1.0, int_stack+7700695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1514529,int_stack+9575889,int_stack+9566169, 1.0, int_stack+7706770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+9566169,int_stack+1514529,int_stack+9658156, 1.0, int_stack+7716490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+9658156,int_stack+9566169,int_stack+9843984, 1.0, int_stack+9974475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6418877,int_stack+9658156,int_stack+9593952, 1.0, int_stack+7095703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+6418877,int_stack+341469, 1.0, int_stack+7254930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+6466505,int_stack+13322274,int_stack+1458963, 1.0, int_stack+7291974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+2271635,int_stack+2268940, 1.0, int_stack+2267785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1462428,int_stack+2275155,int_stack+2271635, 1.0, int_stack+2270095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1467048,int_stack+1462428,int_stack+1458963, 1.0, int_stack+3407652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1473978,int_stack+2279610,int_stack+2275155, 1.0, int_stack+2273175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1479918,int_stack+1473978,int_stack+1462428, 1.0, int_stack+3411117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1489158,int_stack+1479918,int_stack+1467048, 1.0, int_stack+3415737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3407652,int_stack+2285110,int_stack+2279610, 1.0, int_stack+2277135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1458963,int_stack+3407652,int_stack+1473978, 1.0, int_stack+3422667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1500708,int_stack+1458963,int_stack+1479918, 1.0, int_stack+3428607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3415077,int_stack+1500708,int_stack+1489158, 1.0, int_stack+3437847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3432402,int_stack+2288135,int_stack+2285110, 1.0, int_stack+2282085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1470843,int_stack+3432402,int_stack+3407652, 1.0, int_stack+3449397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3432402,int_stack+1470843,int_stack+1458963, 1.0, int_stack+7729090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1458963,int_stack+3432402,int_stack+1500708, 1.0, int_stack+7756156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3432402,int_stack+1458963,int_stack+3415077, 1.0, int_stack+7771556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+1458963,int_stack+3432402,int_stack+9658156, 1.0, int_stack+7384035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+7254930,int_stack+1458963,int_stack+6418877, 1.0, int_stack+7403880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+6559115,int_stack+7254930,int_stack+13322274, 1.0, int_stack+7451508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+2297477,int_stack+2297036,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+2298065,int_stack+2297477,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+2298821,int_stack+2298065,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+2299766,int_stack+2298821,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+2300921,int_stack+2299766,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+2309923,int_stack+2309335,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+2310707,int_stack+2309923,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+2311715,int_stack+2310707,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+2312975,int_stack+2311715,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+2314515,int_stack+2312975,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 1.0, int_stack+3463218, 0.0, zero_stack, 1.0, int_stack+9556908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+2326155,int_stack+2325399,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+2327163,int_stack+2326155,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+2328459,int_stack+2327163,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+2330079,int_stack+2328459,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7254930,int_stack+13374207,int_stack+13384035,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7262706,int_stack+7254930,int_stack+13387923,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+7262706,int_stack+13350057,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+2332059,int_stack+2330079,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7272786,int_stack+13350057,int_stack+13374207,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7282506,int_stack+7272786,int_stack+7254930,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7295466,int_stack+7282506,int_stack+7262706,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7254930,int_stack+7295466,int_stack+13379067,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+7254930,int_stack+13361859, 1.0, int_stack+3065626, 0.0, zero_stack, 1.0, int_stack+9618025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7270806,int_stack+341469,int_stack+13322274, 1.0, int_stack+2793078, 0.0, zero_stack, 1.0, int_stack+9630373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+2346675,int_stack+2345730,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+2347935,int_stack+2346675,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+2349555,int_stack+2347935,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13346979,int_stack+13339419,int_stack+13328889,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+2351580,int_stack+2349555,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13356429,int_stack+13322274,int_stack+13334559,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+13366149,int_stack+13356429,int_stack+13339419,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+9974475,int_stack+13366149,int_stack+13346979,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13328349,int_stack+2354055,int_stack+2351580,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13335774,int_stack+13328349,int_stack+13322274,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+13378749,int_stack+13335774,int_stack+13356429,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13378749,int_stack+13366149,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13341174,int_stack+13322274,int_stack+9974475,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6418877,int_stack+13341174,int_stack+7254930, 1.0, int_stack+8204278, 0.0, zero_stack, 1.0, int_stack+9865989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1458963,int_stack+6418877,int_stack+341469, 1.0, int_stack+8220154, 0.0, zero_stack, 1.0, int_stack+9881865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+7326372,int_stack+1458963,int_stack+7270806, 1.0, int_stack+8257198, 0.0, zero_stack, 1.0, int_stack+9918909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+2358180,int_stack+2357025,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+2359720,int_stack+2358180,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+2361700,int_stack+2359720,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7254930,int_stack+362424,int_stack+349554,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+2364175,int_stack+2361700,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7266480,int_stack+341469,int_stack+356484,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7278360,int_stack+7266480,int_stack+362424,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+7278360,int_stack+7254930,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+7254930,int_stack+2367200,int_stack+2364175,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7293760,int_stack+7254930,int_stack+341469,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+13361019,int_stack+7293760,int_stack+7266480,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7293760,int_stack+13361019,int_stack+7278360,55);
 /*--- compute (m0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13361019,int_stack+7293760,int_stack+348894,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+7254930,int_stack+13361019,int_stack+13341174, 1.0, int_stack+8368159, 0.0, zero_stack, 1.0, int_stack+9988650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+7418982,int_stack+7254930,int_stack+6418877, 1.0, int_stack+8388004, 0.0, zero_stack, 1.0, int_stack+10008495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+5794324,int_stack+7418982,int_stack+1458963, 1.0, int_stack+8435632, 0.0, zero_stack, 1.0, int_stack+10056123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+2376542,int_stack+2376101,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1460286,int_stack+2377130,int_stack+2376542,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+1460286,int_stack+1458963,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1462050,int_stack+2377886,int_stack+2377130,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1464318,int_stack+1462050,int_stack+1460286,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1467846,int_stack+1464318,int_stack+11081112,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+2378831,int_stack+2377886,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1472256,int_stack+1458963,int_stack+1462050,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1476792,int_stack+1472256,int_stack+1464318,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1482672,int_stack+1476792,int_stack+1467846,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1461798,int_stack+2379986,int_stack+2378831,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1465263,int_stack+1461798,int_stack+1458963,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1489287,int_stack+1465263,int_stack+1472256,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1458963,int_stack+1489287,int_stack+1476792,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1489287,int_stack+1458963,int_stack+1482672,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+2388988,int_stack+2388400,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1460727,int_stack+2389772,int_stack+2388988,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1463079,int_stack+1460727,int_stack+1458963,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1466607,int_stack+2390780,int_stack+2389772,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1469631,int_stack+1466607,int_stack+1460727,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1474335,int_stack+1469631,int_stack+1463079,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+2392040,int_stack+2390780,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1480215,int_stack+1458963,int_stack+1466607,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1498548,int_stack+1480215,int_stack+1469631,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1462743,int_stack+1498548,int_stack+1474335,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1471563,int_stack+2393580,int_stack+2392040,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1506388,int_stack+1471563,int_stack+1458963,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1513948,int_stack+1506388,int_stack+1480215,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1471563,int_stack+1513948,int_stack+1498548,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1498548,int_stack+1471563,int_stack+1462743,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1458963,int_stack+1498548,int_stack+1489287, 1.0, int_stack+8725715, 1.0, int_stack+9556908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1510896,int_stack+2405220,int_stack+2404464,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1513164,int_stack+2406228,int_stack+2405220,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1516188,int_stack+1513164,int_stack+1510896,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1520724,int_stack+2407524,int_stack+2406228,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1524612,int_stack+1520724,int_stack+1513164,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1486746,int_stack+1524612,int_stack+1516188,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1510896,int_stack+2409144,int_stack+2407524,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7418982,int_stack+1510896,int_stack+1520724,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7426758,int_stack+7418982,int_stack+1524612,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1515756,int_stack+7426758,int_stack+1486746,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1486746,int_stack+2411124,int_stack+2409144,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7436838,int_stack+1486746,int_stack+1510896,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7446558,int_stack+7436838,int_stack+7418982,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7459518,int_stack+7446558,int_stack+7426758,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7418982,int_stack+7459518,int_stack+1515756,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+7418982,int_stack+1498548, 1.0, int_stack+8786832, 1.0, int_stack+9618025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7434858,int_stack+341469,int_stack+1458963, 1.0, int_stack+8799180, 1.0, int_stack+9630373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1458963,int_stack+2425740,int_stack+2424795,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1461798,int_stack+2427000,int_stack+2425740,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1465578,int_stack+1461798,int_stack+1458963,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1471248,int_stack+2428620,int_stack+2427000,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1476108,int_stack+1471248,int_stack+1461798,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1483668,int_stack+1476108,int_stack+1465578,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1458963,int_stack+2430645,int_stack+2428620,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1493118,int_stack+1458963,int_stack+1471248,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1502838,int_stack+1493118,int_stack+1476108,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+9974475,int_stack+1502838,int_stack+1483668,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1465038,int_stack+2433120,int_stack+2430645,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1472463,int_stack+1465038,int_stack+1458963,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1515438,int_stack+1472463,int_stack+1493118,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1458963,int_stack+1515438,int_stack+1502838,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1477863,int_stack+1458963,int_stack+9974475,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6418877,int_stack+1477863,int_stack+7418982, 1.0, int_stack+9006716, 1.0, int_stack+9865989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+13322274,int_stack+6418877,int_stack+341469, 1.0, int_stack+9022592, 1.0, int_stack+9881865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3407652,int_stack+13322274,int_stack+7434858, 1.0, int_stack+9059636, 1.0, int_stack+9918909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+341469,int_stack+2437245,int_stack+2436090,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+344934,int_stack+2438785,int_stack+2437245,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+349554,int_stack+344934,int_stack+341469,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+356484,int_stack+2440765,int_stack+2438785,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+362424,int_stack+356484,int_stack+344934,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+9006716,int_stack+362424,int_stack+349554,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+341469,int_stack+2443240,int_stack+2440765,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+9018266,int_stack+341469,int_stack+356484,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+9030146,int_stack+9018266,int_stack+362424,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+348894,int_stack+9030146,int_stack+9006716,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+9006716,int_stack+2446265,int_stack+2443240,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+9045546,int_stack+9006716,int_stack+341469,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+9060396,int_stack+9045546,int_stack+9018266,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+9006716,int_stack+9060396,int_stack+9030146,55);
 /*--- compute (m0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+9029816,int_stack+9006716,int_stack+348894,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+9054071,int_stack+9029816,int_stack+1477863, 1.0, int_stack+9199352, 1.0, int_stack+9988650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+9113606,int_stack+9054071,int_stack+6418877, 1.0, int_stack+9219197, 1.0, int_stack+10008495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+2944341,int_stack+9113606,int_stack+13322274, 1.0, int_stack+9266825, 1.0, int_stack+10056123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+2460878,int_stack+2460437,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13323597,int_stack+2461466,int_stack+2460878,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+11081112,int_stack+13323597,int_stack+13322274,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13325361,int_stack+2462222,int_stack+2461466,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13327629,int_stack+13325361,int_stack+13323597,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13331157,int_stack+13327629,int_stack+11081112,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+2463167,int_stack+2462222,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13335567,int_stack+13322274,int_stack+13325361,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+13340103,int_stack+13335567,int_stack+13327629,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13345983,int_stack+13340103,int_stack+13331157,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13325109,int_stack+2464322,int_stack+2463167,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13328574,int_stack+13325109,int_stack+13322274,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+13352598,int_stack+13328574,int_stack+13335567,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13352598,int_stack+13340103,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13352598,int_stack+13322274,int_stack+13345983,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+2480352,int_stack+2479764,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13324038,int_stack+2481136,int_stack+2480352,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13326390,int_stack+13324038,int_stack+13322274,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13329918,int_stack+2482144,int_stack+2481136,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13332942,int_stack+13329918,int_stack+13324038,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13337646,int_stack+13332942,int_stack+13326390,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+2483404,int_stack+2482144,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13343526,int_stack+13322274,int_stack+13329918,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+13361859,int_stack+13343526,int_stack+13332942,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13326054,int_stack+13361859,int_stack+13337646,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13334874,int_stack+2484944,int_stack+2483404,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13369699,int_stack+13334874,int_stack+13322274,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+13377259,int_stack+13369699,int_stack+13343526,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+13334874,int_stack+13377259,int_stack+13361859,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13361859,int_stack+13334874,int_stack+13326054,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+13322274,int_stack+13361859,int_stack+13352598, 2.0, int_stack+9556908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13374207,int_stack+2505620,int_stack+2504864,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13376475,int_stack+2506628,int_stack+2505620,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13379499,int_stack+13376475,int_stack+13374207,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13384035,int_stack+2507924,int_stack+2506628,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13387923,int_stack+13384035,int_stack+13376475,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13350057,int_stack+13387923,int_stack+13379499,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13374207,int_stack+2509544,int_stack+2507924,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6418877,int_stack+13374207,int_stack+13384035,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6426653,int_stack+6418877,int_stack+13387923,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+13379067,int_stack+6426653,int_stack+13350057,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13350057,int_stack+2511524,int_stack+2509544,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6436733,int_stack+13350057,int_stack+13374207,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6446453,int_stack+6436733,int_stack+6418877,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+9006716,int_stack+6446453,int_stack+6426653,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6418877,int_stack+9006716,int_stack+13379067,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+341469,int_stack+6418877,int_stack+13361859, 2.0, int_stack+9618025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+9006716,int_stack+341469,int_stack+13322274, 2.0, int_stack+9630373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13322274,int_stack+2526140,int_stack+2525195,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13325109,int_stack+2527400,int_stack+2526140,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+13328889,int_stack+13325109,int_stack+13322274,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+13334559,int_stack+2529020,int_stack+2527400,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+13339419,int_stack+13334559,int_stack+13325109,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13346979,int_stack+13339419,int_stack+13328889,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+13322274,int_stack+2531045,int_stack+2529020,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13356429,int_stack+13322274,int_stack+13334559,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+13366149,int_stack+13356429,int_stack+13339419,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+9974475,int_stack+13366149,int_stack+13346979,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+13328349,int_stack+2533520,int_stack+2531045,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13335774,int_stack+13328349,int_stack+13322274,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+13378749,int_stack+13335774,int_stack+13356429,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+13322274,int_stack+13378749,int_stack+13366149,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13341174,int_stack+13322274,int_stack+9974475,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+9062282,int_stack+13341174,int_stack+6418877, 2.0, int_stack+9865989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1458963,int_stack+9062282,int_stack+341469, 2.0, int_stack+9881865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+9109910,int_stack+1458963,int_stack+9006716, 2.0, int_stack+9918909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+9006716,int_stack+2537645,int_stack+2536490,55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9010181,int_stack+2539185,int_stack+2537645,55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9014801,int_stack+9010181,int_stack+9006716,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9021731,int_stack+2541165,int_stack+2539185,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9027671,int_stack+9021731,int_stack+9010181,55);
 /*--- compute (m0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+9036911,int_stack+9027671,int_stack+9014801,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9006716,int_stack+2543640,int_stack+2541165,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+9048461,int_stack+9006716,int_stack+9021731,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+341469,int_stack+9048461,int_stack+9027671,55);
 /*--- compute (m0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+9014141,int_stack+341469,int_stack+9036911,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+9031466,int_stack+2546665,int_stack+2543640,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+356869,int_stack+9031466,int_stack+9006716,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6418877,int_stack+356869,int_stack+9048461,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+9031466,int_stack+6418877,int_stack+341469,55);
 /*--- compute (m0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+341469,int_stack+9031466,int_stack+9014141,55);
 /*--- compute (lp|hh) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+9202520,int_stack+341469,int_stack+13341174, 2.0, int_stack+9988650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (kd|hh) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+7418982,int_stack+9202520,int_stack+9062282, 2.0, int_stack+10008495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (if|hh) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+9202520,int_stack+7418982,int_stack+1458963, 2.0, int_stack+10056123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+9837909,int_stack+3778868,int_stack+3315042,441);
     Libderiv->ABCD[11] = int_stack + 9837909;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+9976824,int_stack+4624371,int_stack+4250855,441);
     Libderiv->ABCD[10] = int_stack + 9976824;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+1934361,int_stack+5454754,int_stack+5081238,441);
     Libderiv->ABCD[9] = int_stack + 1934361;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+2073276,int_stack+6295397,int_stack+5921881,441);
     Libderiv->ABCD[8] = int_stack + 2073276;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+2212191,int_stack+7131450,int_stack+6757934,441);
     Libderiv->ABCD[7] = int_stack + 2212191;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+2351106,int_stack+7838392,int_stack+7525596,441);
     Libderiv->ABCD[6] = int_stack + 2351106;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+2490021,int_stack+8883236,int_stack+8509720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8083588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[2] = int_stack + 2490021;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+8694940,int_stack+9714429,int_stack+9340913, 0.0, zero_stack, 1.0, int_stack+8083588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[1] = int_stack + 8694940;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+8833855,int_stack+10424967,int_stack+10130211, 1.0, int_stack+8083588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[0] = int_stack + 8833855;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+9433523,int_stack+10222821,int_stack+10548447,441);
     Libderiv->ABCD[155] = int_stack + 9433523;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+10222821,int_stack+10772412,int_stack+10679802,441);
     Libderiv->ABCD[143] = int_stack + 10222821;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+10361736,int_stack+11083758,int_stack+10895892,441);
     Libderiv->ABCD[142] = int_stack + 10361736;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+10500651,int_stack+11302494,int_stack+7961872,441);
     Libderiv->ABCD[131] = int_stack + 10500651;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+10639566,int_stack+11521230,int_stack+156249,441);
     Libderiv->ABCD[130] = int_stack + 10639566;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+10778481,int_stack+11644710,int_stack+10988502,441);
     Libderiv->ABCD[129] = int_stack + 10778481;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+10917396,int_stack+26595,int_stack+11425974,441);
     Libderiv->ABCD[119] = int_stack + 10917396;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+11056311,int_stack+11860800,int_stack+11768190,441);
     Libderiv->ABCD[118] = int_stack + 11056311;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+9572438,int_stack+12172146,int_stack+11984280,441);
     Libderiv->ABCD[117] = int_stack + 9572438;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+5266458,int_stack+12390882,int_stack+378513,441);
     Libderiv->ABCD[116] = int_stack + 5266458;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+5405373,int_stack+12514362,int_stack+248859,441);
     Libderiv->ABCD[107] = int_stack + 5405373;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+4559555,int_stack+12733098,int_stack+471123,441);
     Libderiv->ABCD[106] = int_stack + 4559555;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+7618206,int_stack+12951834,int_stack+12295626,441);
     Libderiv->ABCD[105] = int_stack + 7618206;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+7757121,int_stack+13075314,int_stack+12076890,441);
     Libderiv->ABCD[104] = int_stack + 7757121;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+7896036,int_stack+13198794,int_stack+11207238,441);
     Libderiv->ABCD[103] = int_stack + 7896036;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+11195226,int_stack+563733,int_stack+12637842,441);
     Libderiv->ABCD[95] = int_stack + 11195226;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+11334141,int_stack+13396362,int_stack+687213,441);
     Libderiv->ABCD[94] = int_stack + 11334141;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+11473056,int_stack+779823,int_stack+12856578,441);
     Libderiv->ABCD[93] = int_stack + 11473056;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+11611971,int_stack+13519842,int_stack+3505872,441);
     Libderiv->ABCD[92] = int_stack + 11611971;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+11750886,int_stack+13643322,int_stack+6014491,441);
     Libderiv->ABCD[91] = int_stack + 11750886;
 /*--- compute (hg|hh) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+6014491,int_stack+13766802,int_stack+6850544,441);
     Libderiv->ABCD[90] = int_stack + 6014491;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+6850544,int_stack+903303,int_stack+4343465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3315042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[47] = int_stack + 6850544;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+6989459,int_stack+13985538,int_stack+1026783, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4250855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[46] = int_stack + 6989459;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+7128374,int_stack+14201628,int_stack+14109018, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5081238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[45] = int_stack + 7128374;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+6153406,int_stack+14420364,int_stack+1119393, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5921881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[44] = int_stack + 6153406;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+6292321,int_stack+14543844,int_stack+5173848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6757934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[43] = int_stack + 6292321;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+11889801,int_stack+14667324,int_stack+14325108, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7525596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[42] = int_stack + 11889801;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+12028716,int_stack+1212003,int_stack+13890282, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+8509720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[38] = int_stack + 12028716;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+12167631,int_stack+14886060,int_stack+3077974, 0.0, zero_stack, 1.0, int_stack+3315042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[35] = int_stack + 12167631;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+12306546,int_stack+15009540,int_stack+2639986, 0.0, zero_stack, 1.0, int_stack+4250855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[34] = int_stack + 12306546;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+12445461,int_stack+1335483,int_stack+14790804, 0.0, zero_stack, 1.0, int_stack+5081238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[33] = int_stack + 12445461;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+12584376,int_stack+15412173,int_stack+15224307, 0.0, zero_stack, 1.0, int_stack+5921881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[32] = int_stack + 12584376;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+12723291,int_stack+15628263,int_stack+15535653, 0.0, zero_stack, 1.0, int_stack+6757934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[31] = int_stack + 12723291;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+12862206,int_stack+15751743,int_stack+1533051, 0.0, zero_stack, 1.0, int_stack+7525596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[30] = int_stack + 12862206;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+13001121,int_stack+15875223,int_stack+1625661, 0.0, zero_stack, 1.0, int_stack+8509720, 1.0, int_stack+9340913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[26] = int_stack + 13001121;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+13140036,int_stack+16093959,int_stack+15316917, 0.0, zero_stack, 2.0, int_stack+9340913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[25] = int_stack + 13140036;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+13278951,int_stack+2820861,int_stack+8602330, 1.0, int_stack+3315042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[23] = int_stack + 13278951;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+13417866,int_stack+1718271,int_stack+15998703, 1.0, int_stack+4250855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[22] = int_stack + 13417866;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+13556781,int_stack+4436075,int_stack+1841751, 1.0, int_stack+5081238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[21] = int_stack + 13556781;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+13695696,int_stack+5578234,int_stack+4815324, 1.0, int_stack+5921881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[20] = int_stack + 13695696;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+13834611,int_stack+4907934,int_stack+5701714, 1.0, int_stack+6757934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[19] = int_stack + 13834611;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+13973526,int_stack+6559115,int_stack+6466505, 1.0, int_stack+7525596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[18] = int_stack + 13973526;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+6431236,int_stack+5794324,int_stack+7326372, 1.0, int_stack+8509720, 0.0, zero_stack, 1.0, int_stack+10130211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[14] = int_stack + 6431236;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+7267289,int_stack+2944341,int_stack+3407652, 1.0, int_stack+9340913, 1.0, int_stack+10130211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[13] = int_stack + 7267289;
 /*--- compute (hg|hh) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+7406204,int_stack+9202520,int_stack+9109910, 2.0, int_stack+10130211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[12] = int_stack + 7406204;

}
