/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_igii(Libderiv_t *, prim_data *);

  /* Computes derivatives of (ig|ii) integrals */

void d1hrr_order_igii(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][6][11] = int_stack + 0;
 Libderiv->deriv_classes[6][7][11] = int_stack + 784;
 Libderiv->deriv_classes[6][8][11] = int_stack + 1792;
 Libderiv->deriv_classes[6][9][11] = int_stack + 3052;
 Libderiv->deriv_classes[6][10][11] = int_stack + 4592;
 Libderiv->deriv_classes[6][11][11] = int_stack + 6440;
 Libderiv->deriv_classes[6][12][11] = int_stack + 8624;
 Libderiv->deriv_classes[7][6][11] = int_stack + 11172;
 Libderiv->deriv_classes[7][7][11] = int_stack + 12180;
 Libderiv->deriv_classes[7][8][11] = int_stack + 13476;
 Libderiv->deriv_classes[7][9][11] = int_stack + 15096;
 Libderiv->deriv_classes[7][10][11] = int_stack + 17076;
 Libderiv->deriv_classes[7][11][11] = int_stack + 19452;
 Libderiv->deriv_classes[7][12][11] = int_stack + 22260;
 Libderiv->deriv_classes[8][6][11] = int_stack + 25536;
 Libderiv->deriv_classes[8][7][11] = int_stack + 26796;
 Libderiv->deriv_classes[8][8][11] = int_stack + 28416;
 Libderiv->deriv_classes[8][9][11] = int_stack + 30441;
 Libderiv->deriv_classes[8][10][11] = int_stack + 32916;
 Libderiv->deriv_classes[8][11][11] = int_stack + 35886;
 Libderiv->deriv_classes[8][12][11] = int_stack + 39396;
 Libderiv->deriv_classes[9][6][11] = int_stack + 43491;
 Libderiv->deriv_classes[9][7][11] = int_stack + 45031;
 Libderiv->deriv_classes[9][8][11] = int_stack + 47011;
 Libderiv->deriv_classes[9][9][11] = int_stack + 49486;
 Libderiv->deriv_classes[9][10][11] = int_stack + 52511;
 Libderiv->deriv_classes[9][11][11] = int_stack + 56141;
 Libderiv->deriv_classes[9][12][11] = int_stack + 60431;
 Libderiv->deriv_classes[10][6][11] = int_stack + 65436;
 Libderiv->deriv_classes[10][7][11] = int_stack + 67284;
 Libderiv->deriv_classes[10][8][11] = int_stack + 69660;
 Libderiv->deriv_classes[10][9][11] = int_stack + 72630;
 Libderiv->deriv_classes[10][10][11] = int_stack + 76260;
 Libderiv->deriv_classes[10][11][11] = int_stack + 80616;
 Libderiv->deriv_classes[10][12][11] = int_stack + 85764;
 Libderiv->deriv_classes[6][6][10] = int_stack + 91770;
 Libderiv->deriv_classes[6][7][10] = int_stack + 92554;
 Libderiv->deriv_classes[6][8][10] = int_stack + 93562;
 Libderiv->deriv_classes[6][9][10] = int_stack + 94822;
 Libderiv->deriv_classes[6][10][10] = int_stack + 96362;
 Libderiv->deriv_classes[6][11][10] = int_stack + 98210;
 Libderiv->deriv_classes[6][12][10] = int_stack + 100394;
 Libderiv->deriv_classes[7][6][10] = int_stack + 102942;
 Libderiv->deriv_classes[7][7][10] = int_stack + 103950;
 Libderiv->deriv_classes[7][8][10] = int_stack + 105246;
 Libderiv->deriv_classes[7][9][10] = int_stack + 106866;
 Libderiv->deriv_classes[7][10][10] = int_stack + 108846;
 Libderiv->deriv_classes[7][11][10] = int_stack + 111222;
 Libderiv->deriv_classes[7][12][10] = int_stack + 114030;
 Libderiv->deriv_classes[8][6][10] = int_stack + 117306;
 Libderiv->deriv_classes[8][7][10] = int_stack + 118566;
 Libderiv->deriv_classes[8][8][10] = int_stack + 120186;
 Libderiv->deriv_classes[8][9][10] = int_stack + 122211;
 Libderiv->deriv_classes[8][10][10] = int_stack + 124686;
 Libderiv->deriv_classes[8][11][10] = int_stack + 127656;
 Libderiv->deriv_classes[8][12][10] = int_stack + 131166;
 Libderiv->deriv_classes[9][6][10] = int_stack + 135261;
 Libderiv->deriv_classes[9][7][10] = int_stack + 136801;
 Libderiv->deriv_classes[9][8][10] = int_stack + 138781;
 Libderiv->deriv_classes[9][9][10] = int_stack + 141256;
 Libderiv->deriv_classes[9][10][10] = int_stack + 144281;
 Libderiv->deriv_classes[9][11][10] = int_stack + 147911;
 Libderiv->deriv_classes[9][12][10] = int_stack + 152201;
 Libderiv->deriv_classes[10][6][10] = int_stack + 157206;
 Libderiv->deriv_classes[10][7][10] = int_stack + 159054;
 Libderiv->deriv_classes[10][8][10] = int_stack + 161430;
 Libderiv->deriv_classes[10][9][10] = int_stack + 164400;
 Libderiv->deriv_classes[10][10][10] = int_stack + 168030;
 Libderiv->deriv_classes[10][11][10] = int_stack + 172386;
 Libderiv->deriv_classes[10][12][10] = int_stack + 177534;
 Libderiv->deriv_classes[6][6][9] = int_stack + 183540;
 Libderiv->deriv_classes[6][7][9] = int_stack + 184324;
 Libderiv->deriv_classes[6][8][9] = int_stack + 185332;
 Libderiv->deriv_classes[6][9][9] = int_stack + 186592;
 Libderiv->deriv_classes[6][10][9] = int_stack + 188132;
 Libderiv->deriv_classes[6][11][9] = int_stack + 189980;
 Libderiv->deriv_classes[6][12][9] = int_stack + 192164;
 Libderiv->deriv_classes[7][6][9] = int_stack + 194712;
 Libderiv->deriv_classes[7][7][9] = int_stack + 195720;
 Libderiv->deriv_classes[7][8][9] = int_stack + 197016;
 Libderiv->deriv_classes[7][9][9] = int_stack + 198636;
 Libderiv->deriv_classes[7][10][9] = int_stack + 200616;
 Libderiv->deriv_classes[7][11][9] = int_stack + 202992;
 Libderiv->deriv_classes[7][12][9] = int_stack + 205800;
 Libderiv->deriv_classes[8][6][9] = int_stack + 209076;
 Libderiv->deriv_classes[8][7][9] = int_stack + 210336;
 Libderiv->deriv_classes[8][8][9] = int_stack + 211956;
 Libderiv->deriv_classes[8][9][9] = int_stack + 213981;
 Libderiv->deriv_classes[8][10][9] = int_stack + 216456;
 Libderiv->deriv_classes[8][11][9] = int_stack + 219426;
 Libderiv->deriv_classes[8][12][9] = int_stack + 222936;
 Libderiv->deriv_classes[9][6][9] = int_stack + 227031;
 Libderiv->deriv_classes[9][7][9] = int_stack + 228571;
 Libderiv->deriv_classes[9][8][9] = int_stack + 230551;
 Libderiv->deriv_classes[9][9][9] = int_stack + 233026;
 Libderiv->deriv_classes[9][10][9] = int_stack + 236051;
 Libderiv->deriv_classes[9][11][9] = int_stack + 239681;
 Libderiv->deriv_classes[9][12][9] = int_stack + 243971;
 Libderiv->deriv_classes[10][6][9] = int_stack + 248976;
 Libderiv->deriv_classes[10][7][9] = int_stack + 250824;
 Libderiv->deriv_classes[10][8][9] = int_stack + 253200;
 Libderiv->deriv_classes[10][9][9] = int_stack + 256170;
 Libderiv->deriv_classes[10][10][9] = int_stack + 259800;
 Libderiv->deriv_classes[10][11][9] = int_stack + 264156;
 Libderiv->deriv_classes[10][12][9] = int_stack + 269304;
 Libderiv->deriv_classes[6][6][8] = int_stack + 275310;
 Libderiv->deriv_classes[6][7][8] = int_stack + 276094;
 Libderiv->deriv_classes[6][8][8] = int_stack + 277102;
 Libderiv->deriv_classes[6][9][8] = int_stack + 278362;
 Libderiv->deriv_classes[6][10][8] = int_stack + 279902;
 Libderiv->deriv_classes[6][11][8] = int_stack + 281750;
 Libderiv->deriv_classes[6][12][8] = int_stack + 283934;
 Libderiv->deriv_classes[7][6][8] = int_stack + 286482;
 Libderiv->deriv_classes[7][7][8] = int_stack + 287490;
 Libderiv->deriv_classes[7][8][8] = int_stack + 288786;
 Libderiv->deriv_classes[7][9][8] = int_stack + 290406;
 Libderiv->deriv_classes[7][10][8] = int_stack + 292386;
 Libderiv->deriv_classes[7][11][8] = int_stack + 294762;
 Libderiv->deriv_classes[7][12][8] = int_stack + 297570;
 Libderiv->deriv_classes[8][6][8] = int_stack + 300846;
 Libderiv->deriv_classes[8][7][8] = int_stack + 302106;
 Libderiv->deriv_classes[8][8][8] = int_stack + 303726;
 Libderiv->deriv_classes[8][9][8] = int_stack + 305751;
 Libderiv->deriv_classes[8][10][8] = int_stack + 308226;
 Libderiv->deriv_classes[8][11][8] = int_stack + 311196;
 Libderiv->deriv_classes[8][12][8] = int_stack + 314706;
 Libderiv->deriv_classes[9][6][8] = int_stack + 318801;
 Libderiv->deriv_classes[9][7][8] = int_stack + 320341;
 Libderiv->deriv_classes[9][8][8] = int_stack + 322321;
 Libderiv->deriv_classes[9][9][8] = int_stack + 324796;
 Libderiv->deriv_classes[9][10][8] = int_stack + 327821;
 Libderiv->deriv_classes[9][11][8] = int_stack + 331451;
 Libderiv->deriv_classes[9][12][8] = int_stack + 335741;
 Libderiv->deriv_classes[10][6][8] = int_stack + 340746;
 Libderiv->deriv_classes[10][7][8] = int_stack + 342594;
 Libderiv->deriv_classes[10][8][8] = int_stack + 344970;
 Libderiv->deriv_classes[10][9][8] = int_stack + 347940;
 Libderiv->deriv_classes[10][10][8] = int_stack + 351570;
 Libderiv->deriv_classes[10][11][8] = int_stack + 355926;
 Libderiv->deriv_classes[10][12][8] = int_stack + 361074;
 Libderiv->deriv_classes[6][6][7] = int_stack + 367080;
 Libderiv->deriv_classes[6][7][7] = int_stack + 367864;
 Libderiv->deriv_classes[6][8][7] = int_stack + 368872;
 Libderiv->deriv_classes[6][9][7] = int_stack + 370132;
 Libderiv->deriv_classes[6][10][7] = int_stack + 371672;
 Libderiv->deriv_classes[6][11][7] = int_stack + 373520;
 Libderiv->deriv_classes[6][12][7] = int_stack + 375704;
 Libderiv->deriv_classes[7][6][7] = int_stack + 378252;
 Libderiv->deriv_classes[7][7][7] = int_stack + 379260;
 Libderiv->deriv_classes[7][8][7] = int_stack + 380556;
 Libderiv->deriv_classes[7][9][7] = int_stack + 382176;
 Libderiv->deriv_classes[7][10][7] = int_stack + 384156;
 Libderiv->deriv_classes[7][11][7] = int_stack + 386532;
 Libderiv->deriv_classes[7][12][7] = int_stack + 389340;
 Libderiv->deriv_classes[8][6][7] = int_stack + 392616;
 Libderiv->deriv_classes[8][7][7] = int_stack + 393876;
 Libderiv->deriv_classes[8][8][7] = int_stack + 395496;
 Libderiv->deriv_classes[8][9][7] = int_stack + 397521;
 Libderiv->deriv_classes[8][10][7] = int_stack + 399996;
 Libderiv->deriv_classes[8][11][7] = int_stack + 402966;
 Libderiv->deriv_classes[8][12][7] = int_stack + 406476;
 Libderiv->deriv_classes[9][6][7] = int_stack + 410571;
 Libderiv->deriv_classes[9][7][7] = int_stack + 412111;
 Libderiv->deriv_classes[9][8][7] = int_stack + 414091;
 Libderiv->deriv_classes[9][9][7] = int_stack + 416566;
 Libderiv->deriv_classes[9][10][7] = int_stack + 419591;
 Libderiv->deriv_classes[9][11][7] = int_stack + 423221;
 Libderiv->deriv_classes[9][12][7] = int_stack + 427511;
 Libderiv->deriv_classes[10][6][7] = int_stack + 432516;
 Libderiv->deriv_classes[10][7][7] = int_stack + 434364;
 Libderiv->deriv_classes[10][8][7] = int_stack + 436740;
 Libderiv->deriv_classes[10][9][7] = int_stack + 439710;
 Libderiv->deriv_classes[10][10][7] = int_stack + 443340;
 Libderiv->deriv_classes[10][11][7] = int_stack + 447696;
 Libderiv->deriv_classes[10][12][7] = int_stack + 452844;
 Libderiv->deriv_classes[6][6][6] = int_stack + 458850;
 Libderiv->deriv_classes[6][7][6] = int_stack + 459634;
 Libderiv->deriv_classes[6][8][6] = int_stack + 460642;
 Libderiv->deriv_classes[6][9][6] = int_stack + 461902;
 Libderiv->deriv_classes[6][10][6] = int_stack + 463442;
 Libderiv->deriv_classes[6][11][6] = int_stack + 465290;
 Libderiv->deriv_classes[6][12][6] = int_stack + 467474;
 Libderiv->deriv_classes[7][6][6] = int_stack + 470022;
 Libderiv->deriv_classes[7][7][6] = int_stack + 471030;
 Libderiv->deriv_classes[7][8][6] = int_stack + 472326;
 Libderiv->deriv_classes[7][9][6] = int_stack + 473946;
 Libderiv->deriv_classes[7][10][6] = int_stack + 475926;
 Libderiv->deriv_classes[7][11][6] = int_stack + 478302;
 Libderiv->deriv_classes[7][12][6] = int_stack + 481110;
 Libderiv->deriv_classes[8][6][6] = int_stack + 484386;
 Libderiv->deriv_classes[8][7][6] = int_stack + 485646;
 Libderiv->deriv_classes[8][8][6] = int_stack + 487266;
 Libderiv->deriv_classes[8][9][6] = int_stack + 489291;
 Libderiv->deriv_classes[8][10][6] = int_stack + 491766;
 Libderiv->deriv_classes[8][11][6] = int_stack + 494736;
 Libderiv->deriv_classes[8][12][6] = int_stack + 498246;
 Libderiv->deriv_classes[9][6][6] = int_stack + 502341;
 Libderiv->deriv_classes[9][7][6] = int_stack + 503881;
 Libderiv->deriv_classes[9][8][6] = int_stack + 505861;
 Libderiv->deriv_classes[9][9][6] = int_stack + 508336;
 Libderiv->deriv_classes[9][10][6] = int_stack + 511361;
 Libderiv->deriv_classes[9][11][6] = int_stack + 514991;
 Libderiv->deriv_classes[9][12][6] = int_stack + 519281;
 Libderiv->dvrr_classes[10][6] = int_stack + 524286;
 Libderiv->deriv_classes[10][6][6] = int_stack + 526134;
 Libderiv->dvrr_classes[10][7] = int_stack + 527982;
 Libderiv->deriv_classes[10][7][6] = int_stack + 530358;
 Libderiv->dvrr_classes[10][8] = int_stack + 532734;
 Libderiv->deriv_classes[10][8][6] = int_stack + 535704;
 Libderiv->dvrr_classes[10][9] = int_stack + 538674;
 Libderiv->deriv_classes[10][9][6] = int_stack + 542304;
 Libderiv->dvrr_classes[10][10] = int_stack + 545934;
 Libderiv->deriv_classes[10][10][6] = int_stack + 550290;
 Libderiv->dvrr_classes[10][11] = int_stack + 554646;
 Libderiv->deriv_classes[10][11][6] = int_stack + 559794;
 Libderiv->deriv_classes[10][12][6] = int_stack + 564942;
 Libderiv->deriv_classes[6][6][2] = int_stack + 570948;
 Libderiv->deriv_classes[6][7][2] = int_stack + 571732;
 Libderiv->deriv_classes[6][8][2] = int_stack + 572740;
 Libderiv->deriv_classes[6][9][2] = int_stack + 574000;
 Libderiv->deriv_classes[6][10][2] = int_stack + 575540;
 Libderiv->deriv_classes[6][11][2] = int_stack + 577388;
 Libderiv->deriv_classes[6][12][2] = int_stack + 579572;
 Libderiv->deriv_classes[7][6][2] = int_stack + 582120;
 Libderiv->deriv_classes[7][7][2] = int_stack + 583128;
 Libderiv->deriv_classes[7][8][2] = int_stack + 584424;
 Libderiv->deriv_classes[7][9][2] = int_stack + 586044;
 Libderiv->deriv_classes[7][10][2] = int_stack + 588024;
 Libderiv->deriv_classes[7][11][2] = int_stack + 590400;
 Libderiv->deriv_classes[7][12][2] = int_stack + 593208;
 Libderiv->deriv_classes[8][6][2] = int_stack + 596484;
 Libderiv->deriv_classes[8][7][2] = int_stack + 597744;
 Libderiv->deriv_classes[8][8][2] = int_stack + 599364;
 Libderiv->deriv_classes[8][9][2] = int_stack + 601389;
 Libderiv->deriv_classes[8][10][2] = int_stack + 603864;
 Libderiv->deriv_classes[8][11][2] = int_stack + 606834;
 Libderiv->deriv_classes[8][12][2] = int_stack + 610344;
 Libderiv->deriv_classes[9][6][2] = int_stack + 614439;
 Libderiv->deriv_classes[9][7][2] = int_stack + 615979;
 Libderiv->deriv_classes[9][8][2] = int_stack + 617959;
 Libderiv->deriv_classes[9][9][2] = int_stack + 620434;
 Libderiv->deriv_classes[9][10][2] = int_stack + 623459;
 Libderiv->deriv_classes[9][11][2] = int_stack + 627089;
 Libderiv->deriv_classes[9][12][2] = int_stack + 631379;
 Libderiv->deriv_classes[10][6][2] = int_stack + 636384;
 Libderiv->deriv_classes[10][7][2] = int_stack + 638232;
 Libderiv->deriv_classes[10][8][2] = int_stack + 640608;
 Libderiv->deriv_classes[10][9][2] = int_stack + 643578;
 Libderiv->deriv_classes[10][10][2] = int_stack + 647208;
 Libderiv->deriv_classes[10][11][2] = int_stack + 651564;
 Libderiv->deriv_classes[10][12][2] = int_stack + 656712;
 Libderiv->deriv_classes[6][6][1] = int_stack + 662718;
 Libderiv->deriv_classes[6][7][1] = int_stack + 663502;
 Libderiv->deriv_classes[6][8][1] = int_stack + 664510;
 Libderiv->deriv_classes[6][9][1] = int_stack + 665770;
 Libderiv->deriv_classes[6][10][1] = int_stack + 667310;
 Libderiv->deriv_classes[6][11][1] = int_stack + 669158;
 Libderiv->deriv_classes[6][12][1] = int_stack + 671342;
 Libderiv->deriv_classes[7][6][1] = int_stack + 673890;
 Libderiv->deriv_classes[7][7][1] = int_stack + 674898;
 Libderiv->deriv_classes[7][8][1] = int_stack + 676194;
 Libderiv->deriv_classes[7][9][1] = int_stack + 677814;
 Libderiv->deriv_classes[7][10][1] = int_stack + 679794;
 Libderiv->deriv_classes[7][11][1] = int_stack + 682170;
 Libderiv->deriv_classes[7][12][1] = int_stack + 684978;
 Libderiv->deriv_classes[8][6][1] = int_stack + 688254;
 Libderiv->deriv_classes[8][7][1] = int_stack + 689514;
 Libderiv->deriv_classes[8][8][1] = int_stack + 691134;
 Libderiv->deriv_classes[8][9][1] = int_stack + 693159;
 Libderiv->deriv_classes[8][10][1] = int_stack + 695634;
 Libderiv->deriv_classes[8][11][1] = int_stack + 698604;
 Libderiv->deriv_classes[8][12][1] = int_stack + 702114;
 Libderiv->deriv_classes[9][6][1] = int_stack + 706209;
 Libderiv->deriv_classes[9][7][1] = int_stack + 707749;
 Libderiv->deriv_classes[9][8][1] = int_stack + 709729;
 Libderiv->deriv_classes[9][9][1] = int_stack + 712204;
 Libderiv->deriv_classes[9][10][1] = int_stack + 715229;
 Libderiv->deriv_classes[9][11][1] = int_stack + 718859;
 Libderiv->deriv_classes[9][12][1] = int_stack + 723149;
 Libderiv->deriv_classes[10][6][1] = int_stack + 728154;
 Libderiv->deriv_classes[10][7][1] = int_stack + 730002;
 Libderiv->deriv_classes[10][8][1] = int_stack + 732378;
 Libderiv->deriv_classes[10][9][1] = int_stack + 735348;
 Libderiv->deriv_classes[10][10][1] = int_stack + 738978;
 Libderiv->deriv_classes[10][11][1] = int_stack + 743334;
 Libderiv->deriv_classes[10][12][1] = int_stack + 748482;
 Libderiv->dvrr_classes[6][6] = int_stack + 754488;
 Libderiv->dvrr_classes[6][7] = int_stack + 755272;
 Libderiv->dvrr_classes[6][8] = int_stack + 756280;
 Libderiv->dvrr_classes[6][9] = int_stack + 757540;
 Libderiv->dvrr_classes[6][10] = int_stack + 759080;
 Libderiv->dvrr_classes[6][11] = int_stack + 760928;
 Libderiv->dvrr_classes[6][12] = int_stack + 763112;
 Libderiv->deriv_classes[6][6][0] = int_stack + 765660;
 Libderiv->deriv_classes[6][7][0] = int_stack + 766444;
 Libderiv->deriv_classes[6][8][0] = int_stack + 767452;
 Libderiv->deriv_classes[6][9][0] = int_stack + 768712;
 Libderiv->deriv_classes[6][10][0] = int_stack + 770252;
 Libderiv->deriv_classes[6][11][0] = int_stack + 772100;
 Libderiv->deriv_classes[6][12][0] = int_stack + 774284;
 Libderiv->dvrr_classes[7][6] = int_stack + 776832;
 Libderiv->dvrr_classes[7][7] = int_stack + 777840;
 Libderiv->dvrr_classes[7][8] = int_stack + 779136;
 Libderiv->dvrr_classes[7][9] = int_stack + 780756;
 Libderiv->dvrr_classes[7][10] = int_stack + 782736;
 Libderiv->dvrr_classes[7][11] = int_stack + 785112;
 Libderiv->dvrr_classes[7][12] = int_stack + 787920;
 Libderiv->deriv_classes[7][6][0] = int_stack + 791196;
 Libderiv->deriv_classes[7][7][0] = int_stack + 792204;
 Libderiv->deriv_classes[7][8][0] = int_stack + 793500;
 Libderiv->deriv_classes[7][9][0] = int_stack + 795120;
 Libderiv->deriv_classes[7][10][0] = int_stack + 797100;
 Libderiv->deriv_classes[7][11][0] = int_stack + 799476;
 Libderiv->deriv_classes[7][12][0] = int_stack + 802284;
 Libderiv->dvrr_classes[8][6] = int_stack + 805560;
 Libderiv->dvrr_classes[8][7] = int_stack + 806820;
 Libderiv->dvrr_classes[8][8] = int_stack + 808440;
 Libderiv->dvrr_classes[8][9] = int_stack + 810465;
 Libderiv->dvrr_classes[8][10] = int_stack + 812940;
 Libderiv->dvrr_classes[8][11] = int_stack + 815910;
 Libderiv->dvrr_classes[8][12] = int_stack + 819420;
 Libderiv->deriv_classes[8][6][0] = int_stack + 823515;
 Libderiv->deriv_classes[8][7][0] = int_stack + 824775;
 Libderiv->deriv_classes[8][8][0] = int_stack + 826395;
 Libderiv->deriv_classes[8][9][0] = int_stack + 828420;
 Libderiv->deriv_classes[8][10][0] = int_stack + 830895;
 Libderiv->deriv_classes[8][11][0] = int_stack + 833865;
 Libderiv->deriv_classes[8][12][0] = int_stack + 837375;
 Libderiv->dvrr_classes[9][6] = int_stack + 841470;
 Libderiv->dvrr_classes[9][7] = int_stack + 843010;
 Libderiv->dvrr_classes[9][8] = int_stack + 844990;
 Libderiv->dvrr_classes[9][9] = int_stack + 847465;
 Libderiv->dvrr_classes[9][10] = int_stack + 850490;
 Libderiv->dvrr_classes[9][11] = int_stack + 854120;
 Libderiv->dvrr_classes[9][12] = int_stack + 858410;
 Libderiv->deriv_classes[9][6][0] = int_stack + 863415;
 Libderiv->deriv_classes[9][7][0] = int_stack + 864955;
 Libderiv->deriv_classes[9][8][0] = int_stack + 866935;
 Libderiv->deriv_classes[9][9][0] = int_stack + 869410;
 Libderiv->deriv_classes[9][10][0] = int_stack + 872435;
 Libderiv->deriv_classes[9][11][0] = int_stack + 876065;
 Libderiv->deriv_classes[9][12][0] = int_stack + 880355;
 Libderiv->deriv_classes[10][6][0] = int_stack + 885360;
 Libderiv->deriv_classes[10][7][0] = int_stack + 887208;
 Libderiv->deriv_classes[10][8][0] = int_stack + 889584;
 Libderiv->deriv_classes[10][9][0] = int_stack + 892554;
 Libderiv->deriv_classes[10][10][0] = int_stack + 896184;
 Libderiv->deriv_classes[10][11][0] = int_stack + 900540;
 Libderiv->deriv_classes[10][12][0] = int_stack + 905688;
 memset(int_stack,0,7293552);

 Libderiv->dvrr_stack = int_stack + 6356992;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_igii(Libderiv, Data);
   Data++;
 }

 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+911694,int_stack+755272,int_stack+754488,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+914046,int_stack+756280,int_stack+755272,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+917070,int_stack+914046,int_stack+911694,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+921774,int_stack+757540,int_stack+756280,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+925554,int_stack+921774,int_stack+914046,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+931602,int_stack+925554,int_stack+917070,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+939442,int_stack+759080,int_stack+757540,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+944062,int_stack+939442,int_stack+921774,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+951622,int_stack+944062,int_stack+925554,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+961702,int_stack+951622,int_stack+931602,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+973462,int_stack+760928,int_stack+759080,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+979006,int_stack+973462,int_stack+939442,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+988246,int_stack+979006,int_stack+944062,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1000846,int_stack+988246,int_stack+951622,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1015966,int_stack+1000846,int_stack+961702,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1032430,int_stack+784,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+754488,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1034782,int_stack+1792,int_stack+784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+755272,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1037806,int_stack+1034782,int_stack+1032430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+911694,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1042510,int_stack+3052,int_stack+1792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756280,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1046290,int_stack+1042510,int_stack+1034782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+914046,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1052338,int_stack+1046290,int_stack+1037806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+917070,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1032430,int_stack+4592,int_stack+3052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+757540,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1060178,int_stack+1032430,int_stack+1042510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921774,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1067738,int_stack+1060178,int_stack+1046290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925554,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1037050,int_stack+1067738,int_stack+1052338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+931602,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1048810,int_stack+6440,int_stack+4592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+759080,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1077818,int_stack+1048810,int_stack+1032430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+939442,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1087058,int_stack+1077818,int_stack+1060178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+944062,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1099658,int_stack+1087058,int_stack+1067738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+951622,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1054354,int_stack+1099658,int_stack+1037050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+961702,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1032430,int_stack+8624,int_stack+6440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760928,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+1032430,int_stack+1048810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973462,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1032430,int_stack+0,int_stack+1077818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+979006,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1114778,int_stack+1032430,int_stack+1087058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+988246,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1032430,int_stack+1114778,int_stack+1099658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000846,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1070818,int_stack+1032430,int_stack+1054354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1015966,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1032430,int_stack+777840,int_stack+776832,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1035454,int_stack+779136,int_stack+777840,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1039342,int_stack+1035454,int_stack+1032430,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1045390,int_stack+780756,int_stack+779136,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1050250,int_stack+1045390,int_stack+1035454,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1058026,int_stack+1050250,int_stack+1039342,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+782736,int_stack+780756,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1092770,int_stack+0,int_stack+1045390,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1102490,int_stack+1092770,int_stack+1050250,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1115450,int_stack+1102490,int_stack+1058026,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1130570,int_stack+785112,int_stack+782736,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1137698,int_stack+1130570,int_stack+0,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1149578,int_stack+1137698,int_stack+1092770,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1165778,int_stack+1149578,int_stack+1102490,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1185218,int_stack+1165778,int_stack+1115450,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5940,int_stack+12180,int_stack+11172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776832,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1206386,int_stack+13476,int_stack+12180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777840,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1210274,int_stack+1206386,int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1032430,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5940,int_stack+15096,int_stack+13476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+779136,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1216322,int_stack+5940,int_stack+1206386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035454,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1224098,int_stack+1216322,int_stack+1210274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1039342,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1206386,int_stack+17076,int_stack+15096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780756,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1234178,int_stack+1206386,int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1045390,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1243898,int_stack+1234178,int_stack+1216322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050250,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1256858,int_stack+1243898,int_stack+1224098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058026,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+5940,int_stack+19452,int_stack+17076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782736,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1212326,int_stack+5940,int_stack+1206386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1271978,int_stack+1212326,int_stack+1234178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1092770,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1224206,int_stack+1271978,int_stack+1243898, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1102490,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1288178,int_stack+1224206,int_stack+1256858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1115450,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1243646,int_stack+22260,int_stack+19452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+785112,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1252070,int_stack+1243646,int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1130570,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1309346,int_stack+1252070,int_stack+1212326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1137698,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1243646,int_stack+1309346,int_stack+1271978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149578,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1309346,int_stack+1243646,int_stack+1224206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1165778,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1206386,int_stack+1309346,int_stack+1288178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1185218,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1234610,int_stack+1206386,int_stack+1070818,784);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5940,int_stack+806820,int_stack+805560,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9720,int_stack+808440,int_stack+806820,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+14580,int_stack+9720,int_stack+5940,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1300466,int_stack+810465,int_stack+808440,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1306541,int_stack+1300466,int_stack+9720,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1316261,int_stack+1306541,int_stack+14580,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1328861,int_stack+812940,int_stack+810465,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1068106,int_stack+1328861,int_stack+1300466,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1336286,int_stack+1068106,int_stack+1306541,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1352486,int_stack+1336286,int_stack+1316261,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1080256,int_stack+815910,int_stack+812940,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1371386,int_stack+1080256,int_stack+1328861,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1386236,int_stack+1371386,int_stack+1068106,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1406486,int_stack+1386236,int_stack+1336286,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1430786,int_stack+1406486,int_stack+1352486,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1457246,int_stack+26796,int_stack+25536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+805560,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1461026,int_stack+28416,int_stack+26796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+806820,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1465886,int_stack+1461026,int_stack+1457246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5940,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+22140,int_stack+30441,int_stack+28416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+808440,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1473446,int_stack+22140,int_stack+1461026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9720,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1483166,int_stack+1473446,int_stack+1465886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14580,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1457246,int_stack+32916,int_stack+30441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+810465,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1495766,int_stack+1457246,int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1300466,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1507916,int_stack+1495766,int_stack+1473446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1306541,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1524116,int_stack+1507916,int_stack+1483166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1316261,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+22140,int_stack+35886,int_stack+32916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+812940,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1464671,int_stack+22140,int_stack+1457246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1328861,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1543016,int_stack+1464671,int_stack+1495766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1068106,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1479521,int_stack+1543016,int_stack+1507916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336286,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1563266,int_stack+1479521,int_stack+1524116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1352486,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1503821,int_stack+39396,int_stack+35886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815910,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1514351,int_stack+1503821,int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080256,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1589726,int_stack+1514351,int_stack+1464671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1371386,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1503821,int_stack+1589726,int_stack+1543016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1386236,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1589726,int_stack+1503821,int_stack+1479521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1406486,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1457246,int_stack+1589726,int_stack+1563266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1430786,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1492526,int_stack+1457246,int_stack+1206386,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1577198,int_stack+1492526,int_stack+1234610,784);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1206386,int_stack+843010,int_stack+841470,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1211006,int_stack+844990,int_stack+843010,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1216946,int_stack+1211006,int_stack+1206386,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1226186,int_stack+847465,int_stack+844990,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1233611,int_stack+1226186,int_stack+1211006,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1245491,int_stack+1233611,int_stack+1216946,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1260891,int_stack+850490,int_stack+847465,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1269966,int_stack+1260891,int_stack+1226186,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+22140,int_stack+1269966,int_stack+1233611,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1708910,int_stack+22140,int_stack+1245491,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1284816,int_stack+854120,int_stack+850490,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1732010,int_stack+1284816,int_stack+1260891,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1750160,int_stack+1732010,int_stack+1269966,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1774910,int_stack+1750160,int_stack+22140,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1804610,int_stack+1774910,int_stack+1708910,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1295706,int_stack+45031,int_stack+43491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+841470,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1836950,int_stack+47011,int_stack+45031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+843010,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1842890,int_stack+1836950,int_stack+1295706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1206386,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1852130,int_stack+49486,int_stack+47011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+844990,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1859555,int_stack+1852130,int_stack+1836950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1211006,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1871435,int_stack+1859555,int_stack+1842890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1216946,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1836950,int_stack+52511,int_stack+49486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+847465,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1886835,int_stack+1836950,int_stack+1852130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1226186,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1901685,int_stack+1886835,int_stack+1859555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233611,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1846025,int_stack+1901685,int_stack+1871435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1245491,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1869125,int_stack+56141,int_stack+52511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850490,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1921485,int_stack+1869125,int_stack+1836950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260891,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1939635,int_stack+1921485,int_stack+1886835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1269966,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1964385,int_stack+1939635,int_stack+1901685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22140,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1880015,int_stack+1964385,int_stack+1846025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1708910,55);
 /*--- compute (m0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1836950,int_stack+60431,int_stack+56141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+854120,55);
 /*--- compute (m0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+41940,int_stack+1836950,int_stack+1869125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1284816,55);
 /*--- compute (m0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1836950,int_stack+41940,int_stack+1921485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1732010,55);
 /*--- compute (m0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1994085,int_stack+1836950,int_stack+1939635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1750160,55);
 /*--- compute (m0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1836950,int_stack+1994085,int_stack+1964385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1774910,55);
 /*--- compute (m0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1912355,int_stack+1836950,int_stack+1880015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1804610,55);
 /*--- compute (lp|ii) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1955475,int_stack+1912355,int_stack+1457246,784);
 /*--- compute (kd|ii) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+2061315,int_stack+1955475,int_stack+1492526,784);
 /*--- compute (if|ii) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+2230659,int_stack+2061315,int_stack+1577198,784);
 /*--- compute (n0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1457246,int_stack+527982,int_stack+524286,66);
 /*--- compute (n0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1462790,int_stack+532734,int_stack+527982,66);
 /*--- compute (n0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1469918,int_stack+1462790,int_stack+1457246,66);
 /*--- compute (n0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1481006,int_stack+538674,int_stack+532734,66);
 /*--- compute (n0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1489916,int_stack+1481006,int_stack+1462790,66);
 /*--- compute (n0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1504172,int_stack+1489916,int_stack+1469918,66);
 /*--- compute (n0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1522652,int_stack+545934,int_stack+538674,66);
 /*--- compute (n0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1533542,int_stack+1522652,int_stack+1481006,66);
 /*--- compute (n0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1551362,int_stack+1533542,int_stack+1489916,66);
 /*--- compute (n0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1575122,int_stack+1551362,int_stack+1504172,66);
 /*--- compute (n0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1602842,int_stack+554646,int_stack+545934,66);
 /*--- compute (n0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1615910,int_stack+1602842,int_stack+1522652,66);
 /*--- compute (n0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1637690,int_stack+1615910,int_stack+1533542,66);
 /*--- compute (n0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1667390,int_stack+1637690,int_stack+1551362,66);
 /*--- compute (n0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1836950,int_stack+1667390,int_stack+1575122,66);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1703030,int_stack+67284,int_stack+65436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524286,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1875758,int_stack+69660,int_stack+67284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527982,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1882886,int_stack+1875758,int_stack+1703030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1457246,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1893974,int_stack+72630,int_stack+69660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+532734,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+41940,int_stack+1893974,int_stack+1875758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1462790,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2450179,int_stack+41940,int_stack+1882886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1469918,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1875758,int_stack+76260,int_stack+72630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+538674,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+56196,int_stack+1875758,int_stack+1893974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1481006,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1886648,int_stack+56196,int_stack+41940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1489916,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2468659,int_stack+1886648,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1504172,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2450179,int_stack+80616,int_stack+76260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545934,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2496379,int_stack+2450179,int_stack+1875758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1522652,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2518159,int_stack+2496379,int_stack+56196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1533542,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+41940,int_stack+2518159,int_stack+1886648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1551362,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2547859,int_stack+41940,int_stack+2468659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1575122,66);
 /*--- compute (n0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1875758,int_stack+85764,int_stack+80616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554646,66);
 /*--- compute (n0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2463247,int_stack+1875758,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1602842,66);
 /*--- compute (n0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1875758,int_stack+2463247,int_stack+2496379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1615910,66);
 /*--- compute (n0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2450179,int_stack+1875758,int_stack+2518159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1637690,66);
 /*--- compute (n0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2494729,int_stack+2450179,int_stack+41940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1667390,66);
 /*--- compute (n0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2586667,int_stack+2494729,int_stack+2547859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1836950,66);
 /*--- compute (mp|ii) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+2450179,int_stack+2586667,int_stack+1912355,784);
 /*--- compute (ld|ii) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+2579539,int_stack+2450179,int_stack+1955475,784);
 /*--- compute (kf|ii) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+2791219,int_stack+2579539,int_stack+2061315,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+92554,int_stack+91770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+754488, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2452531,int_stack+93562,int_stack+92554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+755272, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2455555,int_stack+2452531,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+911694, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2460259,int_stack+94822,int_stack+93562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756280, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2464039,int_stack+2460259,int_stack+2452531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+914046, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2470087,int_stack+2464039,int_stack+2455555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+917070, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+96362,int_stack+94822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+757540, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2477927,int_stack+2450179,int_stack+2460259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921774, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2485487,int_stack+2477927,int_stack+2464039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925554, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2454799,int_stack+2485487,int_stack+2470087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+931602, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2466559,int_stack+98210,int_stack+96362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+759080, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2495567,int_stack+2466559,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+939442, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2504807,int_stack+2495567,int_stack+2477927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+944062, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2517407,int_stack+2504807,int_stack+2485487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+951622, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2472103,int_stack+2517407,int_stack+2454799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+961702, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+100394,int_stack+98210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760928, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2532527,int_stack+2450179,int_stack+2466559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973462, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2532527,int_stack+2495567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+979006, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2532527,int_stack+2450179,int_stack+2504807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+988246, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2532527,int_stack+2517407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000846, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2488567,int_stack+2450179,int_stack+2472103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1015966, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+103950,int_stack+102942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776832, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2453203,int_stack+105246,int_stack+103950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777840, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2457091,int_stack+2453203,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1032430, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2463139,int_stack+106866,int_stack+105246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+779136, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2467999,int_stack+2463139,int_stack+2453203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035454, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2475775,int_stack+2467999,int_stack+2457091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1039342, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+108846,int_stack+106866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780756, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2510519,int_stack+2450179,int_stack+2463139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1045390, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2520239,int_stack+2510519,int_stack+2467999, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050250, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2456119,int_stack+2520239,int_stack+2475775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058026, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2471239,int_stack+111222,int_stack+108846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782736, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2533199,int_stack+2471239,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2545079,int_stack+2533199,int_stack+2510519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1092770, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2561279,int_stack+2545079,int_stack+2520239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1102490, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2510519,int_stack+2561279,int_stack+2456119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1115450, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+114030,int_stack+111222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+785112, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2580719,int_stack+2450179,int_stack+2471239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1130570, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2580719,int_stack+2533199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1137698, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2580719,int_stack+2450179,int_stack+2545079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149578, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2580719,int_stack+2561279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1165778, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2531687,int_stack+2450179,int_stack+2510519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1185218, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2559911,int_stack+2531687,int_stack+2488567,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+118566,int_stack+117306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+805560, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2453959,int_stack+120186,int_stack+118566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+806820, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2458819,int_stack+2453959,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5940, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2466379,int_stack+122211,int_stack+120186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+808440, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2472454,int_stack+2466379,int_stack+2453959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9720, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2482174,int_stack+2472454,int_stack+2458819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14580, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+124686,int_stack+122211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+810465, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2494774,int_stack+2450179,int_stack+2466379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1300466, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2506924,int_stack+2494774,int_stack+2472454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1306541, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2457604,int_stack+2506924,int_stack+2482174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1316261, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2476504,int_stack+127656,int_stack+124686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+812940, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2625767,int_stack+2476504,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1328861, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2640617,int_stack+2625767,int_stack+2494774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1068106, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2660867,int_stack+2640617,int_stack+2506924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336286, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2485414,int_stack+2660867,int_stack+2457604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1352486, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+131166,int_stack+127656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815910, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2511874,int_stack+2450179,int_stack+2476504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080256, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2511874,int_stack+2625767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1371386, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2685167,int_stack+2450179,int_stack+2640617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1386236, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2685167,int_stack+2660867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1406486, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2625767,int_stack+2450179,int_stack+2485414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1430786, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2661047,int_stack+2625767,int_stack+2531687,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1875758,int_stack+2661047,int_stack+2559911,784);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+136801,int_stack+135261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+841470, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2454799,int_stack+138781,int_stack+136801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+843010, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2460739,int_stack+2454799,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1206386, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2469979,int_stack+141256,int_stack+138781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+844990, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2477404,int_stack+2469979,int_stack+2454799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1211006, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2489284,int_stack+2477404,int_stack+2460739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1216946, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+144281,int_stack+141256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+847465, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2504684,int_stack+2450179,int_stack+2469979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1226186, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2519534,int_stack+2504684,int_stack+2477404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233611, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2459254,int_stack+2519534,int_stack+2489284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1245491, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2482354,int_stack+147911,int_stack+144281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850490, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2539334,int_stack+2482354,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260891, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2557484,int_stack+2539334,int_stack+2504684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1269966, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2582234,int_stack+2557484,int_stack+2519534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22140, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2493244,int_stack+2582234,int_stack+2459254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1708910, 0.0, zero_stack,55);
 /*--- compute (m0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+152201,int_stack+147911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+854120, 0.0, zero_stack,55);
 /*--- compute (m0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2745719,int_stack+2450179,int_stack+2482354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1284816, 0.0, zero_stack,55);
 /*--- compute (m0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2745719,int_stack+2539334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1732010, 0.0, zero_stack,55);
 /*--- compute (m0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2745719,int_stack+2450179,int_stack+2557484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1750160, 0.0, zero_stack,55);
 /*--- compute (m0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2745719,int_stack+2582234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1774910, 0.0, zero_stack,55);
 /*--- compute (m0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2745719,int_stack+2450179,int_stack+2493244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1804610, 0.0, zero_stack,55);
 /*--- compute (lp|ii) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+2450179,int_stack+2745719,int_stack+2625767,784);
 /*--- compute (kd|ii) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+2007470,int_stack+2450179,int_stack+2661047,784);
 /*--- compute (if|ii) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+3073459,int_stack+2007470,int_stack+1875758,784);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1875758,int_stack+159054,int_stack+157206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524286, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1881302,int_stack+161430,int_stack+159054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527982, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1888430,int_stack+1881302,int_stack+1875758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1457246, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1899518,int_stack+164400,int_stack+161430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+532734, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1908428,int_stack+1899518,int_stack+1881302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1462790, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1922684,int_stack+1908428,int_stack+1888430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1469918, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1875758,int_stack+168030,int_stack+164400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+538674, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1941164,int_stack+1875758,int_stack+1899518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1481006, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1958984,int_stack+1941164,int_stack+1908428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1489916, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1886648,int_stack+1958984,int_stack+1922684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1504172, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1914368,int_stack+172386,int_stack+168030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545934, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1982744,int_stack+1914368,int_stack+1875758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1522652, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2556019,int_stack+1982744,int_stack+1941164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1533542, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2585719,int_stack+2556019,int_stack+1958984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1551362, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1927436,int_stack+2585719,int_stack+1886648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1575122, 0.0, zero_stack,66);
 /*--- compute (n0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1875758,int_stack+177534,int_stack+172386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554646, 0.0, zero_stack,66);
 /*--- compute (n0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2621359,int_stack+1875758,int_stack+1914368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1602842, 0.0, zero_stack,66);
 /*--- compute (n0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1875758,int_stack+2621359,int_stack+1982744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1615910, 0.0, zero_stack,66);
 /*--- compute (n0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2621359,int_stack+1875758,int_stack+2556019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1637690, 0.0, zero_stack,66);
 /*--- compute (n0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1875758,int_stack+2621359,int_stack+2585719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1667390, 0.0, zero_stack,66);
 /*--- compute (n0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2556019,int_stack+1875758,int_stack+1927436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1836950, 0.0, zero_stack,66);
 /*--- compute (mp|ii) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1875758,int_stack+2556019,int_stack+2745719,784);
 /*--- compute (ld|ii) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+2556019,int_stack+1875758,int_stack+2450179,784);
 /*--- compute (kf|ii) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+3292979,int_stack+2556019,int_stack+2007470,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+184324,int_stack+183540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+754488, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2452531,int_stack+185332,int_stack+184324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+755272, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2455555,int_stack+2452531,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+911694, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2460259,int_stack+186592,int_stack+185332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756280, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2464039,int_stack+2460259,int_stack+2452531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+914046, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2470087,int_stack+2464039,int_stack+2455555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+917070, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+188132,int_stack+186592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+757540, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2477927,int_stack+2450179,int_stack+2460259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921774, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2485487,int_stack+2477927,int_stack+2464039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925554, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2454799,int_stack+2485487,int_stack+2470087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+931602, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2466559,int_stack+189980,int_stack+188132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+759080, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2495567,int_stack+2466559,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+939442, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2504807,int_stack+2495567,int_stack+2477927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+944062, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2517407,int_stack+2504807,int_stack+2485487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+951622, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2472103,int_stack+2517407,int_stack+2454799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+961702, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+192164,int_stack+189980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760928, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2532527,int_stack+2450179,int_stack+2466559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973462, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2532527,int_stack+2495567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+979006, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2532527,int_stack+2450179,int_stack+2504807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+988246, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2532527,int_stack+2517407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000846, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2488567,int_stack+2450179,int_stack+2472103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1015966, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+195720,int_stack+194712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776832, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2453203,int_stack+197016,int_stack+195720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777840, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2457091,int_stack+2453203,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1032430, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2463139,int_stack+198636,int_stack+197016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+779136, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2467999,int_stack+2463139,int_stack+2453203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035454, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2475775,int_stack+2467999,int_stack+2457091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1039342, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+200616,int_stack+198636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780756, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2510519,int_stack+2450179,int_stack+2463139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1045390, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2520239,int_stack+2510519,int_stack+2467999, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050250, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2456119,int_stack+2520239,int_stack+2475775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058026, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2471239,int_stack+202992,int_stack+200616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782736, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2533199,int_stack+2471239,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2545079,int_stack+2533199,int_stack+2510519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1092770, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2561279,int_stack+2545079,int_stack+2520239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1102490, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2510519,int_stack+2561279,int_stack+2456119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1115450, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+205800,int_stack+202992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+785112, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2580719,int_stack+2450179,int_stack+2471239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1130570, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2580719,int_stack+2533199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1137698, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2580719,int_stack+2450179,int_stack+2545079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149578, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2580719,int_stack+2561279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1165778, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2531687,int_stack+2450179,int_stack+2510519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1185218, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2559911,int_stack+2531687,int_stack+2488567,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+210336,int_stack+209076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+805560, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2453959,int_stack+211956,int_stack+210336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+806820, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2458819,int_stack+2453959,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5940, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2466379,int_stack+213981,int_stack+211956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+808440, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2472454,int_stack+2466379,int_stack+2453959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9720, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2482174,int_stack+2472454,int_stack+2458819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14580, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+216456,int_stack+213981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+810465, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2494774,int_stack+2450179,int_stack+2466379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1300466, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2506924,int_stack+2494774,int_stack+2472454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1306541, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2457604,int_stack+2506924,int_stack+2482174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1316261, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2476504,int_stack+219426,int_stack+216456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+812940, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2625767,int_stack+2476504,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1328861, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2640617,int_stack+2625767,int_stack+2494774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1068106, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2660867,int_stack+2640617,int_stack+2506924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336286, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2485414,int_stack+2660867,int_stack+2457604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1352486, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+222936,int_stack+219426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815910, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2511874,int_stack+2450179,int_stack+2476504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080256, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2511874,int_stack+2625767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1371386, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2685167,int_stack+2450179,int_stack+2640617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1386236, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2685167,int_stack+2660867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1406486, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2625767,int_stack+2450179,int_stack+2485414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1430786, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2661047,int_stack+2625767,int_stack+2531687,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1875758,int_stack+2661047,int_stack+2559911,784);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+228571,int_stack+227031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+841470, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2454799,int_stack+230551,int_stack+228571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+843010, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2460739,int_stack+2454799,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1206386, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2469979,int_stack+233026,int_stack+230551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+844990, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2477404,int_stack+2469979,int_stack+2454799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1211006, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2489284,int_stack+2477404,int_stack+2460739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1216946, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+236051,int_stack+233026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+847465, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2504684,int_stack+2450179,int_stack+2469979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1226186, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2519534,int_stack+2504684,int_stack+2477404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233611, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2459254,int_stack+2519534,int_stack+2489284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1245491, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2482354,int_stack+239681,int_stack+236051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850490, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2539334,int_stack+2482354,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260891, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2557484,int_stack+2539334,int_stack+2504684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1269966, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2582234,int_stack+2557484,int_stack+2519534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22140, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2493244,int_stack+2582234,int_stack+2459254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1708910, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+243971,int_stack+239681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+854120, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2745719,int_stack+2450179,int_stack+2482354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1284816, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2745719,int_stack+2539334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1732010, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2745719,int_stack+2450179,int_stack+2557484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1750160, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2745719,int_stack+2582234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1774910, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2745719,int_stack+2450179,int_stack+2493244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1804610, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ii) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+2450179,int_stack+2745719,int_stack+2625767,784);
 /*--- compute (kd|ii) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+2007470,int_stack+2450179,int_stack+2661047,784);
 /*--- compute (if|ii) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+3575219,int_stack+2007470,int_stack+1875758,784);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1875758,int_stack+250824,int_stack+248976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524286, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1881302,int_stack+253200,int_stack+250824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527982, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1888430,int_stack+1881302,int_stack+1875758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1457246, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1899518,int_stack+256170,int_stack+253200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+532734, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1908428,int_stack+1899518,int_stack+1881302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1462790, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1922684,int_stack+1908428,int_stack+1888430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1469918, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1875758,int_stack+259800,int_stack+256170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+538674, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1941164,int_stack+1875758,int_stack+1899518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1481006, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1958984,int_stack+1941164,int_stack+1908428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1489916, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1886648,int_stack+1958984,int_stack+1922684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1504172, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1914368,int_stack+264156,int_stack+259800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545934, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1982744,int_stack+1914368,int_stack+1875758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1522652, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2556019,int_stack+1982744,int_stack+1941164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1533542, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2585719,int_stack+2556019,int_stack+1958984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1551362, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1927436,int_stack+2585719,int_stack+1886648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1575122, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1875758,int_stack+269304,int_stack+264156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554646, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2621359,int_stack+1875758,int_stack+1914368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1602842, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1875758,int_stack+2621359,int_stack+1982744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1615910, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2621359,int_stack+1875758,int_stack+2556019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1637690, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1875758,int_stack+2621359,int_stack+2585719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1667390, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2556019,int_stack+1875758,int_stack+1927436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1836950, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (mp|ii) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1875758,int_stack+2556019,int_stack+2745719,784);
 /*--- compute (ld|ii) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+2556019,int_stack+1875758,int_stack+2450179,784);
 /*--- compute (kf|ii) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+3794739,int_stack+2556019,int_stack+2007470,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+276094,int_stack+275310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+754488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2452531,int_stack+277102,int_stack+276094, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+755272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2455555,int_stack+2452531,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+911694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2460259,int_stack+278362,int_stack+277102, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2464039,int_stack+2460259,int_stack+2452531, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+914046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2470087,int_stack+2464039,int_stack+2455555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+917070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+279902,int_stack+278362, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+757540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2477927,int_stack+2450179,int_stack+2460259, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2485487,int_stack+2477927,int_stack+2464039, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+925554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2454799,int_stack+2485487,int_stack+2470087, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+931602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2466559,int_stack+281750,int_stack+279902, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+759080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2495567,int_stack+2466559,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+939442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2504807,int_stack+2495567,int_stack+2477927, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+944062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2517407,int_stack+2504807,int_stack+2485487, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+951622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2472103,int_stack+2517407,int_stack+2454799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+961702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+283934,int_stack+281750, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2532527,int_stack+2450179,int_stack+2466559, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+973462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2532527,int_stack+2495567, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+979006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2532527,int_stack+2450179,int_stack+2504807, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+988246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2532527,int_stack+2517407, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2488567,int_stack+2450179,int_stack+2472103, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1015966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+287490,int_stack+286482, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2453203,int_stack+288786,int_stack+287490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2457091,int_stack+2453203,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1032430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2463139,int_stack+290406,int_stack+288786, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+779136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2467999,int_stack+2463139,int_stack+2453203, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2475775,int_stack+2467999,int_stack+2457091, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1039342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+292386,int_stack+290406, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2510519,int_stack+2450179,int_stack+2463139, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1045390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2520239,int_stack+2510519,int_stack+2467999, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2456119,int_stack+2520239,int_stack+2475775, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2471239,int_stack+294762,int_stack+292386, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2533199,int_stack+2471239,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2545079,int_stack+2533199,int_stack+2510519, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1092770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2561279,int_stack+2545079,int_stack+2520239, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1102490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2510519,int_stack+2561279,int_stack+2456119, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1115450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+297570,int_stack+294762, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+785112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2580719,int_stack+2450179,int_stack+2471239, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1130570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2580719,int_stack+2533199, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1137698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2580719,int_stack+2450179,int_stack+2545079, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2580719,int_stack+2561279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1165778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2531687,int_stack+2450179,int_stack+2510519, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1185218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2559911,int_stack+2531687,int_stack+2488567,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+302106,int_stack+300846, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+805560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2453959,int_stack+303726,int_stack+302106, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+806820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2458819,int_stack+2453959,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2466379,int_stack+305751,int_stack+303726, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+808440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2472454,int_stack+2466379,int_stack+2453959, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2482174,int_stack+2472454,int_stack+2458819, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+308226,int_stack+305751, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+810465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2494774,int_stack+2450179,int_stack+2466379, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1300466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2506924,int_stack+2494774,int_stack+2472454, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1306541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2457604,int_stack+2506924,int_stack+2482174, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1316261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2476504,int_stack+311196,int_stack+308226, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+812940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2625767,int_stack+2476504,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1328861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2640617,int_stack+2625767,int_stack+2494774, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1068106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2660867,int_stack+2640617,int_stack+2506924, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2485414,int_stack+2660867,int_stack+2457604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1352486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+314706,int_stack+311196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2511874,int_stack+2450179,int_stack+2476504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2511874,int_stack+2625767, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1371386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2685167,int_stack+2450179,int_stack+2640617, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1386236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2685167,int_stack+2660867, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1406486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2625767,int_stack+2450179,int_stack+2485414, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1430786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2661047,int_stack+2625767,int_stack+2531687,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1875758,int_stack+2661047,int_stack+2559911,784);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+320341,int_stack+318801, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+841470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2454799,int_stack+322321,int_stack+320341, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+843010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2460739,int_stack+2454799,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1206386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2469979,int_stack+324796,int_stack+322321, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+844990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2477404,int_stack+2469979,int_stack+2454799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1211006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2489284,int_stack+2477404,int_stack+2460739, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1216946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+327821,int_stack+324796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+847465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2504684,int_stack+2450179,int_stack+2469979, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1226186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2519534,int_stack+2504684,int_stack+2477404, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2459254,int_stack+2519534,int_stack+2489284, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1245491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2482354,int_stack+331451,int_stack+327821, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2539334,int_stack+2482354,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2557484,int_stack+2539334,int_stack+2504684, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1269966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2582234,int_stack+2557484,int_stack+2519534, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2493244,int_stack+2582234,int_stack+2459254, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1708910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+335741,int_stack+331451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+854120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2745719,int_stack+2450179,int_stack+2482354, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1284816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2745719,int_stack+2539334, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1732010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2745719,int_stack+2450179,int_stack+2557484, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1750160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2745719,int_stack+2582234, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1774910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2745719,int_stack+2450179,int_stack+2493244, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1804610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ii) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+2450179,int_stack+2745719,int_stack+2625767,784);
 /*--- compute (kd|ii) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+2007470,int_stack+2450179,int_stack+2661047,784);
 /*--- compute (if|ii) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+41940,int_stack+2007470,int_stack+1875758,784);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1875758,int_stack+342594,int_stack+340746, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1881302,int_stack+344970,int_stack+342594, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+527982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1888430,int_stack+1881302,int_stack+1875758, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1457246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1899518,int_stack+347940,int_stack+344970, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+532734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1908428,int_stack+1899518,int_stack+1881302, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1462790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1922684,int_stack+1908428,int_stack+1888430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1469918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1875758,int_stack+351570,int_stack+347940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+538674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1941164,int_stack+1875758,int_stack+1899518, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1481006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1958984,int_stack+1941164,int_stack+1908428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1489916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1886648,int_stack+1958984,int_stack+1922684, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1504172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1914368,int_stack+355926,int_stack+351570, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1982744,int_stack+1914368,int_stack+1875758, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1522652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2556019,int_stack+1982744,int_stack+1941164, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1533542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2585719,int_stack+2556019,int_stack+1958984, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1551362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1927436,int_stack+2585719,int_stack+1886648, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1575122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1875758,int_stack+361074,int_stack+355926, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2621359,int_stack+1875758,int_stack+1914368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1602842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1875758,int_stack+2621359,int_stack+1982744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1615910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2621359,int_stack+1875758,int_stack+2556019, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1637690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1875758,int_stack+2621359,int_stack+2585719, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1667390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2556019,int_stack+1875758,int_stack+1927436, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1836950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (mp|ii) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1875758,int_stack+2556019,int_stack+2745719,784);
 /*--- compute (ld|ii) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+2556019,int_stack+1875758,int_stack+2450179,784);
 /*--- compute (kf|ii) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+4076979,int_stack+2556019,int_stack+2007470,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+367864,int_stack+367080, 0.0, zero_stack, 1.0, int_stack+754488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2452531,int_stack+368872,int_stack+367864, 0.0, zero_stack, 1.0, int_stack+755272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2455555,int_stack+2452531,int_stack+2450179, 0.0, zero_stack, 1.0, int_stack+911694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2460259,int_stack+370132,int_stack+368872, 0.0, zero_stack, 1.0, int_stack+756280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2464039,int_stack+2460259,int_stack+2452531, 0.0, zero_stack, 1.0, int_stack+914046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2470087,int_stack+2464039,int_stack+2455555, 0.0, zero_stack, 1.0, int_stack+917070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+371672,int_stack+370132, 0.0, zero_stack, 1.0, int_stack+757540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2477927,int_stack+2450179,int_stack+2460259, 0.0, zero_stack, 1.0, int_stack+921774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2485487,int_stack+2477927,int_stack+2464039, 0.0, zero_stack, 1.0, int_stack+925554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2454799,int_stack+2485487,int_stack+2470087, 0.0, zero_stack, 1.0, int_stack+931602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2466559,int_stack+373520,int_stack+371672, 0.0, zero_stack, 1.0, int_stack+759080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2495567,int_stack+2466559,int_stack+2450179, 0.0, zero_stack, 1.0, int_stack+939442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2504807,int_stack+2495567,int_stack+2477927, 0.0, zero_stack, 1.0, int_stack+944062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2517407,int_stack+2504807,int_stack+2485487, 0.0, zero_stack, 1.0, int_stack+951622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2472103,int_stack+2517407,int_stack+2454799, 0.0, zero_stack, 1.0, int_stack+961702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+375704,int_stack+373520, 0.0, zero_stack, 1.0, int_stack+760928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2532527,int_stack+2450179,int_stack+2466559, 0.0, zero_stack, 1.0, int_stack+973462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2532527,int_stack+2495567, 0.0, zero_stack, 1.0, int_stack+979006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2532527,int_stack+2450179,int_stack+2504807, 0.0, zero_stack, 1.0, int_stack+988246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2532527,int_stack+2517407, 0.0, zero_stack, 1.0, int_stack+1000846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2488567,int_stack+2450179,int_stack+2472103, 0.0, zero_stack, 1.0, int_stack+1015966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+379260,int_stack+378252, 0.0, zero_stack, 1.0, int_stack+776832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2453203,int_stack+380556,int_stack+379260, 0.0, zero_stack, 1.0, int_stack+777840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2457091,int_stack+2453203,int_stack+2450179, 0.0, zero_stack, 1.0, int_stack+1032430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2463139,int_stack+382176,int_stack+380556, 0.0, zero_stack, 1.0, int_stack+779136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2467999,int_stack+2463139,int_stack+2453203, 0.0, zero_stack, 1.0, int_stack+1035454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2475775,int_stack+2467999,int_stack+2457091, 0.0, zero_stack, 1.0, int_stack+1039342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+384156,int_stack+382176, 0.0, zero_stack, 1.0, int_stack+780756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2510519,int_stack+2450179,int_stack+2463139, 0.0, zero_stack, 1.0, int_stack+1045390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2520239,int_stack+2510519,int_stack+2467999, 0.0, zero_stack, 1.0, int_stack+1050250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2456119,int_stack+2520239,int_stack+2475775, 0.0, zero_stack, 1.0, int_stack+1058026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2471239,int_stack+386532,int_stack+384156, 0.0, zero_stack, 1.0, int_stack+782736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2533199,int_stack+2471239,int_stack+2450179, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2545079,int_stack+2533199,int_stack+2510519, 0.0, zero_stack, 1.0, int_stack+1092770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2561279,int_stack+2545079,int_stack+2520239, 0.0, zero_stack, 1.0, int_stack+1102490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2510519,int_stack+2561279,int_stack+2456119, 0.0, zero_stack, 1.0, int_stack+1115450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+389340,int_stack+386532, 0.0, zero_stack, 1.0, int_stack+785112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2580719,int_stack+2450179,int_stack+2471239, 0.0, zero_stack, 1.0, int_stack+1130570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2580719,int_stack+2533199, 0.0, zero_stack, 1.0, int_stack+1137698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2580719,int_stack+2450179,int_stack+2545079, 0.0, zero_stack, 1.0, int_stack+1149578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2580719,int_stack+2561279, 0.0, zero_stack, 1.0, int_stack+1165778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2531687,int_stack+2450179,int_stack+2510519, 0.0, zero_stack, 1.0, int_stack+1185218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2559911,int_stack+2531687,int_stack+2488567,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+393876,int_stack+392616, 0.0, zero_stack, 1.0, int_stack+805560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2453959,int_stack+395496,int_stack+393876, 0.0, zero_stack, 1.0, int_stack+806820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2458819,int_stack+2453959,int_stack+2450179, 0.0, zero_stack, 1.0, int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2466379,int_stack+397521,int_stack+395496, 0.0, zero_stack, 1.0, int_stack+808440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2472454,int_stack+2466379,int_stack+2453959, 0.0, zero_stack, 1.0, int_stack+9720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2482174,int_stack+2472454,int_stack+2458819, 0.0, zero_stack, 1.0, int_stack+14580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+399996,int_stack+397521, 0.0, zero_stack, 1.0, int_stack+810465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2494774,int_stack+2450179,int_stack+2466379, 0.0, zero_stack, 1.0, int_stack+1300466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2506924,int_stack+2494774,int_stack+2472454, 0.0, zero_stack, 1.0, int_stack+1306541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2457604,int_stack+2506924,int_stack+2482174, 0.0, zero_stack, 1.0, int_stack+1316261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2476504,int_stack+402966,int_stack+399996, 0.0, zero_stack, 1.0, int_stack+812940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2625767,int_stack+2476504,int_stack+2450179, 0.0, zero_stack, 1.0, int_stack+1328861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2640617,int_stack+2625767,int_stack+2494774, 0.0, zero_stack, 1.0, int_stack+1068106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2660867,int_stack+2640617,int_stack+2506924, 0.0, zero_stack, 1.0, int_stack+1336286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2485414,int_stack+2660867,int_stack+2457604, 0.0, zero_stack, 1.0, int_stack+1352486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+406476,int_stack+402966, 0.0, zero_stack, 1.0, int_stack+815910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2511874,int_stack+2450179,int_stack+2476504, 0.0, zero_stack, 1.0, int_stack+1080256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2511874,int_stack+2625767, 0.0, zero_stack, 1.0, int_stack+1371386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2685167,int_stack+2450179,int_stack+2640617, 0.0, zero_stack, 1.0, int_stack+1386236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2685167,int_stack+2660867, 0.0, zero_stack, 1.0, int_stack+1406486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2625767,int_stack+2450179,int_stack+2485414, 0.0, zero_stack, 1.0, int_stack+1430786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2661047,int_stack+2625767,int_stack+2531687,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1875758,int_stack+2661047,int_stack+2559911,784);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+412111,int_stack+410571, 0.0, zero_stack, 1.0, int_stack+841470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2454799,int_stack+414091,int_stack+412111, 0.0, zero_stack, 1.0, int_stack+843010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2460739,int_stack+2454799,int_stack+2450179, 0.0, zero_stack, 1.0, int_stack+1206386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2469979,int_stack+416566,int_stack+414091, 0.0, zero_stack, 1.0, int_stack+844990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2477404,int_stack+2469979,int_stack+2454799, 0.0, zero_stack, 1.0, int_stack+1211006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2489284,int_stack+2477404,int_stack+2460739, 0.0, zero_stack, 1.0, int_stack+1216946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+419591,int_stack+416566, 0.0, zero_stack, 1.0, int_stack+847465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2504684,int_stack+2450179,int_stack+2469979, 0.0, zero_stack, 1.0, int_stack+1226186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2519534,int_stack+2504684,int_stack+2477404, 0.0, zero_stack, 1.0, int_stack+1233611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2459254,int_stack+2519534,int_stack+2489284, 0.0, zero_stack, 1.0, int_stack+1245491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2482354,int_stack+423221,int_stack+419591, 0.0, zero_stack, 1.0, int_stack+850490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2539334,int_stack+2482354,int_stack+2450179, 0.0, zero_stack, 1.0, int_stack+1260891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2557484,int_stack+2539334,int_stack+2504684, 0.0, zero_stack, 1.0, int_stack+1269966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2582234,int_stack+2557484,int_stack+2519534, 0.0, zero_stack, 1.0, int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2493244,int_stack+2582234,int_stack+2459254, 0.0, zero_stack, 1.0, int_stack+1708910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+427511,int_stack+423221, 0.0, zero_stack, 1.0, int_stack+854120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2745719,int_stack+2450179,int_stack+2482354, 0.0, zero_stack, 1.0, int_stack+1284816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2450179,int_stack+2745719,int_stack+2539334, 0.0, zero_stack, 1.0, int_stack+1732010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2745719,int_stack+2450179,int_stack+2557484, 0.0, zero_stack, 1.0, int_stack+1750160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2745719,int_stack+2582234, 0.0, zero_stack, 1.0, int_stack+1774910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2745719,int_stack+2450179,int_stack+2493244, 0.0, zero_stack, 1.0, int_stack+1804610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ii) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+2450179,int_stack+2745719,int_stack+2625767,784);
 /*--- compute (kd|ii) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+2007470,int_stack+2450179,int_stack+2661047,784);
 /*--- compute (if|ii) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+4359219,int_stack+2007470,int_stack+1875758,784);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1875758,int_stack+434364,int_stack+432516, 0.0, zero_stack, 1.0, int_stack+524286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1881302,int_stack+436740,int_stack+434364, 0.0, zero_stack, 1.0, int_stack+527982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1888430,int_stack+1881302,int_stack+1875758, 0.0, zero_stack, 1.0, int_stack+1457246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1899518,int_stack+439710,int_stack+436740, 0.0, zero_stack, 1.0, int_stack+532734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1908428,int_stack+1899518,int_stack+1881302, 0.0, zero_stack, 1.0, int_stack+1462790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1922684,int_stack+1908428,int_stack+1888430, 0.0, zero_stack, 1.0, int_stack+1469918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1875758,int_stack+443340,int_stack+439710, 0.0, zero_stack, 1.0, int_stack+538674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1941164,int_stack+1875758,int_stack+1899518, 0.0, zero_stack, 1.0, int_stack+1481006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1958984,int_stack+1941164,int_stack+1908428, 0.0, zero_stack, 1.0, int_stack+1489916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1886648,int_stack+1958984,int_stack+1922684, 0.0, zero_stack, 1.0, int_stack+1504172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1914368,int_stack+447696,int_stack+443340, 0.0, zero_stack, 1.0, int_stack+545934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1982744,int_stack+1914368,int_stack+1875758, 0.0, zero_stack, 1.0, int_stack+1522652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2556019,int_stack+1982744,int_stack+1941164, 0.0, zero_stack, 1.0, int_stack+1533542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2585719,int_stack+2556019,int_stack+1958984, 0.0, zero_stack, 1.0, int_stack+1551362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1927436,int_stack+2585719,int_stack+1886648, 0.0, zero_stack, 1.0, int_stack+1575122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1875758,int_stack+452844,int_stack+447696, 0.0, zero_stack, 1.0, int_stack+554646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2621359,int_stack+1875758,int_stack+1914368, 0.0, zero_stack, 1.0, int_stack+1602842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1875758,int_stack+2621359,int_stack+1982744, 0.0, zero_stack, 1.0, int_stack+1615910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2621359,int_stack+1875758,int_stack+2556019, 0.0, zero_stack, 1.0, int_stack+1637690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1875758,int_stack+2621359,int_stack+2585719, 0.0, zero_stack, 1.0, int_stack+1667390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2556019,int_stack+1875758,int_stack+1927436, 0.0, zero_stack, 1.0, int_stack+1836950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (mp|ii) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1875758,int_stack+2556019,int_stack+2745719,784);
 /*--- compute (ld|ii) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+2556019,int_stack+1875758,int_stack+2450179,784);
 /*--- compute (kf|ii) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+4578739,int_stack+2556019,int_stack+2007470,784);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+459634,int_stack+458850, 1.0, int_stack+754488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2452531,int_stack+460642,int_stack+459634, 1.0, int_stack+755272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2455555,int_stack+2452531,int_stack+2450179, 1.0, int_stack+911694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2460259,int_stack+461902,int_stack+460642, 1.0, int_stack+756280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2464039,int_stack+2460259,int_stack+2452531, 1.0, int_stack+914046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2470087,int_stack+2464039,int_stack+2455555, 1.0, int_stack+917070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+911694,int_stack+463442,int_stack+461902, 1.0, int_stack+757540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2450179,int_stack+911694,int_stack+2460259, 1.0, int_stack+921774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2477927,int_stack+2450179,int_stack+2464039, 1.0, int_stack+925554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+916314,int_stack+2477927,int_stack+2470087, 1.0, int_stack+931602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+928074,int_stack+465290,int_stack+463442, 1.0, int_stack+759080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2457739,int_stack+928074,int_stack+911694, 1.0, int_stack+939442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2488007,int_stack+2457739,int_stack+2450179, 1.0, int_stack+944062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+933618,int_stack+2488007,int_stack+2477927, 1.0, int_stack+951622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2466979,int_stack+933618,int_stack+916314, 1.0, int_stack+961702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+467474,int_stack+465290, 1.0, int_stack+760928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+911694,int_stack+2450179,int_stack+928074, 1.0, int_stack+973462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+948738,int_stack+911694,int_stack+2457739, 1.0, int_stack+979006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+911694,int_stack+948738,int_stack+2488007, 1.0, int_stack+988246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+948738,int_stack+911694,int_stack+933618, 1.0, int_stack+1000846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+911694,int_stack+948738,int_stack+2466979, 1.0, int_stack+1015966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+933646,int_stack+471030,int_stack+470022, 1.0, int_stack+776832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+936670,int_stack+472326,int_stack+471030, 1.0, int_stack+777840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+940558,int_stack+936670,int_stack+933646, 1.0, int_stack+1032430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+946606,int_stack+473946,int_stack+472326, 1.0, int_stack+779136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+951466,int_stack+946606,int_stack+936670, 1.0, int_stack+1035454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+959242,int_stack+951466,int_stack+940558, 1.0, int_stack+1039342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1032430,int_stack+475926,int_stack+473946, 1.0, int_stack+780756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+933646,int_stack+1032430,int_stack+946606, 1.0, int_stack+1045390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2450179,int_stack+933646,int_stack+951466, 1.0, int_stack+1050250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1038370,int_stack+2450179,int_stack+959242, 1.0, int_stack+1058026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1053490,int_stack+478302,int_stack+475926, 1.0, int_stack+782736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+943366,int_stack+1053490,int_stack+1032430, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+955246,int_stack+943366,int_stack+933646, 1.0, int_stack+1092770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2463139,int_stack+955246,int_stack+2450179, 1.0, int_stack+1102490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2482579,int_stack+2463139,int_stack+1038370, 1.0, int_stack+1115450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+2450179,int_stack+481110,int_stack+478302, 1.0, int_stack+785112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1032430,int_stack+2450179,int_stack+1053490, 1.0, int_stack+1130570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1046686,int_stack+1032430,int_stack+943366, 1.0, int_stack+1137698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2503747,int_stack+1046686,int_stack+955246, 1.0, int_stack+1149578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1032430,int_stack+2503747,int_stack+2463139, 1.0, int_stack+1165778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2503747,int_stack+1032430,int_stack+2482579, 1.0, int_stack+1185218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2531971,int_stack+2503747,int_stack+911694,784);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+911694,int_stack+485646,int_stack+484386, 1.0, int_stack+805560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+915474,int_stack+487266,int_stack+485646, 1.0, int_stack+806820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+920334,int_stack+915474,int_stack+911694, 1.0, int_stack+5940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+927894,int_stack+489291,int_stack+487266, 1.0, int_stack+808440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+927894,int_stack+915474, 1.0, int_stack+9720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+933969,int_stack+0,int_stack+920334, 1.0, int_stack+14580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+9720,int_stack+491766,int_stack+489291, 1.0, int_stack+810465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+911694,int_stack+9720,int_stack+927894, 1.0, int_stack+1300466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+946569,int_stack+911694,int_stack+0, 1.0, int_stack+1306541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1032430,int_stack+946569,int_stack+933969, 1.0, int_stack+1316261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+494736,int_stack+491766, 1.0, int_stack+812940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+923844,int_stack+0,int_stack+9720, 1.0, int_stack+1328861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2597827,int_stack+923844,int_stack+911694, 1.0, int_stack+1068106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1051330,int_stack+2597827,int_stack+946569, 1.0, int_stack+1336286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+938694,int_stack+1051330,int_stack+1032430, 1.0, int_stack+1352486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1032430,int_stack+498246,int_stack+494736, 1.0, int_stack+815910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+2618077,int_stack+1032430,int_stack+0, 1.0, int_stack+1080256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+2635897,int_stack+2618077,int_stack+923844, 1.0, int_stack+1371386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+2660647,int_stack+2635897,int_stack+2597827, 1.0, int_stack+1386236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+2597827,int_stack+2660647,int_stack+1051330, 1.0, int_stack+1406486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+2631847,int_stack+2597827,int_stack+938694, 1.0, int_stack+1430786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2667127,int_stack+2631847,int_stack+2503747,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1875758,int_stack+2667127,int_stack+2531971,784);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2751799,int_stack+503881,int_stack+502341, 1.0, int_stack+841470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2756419,int_stack+505861,int_stack+503881, 1.0, int_stack+843010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2762359,int_stack+2756419,int_stack+2751799, 1.0, int_stack+1206386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2771599,int_stack+508336,int_stack+505861, 1.0, int_stack+844990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2779024,int_stack+2771599,int_stack+2756419, 1.0, int_stack+1211006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+2779024,int_stack+2762359, 1.0, int_stack+1216946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1206386,int_stack+511361,int_stack+508336, 1.0, int_stack+847465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2751799,int_stack+1206386,int_stack+2771599, 1.0, int_stack+1226186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1032430,int_stack+2751799,int_stack+2779024, 1.0, int_stack+1233611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1215461,int_stack+1032430,int_stack+0, 1.0, int_stack+1245491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+514991,int_stack+511361, 1.0, int_stack+850490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1238561,int_stack+0,int_stack+1206386, 1.0, int_stack+1260891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1052230,int_stack+1238561,int_stack+2751799, 1.0, int_stack+1269966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2751799,int_stack+1052230,int_stack+1032430, 1.0, int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+911694,int_stack+2751799,int_stack+1215461, 1.0, int_stack+1708910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1032430,int_stack+519281,int_stack+514991, 1.0, int_stack+854120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1206386,int_stack+1032430,int_stack+0, 1.0, int_stack+1284816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+0,int_stack+1206386,int_stack+1238561, 1.0, int_stack+1732010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1206386,int_stack+0,int_stack+1052230, 1.0, int_stack+1750160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+0,int_stack+1206386,int_stack+2751799, 1.0, int_stack+1774910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1206386,int_stack+0,int_stack+911694, 1.0, int_stack+1804610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ii) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+2450179,int_stack+1206386,int_stack+2631847,784);
 /*--- compute (kd|ii) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+2007470,int_stack+2450179,int_stack+2667127,784);
 /*--- compute (if|ii) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+2556019,int_stack+2007470,int_stack+1875758,784);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1875758,int_stack+530358,int_stack+526134, 1.0, int_stack+524286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1881302,int_stack+535704,int_stack+530358, 1.0, int_stack+527982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1888430,int_stack+1881302,int_stack+1875758, 1.0, int_stack+1457246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1899518,int_stack+542304,int_stack+535704, 1.0, int_stack+532734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1908428,int_stack+1899518,int_stack+1881302, 1.0, int_stack+1462790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1922684,int_stack+1908428,int_stack+1888430, 1.0, int_stack+1469918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1457246,int_stack+550290,int_stack+542304, 1.0, int_stack+538674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1875758,int_stack+1457246,int_stack+1899518, 1.0, int_stack+1481006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1941164,int_stack+1875758,int_stack+1908428, 1.0, int_stack+1489916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1468136,int_stack+1941164,int_stack+1922684, 1.0, int_stack+1504172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1495856,int_stack+559794,int_stack+550290, 1.0, int_stack+545934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1893578,int_stack+1495856,int_stack+1457246, 1.0, int_stack+1522652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1964924,int_stack+1893578,int_stack+1875758, 1.0, int_stack+1533542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1508924,int_stack+1964924,int_stack+1941164, 1.0, int_stack+1551362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1915358,int_stack+1508924,int_stack+1468136, 1.0, int_stack+1575122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+1875758,int_stack+564942,int_stack+559794, 1.0, int_stack+554646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+1457246,int_stack+1875758,int_stack+1495856, 1.0, int_stack+1602842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+1544564,int_stack+1457246,int_stack+1893578, 1.0, int_stack+1615910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+1457246,int_stack+1544564,int_stack+1964924, 1.0, int_stack+1637690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+1544564,int_stack+1457246,int_stack+1508924, 1.0, int_stack+1667390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+1457246,int_stack+1544564,int_stack+1915358, 1.0, int_stack+1836950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (mp|ii) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1836950,int_stack+1457246,int_stack+1206386,784);
 /*--- compute (ld|ii) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+1457246,int_stack+1836950,int_stack+2450179,784);
 /*--- compute (kf|ii) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+261460,int_stack+1457246,int_stack+2007470,784);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1457246,int_stack+763112,int_stack+760928,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1463798,int_stack+1457246,int_stack+973462,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+1474886,int_stack+1463798,int_stack+979006,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1490286,int_stack+1474886,int_stack+988246,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1457246,int_stack+1490286,int_stack+1000846,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1478414,int_stack+1457246,int_stack+1015966,28);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1457246,int_stack+787920,int_stack+785112,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1500366,int_stack+1457246,int_stack+1130570,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+1457246,int_stack+1500366,int_stack+1137698,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1500366,int_stack+1457246,int_stack+1149578,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1524666,int_stack+1500366,int_stack+1165778,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1551882,int_stack+1524666,int_stack+1185218,36);
 /*--- compute (ip|ii) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1580106,int_stack+1551882,int_stack+1478414,784);
 /*--- compute (l0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1500366,int_stack+819420,int_stack+815910,45);
 /*--- compute (l0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1510896,int_stack+1500366,int_stack+1080256,45);
 /*--- compute (l0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+1645962,int_stack+1510896,int_stack+1371386,45);
 /*--- compute (l0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1500366,int_stack+1645962,int_stack+1386236,45);
 /*--- compute (l0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1645962,int_stack+1500366,int_stack+1406486,45);
 /*--- compute (l0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1500366,int_stack+1645962,int_stack+1430786,45);
 /*--- compute (kp|ii) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1645962,int_stack+1500366,int_stack+1551882,784);
 /*--- compute (id|ii) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1836950,int_stack+1645962,int_stack+1580106,784);
 /*--- compute (m0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1535646,int_stack+858410,int_stack+854120,55);
 /*--- compute (m0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+2450179,int_stack+1535646,int_stack+1284816,55);
 /*--- compute (m0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+2471959,int_stack+2450179,int_stack+1732010,55);
 /*--- compute (m0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+2502209,int_stack+2471959,int_stack+1750160,55);
 /*--- compute (m0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+2502209,int_stack+1774910,55);
 /*--- compute (m0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+2491759,int_stack+2450179,int_stack+1804610,55);
 /*--- compute (lp|ii) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1730634,int_stack+2491759,int_stack+1500366,784);
 /*--- compute (kd|ii) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1968662,int_stack+1730634,int_stack+1645962,784);
 /*--- compute (if|ii) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+911694,int_stack+1968662,int_stack+1836950,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+571732,int_stack+570948,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2452531,int_stack+572740,int_stack+571732,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2455555,int_stack+2452531,int_stack+2450179,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2460259,int_stack+574000,int_stack+572740,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2464039,int_stack+2460259,int_stack+2452531,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2470087,int_stack+2464039,int_stack+2455555,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+575540,int_stack+574000,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2477927,int_stack+2450179,int_stack+2460259,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2534879,int_stack+2477927,int_stack+2464039,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2454799,int_stack+2534879,int_stack+2470087,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2466559,int_stack+577388,int_stack+575540,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2544959,int_stack+2466559,int_stack+2450179,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1535646,int_stack+2544959,int_stack+2477927,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2472103,int_stack+1535646,int_stack+2534879,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2138006,int_stack+2472103,int_stack+2454799,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+2534879,int_stack+579572,int_stack+577388,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+2450179,int_stack+2534879,int_stack+2466559,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+2154470,int_stack+2450179,int_stack+2544959,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+2450179,int_stack+2154470,int_stack+1535646,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+2154470,int_stack+2450179,int_stack+2472103,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+2450179,int_stack+2154470,int_stack+2138006,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2138006,int_stack+583128,int_stack+582120,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2141030,int_stack+584424,int_stack+583128,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2144918,int_stack+2141030,int_stack+2138006,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2150966,int_stack+586044,int_stack+584424,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2155826,int_stack+2150966,int_stack+2141030,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2163602,int_stack+2155826,int_stack+2144918,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2138006,int_stack+588024,int_stack+586044,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2173682,int_stack+2138006,int_stack+2150966,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2183402,int_stack+2173682,int_stack+2155826,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2143946,int_stack+2183402,int_stack+2163602,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2159066,int_stack+590400,int_stack+588024,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2196362,int_stack+2159066,int_stack+2138006,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2208242,int_stack+2196362,int_stack+2173682,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2472131,int_stack+2208242,int_stack+2183402,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2166194,int_stack+2472131,int_stack+2143946,36);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+2138006,int_stack+593208,int_stack+590400,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1535646,int_stack+2138006,int_stack+2159066,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+2138006,int_stack+1535646,int_stack+2196362,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1131214,int_stack+2138006,int_stack+2208242,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+2138006,int_stack+1131214,int_stack+2472131,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1131214,int_stack+2138006,int_stack+2166194,36);
 /*--- compute (ip|ii) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2138006,int_stack+1131214,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1478414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+597744,int_stack+596484,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2453959,int_stack+599364,int_stack+597744,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2458819,int_stack+2453959,int_stack+2450179,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2466379,int_stack+601389,int_stack+599364,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2472454,int_stack+2466379,int_stack+2453959,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2203862,int_stack+2472454,int_stack+2458819,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+603864,int_stack+601389,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2216462,int_stack+2450179,int_stack+2466379,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1159438,int_stack+2216462,int_stack+2472454,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2457604,int_stack+1159438,int_stack+2203862,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2203862,int_stack+606834,int_stack+603864,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2476504,int_stack+2203862,int_stack+2450179,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1175638,int_stack+2476504,int_stack+2216462,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1195888,int_stack+1175638,int_stack+1159438,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1220188,int_stack+1195888,int_stack+2457604,45);
 /*--- compute (l0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+1159438,int_stack+610344,int_stack+606834,45);
 /*--- compute (l0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+2450179,int_stack+1159438,int_stack+2203862,45);
 /*--- compute (l0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+2203862,int_stack+2450179,int_stack+2476504,45);
 /*--- compute (l0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+2450179,int_stack+2203862,int_stack+1175638,45);
 /*--- compute (l0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1159438,int_stack+2450179,int_stack+1195888,45);
 /*--- compute (l0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+2450179,int_stack+1159438,int_stack+1220188,45);
 /*--- compute (kp|ii) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1159438,int_stack+2450179,int_stack+1131214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1551882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (id|ii) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1244110,int_stack+1159438,int_stack+2138006, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1580106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2138006,int_stack+615979,int_stack+614439,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2142626,int_stack+617959,int_stack+615979,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2148566,int_stack+2142626,int_stack+2138006,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2157806,int_stack+620434,int_stack+617959,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2165231,int_stack+2157806,int_stack+2142626,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2177111,int_stack+2165231,int_stack+2148566,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2138006,int_stack+623459,int_stack+620434,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2192511,int_stack+2138006,int_stack+2157806,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2207361,int_stack+2192511,int_stack+2165231,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2147081,int_stack+2207361,int_stack+2177111,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2170181,int_stack+627089,int_stack+623459,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1131214,int_stack+2170181,int_stack+2138006,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1375822,int_stack+1131214,int_stack+2192511,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1400572,int_stack+1375822,int_stack+2207361,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2181071,int_stack+1400572,int_stack+2147081,55);
 /*--- compute (m0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+2138006,int_stack+631379,int_stack+627089,55);
 /*--- compute (m0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+1430272,int_stack+2138006,int_stack+2170181,55);
 /*--- compute (m0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+2138006,int_stack+1430272,int_stack+1131214,55);
 /*--- compute (m0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1430272,int_stack+2138006,int_stack+1375822,55);
 /*--- compute (m0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+2138006,int_stack+1430272,int_stack+1400572,55);
 /*--- compute (m0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1375822,int_stack+2138006,int_stack+2181071,55);
 /*--- compute (lp|ii) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4860979,int_stack+1375822,int_stack+2450179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1500366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (kd|ii) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+4966819,int_stack+4860979,int_stack+1159438, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1645962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (if|ii) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+5136163,int_stack+4966819,int_stack+1244110, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1836950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (n0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2450179,int_stack+638232,int_stack+636384,66);
 /*--- compute (n0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2455723,int_stack+640608,int_stack+638232,66);
 /*--- compute (n0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2462851,int_stack+2455723,int_stack+2450179,66);
 /*--- compute (n0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2473939,int_stack+643578,int_stack+640608,66);
 /*--- compute (n0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2138006,int_stack+2473939,int_stack+2455723,66);
 /*--- compute (n0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2152262,int_stack+2138006,int_stack+2462851,66);
 /*--- compute (n0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2450179,int_stack+647208,int_stack+643578,66);
 /*--- compute (n0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2170742,int_stack+2450179,int_stack+2473939,66);
 /*--- compute (n0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2461069,int_stack+2170742,int_stack+2138006,66);
 /*--- compute (n0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2188562,int_stack+2461069,int_stack+2152262,66);
 /*--- compute (n0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2138006,int_stack+651564,int_stack+647208,66);
 /*--- compute (n0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1418942,int_stack+2138006,int_stack+2450179,66);
 /*--- compute (n0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1440722,int_stack+1418942,int_stack+2170742,66);
 /*--- compute (n0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2151074,int_stack+1440722,int_stack+2461069,66);
 /*--- compute (n0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2450179,int_stack+2151074,int_stack+2188562,66);
 /*--- compute (n0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+2186714,int_stack+656712,int_stack+651564,66);
 /*--- compute (n0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+2202158,int_stack+2186714,int_stack+2138006,66);
 /*--- compute (n0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+1131214,int_stack+2202158,int_stack+1418942,66);
 /*--- compute (n0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+1167514,int_stack+1131214,int_stack+1440722,66);
 /*--- compute (n0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+1418942,int_stack+1167514,int_stack+2151074,66);
 /*--- compute (n0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+1131214,int_stack+1418942,int_stack+2450179,66);
 /*--- compute (mp|ii) ---*/
   d1hrr1_build_mp(Libderiv->AB,int_stack+1182958,int_stack+1131214,int_stack+1375822, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2491759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (ld|ii) ---*/
   d1hrr1_build_ld(Libderiv->AB,int_stack+5355683,int_stack+1182958,int_stack+4860979, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1730634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (kf|ii) ---*/
   d1hrr1_build_kf(Libderiv->AB,int_stack+1131214,int_stack+5355683,int_stack+4966819, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1968662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5355683,int_stack+663502,int_stack+662718,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5358035,int_stack+664510,int_stack+663502,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5361059,int_stack+5358035,int_stack+5355683,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5365763,int_stack+665770,int_stack+664510,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5369543,int_stack+5365763,int_stack+5358035,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5375591,int_stack+5369543,int_stack+5361059,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5355683,int_stack+667310,int_stack+665770,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+5383431,int_stack+5355683,int_stack+5365763,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5390991,int_stack+5383431,int_stack+5369543,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5360303,int_stack+5390991,int_stack+5375591,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+5372063,int_stack+669158,int_stack+667310,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+5401071,int_stack+5372063,int_stack+5355683,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+5410311,int_stack+5401071,int_stack+5383431,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+5422911,int_stack+5410311,int_stack+5390991,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+5377607,int_stack+5422911,int_stack+5360303,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+5355683,int_stack+671342,int_stack+669158,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+5438031,int_stack+5355683,int_stack+5372063,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+5355683,int_stack+5438031,int_stack+5401071,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+5438031,int_stack+5355683,int_stack+5410311,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+5355683,int_stack+5438031,int_stack+5422911,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+5394071,int_stack+5355683,int_stack+5377607,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5355683,int_stack+674898,int_stack+673890,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5358707,int_stack+676194,int_stack+674898,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5362595,int_stack+5358707,int_stack+5355683,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5368643,int_stack+677814,int_stack+676194,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5373503,int_stack+5368643,int_stack+5358707,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5381279,int_stack+5373503,int_stack+5362595,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5355683,int_stack+679794,int_stack+677814,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+5416023,int_stack+5355683,int_stack+5368643,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5425743,int_stack+5416023,int_stack+5373503,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5361623,int_stack+5425743,int_stack+5381279,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+5376743,int_stack+682170,int_stack+679794,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+5438703,int_stack+5376743,int_stack+5355683,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+5450583,int_stack+5438703,int_stack+5416023,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+5466783,int_stack+5450583,int_stack+5425743,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+5416023,int_stack+5466783,int_stack+5361623,36);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+5355683,int_stack+684978,int_stack+682170,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+5486223,int_stack+5355683,int_stack+5376743,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+5355683,int_stack+5486223,int_stack+5438703,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+5486223,int_stack+5355683,int_stack+5450583,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+5355683,int_stack+5486223,int_stack+5466783,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+5437191,int_stack+5355683,int_stack+5416023,36);
 /*--- compute (ip|ii) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+5465415,int_stack+5437191,int_stack+5394071, 0.0, zero_stack, 1.0, int_stack+1478414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5355683,int_stack+689514,int_stack+688254,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5359463,int_stack+691134,int_stack+689514,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5364323,int_stack+5359463,int_stack+5355683,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5371883,int_stack+693159,int_stack+691134,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5377958,int_stack+5371883,int_stack+5359463,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5387678,int_stack+5377958,int_stack+5364323,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5355683,int_stack+695634,int_stack+693159,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+5400278,int_stack+5355683,int_stack+5371883,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5412428,int_stack+5400278,int_stack+5377958,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5363108,int_stack+5412428,int_stack+5387678,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+5382008,int_stack+698604,int_stack+695634,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+5531271,int_stack+5382008,int_stack+5355683,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+5546121,int_stack+5531271,int_stack+5400278,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4860979,int_stack+5546121,int_stack+5412428,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+5390918,int_stack+4860979,int_stack+5363108,45);
 /*--- compute (l0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+5355683,int_stack+702114,int_stack+698604,45);
 /*--- compute (l0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+5417378,int_stack+5355683,int_stack+5382008,45);
 /*--- compute (l0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+5355683,int_stack+5417378,int_stack+5531271,45);
 /*--- compute (l0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+4885279,int_stack+5355683,int_stack+5546121,45);
 /*--- compute (l0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+5355683,int_stack+4885279,int_stack+4860979,45);
 /*--- compute (l0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+4860979,int_stack+5355683,int_stack+5390918,45);
 /*--- compute (kp|ii) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4896259,int_stack+4860979,int_stack+5437191, 0.0, zero_stack, 1.0, int_stack+1551882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (id|ii) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4980931,int_stack+4896259,int_stack+5465415, 0.0, zero_stack, 1.0, int_stack+1580106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5355683,int_stack+707749,int_stack+706209,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5360303,int_stack+709729,int_stack+707749,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5366243,int_stack+5360303,int_stack+5355683,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5375483,int_stack+712204,int_stack+709729,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5382908,int_stack+5375483,int_stack+5360303,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5394788,int_stack+5382908,int_stack+5366243,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5355683,int_stack+715229,int_stack+712204,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+5410188,int_stack+5355683,int_stack+5375483,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5425038,int_stack+5410188,int_stack+5382908,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5364758,int_stack+5425038,int_stack+5394788,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+5387858,int_stack+718859,int_stack+715229,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+5444838,int_stack+5387858,int_stack+5355683,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+5462988,int_stack+5444838,int_stack+5410188,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+5487738,int_stack+5462988,int_stack+5425038,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+5398748,int_stack+5487738,int_stack+5364758,55);
 /*--- compute (m0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+5355683,int_stack+723149,int_stack+718859,55);
 /*--- compute (m0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+5517438,int_stack+5355683,int_stack+5387858,55);
 /*--- compute (m0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+5355683,int_stack+5517438,int_stack+5444838,55);
 /*--- compute (m0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+5517438,int_stack+5355683,int_stack+5462988,55);
 /*--- compute (m0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+5517438,int_stack+5487738,55);
 /*--- compute (m0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+5431088,int_stack+2450179,int_stack+5398748,55);
 /*--- compute (lp|ii) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+543700,int_stack+5431088,int_stack+4860979, 0.0, zero_stack, 1.0, int_stack+1500366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (kd|ii) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+5474208,int_stack+543700,int_stack+4896259, 0.0, zero_stack, 1.0, int_stack+1645962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (if|ii) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+5643552,int_stack+5474208,int_stack+4980931, 0.0, zero_stack, 1.0, int_stack+1836950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (n0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4860979,int_stack+730002,int_stack+728154,66);
 /*--- compute (n0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4866523,int_stack+732378,int_stack+730002,66);
 /*--- compute (n0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4873651,int_stack+4866523,int_stack+4860979,66);
 /*--- compute (n0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4884739,int_stack+735348,int_stack+732378,66);
 /*--- compute (n0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4893649,int_stack+4884739,int_stack+4866523,66);
 /*--- compute (n0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4907905,int_stack+4893649,int_stack+4873651,66);
 /*--- compute (n0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4860979,int_stack+738978,int_stack+735348,66);
 /*--- compute (n0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4926385,int_stack+4860979,int_stack+4884739,66);
 /*--- compute (n0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4944205,int_stack+4926385,int_stack+4893649,66);
 /*--- compute (n0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4871869,int_stack+4944205,int_stack+4907905,66);
 /*--- compute (n0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4899589,int_stack+743334,int_stack+738978,66);
 /*--- compute (n0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4967965,int_stack+4899589,int_stack+4860979,66);
 /*--- compute (n0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4989745,int_stack+4967965,int_stack+4926385,66);
 /*--- compute (n0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+5019445,int_stack+4989745,int_stack+4944205,66);
 /*--- compute (n0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4912657,int_stack+5019445,int_stack+4871869,66);
 /*--- compute (n0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+4860979,int_stack+748482,int_stack+743334,66);
 /*--- compute (n0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+5055085,int_stack+4860979,int_stack+4899589,66);
 /*--- compute (n0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+4860979,int_stack+5055085,int_stack+4967965,66);
 /*--- compute (n0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+5055085,int_stack+4860979,int_stack+4989745,66);
 /*--- compute (n0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+4860979,int_stack+5055085,int_stack+5019445,66);
 /*--- compute (n0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+4951465,int_stack+4860979,int_stack+4912657,66);
 /*--- compute (mp|ii) ---*/
   d1hrr1_build_mp(Libderiv->AB,int_stack+5003209,int_stack+4951465,int_stack+5431088, 0.0, zero_stack, 1.0, int_stack+2491759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (ld|ii) ---*/
   d1hrr1_build_ld(Libderiv->AB,int_stack+5863072,int_stack+5003209,int_stack+543700, 0.0, zero_stack, 1.0, int_stack+1730634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (kf|ii) ---*/
   d1hrr1_build_kf(Libderiv->AB,int_stack+6074752,int_stack+5863072,int_stack+5474208, 0.0, zero_stack, 1.0, int_stack+1968662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5863072,int_stack+766444,int_stack+765660,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5865424,int_stack+767452,int_stack+766444,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5868448,int_stack+5865424,int_stack+5863072,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5873152,int_stack+768712,int_stack+767452,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5876932,int_stack+5873152,int_stack+5865424,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5882980,int_stack+5876932,int_stack+5868448,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5863072,int_stack+770252,int_stack+768712,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+5890820,int_stack+5863072,int_stack+5873152,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5898380,int_stack+5890820,int_stack+5876932,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5867692,int_stack+5898380,int_stack+5882980,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+5879452,int_stack+772100,int_stack+770252,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+5908460,int_stack+5879452,int_stack+5863072,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+5917700,int_stack+5908460,int_stack+5890820,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+5930300,int_stack+5917700,int_stack+5898380,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+5884996,int_stack+5930300,int_stack+5867692,28);
 /*--- compute (i0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+5863072,int_stack+774284,int_stack+772100,28);
 /*--- compute (i0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+5945420,int_stack+5863072,int_stack+5879452,28);
 /*--- compute (i0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+5863072,int_stack+5945420,int_stack+5908460,28);
 /*--- compute (i0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+5945420,int_stack+5863072,int_stack+5917700,28);
 /*--- compute (i0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+5863072,int_stack+5945420,int_stack+5930300,28);
 /*--- compute (i0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+5901460,int_stack+5863072,int_stack+5884996,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5863072,int_stack+792204,int_stack+791196,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5866096,int_stack+793500,int_stack+792204,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5869984,int_stack+5866096,int_stack+5863072,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5876032,int_stack+795120,int_stack+793500,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5880892,int_stack+5876032,int_stack+5866096,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5888668,int_stack+5880892,int_stack+5869984,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5863072,int_stack+797100,int_stack+795120,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+5923412,int_stack+5863072,int_stack+5876032,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5933132,int_stack+5923412,int_stack+5880892,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5869012,int_stack+5933132,int_stack+5888668,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+5884132,int_stack+799476,int_stack+797100,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+5946092,int_stack+5884132,int_stack+5863072,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+5957972,int_stack+5946092,int_stack+5923412,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+5974172,int_stack+5957972,int_stack+5933132,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+5923412,int_stack+5974172,int_stack+5869012,36);
 /*--- compute (k0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+5863072,int_stack+802284,int_stack+799476,36);
 /*--- compute (k0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+5993612,int_stack+5863072,int_stack+5884132,36);
 /*--- compute (k0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+5863072,int_stack+5993612,int_stack+5946092,36);
 /*--- compute (k0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+5993612,int_stack+5863072,int_stack+5957972,36);
 /*--- compute (k0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+5863072,int_stack+5993612,int_stack+5974172,36);
 /*--- compute (k0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+5944580,int_stack+5863072,int_stack+5923412,36);
 /*--- compute (ip|ii) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+5972804,int_stack+5944580,int_stack+5901460, 1.0, int_stack+1478414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5863072,int_stack+824775,int_stack+823515,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5866852,int_stack+826395,int_stack+824775,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5871712,int_stack+5866852,int_stack+5863072,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5879272,int_stack+828420,int_stack+826395,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5885347,int_stack+5879272,int_stack+5866852,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5895067,int_stack+5885347,int_stack+5871712,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5863072,int_stack+830895,int_stack+828420,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+5907667,int_stack+5863072,int_stack+5879272,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5919817,int_stack+5907667,int_stack+5885347,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5870497,int_stack+5919817,int_stack+5895067,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+5889397,int_stack+833865,int_stack+830895,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+6038660,int_stack+5889397,int_stack+5863072,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+6053510,int_stack+6038660,int_stack+5907667,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+543700,int_stack+6053510,int_stack+5919817,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+5898307,int_stack+543700,int_stack+5870497,45);
 /*--- compute (l0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+5863072,int_stack+837375,int_stack+833865,45);
 /*--- compute (l0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+5924767,int_stack+5863072,int_stack+5889397,45);
 /*--- compute (l0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+5863072,int_stack+5924767,int_stack+6038660,45);
 /*--- compute (l0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+568000,int_stack+5863072,int_stack+6053510,45);
 /*--- compute (l0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+5863072,int_stack+568000,int_stack+543700,45);
 /*--- compute (l0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+543700,int_stack+5863072,int_stack+5898307,45);
 /*--- compute (kp|ii) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+578980,int_stack+543700,int_stack+5944580, 1.0, int_stack+1551882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (id|ii) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+663652,int_stack+578980,int_stack+5972804, 1.0, int_stack+1580106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5863072,int_stack+864955,int_stack+863415,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5867692,int_stack+866935,int_stack+864955,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5873632,int_stack+5867692,int_stack+5863072,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5882872,int_stack+869410,int_stack+866935,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5890297,int_stack+5882872,int_stack+5867692,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5902177,int_stack+5890297,int_stack+5873632,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5863072,int_stack+872435,int_stack+869410,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+5917577,int_stack+5863072,int_stack+5882872,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5932427,int_stack+5917577,int_stack+5890297,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5872147,int_stack+5932427,int_stack+5902177,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+5895247,int_stack+876065,int_stack+872435,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+5952227,int_stack+5895247,int_stack+5863072,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+5970377,int_stack+5952227,int_stack+5917577,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+5995127,int_stack+5970377,int_stack+5932427,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+5906137,int_stack+5995127,int_stack+5872147,55);
 /*--- compute (m0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+5863072,int_stack+880355,int_stack+876065,55);
 /*--- compute (m0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+6024827,int_stack+5863072,int_stack+5895247,55);
 /*--- compute (m0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+5863072,int_stack+6024827,int_stack+5952227,55);
 /*--- compute (m0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+6024827,int_stack+5863072,int_stack+5970377,55);
 /*--- compute (m0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+2450179,int_stack+6024827,int_stack+5995127,55);
 /*--- compute (m0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+5938477,int_stack+2450179,int_stack+5906137,55);
 /*--- compute (lp|ii) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4860979,int_stack+5938477,int_stack+543700, 1.0, int_stack+1500366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (kd|ii) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+4966819,int_stack+4860979,int_stack+578980, 1.0, int_stack+1645962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (if|ii) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+5355683,int_stack+4966819,int_stack+663652, 1.0, int_stack+1836950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (n0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+543700,int_stack+887208,int_stack+885360,66);
 /*--- compute (n0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+549244,int_stack+889584,int_stack+887208,66);
 /*--- compute (n0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+556372,int_stack+549244,int_stack+543700,66);
 /*--- compute (n0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+567460,int_stack+892554,int_stack+889584,66);
 /*--- compute (n0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+576370,int_stack+567460,int_stack+549244,66);
 /*--- compute (n0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+590626,int_stack+576370,int_stack+556372,66);
 /*--- compute (n0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+543700,int_stack+896184,int_stack+892554,66);
 /*--- compute (n0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+609106,int_stack+543700,int_stack+567460,66);
 /*--- compute (n0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+626926,int_stack+609106,int_stack+576370,66);
 /*--- compute (n0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+554590,int_stack+626926,int_stack+590626,66);
 /*--- compute (n0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+582310,int_stack+900540,int_stack+896184,66);
 /*--- compute (n0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+650686,int_stack+582310,int_stack+543700,66);
 /*--- compute (n0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+672466,int_stack+650686,int_stack+609106,66);
 /*--- compute (n0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+702166,int_stack+672466,int_stack+626926,66);
 /*--- compute (n0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+595378,int_stack+702166,int_stack+554590,66);
 /*--- compute (n0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+543700,int_stack+905688,int_stack+900540,66);
 /*--- compute (n0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+737806,int_stack+543700,int_stack+582310,66);
 /*--- compute (n0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+543700,int_stack+737806,int_stack+650686,66);
 /*--- compute (n0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+737806,int_stack+543700,int_stack+672466,66);
 /*--- compute (n0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+543700,int_stack+737806,int_stack+702166,66);
 /*--- compute (n0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+634186,int_stack+543700,int_stack+595378,66);
 /*--- compute (mp|ii) ---*/
   d1hrr1_build_mp(Libderiv->AB,int_stack+685930,int_stack+634186,int_stack+5938477, 1.0, int_stack+2491759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (ld|ii) ---*/
   d1hrr1_build_ld(Libderiv->AB,int_stack+5863072,int_stack+685930,int_stack+4860979, 1.0, int_stack+1730634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (kf|ii) ---*/
   d1hrr1_build_kf(Libderiv->AB,int_stack+543700,int_stack+5863072,int_stack+4966819, 1.0, int_stack+1968662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
 /*--- compute (ig|ii) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+1413454,int_stack+2791219,int_stack+2230659,784);
     Libderiv->ABCD[11] = int_stack + 1413454;
 /*--- compute (ig|ii) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+1742734,int_stack+3292979,int_stack+3073459,784);
     Libderiv->ABCD[10] = int_stack + 1742734;
 /*--- compute (ig|ii) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+2072014,int_stack+3794739,int_stack+3575219,784);
     Libderiv->ABCD[9] = int_stack + 2072014;
 /*--- compute (ig|ii) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+2775539,int_stack+4076979,int_stack+41940,784);
     Libderiv->ABCD[8] = int_stack + 2775539;
 /*--- compute (ig|ii) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+3104819,int_stack+4578739,int_stack+4359219,784);
     Libderiv->ABCD[7] = int_stack + 3104819;
 /*--- compute (ig|ii) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+3434099,int_stack+261460,int_stack+2556019,784);
     Libderiv->ABCD[6] = int_stack + 3434099;
 /*--- compute (ig|ii) ---*/
   d1hrr1_build_ig(Libderiv->AB,int_stack+2401294,int_stack+1131214,int_stack+5136163, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+911694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[2] = int_stack + 2401294;
 /*--- compute (ig|ii) ---*/
   d1hrr1_build_ig(Libderiv->AB,int_stack+0,int_stack+6074752,int_stack+5643552, 0.0, zero_stack, 1.0, int_stack+911694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[1] = int_stack + 0;
 /*--- compute (ig|ii) ---*/
   d1hrr1_build_ig(Libderiv->AB,int_stack+5575203,int_stack+543700,int_stack+5355683, 1.0, int_stack+911694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,784);
     Libderiv->ABCD[0] = int_stack + 5575203;

}
