/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_hfhh(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+9, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+12, r12vrr_stack+3, r12vrr_stack+9, NULL, NULL, Data->F+5);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+3, NULL, NULL, Data->F+4);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+30, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+9, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+54, r12vrr_stack+6, r12vrr_stack+3, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+60, r12vrr_stack+54, r12vrr_stack+48, NULL, NULL, r12vrr_stack+3);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+78, r12vrr_stack+6, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+87, r12vrr_stack+81, r12vrr_stack+54, NULL, NULL, r12vrr_stack+6);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+105, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+108, r12vrr_stack+9, r12vrr_stack+105, Data->F+5, Data->F+6, NULL);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+114, r12vrr_stack+48, r12vrr_stack+108, NULL, NULL, r12vrr_stack+9);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+132, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+12);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+168, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+21);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+204, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+30);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+264, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+6, r12vrr_stack+3, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+274, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+78, r12vrr_stack+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+284, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+3, r12vrr_stack+9, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+294, r12vrr_stack+264, r12vrr_stack+284, NULL, NULL, r12vrr_stack+48);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+324, r12vrr_stack+274, r12vrr_stack+264, NULL, NULL, r12vrr_stack+54);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+354, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+60);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+414, r12vrr_stack+6, r12vrr_stack+78, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+81, r12vrr_stack+6, r12vrr_stack+78, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+430, r12vrr_stack+420, r12vrr_stack+274, NULL, NULL, r12vrr_stack+81);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+460, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+87);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+87, r12vrr_stack+105, r12vrr_stack+78, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+93, r12vrr_stack+108, r12vrr_stack+87, r12vrr_stack+9, r12vrr_stack+105, NULL);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+520, r12vrr_stack+284, r12vrr_stack+93, NULL, NULL, r12vrr_stack+108);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+550, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+114);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+610, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+132);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+710, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+168);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+810, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+204);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+960, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+54, r12vrr_stack+48, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+975, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+81, r12vrr_stack+54, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+990, r12vrr_stack+975, r12vrr_stack+960, NULL, NULL, r12vrr_stack+264);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1035, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+414, r12vrr_stack+81, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1050, r12vrr_stack+1035, r12vrr_stack+975, NULL, NULL, r12vrr_stack+274);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1095, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+48, r12vrr_stack+108, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1110, r12vrr_stack+960, r12vrr_stack+1095, NULL, NULL, r12vrr_stack+284);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1155, r12vrr_stack+990, r12vrr_stack+1110, r12vrr_stack+975, r12vrr_stack+960, r12vrr_stack+294);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1245, r12vrr_stack+1050, r12vrr_stack+990, r12vrr_stack+1035, r12vrr_stack+975, r12vrr_stack+324);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1335, r12vrr_stack+1245, r12vrr_stack+1155, r12vrr_stack+1050, r12vrr_stack+990, r12vrr_stack+354);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+324, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+324, r12vrr_stack+6, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+327, r12vrr_stack+81, r12vrr_stack+414, r12vrr_stack+324, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+337, r12vrr_stack+327, r12vrr_stack+420, r12vrr_stack+81, r12vrr_stack+414, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1485, r12vrr_stack+337, r12vrr_stack+1035, NULL, NULL, r12vrr_stack+420);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1530, r12vrr_stack+1485, r12vrr_stack+1050, r12vrr_stack+337, r12vrr_stack+1035, r12vrr_stack+430);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1620, r12vrr_stack+1530, r12vrr_stack+1245, r12vrr_stack+1485, r12vrr_stack+1050, r12vrr_stack+460);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+414, r12vrr_stack+78, r12vrr_stack+6, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+430, r12vrr_stack+87, r12vrr_stack+414, r12vrr_stack+105, r12vrr_stack+78, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+440, r12vrr_stack+93, r12vrr_stack+430, r12vrr_stack+108, r12vrr_stack+87, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+455, r12vrr_stack+1095, r12vrr_stack+440, NULL, NULL, r12vrr_stack+93);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1770, r12vrr_stack+1110, r12vrr_stack+455, r12vrr_stack+960, r12vrr_stack+1095, r12vrr_stack+520);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1860, r12vrr_stack+1155, r12vrr_stack+1770, r12vrr_stack+990, r12vrr_stack+1110, r12vrr_stack+550);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2010, r12vrr_stack+1335, r12vrr_stack+1860, r12vrr_stack+1245, r12vrr_stack+1155, r12vrr_stack+610);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2235, r12vrr_stack+1620, r12vrr_stack+1335, r12vrr_stack+1530, r12vrr_stack+1245, r12vrr_stack+710);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+2460, r12vrr_stack+2235, r12vrr_stack+2010, r12vrr_stack+1620, r12vrr_stack+1335, r12vrr_stack+810);

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+500, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+54, r12vrr_stack+0, r12vrr_stack+500, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+503, r12vrr_stack+9, r12vrr_stack+105, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+2775, r12vrr_stack+12, r12vrr_stack+503, r12vrr_stack+3, r12vrr_stack+9, r12vrr_stack+500);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+2793, r12vrr_stack+30, r12vrr_stack+2775, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+54);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+2823, r12vrr_stack+108, r12vrr_stack+87, NULL, NULL, r12vrr_stack+105);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+2841, r12vrr_stack+114, r12vrr_stack+2823, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+503);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+2877, r12vrr_stack+132, r12vrr_stack+2841, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+2775);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+2937, r12vrr_stack+204, r12vrr_stack+2877, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+2793);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+168, r12vrr_stack+93, r12vrr_stack+430, NULL, NULL, r12vrr_stack+87);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+3027, r12vrr_stack+520, r12vrr_stack+168, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+2823);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+3087, r12vrr_stack+550, r12vrr_stack+3027, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+2841);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+3187, r12vrr_stack+610, r12vrr_stack+3087, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+2877);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+3337, r12vrr_stack+810, r12vrr_stack+3187, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+2937);

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+198, r12vrr_stack+6, r12vrr_stack+3, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+710, r12vrr_stack+414, r12vrr_stack+198, r12vrr_stack+78, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+720, r12vrr_stack+430, r12vrr_stack+710, r12vrr_stack+87, r12vrr_stack+414, NULL);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+735, r12vrr_stack+440, r12vrr_stack+720, NULL, NULL, r12vrr_stack+430);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+3547, r12vrr_stack+455, r12vrr_stack+735, r12vrr_stack+1095, r12vrr_stack+440, r12vrr_stack+168);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+3637, r12vrr_stack+1770, r12vrr_stack+3547, r12vrr_stack+1110, r12vrr_stack+455, r12vrr_stack+3027);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+3787, r12vrr_stack+1860, r12vrr_stack+3637, r12vrr_stack+1155, r12vrr_stack+1770, r12vrr_stack+3087);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+4012, r12vrr_stack+2010, r12vrr_stack+3787, r12vrr_stack+1335, r12vrr_stack+1860, r12vrr_stack+3187);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+4327, r12vrr_stack+2460, r12vrr_stack+4012, r12vrr_stack+2235, r12vrr_stack+2010, r12vrr_stack+3337);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+780, r12vrr_stack+960, r12vrr_stack+1095, r12vrr_stack+264, r12vrr_stack+284, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+294, r12vrr_stack+975, r12vrr_stack+960, r12vrr_stack+274, r12vrr_stack+264, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+352, r12vrr_stack+1095, r12vrr_stack+440, r12vrr_stack+284, r12vrr_stack+93, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4747, r12vrr_stack+780, r12vrr_stack+352, NULL, NULL, r12vrr_stack+1095);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4810, r12vrr_stack+294, r12vrr_stack+780, NULL, NULL, r12vrr_stack+960);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+4873, r12vrr_stack+4810, r12vrr_stack+4747, r12vrr_stack+294, r12vrr_stack+780, r12vrr_stack+1110);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1110, r12vrr_stack+1035, r12vrr_stack+975, r12vrr_stack+420, r12vrr_stack+274, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4999, r12vrr_stack+1110, r12vrr_stack+294, NULL, NULL, r12vrr_stack+975);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+5062, r12vrr_stack+4999, r12vrr_stack+4810, r12vrr_stack+1110, r12vrr_stack+294, r12vrr_stack+990);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+990, r12vrr_stack+440, r12vrr_stack+720, r12vrr_stack+93, r12vrr_stack+430, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+5188, r12vrr_stack+352, r12vrr_stack+990, NULL, NULL, r12vrr_stack+440);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+5251, r12vrr_stack+4747, r12vrr_stack+5188, r12vrr_stack+780, r12vrr_stack+352, r12vrr_stack+455);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5377, r12vrr_stack+4873, r12vrr_stack+5251, r12vrr_stack+4810, r12vrr_stack+4747, r12vrr_stack+1770);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5587, r12vrr_stack+5062, r12vrr_stack+4873, r12vrr_stack+4999, r12vrr_stack+4810, r12vrr_stack+1155);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+5797, r12vrr_stack+5587, r12vrr_stack+5377, r12vrr_stack+5062, r12vrr_stack+4873, r12vrr_stack+1860);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1011, r12vrr_stack+337, r12vrr_stack+1035, r12vrr_stack+327, r12vrr_stack+420, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1131, r12vrr_stack+1011, r12vrr_stack+1110, NULL, NULL, r12vrr_stack+1035);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+6112, r12vrr_stack+1131, r12vrr_stack+4999, r12vrr_stack+1011, r12vrr_stack+1110, r12vrr_stack+1050);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+6238, r12vrr_stack+6112, r12vrr_stack+5062, r12vrr_stack+1131, r12vrr_stack+4999, r12vrr_stack+1245);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+6448, r12vrr_stack+6238, r12vrr_stack+5587, r12vrr_stack+6112, r12vrr_stack+5062, r12vrr_stack+1335);

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1032, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+1032, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+420, r12vrr_stack+198, r12vrr_stack+48, r12vrr_stack+6, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1050, r12vrr_stack+710, r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+198, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1065, r12vrr_stack+720, r12vrr_stack+1050, r12vrr_stack+430, r12vrr_stack+710, NULL);

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1194, r12vrr_stack+990, r12vrr_stack+1065, NULL, NULL, r12vrr_stack+720);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1257, r12vrr_stack+5188, r12vrr_stack+1194, r12vrr_stack+352, r12vrr_stack+990, r12vrr_stack+735);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+6763, r12vrr_stack+5251, r12vrr_stack+1257, r12vrr_stack+4747, r12vrr_stack+5188, r12vrr_stack+3547);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+6973, r12vrr_stack+5377, r12vrr_stack+6763, r12vrr_stack+4873, r12vrr_stack+5251, r12vrr_stack+3637);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+7288, r12vrr_stack+5797, r12vrr_stack+6973, r12vrr_stack+5587, r12vrr_stack+5377, r12vrr_stack+3787);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+7729, r12vrr_stack+6448, r12vrr_stack+5797, r12vrr_stack+6238, r12vrr_stack+5587, r12vrr_stack+2010);
 tmp = r12vrr_stack + 7729;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+8170, r12vrr_stack+7729, r12vrr_stack+7288, r12vrr_stack+6448, r12vrr_stack+5797, r12vrr_stack+4012);
 tmp = r12vrr_stack + 8170;
 target_ptr = Libr12->gvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1383, r12vrr_stack+780, r12vrr_stack+352, r12vrr_stack+960, r12vrr_stack+1095, NULL);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1411, r12vrr_stack+294, r12vrr_stack+780, r12vrr_stack+975, r12vrr_stack+960, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+8758, r12vrr_stack+1411, r12vrr_stack+1383, NULL, NULL, r12vrr_stack+780);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1439, r12vrr_stack+1110, r12vrr_stack+294, r12vrr_stack+1035, r12vrr_stack+975, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+8842, r12vrr_stack+1439, r12vrr_stack+1411, NULL, NULL, r12vrr_stack+294);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+960, r12vrr_stack+352, r12vrr_stack+990, r12vrr_stack+1095, r12vrr_stack+440, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+8926, r12vrr_stack+1383, r12vrr_stack+960, NULL, NULL, r12vrr_stack+352);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+9010, r12vrr_stack+8758, r12vrr_stack+8926, r12vrr_stack+1411, r12vrr_stack+1383, r12vrr_stack+4747);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+9178, r12vrr_stack+8842, r12vrr_stack+8758, r12vrr_stack+1439, r12vrr_stack+1411, r12vrr_stack+4810);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+9346, r12vrr_stack+9178, r12vrr_stack+9010, r12vrr_stack+8842, r12vrr_stack+8758, r12vrr_stack+4873);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+4747, r12vrr_stack+1011, r12vrr_stack+1110, r12vrr_stack+337, r12vrr_stack+1035, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+4775, r12vrr_stack+4747, r12vrr_stack+1439, NULL, NULL, r12vrr_stack+1110);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+9626, r12vrr_stack+4775, r12vrr_stack+8842, r12vrr_stack+4747, r12vrr_stack+1439, r12vrr_stack+4999);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+9794, r12vrr_stack+9626, r12vrr_stack+9178, r12vrr_stack+4775, r12vrr_stack+8842, r12vrr_stack+5062);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+4859, r12vrr_stack+990, r12vrr_stack+1065, r12vrr_stack+440, r12vrr_stack+720, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+4887, r12vrr_stack+960, r12vrr_stack+4859, NULL, NULL, r12vrr_stack+990);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4971, r12vrr_stack+8926, r12vrr_stack+4887, r12vrr_stack+1383, r12vrr_stack+960, r12vrr_stack+5188);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+10074, r12vrr_stack+9010, r12vrr_stack+4971, r12vrr_stack+8758, r12vrr_stack+8926, r12vrr_stack+5251);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+10354, r12vrr_stack+9346, r12vrr_stack+10074, r12vrr_stack+9178, r12vrr_stack+9010, r12vrr_stack+5377);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+10774, r12vrr_stack+9794, r12vrr_stack+9346, r12vrr_stack+9626, r12vrr_stack+9178, r12vrr_stack+5587);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+11194, r12vrr_stack+10774, r12vrr_stack+10354, r12vrr_stack+9794, r12vrr_stack+9346, r12vrr_stack+5797);
 tmp = r12vrr_stack + 11194;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+5587, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+5590, r12vrr_stack+1032, r12vrr_stack+5587, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+5596, r12vrr_stack+48, r12vrr_stack+5590, r12vrr_stack+3, r12vrr_stack+1032, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1035, r12vrr_stack+420, r12vrr_stack+5596, r12vrr_stack+198, r12vrr_stack+48, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+5606, r12vrr_stack+1050, r12vrr_stack+1035, r12vrr_stack+710, r12vrr_stack+420, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5627, r12vrr_stack+1065, r12vrr_stack+5606, r12vrr_stack+720, r12vrr_stack+1050, NULL);

 /*--- compute (p0|i0)^5 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5655, r12vrr_stack+4859, r12vrr_stack+5627, NULL, NULL, r12vrr_stack+1065);

 /*--- compute (d0|i0)^4 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+11782, r12vrr_stack+4887, r12vrr_stack+5655, r12vrr_stack+960, r12vrr_stack+4859, r12vrr_stack+1194);

 /*--- compute (f0|i0)^3 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+11950, r12vrr_stack+4971, r12vrr_stack+11782, r12vrr_stack+8926, r12vrr_stack+4887, r12vrr_stack+1257);

 /*--- compute (g0|i0)^2 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+12230, r12vrr_stack+10074, r12vrr_stack+11950, r12vrr_stack+9010, r12vrr_stack+4971, r12vrr_stack+6763);

 /*--- compute (h0|i0)^1 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+12650, r12vrr_stack+10354, r12vrr_stack+12230, r12vrr_stack+9346, r12vrr_stack+10074, r12vrr_stack+6973);

 /*--- compute (i0|i0)^0 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+13238, r12vrr_stack+11194, r12vrr_stack+12650, r12vrr_stack+10774, r12vrr_stack+10354, r12vrr_stack+7288);
 tmp = r12vrr_stack + 13238;
 target_ptr = Libr12->gvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5739, r12vrr_stack+1383, r12vrr_stack+960, r12vrr_stack+780, r12vrr_stack+352, NULL);

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5139, r12vrr_stack+1411, r12vrr_stack+1383, r12vrr_stack+294, r12vrr_stack+780, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14022, r12vrr_stack+5139, r12vrr_stack+5739, NULL, NULL, r12vrr_stack+1383);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+373, r12vrr_stack+1439, r12vrr_stack+1411, r12vrr_stack+1110, r12vrr_stack+294, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14130, r12vrr_stack+373, r12vrr_stack+5139, NULL, NULL, r12vrr_stack+1411);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+264, r12vrr_stack+960, r12vrr_stack+4859, r12vrr_stack+352, r12vrr_stack+990, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14238, r12vrr_stack+5739, r12vrr_stack+264, NULL, NULL, r12vrr_stack+960);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14346, r12vrr_stack+14022, r12vrr_stack+14238, r12vrr_stack+5139, r12vrr_stack+5739, r12vrr_stack+8926);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14562, r12vrr_stack+14130, r12vrr_stack+14022, r12vrr_stack+373, r12vrr_stack+5139, r12vrr_stack+8758);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14778, r12vrr_stack+14562, r12vrr_stack+14346, r12vrr_stack+14130, r12vrr_stack+14022, r12vrr_stack+9010);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8758, r12vrr_stack+4747, r12vrr_stack+1439, r12vrr_stack+1011, r12vrr_stack+1110, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8926, r12vrr_stack+8758, r12vrr_stack+373, NULL, NULL, r12vrr_stack+1439);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15138, r12vrr_stack+8926, r12vrr_stack+14130, r12vrr_stack+8758, r12vrr_stack+373, r12vrr_stack+8842);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15354, r12vrr_stack+15138, r12vrr_stack+14562, r12vrr_stack+8926, r12vrr_stack+14130, r12vrr_stack+9178);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8794, r12vrr_stack+4859, r12vrr_stack+5627, r12vrr_stack+990, r12vrr_stack+1065, NULL);

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9034, r12vrr_stack+264, r12vrr_stack+8794, NULL, NULL, r12vrr_stack+4859);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15714, r12vrr_stack+14238, r12vrr_stack+9034, r12vrr_stack+5739, r12vrr_stack+264, r12vrr_stack+4887);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15930, r12vrr_stack+14346, r12vrr_stack+15714, r12vrr_stack+14022, r12vrr_stack+14238, r12vrr_stack+4971);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+16290, r12vrr_stack+14778, r12vrr_stack+15930, r12vrr_stack+14562, r12vrr_stack+14346, r12vrr_stack+10074);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+16830, r12vrr_stack+15354, r12vrr_stack+14778, r12vrr_stack+15138, r12vrr_stack+14562, r12vrr_stack+9346);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+17370, r12vrr_stack+16830, r12vrr_stack+16290, r12vrr_stack+15354, r12vrr_stack+14778, r12vrr_stack+10354);
 tmp = r12vrr_stack + 17370;
 target_ptr = Libr12->gvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^12 ---*/
 _BUILD_00p0(Data,r12vrr_stack+8830, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /*--- compute (00|d0)^11 ---*/
 _BUILD_00d0(Data,r12vrr_stack+8833, r12vrr_stack+5587, r12vrr_stack+8830, Data->F+11, Data->F+12, NULL);

 /*--- compute (00|f0)^10 ---*/
 _BUILD_00f0(Data,r12vrr_stack+8839, r12vrr_stack+5590, r12vrr_stack+8833, r12vrr_stack+1032, r12vrr_stack+5587, NULL);

 /*--- compute (00|g0)^9 ---*/
 _BUILD_00g0(Data,r12vrr_stack+8849, r12vrr_stack+5596, r12vrr_stack+8839, r12vrr_stack+48, r12vrr_stack+5590, NULL);

 /*--- compute (00|h0)^8 ---*/
 _BUILD_00h0(Data,r12vrr_stack+352, r12vrr_stack+1035, r12vrr_stack+8849, r12vrr_stack+420, r12vrr_stack+5596, NULL);

 /*--- compute (00|i0)^7 ---*/
 _BUILD_00i0(Data,r12vrr_stack+8864, r12vrr_stack+5606, r12vrr_stack+352, r12vrr_stack+1050, r12vrr_stack+1035, NULL);

 /*--- compute (00|k0)^6 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9142, r12vrr_stack+5627, r12vrr_stack+8864, r12vrr_stack+1065, r12vrr_stack+5606, NULL);

 /*--- compute (p0|k0)^5 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9178, r12vrr_stack+8794, r12vrr_stack+9142, NULL, NULL, r12vrr_stack+5627);

 /*--- compute (d0|k0)^4 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9286, r12vrr_stack+9034, r12vrr_stack+9178, r12vrr_stack+264, r12vrr_stack+8794, r12vrr_stack+5655);

 /*--- compute (f0|k0)^3 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18126, r12vrr_stack+15714, r12vrr_stack+9286, r12vrr_stack+14238, r12vrr_stack+9034, r12vrr_stack+11782);

 /*--- compute (g0|k0)^2 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18486, r12vrr_stack+15930, r12vrr_stack+18126, r12vrr_stack+14346, r12vrr_stack+15714, r12vrr_stack+11950);

 /*--- compute (h0|k0)^1 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+19026, r12vrr_stack+16290, r12vrr_stack+18486, r12vrr_stack+14778, r12vrr_stack+15930, r12vrr_stack+12230);

 /*--- compute (i0|k0)^0 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+19782, r12vrr_stack+17370, r12vrr_stack+19026, r12vrr_stack+16830, r12vrr_stack+16290, r12vrr_stack+12650);
 tmp = r12vrr_stack + 19782;
 target_ptr = Libr12->gvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1086, r12vrr_stack+5739, r12vrr_stack+264, r12vrr_stack+1383, r12vrr_stack+960, NULL);

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9502, r12vrr_stack+5139, r12vrr_stack+5739, r12vrr_stack+1411, r12vrr_stack+1383, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+20790, r12vrr_stack+9502, r12vrr_stack+1086, NULL, NULL, r12vrr_stack+5739);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9547, r12vrr_stack+373, r12vrr_stack+5139, r12vrr_stack+1439, r12vrr_stack+1411, NULL);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+20925, r12vrr_stack+9547, r12vrr_stack+9502, NULL, NULL, r12vrr_stack+5139);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1383, r12vrr_stack+264, r12vrr_stack+8794, r12vrr_stack+960, r12vrr_stack+4859, NULL);

 /*--- compute (p0|l0)^3 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21060, r12vrr_stack+1086, r12vrr_stack+1383, NULL, NULL, r12vrr_stack+264);

 /*--- compute (d0|l0)^2 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21195, r12vrr_stack+20790, r12vrr_stack+21060, r12vrr_stack+9502, r12vrr_stack+1086, r12vrr_stack+14238);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21465, r12vrr_stack+20925, r12vrr_stack+20790, r12vrr_stack+9547, r12vrr_stack+9502, r12vrr_stack+14022);

 /*--- compute (f0|l0)^1 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21735, r12vrr_stack+21465, r12vrr_stack+21195, r12vrr_stack+20925, r12vrr_stack+20790, r12vrr_stack+14346);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14022, r12vrr_stack+8758, r12vrr_stack+373, r12vrr_stack+4747, r12vrr_stack+1439, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14238, r12vrr_stack+14022, r12vrr_stack+9547, NULL, NULL, r12vrr_stack+373);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+22185, r12vrr_stack+14238, r12vrr_stack+20925, r12vrr_stack+14022, r12vrr_stack+9547, r12vrr_stack+14130);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+22455, r12vrr_stack+22185, r12vrr_stack+21465, r12vrr_stack+14238, r12vrr_stack+20925, r12vrr_stack+14562);

 /*--- compute (00|l0)^5 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14067, r12vrr_stack+8794, r12vrr_stack+9142, r12vrr_stack+4859, r12vrr_stack+5627, NULL);

 /*--- compute (p0|l0)^4 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14373, r12vrr_stack+1383, r12vrr_stack+14067, NULL, NULL, r12vrr_stack+8794);

 /*--- compute (d0|l0)^3 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14508, r12vrr_stack+21060, r12vrr_stack+14373, r12vrr_stack+1086, r12vrr_stack+1383, r12vrr_stack+9034);

 /*--- compute (f0|l0)^2 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+22905, r12vrr_stack+21195, r12vrr_stack+14508, r12vrr_stack+20790, r12vrr_stack+21060, r12vrr_stack+15714);

 /*--- compute (g0|l0)^1 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+23355, r12vrr_stack+21735, r12vrr_stack+22905, r12vrr_stack+21465, r12vrr_stack+21195, r12vrr_stack+15930);

 /*--- compute (g0|l0)^0 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+24030, r12vrr_stack+22455, r12vrr_stack+21735, r12vrr_stack+22185, r12vrr_stack+21465, r12vrr_stack+14778);

 /*--- compute (h0|l0)^0 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+24705, r12vrr_stack+24030, r12vrr_stack+23355, r12vrr_stack+22455, r12vrr_stack+21735, r12vrr_stack+16290);
 tmp = r12vrr_stack + 24705;
 target_ptr = Libr12->gvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^13 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1032, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /*--- compute (00|d0)^12 ---*/
 _BUILD_00d0(Data,r12vrr_stack+14778, r12vrr_stack+8830, r12vrr_stack+1032, Data->F+12, Data->F+13, NULL);

 /*--- compute (00|f0)^11 ---*/
 _BUILD_00f0(Data,r12vrr_stack+14784, r12vrr_stack+8833, r12vrr_stack+14778, r12vrr_stack+5587, r12vrr_stack+8830, NULL);

 /*--- compute (00|g0)^10 ---*/
 _BUILD_00g0(Data,r12vrr_stack+14794, r12vrr_stack+8839, r12vrr_stack+14784, r12vrr_stack+5590, r12vrr_stack+8833, NULL);

 /*--- compute (00|h0)^9 ---*/
 _BUILD_00h0(Data,r12vrr_stack+14809, r12vrr_stack+8849, r12vrr_stack+14794, r12vrr_stack+5596, r12vrr_stack+8839, NULL);

 /*--- compute (00|i0)^8 ---*/
 _BUILD_00i0(Data,r12vrr_stack+14830, r12vrr_stack+352, r12vrr_stack+14809, r12vrr_stack+1035, r12vrr_stack+8849, NULL);

 /*--- compute (00|k0)^7 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14858, r12vrr_stack+8864, r12vrr_stack+14830, r12vrr_stack+5606, r12vrr_stack+352, NULL);

 /*--- compute (00|l0)^6 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14894, r12vrr_stack+9142, r12vrr_stack+14858, r12vrr_stack+5627, r12vrr_stack+8864, NULL);

 /*--- compute (p0|l0)^5 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14939, r12vrr_stack+14067, r12vrr_stack+14894, NULL, NULL, r12vrr_stack+9142);

 /*--- compute (d0|l0)^4 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+25650, r12vrr_stack+14373, r12vrr_stack+14939, r12vrr_stack+1383, r12vrr_stack+14067, r12vrr_stack+9178);

 /*--- compute (f0|l0)^3 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+25920, r12vrr_stack+14508, r12vrr_stack+25650, r12vrr_stack+21060, r12vrr_stack+14373, r12vrr_stack+9286);

 /*--- compute (g0|l0)^2 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+26370, r12vrr_stack+22905, r12vrr_stack+25920, r12vrr_stack+21195, r12vrr_stack+14508, r12vrr_stack+18126);

 /*--- compute (h0|l0)^1 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+27045, r12vrr_stack+23355, r12vrr_stack+26370, r12vrr_stack+21735, r12vrr_stack+22905, r12vrr_stack+18486);

 /*--- compute (i0|l0)^0 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+27990, r12vrr_stack+24705, r12vrr_stack+27045, r12vrr_stack+24030, r12vrr_stack+23355, r12vrr_stack+19026);
 tmp = r12vrr_stack + 27990;
 target_ptr = Libr12->gvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+15074, r12vrr_stack+1086, r12vrr_stack+1383, r12vrr_stack+5739, r12vrr_stack+264, NULL);

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+14112, r12vrr_stack+9502, r12vrr_stack+1086, r12vrr_stack+5139, r12vrr_stack+5739, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29250, r12vrr_stack+14112, r12vrr_stack+15074, NULL, NULL, r12vrr_stack+1086);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+5739, r12vrr_stack+9547, r12vrr_stack+9502, r12vrr_stack+373, r12vrr_stack+5139, NULL);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29415, r12vrr_stack+5739, r12vrr_stack+14112, NULL, NULL, r12vrr_stack+9502);

 /*--- compute (00|m0)^4 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+14167, r12vrr_stack+1383, r12vrr_stack+14067, r12vrr_stack+264, r12vrr_stack+8794, NULL);

 /*--- compute (p0|m0)^3 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29580, r12vrr_stack+15074, r12vrr_stack+14167, NULL, NULL, r12vrr_stack+1383);

 /*--- compute (d0|m0)^2 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29745, r12vrr_stack+29250, r12vrr_stack+29580, r12vrr_stack+14112, r12vrr_stack+15074, r12vrr_stack+21060);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+30075, r12vrr_stack+29415, r12vrr_stack+29250, r12vrr_stack+5739, r12vrr_stack+14112, r12vrr_stack+20790);

 /*--- compute (f0|m0)^1 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+30405, r12vrr_stack+30075, r12vrr_stack+29745, r12vrr_stack+29415, r12vrr_stack+29250, r12vrr_stack+21195);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20790, r12vrr_stack+14022, r12vrr_stack+9547, r12vrr_stack+8758, r12vrr_stack+373, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21060, r12vrr_stack+20790, r12vrr_stack+5739, NULL, NULL, r12vrr_stack+9547);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+30955, r12vrr_stack+21060, r12vrr_stack+29415, r12vrr_stack+20790, r12vrr_stack+5739, r12vrr_stack+20925);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+31285, r12vrr_stack+30955, r12vrr_stack+30075, r12vrr_stack+21060, r12vrr_stack+29415, r12vrr_stack+21465);

 /*--- compute (00|m0)^5 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20845, r12vrr_stack+14067, r12vrr_stack+14894, r12vrr_stack+8794, r12vrr_stack+9142, NULL);

 /*--- compute (p0|m0)^4 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21225, r12vrr_stack+14167, r12vrr_stack+20845, NULL, NULL, r12vrr_stack+14067);

 /*--- compute (d0|m0)^3 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21390, r12vrr_stack+29580, r12vrr_stack+21225, r12vrr_stack+15074, r12vrr_stack+14167, r12vrr_stack+14373);

 /*--- compute (f0|m0)^2 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+31835, r12vrr_stack+29745, r12vrr_stack+21390, r12vrr_stack+29250, r12vrr_stack+29580, r12vrr_stack+14508);

 /*--- compute (g0|m0)^1 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+32385, r12vrr_stack+30405, r12vrr_stack+31835, r12vrr_stack+30075, r12vrr_stack+29745, r12vrr_stack+22905);

 /*--- compute (g0|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+33210, r12vrr_stack+31285, r12vrr_stack+30405, r12vrr_stack+30955, r12vrr_stack+30075, r12vrr_stack+21735);

 /*--- compute (h0|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+34035, r12vrr_stack+33210, r12vrr_stack+32385, r12vrr_stack+31285, r12vrr_stack+30405, r12vrr_stack+23355);
 tmp = r12vrr_stack + 34035;
 target_ptr = Libr12->gvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^14 ---*/
 _BUILD_00p0(Data,r12vrr_stack+5794, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /*--- compute (00|d0)^13 ---*/
 _BUILD_00d0(Data,r12vrr_stack+373, r12vrr_stack+1032, r12vrr_stack+5794, Data->F+13, Data->F+14, NULL);

 /*--- compute (00|f0)^12 ---*/
 _BUILD_00f0(Data,r12vrr_stack+379, r12vrr_stack+14778, r12vrr_stack+373, r12vrr_stack+8830, r12vrr_stack+1032, NULL);

 /*--- compute (00|g0)^11 ---*/
 _BUILD_00g0(Data,r12vrr_stack+389, r12vrr_stack+14784, r12vrr_stack+379, r12vrr_stack+8833, r12vrr_stack+14778, NULL);

 /*--- compute (00|h0)^10 ---*/
 _BUILD_00h0(Data,r12vrr_stack+20900, r12vrr_stack+14794, r12vrr_stack+389, r12vrr_stack+8839, r12vrr_stack+14784, NULL);

 /*--- compute (00|i0)^9 ---*/
 _BUILD_00i0(Data,r12vrr_stack+20921, r12vrr_stack+14809, r12vrr_stack+20900, r12vrr_stack+8849, r12vrr_stack+14794, NULL);

 /*--- compute (00|k0)^8 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+20949, r12vrr_stack+14830, r12vrr_stack+20921, r12vrr_stack+352, r12vrr_stack+14809, NULL);

 /*--- compute (00|l0)^7 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+20985, r12vrr_stack+14858, r12vrr_stack+20949, r12vrr_stack+8864, r12vrr_stack+14830, NULL);

 /*--- compute (00|m0)^6 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21720, r12vrr_stack+14894, r12vrr_stack+20985, r12vrr_stack+9142, r12vrr_stack+14858, NULL);

 /*--- compute (p0|m0)^5 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21775, r12vrr_stack+20845, r12vrr_stack+21720, NULL, NULL, r12vrr_stack+14894);

 /*--- compute (d0|m0)^4 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+35190, r12vrr_stack+21225, r12vrr_stack+21775, r12vrr_stack+14167, r12vrr_stack+20845, r12vrr_stack+14939);

 /*--- compute (f0|m0)^3 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+35520, r12vrr_stack+21390, r12vrr_stack+35190, r12vrr_stack+29580, r12vrr_stack+21225, r12vrr_stack+25650);

 /*--- compute (g0|m0)^2 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+36070, r12vrr_stack+31835, r12vrr_stack+35520, r12vrr_stack+29745, r12vrr_stack+21390, r12vrr_stack+25920);

 /*--- compute (h0|m0)^1 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+36895, r12vrr_stack+32385, r12vrr_stack+36070, r12vrr_stack+30405, r12vrr_stack+31835, r12vrr_stack+26370);

 /*--- compute (i0|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+38050, r12vrr_stack+34035, r12vrr_stack+36895, r12vrr_stack+33210, r12vrr_stack+32385, r12vrr_stack+27045);
 tmp = r12vrr_stack + 38050;
 target_ptr = Libr12->gvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^3 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+21940, r12vrr_stack+15074, r12vrr_stack+14167, r12vrr_stack+1086, r12vrr_stack+1383, NULL);

 /*--- compute (00|n0)^2 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+22006, r12vrr_stack+14112, r12vrr_stack+15074, r12vrr_stack+9502, r12vrr_stack+1086, NULL);

 /*--- compute (p0|n0)^2 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39590, r12vrr_stack+22006, r12vrr_stack+21940, NULL, NULL, r12vrr_stack+15074);

 /*--- compute (00|n0)^1 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+22072, r12vrr_stack+5739, r12vrr_stack+14112, r12vrr_stack+9547, r12vrr_stack+9502, NULL);

 /*--- compute (p0|n0)^1 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39788, r12vrr_stack+22072, r12vrr_stack+22006, NULL, NULL, r12vrr_stack+14112);

 /*--- compute (00|n0)^4 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+39986, r12vrr_stack+14167, r12vrr_stack+20845, r12vrr_stack+1383, r12vrr_stack+14067, NULL);

 /*--- compute (p0|n0)^3 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+40052, r12vrr_stack+21940, r12vrr_stack+39986, NULL, NULL, r12vrr_stack+14167);

 /*--- compute (d0|n0)^2 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+40250, r12vrr_stack+39590, r12vrr_stack+40052, r12vrr_stack+22006, r12vrr_stack+21940, r12vrr_stack+29580);

 /*--- compute (d0|n0)^1 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+40646, r12vrr_stack+39788, r12vrr_stack+39590, r12vrr_stack+22072, r12vrr_stack+22006, r12vrr_stack+29250);

 /*--- compute (f0|n0)^1 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+41042, r12vrr_stack+40646, r12vrr_stack+40250, r12vrr_stack+39788, r12vrr_stack+39590, r12vrr_stack+29745);

 /*--- compute (00|n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29250, r12vrr_stack+20790, r12vrr_stack+5739, r12vrr_stack+14022, r12vrr_stack+9547, NULL);

 /*--- compute (p0|n0)^0 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29580, r12vrr_stack+29250, r12vrr_stack+22072, NULL, NULL, r12vrr_stack+5739);

 /*--- compute (d0|n0)^0 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+41702, r12vrr_stack+29580, r12vrr_stack+39788, r12vrr_stack+29250, r12vrr_stack+22072, r12vrr_stack+29415);

 /*--- compute (f0|n0)^0 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+42098, r12vrr_stack+41702, r12vrr_stack+40646, r12vrr_stack+29580, r12vrr_stack+39788, r12vrr_stack+30075);

 /*--- compute (00|n0)^5 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29316, r12vrr_stack+20845, r12vrr_stack+21720, r12vrr_stack+14067, r12vrr_stack+14894, NULL);

 /*--- compute (p0|n0)^4 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29382, r12vrr_stack+39986, r12vrr_stack+29316, NULL, NULL, r12vrr_stack+20845);

 /*--- compute (d0|n0)^3 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29778, r12vrr_stack+40052, r12vrr_stack+29382, r12vrr_stack+21940, r12vrr_stack+39986, r12vrr_stack+21225);

 /*--- compute (f0|n0)^2 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+42758, r12vrr_stack+40250, r12vrr_stack+29778, r12vrr_stack+39590, r12vrr_stack+40052, r12vrr_stack+21390);

 /*--- compute (g0|n0)^1 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+43418, r12vrr_stack+41042, r12vrr_stack+42758, r12vrr_stack+40646, r12vrr_stack+40250, r12vrr_stack+31835);

 /*--- compute (g0|n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+44408, r12vrr_stack+42098, r12vrr_stack+41042, r12vrr_stack+41702, r12vrr_stack+40646, r12vrr_stack+30405);

 /*--- compute (h0|n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+45398, r12vrr_stack+44408, r12vrr_stack+43418, r12vrr_stack+42098, r12vrr_stack+41042, r12vrr_stack+32385);
 tmp = r12vrr_stack + 45398;
 target_ptr = Libr12->gvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^15 ---*/
 _BUILD_00p0(Data,r12vrr_stack+30174, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /*--- compute (00|d0)^14 ---*/
 _BUILD_00d0(Data,r12vrr_stack+30177, r12vrr_stack+5794, r12vrr_stack+30174, Data->F+14, Data->F+15, NULL);

 /*--- compute (00|f0)^13 ---*/
 _BUILD_00f0(Data,r12vrr_stack+404, r12vrr_stack+373, r12vrr_stack+30177, r12vrr_stack+1032, r12vrr_stack+5794, NULL);

 /*--- compute (00|g0)^12 ---*/
 _BUILD_00g0(Data,r12vrr_stack+30183, r12vrr_stack+379, r12vrr_stack+404, r12vrr_stack+14778, r12vrr_stack+373, NULL);

 /*--- compute (00|h0)^11 ---*/
 _BUILD_00h0(Data,r12vrr_stack+30198, r12vrr_stack+389, r12vrr_stack+30183, r12vrr_stack+14784, r12vrr_stack+379, NULL);

 /*--- compute (00|i0)^10 ---*/
 _BUILD_00i0(Data,r12vrr_stack+30219, r12vrr_stack+20900, r12vrr_stack+30198, r12vrr_stack+14794, r12vrr_stack+389, NULL);

 /*--- compute (00|k0)^9 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+30247, r12vrr_stack+20921, r12vrr_stack+30219, r12vrr_stack+14809, r12vrr_stack+20900, NULL);

 /*--- compute (00|l0)^8 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1086, r12vrr_stack+20949, r12vrr_stack+30247, r12vrr_stack+14830, r12vrr_stack+20921, NULL);

 /*--- compute (00|m0)^7 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+30283, r12vrr_stack+20985, r12vrr_stack+1086, r12vrr_stack+14858, r12vrr_stack+20949, NULL);

 /*--- compute (00|n0)^6 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+30338, r12vrr_stack+21720, r12vrr_stack+30283, r12vrr_stack+14894, r12vrr_stack+20985, NULL);

 /*--- compute (p0|n0)^5 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+30404, r12vrr_stack+29316, r12vrr_stack+30338, NULL, NULL, r12vrr_stack+21720);

 /*--- compute (d0|n0)^4 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+46784, r12vrr_stack+29382, r12vrr_stack+30404, r12vrr_stack+39986, r12vrr_stack+29316, r12vrr_stack+21775);

 /*--- compute (f0|n0)^3 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+47180, r12vrr_stack+29778, r12vrr_stack+46784, r12vrr_stack+40052, r12vrr_stack+29382, r12vrr_stack+35190);

 /*--- compute (g0|n0)^2 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+47840, r12vrr_stack+42758, r12vrr_stack+47180, r12vrr_stack+40250, r12vrr_stack+29778, r12vrr_stack+35520);

 /*--- compute (h0|n0)^1 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+48830, r12vrr_stack+43418, r12vrr_stack+47840, r12vrr_stack+41042, r12vrr_stack+42758, r12vrr_stack+36070);

 /*--- compute (i0|n0)^0 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+50216, r12vrr_stack+45398, r12vrr_stack+48830, r12vrr_stack+44408, r12vrr_stack+43418, r12vrr_stack+36895);
 tmp = r12vrr_stack + 50216;
 target_ptr = Libr12->gvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|o0)^3 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+30602, r12vrr_stack+21940, r12vrr_stack+39986, r12vrr_stack+15074, r12vrr_stack+14167, NULL);

 /*--- compute (00|o0)^2 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+30680, r12vrr_stack+22006, r12vrr_stack+21940, r12vrr_stack+14112, r12vrr_stack+15074, NULL);

 /*--- compute (p0|o0)^2 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+52064, r12vrr_stack+30680, r12vrr_stack+30602, NULL, NULL, r12vrr_stack+21940);

 /*--- compute (00|o0)^1 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+30758, r12vrr_stack+22072, r12vrr_stack+22006, r12vrr_stack+5739, r12vrr_stack+14112, NULL);

 /*--- compute (p0|o0)^1 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+52298, r12vrr_stack+30758, r12vrr_stack+30680, NULL, NULL, r12vrr_stack+22006);

 /*--- compute (00|o0)^4 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+21940, r12vrr_stack+39986, r12vrr_stack+29316, r12vrr_stack+14167, r12vrr_stack+20845, NULL);

 /*--- compute (p0|o0)^3 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+52532, r12vrr_stack+30602, r12vrr_stack+21940, NULL, NULL, r12vrr_stack+39986);

 /*--- compute (d0|o0)^2 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+52766, r12vrr_stack+52064, r12vrr_stack+52532, r12vrr_stack+30680, r12vrr_stack+30602, r12vrr_stack+40052);

 /*--- compute (d0|o0)^1 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+53234, r12vrr_stack+52298, r12vrr_stack+52064, r12vrr_stack+30758, r12vrr_stack+30680, r12vrr_stack+39590);

 /*--- compute (f0|o0)^1 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+53702, r12vrr_stack+53234, r12vrr_stack+52766, r12vrr_stack+52298, r12vrr_stack+52064, r12vrr_stack+40250);

 /*--- compute (00|o0)^0 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+30680, r12vrr_stack+29250, r12vrr_stack+22072, r12vrr_stack+20790, r12vrr_stack+5739, NULL);

 /*--- compute (p0|o0)^0 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+39986, r12vrr_stack+30680, r12vrr_stack+30758, NULL, NULL, r12vrr_stack+22072);

 /*--- compute (d0|o0)^0 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+54482, r12vrr_stack+39986, r12vrr_stack+52298, r12vrr_stack+30680, r12vrr_stack+30758, r12vrr_stack+39788);

 /*--- compute (f0|o0)^0 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+54950, r12vrr_stack+54482, r12vrr_stack+53234, r12vrr_stack+39986, r12vrr_stack+52298, r12vrr_stack+40646);

 /*--- compute (00|o0)^5 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+52298, r12vrr_stack+29316, r12vrr_stack+30338, r12vrr_stack+20845, r12vrr_stack+21720, NULL);

 /*--- compute (p0|o0)^4 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+30680, r12vrr_stack+21940, r12vrr_stack+52298, NULL, NULL, r12vrr_stack+29316);

 /*--- compute (d0|o0)^3 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+39590, r12vrr_stack+52532, r12vrr_stack+30680, r12vrr_stack+30602, r12vrr_stack+21940, r12vrr_stack+29382);

 /*--- compute (f0|o0)^2 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+40058, r12vrr_stack+52766, r12vrr_stack+39590, r12vrr_stack+52064, r12vrr_stack+52532, r12vrr_stack+29778);

 /*--- compute (g0|o0)^1 ---*/
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+55730, r12vrr_stack+53702, r12vrr_stack+40058, r12vrr_stack+53234, r12vrr_stack+52766, r12vrr_stack+42758);

 /*--- compute (g0|o0)^0 ---*/
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+56900, r12vrr_stack+54950, r12vrr_stack+53702, r12vrr_stack+54482, r12vrr_stack+53234, r12vrr_stack+41042);

 /*--- compute (h0|o0)^0 ---*/
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+58070, r12vrr_stack+56900, r12vrr_stack+55730, r12vrr_stack+54950, r12vrr_stack+53702, r12vrr_stack+43418);
 tmp = r12vrr_stack + 58070;
 target_ptr = Libr12->gvrr_classes[5][11];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^6 ---*/
 _BUILD_p000(Data,r12vrr_stack+1032, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (d0|00)^5 ---*/
 _BUILD_d000(Data,r12vrr_stack+53234, r12vrr_stack+500, r12vrr_stack+1032, Data->F+5, Data->F+6, NULL);

 /*--- compute (f0|00)^4 ---*/
 _BUILD_f000(Data,r12vrr_stack+53240, r12vrr_stack+54, r12vrr_stack+53234, r12vrr_stack+0, r12vrr_stack+500, NULL);

 /*--- compute (p0|p0)^6 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+5587, r12vrr_stack+105, r12vrr_stack+78, NULL, NULL, Data->F+7);

 /*--- compute (d0|p0)^5 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+60, r12vrr_stack+503, r12vrr_stack+5587, r12vrr_stack+9, r12vrr_stack+105, r12vrr_stack+1032);

 /*--- compute (f0|p0)^4 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+21030, r12vrr_stack+2775, r12vrr_stack+60, r12vrr_stack+12, r12vrr_stack+503, r12vrr_stack+53234);

 /*--- compute (g0|p0)^3 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+53250, r12vrr_stack+2793, r12vrr_stack+21030, r12vrr_stack+30, r12vrr_stack+2775, r12vrr_stack+53240);

 /*--- compute (p0|d0)^6 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+9, r12vrr_stack+87, r12vrr_stack+414, NULL, NULL, r12vrr_stack+78);

 /*--- compute (d0|d0)^5 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+53295, r12vrr_stack+2823, r12vrr_stack+9, r12vrr_stack+108, r12vrr_stack+87, r12vrr_stack+5587);

 /*--- compute (f0|d0)^4 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+264, r12vrr_stack+2841, r12vrr_stack+53295, r12vrr_stack+114, r12vrr_stack+2823, r12vrr_stack+60);

 /*--- compute (g0|d0)^3 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+53331, r12vrr_stack+2877, r12vrr_stack+264, r12vrr_stack+132, r12vrr_stack+2841, r12vrr_stack+21030);

 /*--- compute (h0|d0)^2 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+14112, r12vrr_stack+2937, r12vrr_stack+53331, r12vrr_stack+204, r12vrr_stack+2877, r12vrr_stack+53250);

 /*--- compute (p0|f0)^6 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+960, r12vrr_stack+430, r12vrr_stack+710, NULL, NULL, r12vrr_stack+414);

 /*--- compute (d0|f0)^5 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+204, r12vrr_stack+168, r12vrr_stack+960, r12vrr_stack+93, r12vrr_stack+430, r12vrr_stack+9);

 /*--- compute (f0|f0)^4 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+53421, r12vrr_stack+3027, r12vrr_stack+204, r12vrr_stack+520, r12vrr_stack+168, r12vrr_stack+53295);

 /*--- compute (g0|f0)^3 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+53521, r12vrr_stack+3087, r12vrr_stack+53421, r12vrr_stack+550, r12vrr_stack+3027, r12vrr_stack+264);

 /*--- compute (h0|f0)^2 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+54482, r12vrr_stack+3187, r12vrr_stack+53521, r12vrr_stack+610, r12vrr_stack+3087, r12vrr_stack+53331);

 /*--- compute (i0|f0)^1 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+54692, r12vrr_stack+3337, r12vrr_stack+54482, r12vrr_stack+810, r12vrr_stack+3187, r12vrr_stack+14112);

 /*--- compute (p0|g0)^6 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+108, r12vrr_stack+720, r12vrr_stack+1050, NULL, NULL, r12vrr_stack+710);

 /*--- compute (d0|g0)^5 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+54972, r12vrr_stack+735, r12vrr_stack+108, r12vrr_stack+440, r12vrr_stack+720, r12vrr_stack+960);

 /*--- compute (f0|g0)^4 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+55062, r12vrr_stack+3547, r12vrr_stack+54972, r12vrr_stack+455, r12vrr_stack+735, r12vrr_stack+204);

 /*--- compute (g0|g0)^3 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+55212, r12vrr_stack+3637, r12vrr_stack+55062, r12vrr_stack+1770, r12vrr_stack+3547, r12vrr_stack+53421);

 /*--- compute (h0|g0)^2 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+40838, r12vrr_stack+3787, r12vrr_stack+55212, r12vrr_stack+1860, r12vrr_stack+3637, r12vrr_stack+53521);

 /*--- compute (i0|g0)^1 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+41153, r12vrr_stack+4012, r12vrr_stack+40838, r12vrr_stack+2010, r12vrr_stack+3787, r12vrr_stack+54482);

 /*--- compute (k0|g0)^0 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+59708, r12vrr_stack+4327, r12vrr_stack+41153, r12vrr_stack+2460, r12vrr_stack+4012, r12vrr_stack+54692);

 /*--- compute (p0|h0)^6 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1770, r12vrr_stack+1065, r12vrr_stack+5606, NULL, NULL, r12vrr_stack+1050);

 /*--- compute (d0|h0)^5 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1833, r12vrr_stack+1194, r12vrr_stack+1770, r12vrr_stack+990, r12vrr_stack+1065, r12vrr_stack+108);

 /*--- compute (f0|h0)^4 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+1959, r12vrr_stack+1257, r12vrr_stack+1833, r12vrr_stack+5188, r12vrr_stack+1194, r12vrr_stack+54972);

 /*--- compute (g0|h0)^3 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+60248, r12vrr_stack+6763, r12vrr_stack+1959, r12vrr_stack+5251, r12vrr_stack+1257, r12vrr_stack+55062);

 /*--- compute (h0|h0)^2 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+60563, r12vrr_stack+6973, r12vrr_stack+60248, r12vrr_stack+5377, r12vrr_stack+6763, r12vrr_stack+55212);

 /*--- compute (i0|h0)^1 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+61004, r12vrr_stack+7288, r12vrr_stack+60563, r12vrr_stack+5797, r12vrr_stack+6973, r12vrr_stack+40838);

 /*--- compute (k0|h0)^0 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+61592, r12vrr_stack+8170, r12vrr_stack+61004, r12vrr_stack+7729, r12vrr_stack+7288, r12vrr_stack+41153);
 tmp = r12vrr_stack + 61592;
 target_ptr = Libr12->gvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^6 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5797, r12vrr_stack+5627, r12vrr_stack+8864, NULL, NULL, r12vrr_stack+5606);

 /*--- compute (d0|i0)^5 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5881, r12vrr_stack+5655, r12vrr_stack+5797, r12vrr_stack+4859, r12vrr_stack+5627, r12vrr_stack+1770);

 /*--- compute (f0|i0)^4 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+55437, r12vrr_stack+11782, r12vrr_stack+5881, r12vrr_stack+4887, r12vrr_stack+5655, r12vrr_stack+1833);

 /*--- compute (g0|i0)^3 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+5139, r12vrr_stack+11950, r12vrr_stack+55437, r12vrr_stack+4971, r12vrr_stack+11782, r12vrr_stack+1959);

 /*--- compute (h0|i0)^2 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+62348, r12vrr_stack+12230, r12vrr_stack+5139, r12vrr_stack+10074, r12vrr_stack+11950, r12vrr_stack+60248);

 /*--- compute (i0|i0)^1 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+62936, r12vrr_stack+12650, r12vrr_stack+62348, r12vrr_stack+10354, r12vrr_stack+12230, r12vrr_stack+60563);

 /*--- compute (k0|i0)^0 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+63720, r12vrr_stack+13238, r12vrr_stack+62936, r12vrr_stack+11194, r12vrr_stack+12650, r12vrr_stack+61004);
 tmp = r12vrr_stack + 63720;
 target_ptr = Libr12->gvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^6 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10074, r12vrr_stack+9142, r12vrr_stack+14858, NULL, NULL, r12vrr_stack+8864);

 /*--- compute (d0|k0)^5 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10182, r12vrr_stack+9178, r12vrr_stack+10074, r12vrr_stack+8794, r12vrr_stack+9142, r12vrr_stack+5797);

 /*--- compute (f0|k0)^4 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10398, r12vrr_stack+9286, r12vrr_stack+10182, r12vrr_stack+9034, r12vrr_stack+9178, r12vrr_stack+5881);

 /*--- compute (g0|k0)^3 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+64728, r12vrr_stack+18126, r12vrr_stack+10398, r12vrr_stack+15714, r12vrr_stack+9286, r12vrr_stack+55437);

 /*--- compute (h0|k0)^2 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+65268, r12vrr_stack+18486, r12vrr_stack+64728, r12vrr_stack+15930, r12vrr_stack+18126, r12vrr_stack+5139);

 /*--- compute (i0|k0)^1 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+66024, r12vrr_stack+19026, r12vrr_stack+65268, r12vrr_stack+16290, r12vrr_stack+18486, r12vrr_stack+62348);

 /*--- compute (k0|k0)^0 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+67032, r12vrr_stack+19782, r12vrr_stack+66024, r12vrr_stack+17370, r12vrr_stack+19026, r12vrr_stack+62936);
 tmp = r12vrr_stack + 67032;
 target_ptr = Libr12->gvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^6 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15714, r12vrr_stack+14894, r12vrr_stack+20985, NULL, NULL, r12vrr_stack+14858);

 /*--- compute (d0|l0)^5 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15849, r12vrr_stack+14939, r12vrr_stack+15714, r12vrr_stack+14067, r12vrr_stack+14894, r12vrr_stack+10074);

 /*--- compute (f0|l0)^4 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16119, r12vrr_stack+25650, r12vrr_stack+15849, r12vrr_stack+14373, r12vrr_stack+14939, r12vrr_stack+10182);

 /*--- compute (g0|l0)^3 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+68328, r12vrr_stack+25920, r12vrr_stack+16119, r12vrr_stack+14508, r12vrr_stack+25650, r12vrr_stack+10398);

 /*--- compute (h0|l0)^2 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+69003, r12vrr_stack+26370, r12vrr_stack+68328, r12vrr_stack+22905, r12vrr_stack+25920, r12vrr_stack+64728);

 /*--- compute (i0|l0)^1 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+69948, r12vrr_stack+27045, r12vrr_stack+69003, r12vrr_stack+23355, r12vrr_stack+26370, r12vrr_stack+65268);

 /*--- compute (k0|l0)^0 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+71208, r12vrr_stack+27990, r12vrr_stack+69948, r12vrr_stack+24705, r12vrr_stack+27045, r12vrr_stack+66024);
 tmp = r12vrr_stack + 71208;
 target_ptr = Libr12->gvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|m0)^6 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+22905, r12vrr_stack+21720, r12vrr_stack+30283, NULL, NULL, r12vrr_stack+20985);

 /*--- compute (d0|m0)^5 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+23070, r12vrr_stack+21775, r12vrr_stack+22905, r12vrr_stack+20845, r12vrr_stack+21720, r12vrr_stack+15714);

 /*--- compute (f0|m0)^4 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+23400, r12vrr_stack+35190, r12vrr_stack+23070, r12vrr_stack+21225, r12vrr_stack+21775, r12vrr_stack+15849);

 /*--- compute (g0|m0)^3 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+72828, r12vrr_stack+35520, r12vrr_stack+23400, r12vrr_stack+21390, r12vrr_stack+35190, r12vrr_stack+16119);

 /*--- compute (h0|m0)^2 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+73653, r12vrr_stack+36070, r12vrr_stack+72828, r12vrr_stack+31835, r12vrr_stack+35520, r12vrr_stack+68328);

 /*--- compute (i0|m0)^1 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+74808, r12vrr_stack+36895, r12vrr_stack+73653, r12vrr_stack+32385, r12vrr_stack+36070, r12vrr_stack+69003);

 /*--- compute (k0|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+76348, r12vrr_stack+38050, r12vrr_stack+74808, r12vrr_stack+34035, r12vrr_stack+36895, r12vrr_stack+69948);
 tmp = r12vrr_stack + 76348;
 target_ptr = Libr12->gvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^16 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /*--- compute (00|d0)^15 ---*/
 _BUILD_00d0(Data,r12vrr_stack+31835, r12vrr_stack+30174, r12vrr_stack+0, Data->F+15, Data->F+16, NULL);

 /*--- compute (00|f0)^14 ---*/
 _BUILD_00f0(Data,r12vrr_stack+31841, r12vrr_stack+30177, r12vrr_stack+31835, r12vrr_stack+5794, r12vrr_stack+30174, NULL);

 /*--- compute (00|g0)^13 ---*/
 _BUILD_00g0(Data,r12vrr_stack+153, r12vrr_stack+404, r12vrr_stack+31841, r12vrr_stack+373, r12vrr_stack+30177, NULL);

 /*--- compute (00|h0)^12 ---*/
 _BUILD_00h0(Data,r12vrr_stack+990, r12vrr_stack+30183, r12vrr_stack+153, r12vrr_stack+379, r12vrr_stack+404, NULL);

 /*--- compute (00|i0)^11 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5559, r12vrr_stack+30198, r12vrr_stack+990, r12vrr_stack+389, r12vrr_stack+30183, NULL);

 /*--- compute (00|k0)^10 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+31851, r12vrr_stack+30219, r12vrr_stack+5559, r12vrr_stack+20900, r12vrr_stack+30198, NULL);

 /*--- compute (00|l0)^9 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14067, r12vrr_stack+30247, r12vrr_stack+31851, r12vrr_stack+20921, r12vrr_stack+30219, NULL);

 /*--- compute (00|m0)^8 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+8794, r12vrr_stack+1086, r12vrr_stack+14067, r12vrr_stack+20949, r12vrr_stack+30247, NULL);

 /*--- compute (00|n0)^7 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+2169, r12vrr_stack+30283, r12vrr_stack+8794, r12vrr_stack+20985, r12vrr_stack+1086, NULL);

 /*--- compute (p0|n0)^6 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+512, r12vrr_stack+30338, r12vrr_stack+2169, NULL, NULL, r12vrr_stack+30283);

 /*--- compute (d0|n0)^5 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+31887, r12vrr_stack+30404, r12vrr_stack+512, r12vrr_stack+29316, r12vrr_stack+30338, r12vrr_stack+22905);

 /*--- compute (f0|n0)^4 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+32283, r12vrr_stack+46784, r12vrr_stack+31887, r12vrr_stack+29382, r12vrr_stack+30404, r12vrr_stack+23070);

 /*--- compute (g0|n0)^3 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+78328, r12vrr_stack+47180, r12vrr_stack+32283, r12vrr_stack+29778, r12vrr_stack+46784, r12vrr_stack+23400);

 /*--- compute (h0|n0)^2 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+79318, r12vrr_stack+47840, r12vrr_stack+78328, r12vrr_stack+42758, r12vrr_stack+47180, r12vrr_stack+72828);

 /*--- compute (i0|n0)^1 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+80704, r12vrr_stack+48830, r12vrr_stack+79318, r12vrr_stack+43418, r12vrr_stack+47840, r12vrr_stack+73653);

 /*--- compute (k0|n0)^0 ---*/
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+82552, r12vrr_stack+50216, r12vrr_stack+80704, r12vrr_stack+45398, r12vrr_stack+48830, r12vrr_stack+74808);
 tmp = r12vrr_stack + 82552;
 target_ptr = Libr12->gvrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|o0)^6 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+30602, r12vrr_stack+30338, r12vrr_stack+2169, r12vrr_stack+21720, r12vrr_stack+30283, NULL);

 /*--- compute (p0|o0)^5 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+52064, r12vrr_stack+52298, r12vrr_stack+30602, NULL, NULL, r12vrr_stack+30338);

 /*--- compute (d0|o0)^4 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+42758, r12vrr_stack+30680, r12vrr_stack+52064, r12vrr_stack+21940, r12vrr_stack+52298, r12vrr_stack+30404);

 /*--- compute (f0|o0)^3 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+43226, r12vrr_stack+39590, r12vrr_stack+42758, r12vrr_stack+52532, r12vrr_stack+30680, r12vrr_stack+46784);

 /*--- compute (g0|o0)^2 ---*/
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+84928, r12vrr_stack+40058, r12vrr_stack+43226, r12vrr_stack+52766, r12vrr_stack+39590, r12vrr_stack+47180);

 /*--- compute (h0|o0)^1 ---*/
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+86098, r12vrr_stack+55730, r12vrr_stack+84928, r12vrr_stack+53702, r12vrr_stack+40058, r12vrr_stack+47840);

 /*--- compute (i0|o0)^0 ---*/
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+87736, r12vrr_stack+58070, r12vrr_stack+86098, r12vrr_stack+56900, r12vrr_stack+55730, r12vrr_stack+48830);
 tmp = r12vrr_stack + 87736;
 target_ptr = Libr12->gvrr_classes[6][11];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^7 ---*/
 _BUILD_p000(Data,r12vrr_stack+21940, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (d0|00)^6 ---*/
 _BUILD_d000(Data,r12vrr_stack+21943, r12vrr_stack+1032, r12vrr_stack+21940, Data->F+6, Data->F+7, NULL);

 /*--- compute (f0|00)^5 ---*/
 _BUILD_f000(Data,r12vrr_stack+21949, r12vrr_stack+53234, r12vrr_stack+21943, r12vrr_stack+500, r12vrr_stack+1032, NULL);

 /*--- compute (g0|00)^4 ---*/
 _BUILD_g000(Data,r12vrr_stack+21959, r12vrr_stack+53240, r12vrr_stack+21949, r12vrr_stack+54, r12vrr_stack+53234, NULL);

 /*--- compute (p0|p0)^7 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21974, r12vrr_stack+78, r12vrr_stack+6, NULL, NULL, Data->F+8);

 /*--- compute (d0|p0)^6 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+21983, r12vrr_stack+5587, r12vrr_stack+21974, r12vrr_stack+105, r12vrr_stack+78, r12vrr_stack+21940);

 /*--- compute (f0|p0)^5 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+22001, r12vrr_stack+60, r12vrr_stack+21983, r12vrr_stack+503, r12vrr_stack+5587, r12vrr_stack+21943);

 /*--- compute (g0|p0)^4 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+22031, r12vrr_stack+21030, r12vrr_stack+22001, r12vrr_stack+2775, r12vrr_stack+60, r12vrr_stack+21949);

 /*--- compute (h0|p0)^3 ---*/
 _BUILD_h0p0(Data,r12vrr_stack+6049, r12vrr_stack+53250, r12vrr_stack+22031, r12vrr_stack+2793, r12vrr_stack+21030, r12vrr_stack+21959);

 /*--- compute (p0|d0)^7 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+2775, r12vrr_stack+414, r12vrr_stack+198, NULL, NULL, r12vrr_stack+6);

 /*--- compute (d0|d0)^6 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+22076, r12vrr_stack+9, r12vrr_stack+2775, r12vrr_stack+87, r12vrr_stack+414, r12vrr_stack+21974);

 /*--- compute (f0|d0)^5 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+22112, r12vrr_stack+53295, r12vrr_stack+22076, r12vrr_stack+2823, r12vrr_stack+9, r12vrr_stack+21983);

 /*--- compute (g0|d0)^4 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+44006, r12vrr_stack+264, r12vrr_stack+22112, r12vrr_stack+2841, r12vrr_stack+53295, r12vrr_stack+22001);

 /*--- compute (h0|d0)^3 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+44096, r12vrr_stack+53331, r12vrr_stack+44006, r12vrr_stack+2877, r12vrr_stack+264, r12vrr_stack+22031);

 /*--- compute (i0|d0)^2 ---*/
 _BUILD_i0d0(Data,r12vrr_stack+44222, r12vrr_stack+14112, r12vrr_stack+44096, r12vrr_stack+2937, r12vrr_stack+53331, r12vrr_stack+6049);

 /*--- compute (p0|f0)^7 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+2793, r12vrr_stack+710, r12vrr_stack+420, NULL, NULL, r12vrr_stack+198);

 /*--- compute (d0|f0)^6 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+2823, r12vrr_stack+960, r12vrr_stack+2793, r12vrr_stack+430, r12vrr_stack+710, r12vrr_stack+2775);

 /*--- compute (f0|f0)^5 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+2883, r12vrr_stack+204, r12vrr_stack+2823, r12vrr_stack+168, r12vrr_stack+960, r12vrr_stack+22076);

 /*--- compute (g0|f0)^4 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+29778, r12vrr_stack+53421, r12vrr_stack+2883, r12vrr_stack+3027, r12vrr_stack+204, r12vrr_stack+22112);

 /*--- compute (h0|f0)^3 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+29928, r12vrr_stack+53521, r12vrr_stack+29778, r12vrr_stack+3087, r12vrr_stack+53421, r12vrr_stack+44006);

 /*--- compute (i0|f0)^2 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+4859, r12vrr_stack+54482, r12vrr_stack+29928, r12vrr_stack+3187, r12vrr_stack+53521, r12vrr_stack+44096);

 /*--- compute (k0|f0)^1 ---*/
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+21225, r12vrr_stack+54692, r12vrr_stack+4859, r12vrr_stack+3337, r12vrr_stack+54482, r12vrr_stack+44222);

 /*--- compute (p0|g0)^7 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+430, r12vrr_stack+1050, r12vrr_stack+1035, NULL, NULL, r12vrr_stack+420);

 /*--- compute (d0|g0)^6 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2983, r12vrr_stack+108, r12vrr_stack+430, r12vrr_stack+720, r12vrr_stack+1050, r12vrr_stack+2793);

 /*--- compute (f0|g0)^5 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+3073, r12vrr_stack+54972, r12vrr_stack+2983, r12vrr_stack+735, r12vrr_stack+108, r12vrr_stack+2823);

 /*--- compute (g0|g0)^4 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+720, r12vrr_stack+55062, r12vrr_stack+3073, r12vrr_stack+3547, r12vrr_stack+54972, r12vrr_stack+2883);

 /*--- compute (h0|g0)^3 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+3223, r12vrr_stack+55212, r12vrr_stack+720, r12vrr_stack+3637, r12vrr_stack+55062, r12vrr_stack+29778);

 /*--- compute (i0|g0)^2 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+14373, r12vrr_stack+40838, r12vrr_stack+3223, r12vrr_stack+3787, r12vrr_stack+55212, r12vrr_stack+29928);

 /*--- compute (k0|g0)^1 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+53671, r12vrr_stack+41153, r12vrr_stack+14373, r12vrr_stack+4012, r12vrr_stack+40838, r12vrr_stack+4859);

 /*--- compute (l0|g0)^0 ---*/
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+3538, r12vrr_stack+59708, r12vrr_stack+53671, r12vrr_stack+4327, r12vrr_stack+41153, r12vrr_stack+21225);

 /*--- compute (p0|h0)^7 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4213, r12vrr_stack+5606, r12vrr_stack+352, NULL, NULL, r12vrr_stack+1035);

 /*--- compute (d0|h0)^6 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+29316, r12vrr_stack+1770, r12vrr_stack+4213, r12vrr_stack+1065, r12vrr_stack+5606, r12vrr_stack+430);

 /*--- compute (f0|h0)^5 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+32943, r12vrr_stack+1833, r12vrr_stack+29316, r12vrr_stack+1194, r12vrr_stack+1770, r12vrr_stack+2983);

 /*--- compute (g0|h0)^4 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+52376, r12vrr_stack+1959, r12vrr_stack+32943, r12vrr_stack+1257, r12vrr_stack+1833, r12vrr_stack+3073);

 /*--- compute (h0|h0)^3 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+52691, r12vrr_stack+60248, r12vrr_stack+52376, r12vrr_stack+6763, r12vrr_stack+1959, r12vrr_stack+720);

 /*--- compute (i0|h0)^2 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+89920, r12vrr_stack+60563, r12vrr_stack+52691, r12vrr_stack+6973, r12vrr_stack+60248, r12vrr_stack+3223);

 /*--- compute (k0|h0)^1 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+90508, r12vrr_stack+61004, r12vrr_stack+89920, r12vrr_stack+7288, r12vrr_stack+60563, r12vrr_stack+14373);

 /*--- compute (l0|h0)^0 ---*/
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+6763, r12vrr_stack+61592, r12vrr_stack+90508, r12vrr_stack+8170, r12vrr_stack+61004, r12vrr_stack+53671);
 tmp = r12vrr_stack + 6763;
 target_ptr = Libr12->gvrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^7 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1194, r12vrr_stack+8864, r12vrr_stack+14830, NULL, NULL, r12vrr_stack+352);

 /*--- compute (d0|i0)^6 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+1278, r12vrr_stack+5797, r12vrr_stack+1194, r12vrr_stack+5627, r12vrr_stack+8864, r12vrr_stack+4213);

 /*--- compute (f0|i0)^5 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+91264, r12vrr_stack+5881, r12vrr_stack+1278, r12vrr_stack+5655, r12vrr_stack+5797, r12vrr_stack+29316);

 /*--- compute (g0|i0)^4 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+91544, r12vrr_stack+55437, r12vrr_stack+91264, r12vrr_stack+11782, r12vrr_stack+5881, r12vrr_stack+32943);

 /*--- compute (h0|i0)^3 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+91964, r12vrr_stack+5139, r12vrr_stack+91544, r12vrr_stack+11950, r12vrr_stack+55437, r12vrr_stack+52376);

 /*--- compute (i0|i0)^2 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+92552, r12vrr_stack+62348, r12vrr_stack+91964, r12vrr_stack+12230, r12vrr_stack+5139, r12vrr_stack+52691);

 /*--- compute (k0|i0)^1 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+93336, r12vrr_stack+62936, r12vrr_stack+92552, r12vrr_stack+12650, r12vrr_stack+62348, r12vrr_stack+89920);

 /*--- compute (l0|i0)^0 ---*/
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+11782, r12vrr_stack+63720, r12vrr_stack+93336, r12vrr_stack+13238, r12vrr_stack+62936, r12vrr_stack+90508);
 tmp = r12vrr_stack + 11782;
 target_ptr = Libr12->gvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^7 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9034, r12vrr_stack+14858, r12vrr_stack+20949, NULL, NULL, r12vrr_stack+14830);

 /*--- compute (d0|k0)^6 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+16569, r12vrr_stack+10074, r12vrr_stack+9034, r12vrr_stack+9142, r12vrr_stack+14858, r12vrr_stack+1194);

 /*--- compute (f0|k0)^5 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+94344, r12vrr_stack+10182, r12vrr_stack+16569, r12vrr_stack+9178, r12vrr_stack+10074, r12vrr_stack+1278);

 /*--- compute (g0|k0)^4 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+94704, r12vrr_stack+10398, r12vrr_stack+94344, r12vrr_stack+9286, r12vrr_stack+10182, r12vrr_stack+91264);

 /*--- compute (h0|k0)^3 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+95244, r12vrr_stack+64728, r12vrr_stack+94704, r12vrr_stack+18126, r12vrr_stack+10398, r12vrr_stack+91544);

 /*--- compute (i0|k0)^2 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+96000, r12vrr_stack+65268, r12vrr_stack+95244, r12vrr_stack+18486, r12vrr_stack+64728, r12vrr_stack+91964);

 /*--- compute (k0|k0)^1 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+97008, r12vrr_stack+66024, r12vrr_stack+96000, r12vrr_stack+19026, r12vrr_stack+65268, r12vrr_stack+92552);

 /*--- compute (l0|k0)^0 ---*/
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18126, r12vrr_stack+67032, r12vrr_stack+97008, r12vrr_stack+19782, r12vrr_stack+66024, r12vrr_stack+93336);
 tmp = r12vrr_stack + 18126;
 target_ptr = Libr12->gvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^7 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21585, r12vrr_stack+20985, r12vrr_stack+1086, NULL, NULL, r12vrr_stack+20949);

 /*--- compute (d0|l0)^6 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9142, r12vrr_stack+15714, r12vrr_stack+21585, r12vrr_stack+14894, r12vrr_stack+20985, r12vrr_stack+9034);

 /*--- compute (f0|l0)^5 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+98304, r12vrr_stack+15849, r12vrr_stack+9142, r12vrr_stack+14939, r12vrr_stack+15714, r12vrr_stack+16569);

 /*--- compute (g0|l0)^4 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+98754, r12vrr_stack+16119, r12vrr_stack+98304, r12vrr_stack+25650, r12vrr_stack+15849, r12vrr_stack+94344);

 /*--- compute (h0|l0)^3 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+99429, r12vrr_stack+68328, r12vrr_stack+98754, r12vrr_stack+25920, r12vrr_stack+16119, r12vrr_stack+94704);

 /*--- compute (i0|l0)^2 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+100374, r12vrr_stack+69003, r12vrr_stack+99429, r12vrr_stack+26370, r12vrr_stack+68328, r12vrr_stack+95244);

 /*--- compute (k0|l0)^1 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+101634, r12vrr_stack+69948, r12vrr_stack+100374, r12vrr_stack+27045, r12vrr_stack+69003, r12vrr_stack+96000);

 /*--- compute (l0|l0)^0 ---*/
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+25650, r12vrr_stack+71208, r12vrr_stack+101634, r12vrr_stack+27990, r12vrr_stack+69948, r12vrr_stack+97008);
 tmp = r12vrr_stack + 25650;
 target_ptr = Libr12->gvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|m0)^7 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+27675, r12vrr_stack+30283, r12vrr_stack+8794, NULL, NULL, r12vrr_stack+1086);

 /*--- compute (d0|m0)^6 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+103254, r12vrr_stack+22905, r12vrr_stack+27675, r12vrr_stack+21720, r12vrr_stack+30283, r12vrr_stack+21585);

 /*--- compute (f0|m0)^5 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+103584, r12vrr_stack+23070, r12vrr_stack+103254, r12vrr_stack+21775, r12vrr_stack+22905, r12vrr_stack+9142);

 /*--- compute (g0|m0)^4 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+104134, r12vrr_stack+23400, r12vrr_stack+103584, r12vrr_stack+35190, r12vrr_stack+23070, r12vrr_stack+98304);

 /*--- compute (h0|m0)^3 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+104959, r12vrr_stack+72828, r12vrr_stack+104134, r12vrr_stack+35520, r12vrr_stack+23400, r12vrr_stack+98754);

 /*--- compute (i0|m0)^2 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+106114, r12vrr_stack+73653, r12vrr_stack+104959, r12vrr_stack+36070, r12vrr_stack+72828, r12vrr_stack+99429);

 /*--- compute (k0|m0)^1 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+107654, r12vrr_stack+74808, r12vrr_stack+106114, r12vrr_stack+36895, r12vrr_stack+73653, r12vrr_stack+100374);

 /*--- compute (l0|m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+35190, r12vrr_stack+76348, r12vrr_stack+107654, r12vrr_stack+38050, r12vrr_stack+74808, r12vrr_stack+101634);
 tmp = r12vrr_stack + 35190;
 target_ptr = Libr12->gvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^17 ---*/
 _BUILD_00p0(Data,r12vrr_stack+37665, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /*--- compute (00|d0)^16 ---*/
 _BUILD_00d0(Data,r12vrr_stack+54, r12vrr_stack+0, r12vrr_stack+37665, Data->F+16, Data->F+17, NULL);

 /*--- compute (00|f0)^15 ---*/
 _BUILD_00f0(Data,r12vrr_stack+37668, r12vrr_stack+31835, r12vrr_stack+54, r12vrr_stack+30174, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^14 ---*/
 _BUILD_00g0(Data,r12vrr_stack+945, r12vrr_stack+31841, r12vrr_stack+37668, r12vrr_stack+30177, r12vrr_stack+31835, NULL);

 /*--- compute (00|h0)^13 ---*/
 _BUILD_00h0(Data,r12vrr_stack+7708, r12vrr_stack+153, r12vrr_stack+945, r12vrr_stack+404, r12vrr_stack+31841, NULL);

 /*--- compute (00|i0)^12 ---*/
 _BUILD_00i0(Data,r12vrr_stack+37678, r12vrr_stack+990, r12vrr_stack+7708, r12vrr_stack+30183, r12vrr_stack+153, NULL);

 /*--- compute (00|k0)^11 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+19746, r12vrr_stack+5559, r12vrr_stack+37678, r12vrr_stack+30198, r12vrr_stack+990, NULL);

 /*--- compute (00|l0)^10 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16785, r12vrr_stack+31851, r12vrr_stack+19746, r12vrr_stack+30219, r12vrr_stack+5559, NULL);

 /*--- compute (00|m0)^9 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+37706, r12vrr_stack+14067, r12vrr_stack+16785, r12vrr_stack+30247, r12vrr_stack+31851, NULL);

 /*--- compute (00|n0)^8 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+37761, r12vrr_stack+8794, r12vrr_stack+37706, r12vrr_stack+1086, r12vrr_stack+14067, NULL);

 /*--- compute (p0|n0)^7 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+37827, r12vrr_stack+2169, r12vrr_stack+37761, NULL, NULL, r12vrr_stack+8794);

 /*--- compute (d0|n0)^6 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+109634, r12vrr_stack+512, r12vrr_stack+37827, r12vrr_stack+30338, r12vrr_stack+2169, r12vrr_stack+27675);

 /*--- compute (f0|n0)^5 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+110030, r12vrr_stack+31887, r12vrr_stack+109634, r12vrr_stack+30404, r12vrr_stack+512, r12vrr_stack+103254);

 /*--- compute (g0|n0)^4 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+110690, r12vrr_stack+32283, r12vrr_stack+110030, r12vrr_stack+46784, r12vrr_stack+31887, r12vrr_stack+103584);

 /*--- compute (h0|n0)^3 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+111680, r12vrr_stack+78328, r12vrr_stack+110690, r12vrr_stack+47180, r12vrr_stack+32283, r12vrr_stack+104134);

 /*--- compute (i0|n0)^2 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+113066, r12vrr_stack+79318, r12vrr_stack+111680, r12vrr_stack+47840, r12vrr_stack+78328, r12vrr_stack+104959);

 /*--- compute (k0|n0)^1 ---*/
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+114914, r12vrr_stack+80704, r12vrr_stack+113066, r12vrr_stack+48830, r12vrr_stack+79318, r12vrr_stack+106114);

 /*--- compute (l0|n0)^0 ---*/
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+46784, r12vrr_stack+82552, r12vrr_stack+114914, r12vrr_stack+50216, r12vrr_stack+80704, r12vrr_stack+107654);
 tmp = r12vrr_stack + 46784;
 target_ptr = Libr12->gvrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|o0)^7 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+49754, r12vrr_stack+2169, r12vrr_stack+37761, r12vrr_stack+30283, r12vrr_stack+8794, NULL);

 /*--- compute (p0|o0)^6 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+49832, r12vrr_stack+30602, r12vrr_stack+49754, NULL, NULL, r12vrr_stack+2169);

 /*--- compute (d0|o0)^5 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+117290, r12vrr_stack+52064, r12vrr_stack+49832, r12vrr_stack+52298, r12vrr_stack+30602, r12vrr_stack+512);

 /*--- compute (f0|o0)^4 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+117758, r12vrr_stack+42758, r12vrr_stack+117290, r12vrr_stack+30680, r12vrr_stack+52064, r12vrr_stack+31887);

 /*--- compute (g0|o0)^3 ---*/
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+118538, r12vrr_stack+43226, r12vrr_stack+117758, r12vrr_stack+39590, r12vrr_stack+42758, r12vrr_stack+32283);

 /*--- compute (h0|o0)^2 ---*/
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+119708, r12vrr_stack+84928, r12vrr_stack+118538, r12vrr_stack+40058, r12vrr_stack+43226, r12vrr_stack+78328);

 /*--- compute (i0|o0)^1 ---*/
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+121346, r12vrr_stack+86098, r12vrr_stack+119708, r12vrr_stack+55730, r12vrr_stack+84928, r12vrr_stack+79318);

 /*--- compute (k0|o0)^0 ---*/
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+123530, r12vrr_stack+87736, r12vrr_stack+121346, r12vrr_stack+58070, r12vrr_stack+86098, r12vrr_stack+80704);
 tmp = r12vrr_stack + 123530;
 target_ptr = Libr12->gvrr_classes[7][11];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^8 ---*/
 _BUILD_p000(Data,r12vrr_stack+39590, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (d0|00)^7 ---*/
 _BUILD_d000(Data,r12vrr_stack+39593, r12vrr_stack+21940, r12vrr_stack+39590, Data->F+7, Data->F+8, NULL);

 /*--- compute (f0|00)^6 ---*/
 _BUILD_f000(Data,r12vrr_stack+39599, r12vrr_stack+21943, r12vrr_stack+39593, r12vrr_stack+1032, r12vrr_stack+21940, NULL);

 /*--- compute (g0|00)^5 ---*/
 _BUILD_g000(Data,r12vrr_stack+39609, r12vrr_stack+21949, r12vrr_stack+39599, r12vrr_stack+53234, r12vrr_stack+21943, NULL);

 /*--- compute (h0|00)^4 ---*/
 _BUILD_h000(Data,r12vrr_stack+1065, r12vrr_stack+21959, r12vrr_stack+39609, r12vrr_stack+53240, r12vrr_stack+21949, NULL);

 /*--- compute (p0|p0)^8 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+39624, r12vrr_stack+6, r12vrr_stack+3, NULL, NULL, Data->F+9);

 /*--- compute (d0|p0)^7 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+44390, r12vrr_stack+21974, r12vrr_stack+39624, r12vrr_stack+78, r12vrr_stack+6, r12vrr_stack+39590);

 /*--- compute (f0|p0)^6 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+168, r12vrr_stack+21983, r12vrr_stack+44390, r12vrr_stack+5587, r12vrr_stack+21974, r12vrr_stack+39593);

 /*--- compute (g0|p0)^5 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+39633, r12vrr_stack+22001, r12vrr_stack+168, r12vrr_stack+60, r12vrr_stack+21983, r12vrr_stack+39599);

 /*--- compute (h0|p0)^4 ---*/
 _BUILD_h0p0(Data,r12vrr_stack+39678, r12vrr_stack+22031, r12vrr_stack+39633, r12vrr_stack+21030, r12vrr_stack+22001, r12vrr_stack+39609);

 /*--- compute (i0|p0)^3 ---*/
 _BUILD_i0p0(Data,r12vrr_stack+39741, r12vrr_stack+6049, r12vrr_stack+39678, r12vrr_stack+53250, r12vrr_stack+22031, r12vrr_stack+1065);

 /*--- compute (p0|d0)^8 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1065, r12vrr_stack+198, r12vrr_stack+48, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^7 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+6049, r12vrr_stack+2775, r12vrr_stack+1065, r12vrr_stack+414, r12vrr_stack+198, r12vrr_stack+39624);

 /*--- compute (f0|d0)^6 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+39825, r12vrr_stack+22076, r12vrr_stack+6049, r12vrr_stack+9, r12vrr_stack+2775, r12vrr_stack+44390);

 /*--- compute (g0|d0)^5 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+39885, r12vrr_stack+22112, r12vrr_stack+39825, r12vrr_stack+53295, r12vrr_stack+22076, r12vrr_stack+168);

 /*--- compute (h0|d0)^4 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+39975, r12vrr_stack+44006, r12vrr_stack+39885, r12vrr_stack+264, r12vrr_stack+22112, r12vrr_stack+39633);

 /*--- compute (i0|d0)^3 ---*/
 _BUILD_i0d0(Data,r12vrr_stack+40101, r12vrr_stack+44096, r12vrr_stack+39975, r12vrr_stack+53331, r12vrr_stack+44006, r12vrr_stack+39678);

 /*--- compute (k0|d0)^2 ---*/
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,r12vrr_stack+40269, r12vrr_stack+44222, r12vrr_stack+40101, r12vrr_stack+14112, r12vrr_stack+44096, r12vrr_stack+39741);

 /*--- compute (p0|f0)^8 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+21030, r12vrr_stack+420, r12vrr_stack+5596, NULL, NULL, r12vrr_stack+48);

 /*--- compute (d0|f0)^7 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+264, r12vrr_stack+2793, r12vrr_stack+21030, r12vrr_stack+710, r12vrr_stack+420, r12vrr_stack+1065);

 /*--- compute (f0|f0)^6 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+14112, r12vrr_stack+2823, r12vrr_stack+264, r12vrr_stack+960, r12vrr_stack+2793, r12vrr_stack+6049);

 /*--- compute (g0|f0)^5 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+50066, r12vrr_stack+2883, r12vrr_stack+14112, r12vrr_stack+204, r12vrr_stack+2823, r12vrr_stack+39825);

 /*--- compute (h0|f0)^4 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+44006, r12vrr_stack+29778, r12vrr_stack+50066, r12vrr_stack+53421, r12vrr_stack+2883, r12vrr_stack+39885);

 /*--- compute (i0|f0)^3 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+39590, r12vrr_stack+29928, r12vrr_stack+44006, r12vrr_stack+53521, r12vrr_stack+29778, r12vrr_stack+39975);

 /*--- compute (k0|f0)^2 ---*/
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+21720, r12vrr_stack+4859, r12vrr_stack+39590, r12vrr_stack+54482, r12vrr_stack+29928, r12vrr_stack+40101);

 /*--- compute (l0|f0)^1 ---*/
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+29778, r12vrr_stack+21225, r12vrr_stack+21720, r12vrr_stack+54692, r12vrr_stack+4859, r12vrr_stack+40269);

 /*--- compute (p0|g0)^8 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+4859, r12vrr_stack+1035, r12vrr_stack+8849, NULL, NULL, r12vrr_stack+5596);

 /*--- compute (d0|g0)^7 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+4904, r12vrr_stack+430, r12vrr_stack+4859, r12vrr_stack+1050, r12vrr_stack+1035, r12vrr_stack+21030);

 /*--- compute (f0|g0)^6 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+27840, r12vrr_stack+2983, r12vrr_stack+4904, r12vrr_stack+108, r12vrr_stack+430, r12vrr_stack+264);

 /*--- compute (g0|g0)^5 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+21225, r12vrr_stack+3073, r12vrr_stack+27840, r12vrr_stack+54972, r12vrr_stack+2983, r12vrr_stack+14112);

 /*--- compute (h0|g0)^4 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+39870, r12vrr_stack+720, r12vrr_stack+21225, r12vrr_stack+55062, r12vrr_stack+3073, r12vrr_stack+50066);

 /*--- compute (i0|g0)^3 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+2775, r12vrr_stack+3223, r12vrr_stack+39870, r12vrr_stack+55212, r12vrr_stack+720, r12vrr_stack+44006);

 /*--- compute (k0|g0)^2 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+40185, r12vrr_stack+14373, r12vrr_stack+2775, r12vrr_stack+40838, r12vrr_stack+3223, r12vrr_stack+39590);

 /*--- compute (l0|g0)^1 ---*/
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+54211, r12vrr_stack+53671, r12vrr_stack+40185, r12vrr_stack+41153, r12vrr_stack+14373, r12vrr_stack+21720);

 /*--- compute (m0|g0)^0 ---*/
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+40725, r12vrr_stack+3538, r12vrr_stack+54211, r12vrr_stack+59708, r12vrr_stack+53671, r12vrr_stack+29778);

 /*--- compute (p0|h0)^8 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+6049, r12vrr_stack+352, r12vrr_stack+14809, NULL, NULL, r12vrr_stack+8849);

 /*--- compute (d0|h0)^7 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+14112, r12vrr_stack+4213, r12vrr_stack+6049, r12vrr_stack+5606, r12vrr_stack+352, r12vrr_stack+4859);

 /*--- compute (f0|h0)^6 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5587, r12vrr_stack+29316, r12vrr_stack+14112, r12vrr_stack+1770, r12vrr_stack+4213, r12vrr_stack+4904);

 /*--- compute (g0|h0)^5 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+29778, r12vrr_stack+32943, r12vrr_stack+5587, r12vrr_stack+1833, r12vrr_stack+29316, r12vrr_stack+27840);

 /*--- compute (h0|h0)^4 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+21720, r12vrr_stack+52376, r12vrr_stack+29778, r12vrr_stack+1959, r12vrr_stack+32943, r12vrr_stack+21225);

 /*--- compute (i0|h0)^3 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+55717, r12vrr_stack+52691, r12vrr_stack+21720, r12vrr_stack+60248, r12vrr_stack+52376, r12vrr_stack+39870);

 /*--- compute (k0|h0)^2 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+53132, r12vrr_stack+89920, r12vrr_stack+55717, r12vrr_stack+60563, r12vrr_stack+52691, r12vrr_stack+2775);

 /*--- compute (l0|h0)^1 ---*/
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+126338, r12vrr_stack+90508, r12vrr_stack+53132, r12vrr_stack+61004, r12vrr_stack+89920, r12vrr_stack+40185);

 /*--- compute (m0|h0)^0 ---*/
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+60248, r12vrr_stack+6763, r12vrr_stack+126338, r12vrr_stack+61592, r12vrr_stack+90508, r12vrr_stack+54211);
 tmp = r12vrr_stack + 60248;
 target_ptr = Libr12->gvrr_classes[9][5];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^8 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+89920, r12vrr_stack+14830, r12vrr_stack+20921, NULL, NULL, r12vrr_stack+14809);

 /*--- compute (d0|i0)^7 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+90004, r12vrr_stack+1194, r12vrr_stack+89920, r12vrr_stack+8864, r12vrr_stack+14830, r12vrr_stack+6049);

 /*--- compute (f0|i0)^6 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4859, r12vrr_stack+1278, r12vrr_stack+90004, r12vrr_stack+5797, r12vrr_stack+1194, r12vrr_stack+14112);

 /*--- compute (g0|i0)^5 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+90172, r12vrr_stack+91264, r12vrr_stack+4859, r12vrr_stack+5881, r12vrr_stack+1278, r12vrr_stack+5587);

 /*--- compute (h0|i0)^4 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+90592, r12vrr_stack+91544, r12vrr_stack+90172, r12vrr_stack+55437, r12vrr_stack+91264, r12vrr_stack+29778);

 /*--- compute (i0|i0)^3 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+39590, r12vrr_stack+91964, r12vrr_stack+90592, r12vrr_stack+5139, r12vrr_stack+91544, r12vrr_stack+21720);

 /*--- compute (k0|i0)^2 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+53888, r12vrr_stack+92552, r12vrr_stack+39590, r12vrr_stack+62348, r12vrr_stack+91964, r12vrr_stack+55717);

 /*--- compute (l0|i0)^1 ---*/
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+91180, r12vrr_stack+93336, r12vrr_stack+53888, r12vrr_stack+62936, r12vrr_stack+92552, r12vrr_stack+53132);

 /*--- compute (m0|i0)^0 ---*/
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+52298, r12vrr_stack+11782, r12vrr_stack+91180, r12vrr_stack+63720, r12vrr_stack+93336, r12vrr_stack+126338);
 tmp = r12vrr_stack + 52298;
 target_ptr = Libr12->gvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^8 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+126338, r12vrr_stack+20949, r12vrr_stack+30247, NULL, NULL, r12vrr_stack+20921);

 /*--- compute (d0|k0)^7 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+126446, r12vrr_stack+9034, r12vrr_stack+126338, r12vrr_stack+14858, r12vrr_stack+20949, r12vrr_stack+89920);

 /*--- compute (f0|k0)^6 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+21225, r12vrr_stack+16569, r12vrr_stack+126446, r12vrr_stack+10074, r12vrr_stack+9034, r12vrr_stack+90004);

 /*--- compute (g0|k0)^5 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+126662, r12vrr_stack+94344, r12vrr_stack+21225, r12vrr_stack+10182, r12vrr_stack+16569, r12vrr_stack+4859);

 /*--- compute (h0|k0)^4 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+127202, r12vrr_stack+94704, r12vrr_stack+126662, r12vrr_stack+10398, r12vrr_stack+94344, r12vrr_stack+90172);

 /*--- compute (i0|k0)^3 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+62348, r12vrr_stack+95244, r12vrr_stack+127202, r12vrr_stack+64728, r12vrr_stack+94704, r12vrr_stack+90592);

 /*--- compute (k0|k0)^2 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+92440, r12vrr_stack+96000, r12vrr_stack+62348, r12vrr_stack+65268, r12vrr_stack+95244, r12vrr_stack+39590);

 /*--- compute (l0|k0)^1 ---*/
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+93736, r12vrr_stack+97008, r12vrr_stack+92440, r12vrr_stack+66024, r12vrr_stack+96000, r12vrr_stack+53888);

 /*--- compute (m0|k0)^0 ---*/
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+64728, r12vrr_stack+18126, r12vrr_stack+93736, r12vrr_stack+67032, r12vrr_stack+97008, r12vrr_stack+91180);
 tmp = r12vrr_stack + 64728;
 target_ptr = Libr12->gvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^8 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+39590, r12vrr_stack+1086, r12vrr_stack+14067, NULL, NULL, r12vrr_stack+30247);

 /*--- compute (d0|l0)^7 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+39725, r12vrr_stack+21585, r12vrr_stack+39590, r12vrr_stack+20985, r12vrr_stack+1086, r12vrr_stack+126338);

 /*--- compute (f0|l0)^6 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+39995, r12vrr_stack+9142, r12vrr_stack+39725, r12vrr_stack+15714, r12vrr_stack+21585, r12vrr_stack+126446);

 /*--- compute (g0|l0)^5 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+4859, r12vrr_stack+98304, r12vrr_stack+39995, r12vrr_stack+15849, r12vrr_stack+9142, r12vrr_stack+21225);

 /*--- compute (h0|l0)^4 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21225, r12vrr_stack+98754, r12vrr_stack+4859, r12vrr_stack+16119, r12vrr_stack+98304, r12vrr_stack+126662);

 /*--- compute (i0|l0)^3 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+89920, r12vrr_stack+99429, r12vrr_stack+21225, r12vrr_stack+68328, r12vrr_stack+98754, r12vrr_stack+127202);

 /*--- compute (k0|l0)^2 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+126338, r12vrr_stack+100374, r12vrr_stack+89920, r12vrr_stack+69003, r12vrr_stack+99429, r12vrr_stack+62348);

 /*--- compute (l0|l0)^1 ---*/
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+95356, r12vrr_stack+101634, r12vrr_stack+126338, r12vrr_stack+69948, r12vrr_stack+100374, r12vrr_stack+92440);

 /*--- compute (m0|l0)^0 ---*/
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+68328, r12vrr_stack+25650, r12vrr_stack+95356, r12vrr_stack+71208, r12vrr_stack+101634, r12vrr_stack+93736);
 tmp = r12vrr_stack + 68328;
 target_ptr = Libr12->gvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|m0)^8 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+62348, r12vrr_stack+8794, r12vrr_stack+37706, NULL, NULL, r12vrr_stack+14067);

 /*--- compute (d0|m0)^7 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+62513, r12vrr_stack+27675, r12vrr_stack+62348, r12vrr_stack+30283, r12vrr_stack+8794, r12vrr_stack+39590);

 /*--- compute (f0|m0)^6 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+62843, r12vrr_stack+103254, r12vrr_stack+62513, r12vrr_stack+22905, r12vrr_stack+27675, r12vrr_stack+39725);

 /*--- compute (g0|m0)^5 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+15714, r12vrr_stack+103584, r12vrr_stack+62843, r12vrr_stack+23070, r12vrr_stack+103254, r12vrr_stack+39995);

 /*--- compute (h0|m0)^4 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+91180, r12vrr_stack+104134, r12vrr_stack+15714, r12vrr_stack+23400, r12vrr_stack+103584, r12vrr_stack+4859);

 /*--- compute (i0|m0)^3 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+92335, r12vrr_stack+104959, r12vrr_stack+91180, r12vrr_stack+72828, r12vrr_stack+104134, r12vrr_stack+21225);

 /*--- compute (k0|m0)^2 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+97381, r12vrr_stack+106114, r12vrr_stack+92335, r12vrr_stack+73653, r12vrr_stack+104959, r12vrr_stack+89920);

 /*--- compute (l0|m0)^1 ---*/
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+99361, r12vrr_stack+107654, r12vrr_stack+97381, r12vrr_stack+74808, r12vrr_stack+106114, r12vrr_stack+126338);

 /*--- compute (m0|m0)^0 ---*/
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+72828, r12vrr_stack+35190, r12vrr_stack+99361, r12vrr_stack+76348, r12vrr_stack+107654, r12vrr_stack+95356);
 tmp = r12vrr_stack + 72828;
 target_ptr = Libr12->gvrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^18 ---*/
 _BUILD_00p0(Data,r12vrr_stack+126338, Data->F+18, Data->F+19, NULL, NULL, NULL);

 /*--- compute (00|d0)^17 ---*/
 _BUILD_00d0(Data,r12vrr_stack+126341, r12vrr_stack+37665, r12vrr_stack+126338, Data->F+17, Data->F+18, NULL);

 /*--- compute (00|f0)^16 ---*/
 _BUILD_00f0(Data,r12vrr_stack+126347, r12vrr_stack+54, r12vrr_stack+126341, r12vrr_stack+0, r12vrr_stack+37665, NULL);

 /*--- compute (00|g0)^15 ---*/
 _BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+37668, r12vrr_stack+126347, r12vrr_stack+31835, r12vrr_stack+54, NULL);

 /*--- compute (00|h0)^14 ---*/
 _BUILD_00h0(Data,r12vrr_stack+15, r12vrr_stack+945, r12vrr_stack+0, r12vrr_stack+31841, r12vrr_stack+37668, NULL);

 /*--- compute (00|i0)^13 ---*/
 _BUILD_00i0(Data,r12vrr_stack+36, r12vrr_stack+7708, r12vrr_stack+15, r12vrr_stack+153, r12vrr_stack+945, NULL);

 /*--- compute (00|k0)^12 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+0, r12vrr_stack+37678, r12vrr_stack+36, r12vrr_stack+990, r12vrr_stack+7708, NULL);

 /*--- compute (00|l0)^11 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+36, r12vrr_stack+19746, r12vrr_stack+0, r12vrr_stack+5559, r12vrr_stack+37678, NULL);

 /*--- compute (00|m0)^10 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+126338, r12vrr_stack+16785, r12vrr_stack+36, r12vrr_stack+31851, r12vrr_stack+19746, NULL);

 /*--- compute (00|n0)^9 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+0, r12vrr_stack+37706, r12vrr_stack+126338, r12vrr_stack+14067, r12vrr_stack+16785, NULL);

 /*--- compute (p0|n0)^8 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+126338, r12vrr_stack+37761, r12vrr_stack+0, NULL, NULL, r12vrr_stack+37706);

 /*--- compute (d0|n0)^7 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+126536, r12vrr_stack+37827, r12vrr_stack+126338, r12vrr_stack+2169, r12vrr_stack+37761, r12vrr_stack+62348);

 /*--- compute (f0|n0)^6 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+126932, r12vrr_stack+109634, r12vrr_stack+126536, r12vrr_stack+512, r12vrr_stack+37827, r12vrr_stack+62513);

 /*--- compute (g0|n0)^5 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+89920, r12vrr_stack+110030, r12vrr_stack+126932, r12vrr_stack+31887, r12vrr_stack+109634, r12vrr_stack+62843);

 /*--- compute (h0|n0)^4 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+126338, r12vrr_stack+110690, r12vrr_stack+89920, r12vrr_stack+32283, r12vrr_stack+110030, r12vrr_stack+15714);

 /*--- compute (i0|n0)^3 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+93875, r12vrr_stack+111680, r12vrr_stack+126338, r12vrr_stack+78328, r12vrr_stack+110690, r12vrr_stack+91180);

 /*--- compute (k0|n0)^2 ---*/
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+89920, r12vrr_stack+113066, r12vrr_stack+93875, r12vrr_stack+79318, r12vrr_stack+111680, r12vrr_stack+92335);

 /*--- compute (l0|n0)^1 ---*/
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+92296, r12vrr_stack+114914, r12vrr_stack+89920, r12vrr_stack+80704, r12vrr_stack+113066, r12vrr_stack+97381);

 /*--- compute (m0|n0)^0 ---*/
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+78328, r12vrr_stack+46784, r12vrr_stack+92296, r12vrr_stack+82552, r12vrr_stack+114914, r12vrr_stack+99361);

 /*--- compute (00|o0)^8 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+89920, r12vrr_stack+37761, r12vrr_stack+0, r12vrr_stack+8794, r12vrr_stack+37706, NULL);

 /*--- compute (p0|o0)^7 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+89998, r12vrr_stack+49754, r12vrr_stack+89920, NULL, NULL, r12vrr_stack+37761);

 /*--- compute (d0|o0)^6 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+90232, r12vrr_stack+49832, r12vrr_stack+89998, r12vrr_stack+30602, r12vrr_stack+49754, r12vrr_stack+37827);

 /*--- compute (f0|o0)^5 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+90700, r12vrr_stack+117290, r12vrr_stack+90232, r12vrr_stack+52064, r12vrr_stack+49832, r12vrr_stack+109634);

 /*--- compute (g0|o0)^4 ---*/
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+91480, r12vrr_stack+117758, r12vrr_stack+90700, r12vrr_stack+42758, r12vrr_stack+117290, r12vrr_stack+110030);

 /*--- compute (h0|o0)^3 ---*/
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+92650, r12vrr_stack+118538, r12vrr_stack+91480, r12vrr_stack+43226, r12vrr_stack+117758, r12vrr_stack+110690);

 /*--- compute (i0|o0)^2 ---*/
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+89920, r12vrr_stack+119708, r12vrr_stack+92650, r12vrr_stack+84928, r12vrr_stack+118538, r12vrr_stack+111680);

 /*--- compute (k0|o0)^1 ---*/
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+92104, r12vrr_stack+121346, r12vrr_stack+89920, r12vrr_stack+86098, r12vrr_stack+119708, r12vrr_stack+113066);

 /*--- compute (l0|o0)^0 ---*/
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+117290, r12vrr_stack+123530, r12vrr_stack+92104, r12vrr_stack+87736, r12vrr_stack+121346, r12vrr_stack+114914);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+89920, &(Data->ss_r12_ss), NULL, r12vrr_stack+324, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+89923, r12vrr_stack+89920, &(Data->ss_r12_ss), r12vrr_stack+81, r12vrr_stack+324, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+89929, r12vrr_stack+89923, r12vrr_stack+89920, r12vrr_stack+327, r12vrr_stack+81, r12vrr_stack+324, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+89939, r12vrr_stack+89929, r12vrr_stack+89923, r12vrr_stack+337, r12vrr_stack+327, r12vrr_stack+81, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+7708, r12vrr_stack+89939, r12vrr_stack+89929, r12vrr_stack+1011, r12vrr_stack+337, r12vrr_stack+327, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+89954, r12vrr_stack+7708, NULL, r12vrr_stack+1131, r12vrr_stack+1011, NULL, r12vrr_stack+337);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+90017, r12vrr_stack+89954, r12vrr_stack+7708, r12vrr_stack+6112, r12vrr_stack+1131, r12vrr_stack+1011, r12vrr_stack+1485);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+90143, r12vrr_stack+90017, r12vrr_stack+89954, r12vrr_stack+6238, r12vrr_stack+6112, r12vrr_stack+1131, r12vrr_stack+1530);

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+27675, r12vrr_stack+90143, r12vrr_stack+90017, r12vrr_stack+6448, r12vrr_stack+6238, r12vrr_stack+6112, r12vrr_stack+1620);

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+90353, r12vrr_stack+27675, r12vrr_stack+90143, r12vrr_stack+7729, r12vrr_stack+6448, r12vrr_stack+6238, r12vrr_stack+2235);
 tmp = r12vrr_stack + 90353;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||h0)^0 ---*/
 _R_BUILD_i0h0(Data,r12vrr_stack+90794, r12vrr_stack+90353, r12vrr_stack+27675, r12vrr_stack+8170, r12vrr_stack+7729, r12vrr_stack+6448, r12vrr_stack+2460);
 tmp = r12vrr_stack + 90794;
 target_ptr = Libr12->rvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||h0)^0 ---*/
 _R_BUILD_k0h0(Data,r12vrr_stack+91382, r12vrr_stack+90794, r12vrr_stack+90353, r12vrr_stack+61592, r12vrr_stack+8170, r12vrr_stack+7729, r12vrr_stack+4327);
 tmp = r12vrr_stack + 91382;
 target_ptr = Libr12->rvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+27675, r12vrr_stack+7708, r12vrr_stack+89939, r12vrr_stack+4747, r12vrr_stack+1011, r12vrr_stack+337, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+27703, r12vrr_stack+27675, NULL, r12vrr_stack+4775, r12vrr_stack+4747, NULL, r12vrr_stack+1011);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+27787, r12vrr_stack+27703, r12vrr_stack+27675, r12vrr_stack+9626, r12vrr_stack+4775, r12vrr_stack+4747, r12vrr_stack+1131);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+89920, r12vrr_stack+27787, r12vrr_stack+27703, r12vrr_stack+9794, r12vrr_stack+9626, r12vrr_stack+4775, r12vrr_stack+6112);

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+90200, r12vrr_stack+89920, r12vrr_stack+27787, r12vrr_stack+10774, r12vrr_stack+9794, r12vrr_stack+9626, r12vrr_stack+6238);

 /*--- compute (h0||i0)^0 ---*/
 _R_BUILD_h0i0(Data,r12vrr_stack+92138, r12vrr_stack+90200, r12vrr_stack+89920, r12vrr_stack+11194, r12vrr_stack+10774, r12vrr_stack+9794, r12vrr_stack+6448);
 tmp = r12vrr_stack + 92138;
 target_ptr = Libr12->rvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||i0)^0 ---*/
 _R_BUILD_i0i0(Data,r12vrr_stack+92726, r12vrr_stack+92138, r12vrr_stack+90200, r12vrr_stack+13238, r12vrr_stack+11194, r12vrr_stack+10774, r12vrr_stack+7729);
 tmp = r12vrr_stack + 92726;
 target_ptr = Libr12->rvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||i0)^0 ---*/
 _R_BUILD_k0i0(Data,r12vrr_stack+93510, r12vrr_stack+92726, r12vrr_stack+92138, r12vrr_stack+63720, r12vrr_stack+13238, r12vrr_stack+11194, r12vrr_stack+8170);
 tmp = r12vrr_stack + 93510;
 target_ptr = Libr12->rvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+19746, r12vrr_stack+27675, r12vrr_stack+7708, r12vrr_stack+8758, r12vrr_stack+4747, r12vrr_stack+1011, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+92138, r12vrr_stack+19746, NULL, r12vrr_stack+8926, r12vrr_stack+8758, NULL, r12vrr_stack+4747);

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+92246, r12vrr_stack+92138, r12vrr_stack+19746, r12vrr_stack+15138, r12vrr_stack+8926, r12vrr_stack+8758, r12vrr_stack+4775);

 /*--- compute (f0||k0)^0 ---*/
 _R_BUILD_f0k0(Data,r12vrr_stack+4775, r12vrr_stack+92246, r12vrr_stack+92138, r12vrr_stack+15354, r12vrr_stack+15138, r12vrr_stack+8926, r12vrr_stack+9626);

 /*--- compute (g0||k0)^0 ---*/
 _R_BUILD_g0k0(Data,r12vrr_stack+5135, r12vrr_stack+4775, r12vrr_stack+92246, r12vrr_stack+16830, r12vrr_stack+15354, r12vrr_stack+15138, r12vrr_stack+9794);

 /*--- compute (h0||k0)^0 ---*/
 _R_BUILD_h0k0(Data,r12vrr_stack+5675, r12vrr_stack+5135, r12vrr_stack+4775, r12vrr_stack+17370, r12vrr_stack+16830, r12vrr_stack+15354, r12vrr_stack+10774);
 tmp = r12vrr_stack + 5675;
 target_ptr = Libr12->rvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||k0)^0 ---*/
 _R_BUILD_i0k0(Data,r12vrr_stack+94518, r12vrr_stack+5675, r12vrr_stack+5135, r12vrr_stack+19782, r12vrr_stack+17370, r12vrr_stack+16830, r12vrr_stack+11194);
 tmp = r12vrr_stack + 94518;
 target_ptr = Libr12->rvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||k0)^0 ---*/
 _R_BUILD_k0k0(Data,r12vrr_stack+95526, r12vrr_stack+94518, r12vrr_stack+5675, r12vrr_stack+67032, r12vrr_stack+19782, r12vrr_stack+17370, r12vrr_stack+13238);
 tmp = r12vrr_stack + 95526;
 target_ptr = Libr12->rvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+4775, r12vrr_stack+19746, r12vrr_stack+27675, r12vrr_stack+14022, r12vrr_stack+8758, r12vrr_stack+4747, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+27675, r12vrr_stack+4775, NULL, r12vrr_stack+14238, r12vrr_stack+14022, NULL, r12vrr_stack+8758);

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+4820, r12vrr_stack+27675, r12vrr_stack+4775, r12vrr_stack+22185, r12vrr_stack+14238, r12vrr_stack+14022, r12vrr_stack+8926);

 /*--- compute (f0||l0)^0 ---*/
 _R_BUILD_f0l0(Data,r12vrr_stack+5090, r12vrr_stack+4820, r12vrr_stack+27675, r12vrr_stack+22455, r12vrr_stack+22185, r12vrr_stack+14238, r12vrr_stack+15138);

 /*--- compute (g0||l0)^0 ---*/
 _R_BUILD_g0l0(Data,r12vrr_stack+5540, r12vrr_stack+5090, r12vrr_stack+4820, r12vrr_stack+24030, r12vrr_stack+22455, r12vrr_stack+22185, r12vrr_stack+15354);

 /*--- compute (h0||l0)^0 ---*/
 _R_BUILD_h0l0(Data,r12vrr_stack+96822, r12vrr_stack+5540, r12vrr_stack+5090, r12vrr_stack+24705, r12vrr_stack+24030, r12vrr_stack+22455, r12vrr_stack+16830);
 tmp = r12vrr_stack + 96822;
 target_ptr = Libr12->rvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||l0)^0 ---*/
 _R_BUILD_i0l0(Data,r12vrr_stack+97767, r12vrr_stack+96822, r12vrr_stack+5540, r12vrr_stack+27990, r12vrr_stack+24705, r12vrr_stack+24030, r12vrr_stack+17370);
 tmp = r12vrr_stack + 97767;
 target_ptr = Libr12->rvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||l0)^0 ---*/
 _R_BUILD_k0l0(Data,r12vrr_stack+4820, r12vrr_stack+97767, r12vrr_stack+96822, r12vrr_stack+71208, r12vrr_stack+27990, r12vrr_stack+24705, r12vrr_stack+19782);
 tmp = r12vrr_stack + 4820;
 target_ptr = Libr12->rvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+96822, r12vrr_stack+4775, r12vrr_stack+19746, r12vrr_stack+20790, r12vrr_stack+14022, r12vrr_stack+8758, NULL);

 /*--- compute (p0||m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8758, r12vrr_stack+96822, NULL, r12vrr_stack+21060, r12vrr_stack+20790, NULL, r12vrr_stack+14022);

 /*--- compute (d0||m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8923, r12vrr_stack+8758, r12vrr_stack+96822, r12vrr_stack+30955, r12vrr_stack+21060, r12vrr_stack+20790, r12vrr_stack+14238);

 /*--- compute (f0||m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+9253, r12vrr_stack+8923, r12vrr_stack+8758, r12vrr_stack+31285, r12vrr_stack+30955, r12vrr_stack+21060, r12vrr_stack+22185);

 /*--- compute (g0||m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+9803, r12vrr_stack+9253, r12vrr_stack+8923, r12vrr_stack+33210, r12vrr_stack+31285, r12vrr_stack+30955, r12vrr_stack+22455);

 /*--- compute (h0||m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+99027, r12vrr_stack+9803, r12vrr_stack+9253, r12vrr_stack+34035, r12vrr_stack+33210, r12vrr_stack+31285, r12vrr_stack+24030);
 tmp = r12vrr_stack + 99027;
 target_ptr = Libr12->rvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+100182, r12vrr_stack+99027, r12vrr_stack+9803, r12vrr_stack+38050, r12vrr_stack+34035, r12vrr_stack+33210, r12vrr_stack+24705);
 tmp = r12vrr_stack + 100182;
 target_ptr = Libr12->rvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8758, r12vrr_stack+100182, r12vrr_stack+99027, r12vrr_stack+76348, r12vrr_stack+38050, r12vrr_stack+34035, r12vrr_stack+27990);
 tmp = r12vrr_stack + 8758;
 target_ptr = Libr12->rvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+99027, r12vrr_stack+96822, r12vrr_stack+4775, r12vrr_stack+29250, r12vrr_stack+20790, r12vrr_stack+14022, NULL);

 /*--- compute (p0||n0)^0 ---*/
 am[0] = 1;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+14022, r12vrr_stack+99027, NULL, r12vrr_stack+29580, r12vrr_stack+29250, NULL, r12vrr_stack+20790);

 /*--- compute (d0||n0)^0 ---*/
 am[0] = 2;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+14220, r12vrr_stack+14022, r12vrr_stack+99027, r12vrr_stack+41702, r12vrr_stack+29580, r12vrr_stack+29250, r12vrr_stack+21060);

 /*--- compute (f0||n0)^0 ---*/
 am[0] = 3;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+99027, r12vrr_stack+14220, r12vrr_stack+14022, r12vrr_stack+42098, r12vrr_stack+41702, r12vrr_stack+29580, r12vrr_stack+30955);

 /*--- compute (g0||n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+29250, r12vrr_stack+99027, r12vrr_stack+14220, r12vrr_stack+44408, r12vrr_stack+42098, r12vrr_stack+41702, r12vrr_stack+31285);

 /*--- compute (h0||n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+14022, r12vrr_stack+29250, r12vrr_stack+99027, r12vrr_stack+45398, r12vrr_stack+44408, r12vrr_stack+42098, r12vrr_stack+33210);
 tmp = r12vrr_stack + 14022;
 target_ptr = Libr12->rvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||n0)^0 ---*/
 am[0] = 6;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+30240, r12vrr_stack+14022, r12vrr_stack+29250, r12vrr_stack+50216, r12vrr_stack+45398, r12vrr_stack+44408, r12vrr_stack+34035);
 tmp = r12vrr_stack + 30240;
 target_ptr = Libr12->rvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||n0)^0 ---*/
 am[0] = 7;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+20790, r12vrr_stack+30240, r12vrr_stack+14022, r12vrr_stack+82552, r12vrr_stack+50216, r12vrr_stack+45398, r12vrr_stack+38050);
 tmp = r12vrr_stack + 20790;
 target_ptr = Libr12->rvrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+14022, r12vrr_stack+7729, r12vrr_stack+11194, r12vrr_stack+8170, r12vrr_stack+4327, r12vrr_stack+2460);
 tmp = r12vrr_stack + 14022;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+92138, r12vrr_stack+11194, r12vrr_stack+17370, r12vrr_stack+13238, r12vrr_stack+8170, r12vrr_stack+7729);
 tmp = r12vrr_stack + 92138;
 target_ptr = Libr12->t2vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+14463, r12vrr_stack+17370, r12vrr_stack+24705, r12vrr_stack+19782, r12vrr_stack+13238, r12vrr_stack+11194);
 tmp = r12vrr_stack + 14463;
 target_ptr = Libr12->t2vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+96822, r12vrr_stack+24705, r12vrr_stack+34035, r12vrr_stack+27990, r12vrr_stack+19782, r12vrr_stack+17370);
 tmp = r12vrr_stack + 96822;
 target_ptr = Libr12->t2vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+99027, r12vrr_stack+34035, r12vrr_stack+45398, r12vrr_stack+38050, r12vrr_stack+27990, r12vrr_stack+24705);
 tmp = r12vrr_stack + 99027;
 target_ptr = Libr12->t2vrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+15219, r12vrr_stack+45398, r12vrr_stack+58070, r12vrr_stack+50216, r12vrr_stack+38050, r12vrr_stack+34035);
 tmp = r12vrr_stack + 15219;
 target_ptr = Libr12->t2vrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_i0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+29250, r12vrr_stack+8170, r12vrr_stack+13238, r12vrr_stack+61592, r12vrr_stack+59708, r12vrr_stack+4327);
 tmp = r12vrr_stack + 29250;
 target_ptr = Libr12->t2vrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_i0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+32088, r12vrr_stack+13238, r12vrr_stack+19782, r12vrr_stack+63720, r12vrr_stack+61592, r12vrr_stack+8170);
 tmp = r12vrr_stack + 32088;
 target_ptr = Libr12->t2vrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_i0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+101722, r12vrr_stack+19782, r12vrr_stack+27990, r12vrr_stack+67032, r12vrr_stack+63720, r12vrr_stack+13238);
 tmp = r12vrr_stack + 101722;
 target_ptr = Libr12->t2vrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_i0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+102730, r12vrr_stack+27990, r12vrr_stack+38050, r12vrr_stack+71208, r12vrr_stack+67032, r12vrr_stack+19782);
 tmp = r12vrr_stack + 102730;
 target_ptr = Libr12->t2vrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+103990, r12vrr_stack+38050, r12vrr_stack+50216, r12vrr_stack+76348, r12vrr_stack+71208, r12vrr_stack+27990);
 tmp = r12vrr_stack + 103990;
 target_ptr = Libr12->t2vrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|n0)^0 ---*/
 am[0] = 6;  am[1] = 10;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+105530, r12vrr_stack+50216, r12vrr_stack+87736, r12vrr_stack+82552, r12vrr_stack+76348, r12vrr_stack+38050);
 tmp = r12vrr_stack + 105530;
 target_ptr = Libr12->t2vrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_k0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+23166, r12vrr_stack+61592, r12vrr_stack+63720, r12vrr_stack+6763, r12vrr_stack+3538, r12vrr_stack+59708);
 tmp = r12vrr_stack + 23166;
 target_ptr = Libr12->t2vrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_k0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+107378, r12vrr_stack+63720, r12vrr_stack+67032, r12vrr_stack+11782, r12vrr_stack+6763, r12vrr_stack+61592);
 tmp = r12vrr_stack + 107378;
 target_ptr = Libr12->t2vrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_k0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+108386, r12vrr_stack+67032, r12vrr_stack+71208, r12vrr_stack+18126, r12vrr_stack+11782, r12vrr_stack+63720);
 tmp = r12vrr_stack + 108386;
 target_ptr = Libr12->t2vrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_k0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+109682, r12vrr_stack+71208, r12vrr_stack+76348, r12vrr_stack+25650, r12vrr_stack+18126, r12vrr_stack+67032);
 tmp = r12vrr_stack + 109682;
 target_ptr = Libr12->t2vrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+111302, r12vrr_stack+76348, r12vrr_stack+82552, r12vrr_stack+35190, r12vrr_stack+25650, r12vrr_stack+71208);
 tmp = r12vrr_stack + 111302;
 target_ptr = Libr12->t2vrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|n0)^0 ---*/
 am[0] = 7;  am[1] = 10;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+113282, r12vrr_stack+82552, r12vrr_stack+123530, r12vrr_stack+46784, r12vrr_stack+35190, r12vrr_stack+76348);
 tmp = r12vrr_stack + 113282;
 target_ptr = Libr12->t2vrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_l0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+115658, r12vrr_stack+6763, r12vrr_stack+11782, r12vrr_stack+60248, r12vrr_stack+40725, r12vrr_stack+3538);
 tmp = r12vrr_stack + 115658;
 target_ptr = Libr12->t2vrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_l0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+84928, r12vrr_stack+11782, r12vrr_stack+18126, r12vrr_stack+52298, r12vrr_stack+60248, r12vrr_stack+6763);
 tmp = r12vrr_stack + 84928;
 target_ptr = Libr12->t2vrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_l0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+120800, r12vrr_stack+18126, r12vrr_stack+25650, r12vrr_stack+64728, r12vrr_stack+52298, r12vrr_stack+11782);
 tmp = r12vrr_stack + 120800;
 target_ptr = Libr12->t2vrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_l0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+25650, r12vrr_stack+35190, r12vrr_stack+68328, r12vrr_stack+64728, r12vrr_stack+18126);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t2vrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+2025, r12vrr_stack+35190, r12vrr_stack+46784, r12vrr_stack+72828, r12vrr_stack+68328, r12vrr_stack+25650);
 tmp = r12vrr_stack + 2025;
 target_ptr = Libr12->t2vrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T2]|n0)^0 ---*/
 am[0] = 8;  am[1] = 10;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+39590, r12vrr_stack+46784, r12vrr_stack+117290, r12vrr_stack+78328, r12vrr_stack+72828, r12vrr_stack+35190);
 tmp = r12vrr_stack + 39590;
 target_ptr = Libr12->t2vrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+89920, r12vrr_stack+7729, r12vrr_stack+8170, r12vrr_stack+11194, r12vrr_stack+10774, r12vrr_stack+6448);
 tmp = r12vrr_stack + 89920;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+116603, r12vrr_stack+11194, r12vrr_stack+13238, r12vrr_stack+17370, r12vrr_stack+16830, r12vrr_stack+10774);
 tmp = r12vrr_stack + 116603;
 target_ptr = Libr12->t1vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+86188, r12vrr_stack+17370, r12vrr_stack+19782, r12vrr_stack+24705, r12vrr_stack+24030, r12vrr_stack+16830);
 tmp = r12vrr_stack + 86188;
 target_ptr = Libr12->t1vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+122420, r12vrr_stack+24705, r12vrr_stack+27990, r12vrr_stack+34035, r12vrr_stack+33210, r12vrr_stack+24030);
 tmp = r12vrr_stack + 122420;
 target_ptr = Libr12->t1vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+126338, r12vrr_stack+34035, r12vrr_stack+38050, r12vrr_stack+45398, r12vrr_stack+44408, r12vrr_stack+33210);
 tmp = r12vrr_stack + 126338;
 target_ptr = Libr12->t1vrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+42560, r12vrr_stack+45398, r12vrr_stack+50216, r12vrr_stack+58070, r12vrr_stack+56900, r12vrr_stack+44408);
 tmp = r12vrr_stack + 42560;
 target_ptr = Libr12->t1vrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_i0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+16605, r12vrr_stack+8170, r12vrr_stack+61592, r12vrr_stack+13238, r12vrr_stack+11194, r12vrr_stack+7729);
 tmp = r12vrr_stack + 16605;
 target_ptr = Libr12->t1vrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_i0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+32872, r12vrr_stack+13238, r12vrr_stack+63720, r12vrr_stack+19782, r12vrr_stack+17370, r12vrr_stack+11194);
 tmp = r12vrr_stack + 32872;
 target_ptr = Libr12->t1vrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_i0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+10738, r12vrr_stack+19782, r12vrr_stack+67032, r12vrr_stack+27990, r12vrr_stack+24705, r12vrr_stack+17370);
 tmp = r12vrr_stack + 10738;
 target_ptr = Libr12->t1vrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_i0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+62348, r12vrr_stack+27990, r12vrr_stack+71208, r12vrr_stack+38050, r12vrr_stack+34035, r12vrr_stack+24705);
 tmp = r12vrr_stack + 62348;
 target_ptr = Libr12->t1vrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+23922, r12vrr_stack+38050, r12vrr_stack+76348, r12vrr_stack+50216, r12vrr_stack+45398, r12vrr_stack+34035);
 tmp = r12vrr_stack + 23922;
 target_ptr = Libr12->t1vrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|n0)^0 ---*/
 am[0] = 6;  am[1] = 10;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+53838, r12vrr_stack+50216, r12vrr_stack+82552, r12vrr_stack+87736, r12vrr_stack+58070, r12vrr_stack+45398);
 tmp = r12vrr_stack + 53838;
 target_ptr = Libr12->t1vrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_k0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+17193, r12vrr_stack+61592, r12vrr_stack+6763, r12vrr_stack+63720, r12vrr_stack+13238, r12vrr_stack+8170);
 tmp = r12vrr_stack + 17193;
 target_ptr = Libr12->t1vrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_k0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+33656, r12vrr_stack+63720, r12vrr_stack+11782, r12vrr_stack+67032, r12vrr_stack+19782, r12vrr_stack+13238);
 tmp = r12vrr_stack + 33656;
 target_ptr = Libr12->t1vrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_k0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+43946, r12vrr_stack+67032, r12vrr_stack+18126, r12vrr_stack+71208, r12vrr_stack+27990, r12vrr_stack+19782);
 tmp = r12vrr_stack + 43946;
 target_ptr = Libr12->t1vrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_k0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+55686, r12vrr_stack+71208, r12vrr_stack+25650, r12vrr_stack+76348, r12vrr_stack+38050, r12vrr_stack+27990);
 tmp = r12vrr_stack + 55686;
 target_ptr = Libr12->t1vrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+57306, r12vrr_stack+76348, r12vrr_stack+35190, r12vrr_stack+82552, r12vrr_stack+50216, r12vrr_stack+38050);
 tmp = r12vrr_stack + 57306;
 target_ptr = Libr12->t1vrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|n0)^0 ---*/
 am[0] = 7;  am[1] = 10;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+127493, r12vrr_stack+82552, r12vrr_stack+46784, r12vrr_stack+123530, r12vrr_stack+87736, r12vrr_stack+50216);
 tmp = r12vrr_stack + 127493;
 target_ptr = Libr12->t1vrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_l0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+86944, r12vrr_stack+6763, r12vrr_stack+60248, r12vrr_stack+11782, r12vrr_stack+63720, r12vrr_stack+61592);
 tmp = r12vrr_stack + 86944;
 target_ptr = Libr12->t1vrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_l0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+60248, r12vrr_stack+11782, r12vrr_stack+52298, r12vrr_stack+18126, r12vrr_stack+67032, r12vrr_stack+63720);
 tmp = r12vrr_stack + 60248;
 target_ptr = Libr12->t1vrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_l0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+87889, r12vrr_stack+18126, r12vrr_stack+64728, r12vrr_stack+25650, r12vrr_stack+71208, r12vrr_stack+67032);
 tmp = r12vrr_stack + 87889;
 target_ptr = Libr12->t1vrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_l0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+64728, r12vrr_stack+25650, r12vrr_stack+68328, r12vrr_stack+35190, r12vrr_stack+76348, r12vrr_stack+71208);
 tmp = r12vrr_stack + 64728;
 target_ptr = Libr12->t1vrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+68328, r12vrr_stack+35190, r12vrr_stack+72828, r12vrr_stack+46784, r12vrr_stack+82552, r12vrr_stack+76348);
 tmp = r12vrr_stack + 68328;
 target_ptr = Libr12->t1vrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0|[r12,T1]|n0)^0 ---*/
 am[0] = 8;  am[1] = 10;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+72828, r12vrr_stack+46784, r12vrr_stack+78328, r12vrr_stack+117290, r12vrr_stack+123530, r12vrr_stack+82552);
 tmp = r12vrr_stack + 72828;
 target_ptr = Libr12->t1vrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||h0)^0 ---*/
 _R_BUILD_l0h0(Data,r12vrr_stack+78328, r12vrr_stack+91382, r12vrr_stack+90794, r12vrr_stack+6763, r12vrr_stack+61592, r12vrr_stack+8170, r12vrr_stack+59708);
 tmp = r12vrr_stack + 78328;
 target_ptr = Libr12->rvrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||i0)^0 ---*/
 _R_BUILD_l0i0(Data,r12vrr_stack+79273, r12vrr_stack+93510, r12vrr_stack+92726, r12vrr_stack+11782, r12vrr_stack+63720, r12vrr_stack+13238, r12vrr_stack+61592);
 tmp = r12vrr_stack + 79273;
 target_ptr = Libr12->rvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||k0)^0 ---*/
 _R_BUILD_l0k0(Data,r12vrr_stack+92726, r12vrr_stack+95526, r12vrr_stack+94518, r12vrr_stack+18126, r12vrr_stack+67032, r12vrr_stack+19782, r12vrr_stack+63720);
 tmp = r12vrr_stack + 92726;
 target_ptr = Libr12->rvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||l0)^0 ---*/
 _R_BUILD_l0l0(Data,r12vrr_stack+94346, r12vrr_stack+4820, r12vrr_stack+97767, r12vrr_stack+25650, r12vrr_stack+71208, r12vrr_stack+27990, r12vrr_stack+67032);
 tmp = r12vrr_stack + 94346;
 target_ptr = Libr12->rvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||m0)^0 ---*/
 am[0] = 8;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+17949, r12vrr_stack+8758, r12vrr_stack+100182, r12vrr_stack+35190, r12vrr_stack+76348, r12vrr_stack+38050, r12vrr_stack+71208);
 tmp = r12vrr_stack + 17949;
 target_ptr = Libr12->rvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (l0||n0)^0 ---*/
 am[0] = 8;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+34664, r12vrr_stack+20790, r12vrr_stack+30240, r12vrr_stack+46784, r12vrr_stack+82552, r12vrr_stack+50216, r12vrr_stack+76348);
 tmp = r12vrr_stack + 34664;
 target_ptr = Libr12->rvrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];


}

